(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1136098,      16549]*)
(*NotebookOutlinePosition[   1136864,      16576]*)
(*  CellTagsIndexPosition[   1136820,      16572]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Mathematica in electrical engineering", "Title"],

Cell["developing a modern learning environment", "Subtitle"],

Cell["\<\
Mariusz Jankowski
University of Southern Maine\
\>", "Author"],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell[TextData[{
  "A recent award from the National Science Foundation was used to establish \
a computer-integrated classroom to support instruction in selected \
undergraduate electrical engineering courses. The new classroom is being used \
to address three pedagogically fundamental problems:\n\n(1) insufficient \
mastery of engineering mathematics by many students,\n(2) student passivity \
within the traditional lecture format,\n(3) insufficient use of computation \
and visualization in the learning process.\n\nNew electronic courseware is \
being developed, in the form of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notebooks and packages, to facilitate and foster an active learning \
environment. Through increased use of computation and scientific \
visualization, we expect to see improvements in students' level of interest, \
increased classroom participation and finally, improved learning outcomes."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Mathematica Classroom", "Section"],

Cell[TextData[{
  "The ",
  ButtonBox["Mathematica classroom",
    ButtonData:>{
      URL[ 
      "http://www.ee.usm.maine.edu/ee/projects/jankowski/classroom.html"], 
      None},
    ButtonStyle->"Hyperlink"],
  " was established as a result of a National Science Foundation grant from \
the Division of Undergraduate Education (DUE-9650253). The classroom is \
organized to maximize interaction between student, course material, \
instructor and computers. The arrangement of computers around the periphery \
of the room and seminar tables in the center, allows easy mixing of classroom \
activities to suit the specific computational needs of any particular lecture \
session."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .35714 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0085034 0.47619 [
[ 0 0 0 0 ]
[ 1 .35714 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .35714 L
0 .35714 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0085034 0.477324 0.348639 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00372024 0.0178571 0.00372024 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01786 translate
.95238 .71428 scale
768 string
256 192 8 [256 0 0 192 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
8380798D8A839B9891A8A59EAEABA4ACA9A2A6A39CA19E97ABA8A1ABA8A1ACA9A2ADAAA3ADAAA3\
AEABA4AFACA5AFACA5B1AEA7B1AEA7B1AEA7B1AEA7B1AEA7B1AEA7B1AEA7B1AEA7
B1AEA7B1AEA7B1AEA7B1AEA7B1AEA7B1AEA7B1AEA7B1AEA7B1AEA7B1AEA7B1AEA7B1AEA7B1AEA7\
B1AEA7B1AEA7B1AEA7B1AEA7AEABA4ABA8A1A8A59EA6A39CA7A49DA9A69FACA89F
B4ADA3B6AEA3B6AEA3B7AFA4B8B0A5B8B0A5B9B1A6B9B1A6B8B0A5B7AFA4B5ADA2B5ADA2B6AEA3\
B8B0A5BBB3A8BCB5ABB0A9A3B8B3AFB8B3AFAEA9A5ADA8A4B9B4B0BFBAB6BBB6B2
BBB6B2B6B1ADB0ABA7AFAAA6B4AFABBBB6B2BFBAB6BFBCB7B0B3ACB3B8B1B8BDB6B9BEB7B7BCB5\
B4B9B2B4B9B2B5BAB3B9BEB7BABFB8BEC3BCC3C8C1C3C8C1B8BDB6A5AAA3969B95
46464839383D28272C1A191E1413181312171413181413180F0E1312111616151A19181D1A191E\
19181D17161B1415190E0F130E121511151814181B15191C161A1D161A1D161A1D
15191C171B1E191D20191D20171B1E1115180C1013080C0F090D10090D10090D100A0E110D1114\
10141713171A14181B090D10090D10090D10090D10090D10090D10090D10090D10
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10\
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10
090D10090D10090D10090D10090D10090D10090D10080D11080F15060F16040D14030C13030C13\
040D14060F160710170F181F091219040D14030C13050E15071017071017070E16
0B0B150C0A150C0A150C0A150C0A150C0A150C0A150C0A150C0A150C0A150C0A150C0A150C0A15\
0C0A150C0A150B0B13090C13080D11080D11080D11080D11080D11080D11080D11
04090D050A0E060B0F080D110A0F130B10140C11150D1215030909030907030907030907020806\
020806020806020806040A08030907020806020806030907040A08060C0A090E0A
1615130D09060B0704171310211D1A201C19201C19231F1C2824212A26232E2A2734302D393532\
3F3B38433F3C45413E
95928B99968F9F9C95A5A29BA8A59EA9A69FA7A49DA6A39CABA8A1ACA9A2ACA9A2ADAAA3AEABA4\
AEABA4AFACA5AFACA5B1AEA7B1AEA7B1AEA7B1AEA7B1AEA7B1AEA7B1AEA7B1AEA7
B1AEA7B1AEA7B1AEA7B1AEA7B1AEA7B1AEA7B1AEA7B1AEA7B1AEA7B1AEA7B1AEA7B1AEA7B1AEA7\
B1AEA7B1AEA7B1AEA7B3B0A9B2AFA8B0ADA6AEABA4ADAAA3ADAAA3AEABA4AFABA2
ABA49AADA59AAFA79CB2AA9FB5ADA2B8B0A5BAB2A7BBB3A8B5ADA2B6AEA3B8B0A5B8B0A5B8B0A5\
B5ADA2B3ABA0B0A99FB7B0AABCB7B3BCB7B3B7B2AEB8B3AFBDB8B4B6B1ADA8A39F
B3AEAAB6B1ADBBB6B2C2BDB9C4BFBBBEB9B5B3AEAAA9A6A1BBBEB7B5BAB3B1B6AFB0B5AEB5BAB3\
BFC4BDCACFC8D1D6CFCACFC8B7BCB5989D96797E775D625B4348412D322B20251F
262628201F2419181D16151A17161B17161B16151A14131814131815141916151A17161B18171C\
17161B16151A1415190B0C100B0F1210141714181B181C1F1B1F221C20231D2124
171B1E191D201B1F221B1F22191D2014181B0E12150B0F12090D10090D10090D100A0E110D1114\
10141713171A14181B090D10090D10090D10090D10090D10090D10090D10090D10
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10\
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10
090D10090D10090D10090D10090D10090D10090D10080D11080F15060F16040D14030C13030C13\
040D14060F160710170F181F091219040D14030C13050E15071017071017070E16
0B0B150C0A150C0A150C0A150C0A150C0A150C0A150C0A150C0A150C0A150C0A150C0A150C0A15\
0C0A150C0A150B0B13090C13080D11080D11080D11080D11080D11080D11080D11
0A0F130A0F13090E12090E12080D11070C10070C10070C0F0E14140D13110B110F080E0C050B09\
030907010705000503060C0A050B09040A08040A08050B09070D0B080E0C0B100C
0A09070D09060E0A07120E0B1A161328242135312E3D393645413E4844414D4946534F4C5A5653\
615D5A65615E686461
A6A39CA5A29BA3A099A29F98A29F98A5A29BA8A59EAAA7A0ACA9A2ACA9A2ADAAA3ADAAA3AEABA4\
AFACA5AFACA5B0ADA6B2AFA8B2AFA8B2AFA8B2AFA8B2AFA8B2AFA8B2AFA8B2AFA8
B2AFA8B2AFA8B2AFA8B2AFA8B2AFA8B2AFA8B2AFA8B2AFA8B2AFA8B2AFA8B2AFA8B2AFA8B2AFA8\
B2AFA8B2AFA8B2AFA8B4B1AAB5B2ABB6B3ACB6B3ACB5B2ABB4B1AAB2AFA8B2AEA5
ABA49AADA59AAEA69BB0A89DB1A99EB3ABA0B4ACA1B5ADA2ACA499B0A89DB6AEA3BBB3A8BCB4A9\
B9B1A6B4ACA1AFA89EB5AEA8B6B1ADB5B0ACB5B0ACBCB7B3C4BFBBBFBAB6B4AFAB
C2BDB9BCB7B3B4AFABB0ABA7B3AEAAB6B1ADB9B4B0B8B5B0B3B6AFB4B9B2BCC1BAC5CAC3C5CAC3\
B7BCB5A0A59E8E938C535851474C45353A33262B2420251E1F241D1F241D1F241E
1D1D1F1E1D22201F242524292A292E29282D2423281F1E231C1B201B1A1F19181D16151A151419\
1413181514191415190D0E120C10130F131612161915191C161A1D161A1D161A1D
14181B15191C161A1D161A1D14181B1014170C1013090D10090D10090D10090D100A0E110D1114\
10141713171A14181B090D10090D10090D10090D10090D10090D10090D10090D10
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10\
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10
090D10090D10090D10090D10090D10090D10090D10080D11080F15060F16040D14030C13030C13\
040D14060F160710170F181F091219040D14030C13050E15071017071017070E16
0B0B150C0A150C0A150C0A150C0A150C0A150C0A150C0A150C0A150C0A150C0A150C0A150C0A15\
0C0A150C0A150B0B13090C13080D11080D11080D11080D11080D11080D11080D11
050A0E050A0E04090D03080C03080C02070B02070B02070A020808030907040A08050B09060C0A\
080E0C090F0D090F0D080E0C070D0B060C0A060C0A070D0B080E0C0A100E0C110D
06050315110E181411130F0C211D1A45413E625E5B6B67646F6B68716D6A74706D7773707B7774\
7F7B78827E7B84807D
A8A59EA6A39CA3A099A19E97A29F98A5A29BA8A59EABA8A1ADAAA3ADAAA3AEABA4AEABA4AFACA5\
B0ADA6B0ADA6B1AEA7B3B0A9B3B0A9B3B0A9B3B0A9B3B0A9B3B0A9B3B0A9B3B0A9
B3B0A9B3B0A9B3B0A9B3B0A9B3B0A9B3B0A9B3B0A9B3B0A9B3B0A9B3B0A9B3B0A9B3B0A9B3B0A9\
B3B0A9B3B0A9B3B0A9B3B0A9B5B2ABB8B5AEB9B6AFB9B6AFB7B4ADB4B1AAB3AFA6
B6AFA5B6AEA3B4ACA1B2AA9FB0A89DADA59AACA499ABA398A39B90A8A095AFA79CB6AEA3BBB3A8\
BDB5AABCB4A9BBB4AAB2ADA7B0ABA7ACA7A3A8A39FAAA5A1B2ADA9B8B3AFBAB5B1
BEB9B5B7B2AEB0ABA7B0ABA7B9B4B0C4BFBBCEC9C5D2CFCA959891727770464B44252A23171C15\
151A13141912121710131811151A13181D161D221B222720242922242922222721
2C2C2E2C2B302E2D323332373534393332372C2B3026252A2524292120251C1B2018171C151419\
14131815141915161A1415191216191216191115180E12150B0F12080C0F070B0E
0C10130D11140D11140D11140B0F12080C0F05090C03070A090D10090D10090D100A0E110D1114\
10141713171A14181B090D10090D10090D10090D10090D10090D10090D10090D10
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10\
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10
090D10090D10090D10090D10090D10090D10090D10080D11080F15060F16040D14030C13030C13\
040D14060F160710170F181F091219040D14030C13050E15071017071017070E16
0B0B150C0A150C0A150C0A150C0A150C0A150C0A150C0A150C0A150C0A150C0A150C0A150C0A15\
0C0A150C0A150B0B13090C11080D11080D11080D11080D11080D11080D11080D11
03080C03080C04090D050A0E060B0F070C10080D11090E11010707020806040A08060C0A080E0C\
0A100E0C12100C1210080E0C070D0B060C0A060C0A070D0B080E0C0A100E0C110D
0F0E0C1F1B181F1B1819151236322F6F6B68908C89908C898E8A878D89868C88858B8784898582\
87838086827F86827F
A09D96A09D96A29F98A4A19AA6A39CA7A49DA8A59EA9A69FADAAA3AEABA4AEABA4AFACA5B0ADA6\
B0ADA6B1AEA7B1AEA7B3B0A9B3B0A9B3B0A9B3B0A9B3B0A9B3B0A9B3B0A9B3B0A9
B3B0A9B3B0A9B3B0A9B3B0A9B3B0A9B3B0A9B3B0A9B3B0A9B3B0A9B3B0A9B3B0A9B3B0A9B3B0A9\
B3B0A9B3B0A9B3B0A9B1AEA7B3B0A9B6B3ACB8B5AEB8B5AEB6B3ACB4B1AAB3AFA6
BBB4AABAB3A9B8B1A7B5AEA4B2ABA1AFA89EADA69CACA59BA39C92A49D93A69F95A9A298AEA79D\
B2ABA1B6AFA5B9B2AAC0BBB7C1BDBAC3BFBCBEBAB7B5B1AEB0ACA9B5B1AEBDB9B6
AFABA8B5B1AEBFBBB8C8C4C1C9C5C2BFBBB8ADA9A69E9D9986888360655F2F342E0C110B000500\
0409030A0F090C110B1A1F1920251F292E282E332D2E332D282D272126201D221E
2F2F312C2B302A292E2B2A2F2D2C312C2B3028272C2423282B2A2F28272C2221261C1B2018171C\
17161B17161B16171B18191D161A1D15191C13171A1014170C1013080C0F060A0D
090D100A0E11090D10090D10080C0F060A0D04080B03070A090D10090D10090D100A0E110D1114\
10141713171A14181B090D10090D10090D10090D10090D10090D10090D10090D10
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10\
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10
090D10090D10090D10090D10090D10090D10090D10080D11080F15070E14050C12040B11040B11\
050C12070E14080F1510171D0A1117050C12040B11060D13080F15080F15090E14
0B0B130C0B130C0B130C0B130C0B130C0B130C0B130C0B130C0B130C0B130C0B130C0B130C0B13\
0C0B130C0B130B0B13090C11090D10090D10090D10090D10090D10090D10090D10
0A0E110A0E110A0E110B0F120B0F120B0F120B0F120B0F120E12130D11100C100F0A0E0D080C0B\
060A09040807040807080C0B080C0B070B0A070B0A070B0A090D0C0B0F0E0E100D
1312101B17141814111D19164B47448A8683A29E9B96928F95918E938F8C918D8A8E8A878B8784\
89858286827F85817E
9B98919E9B94A29F98A7A49DAAA7A0AAA7A0A9A69FA8A59EAEABA4AFACA5AFACA5B0ADA6B1AEA7\
B1AEA7B2AFA8B2AFA8B4B1AAB4B1AAB4B1AAB4B1AAB4B1AAB4B1AAB4B1AAB4B1AA
B4B1AAB4B1AAB4B1AAB4B1AAB4B1AAB4B1AAB4B1AAB4B1AAB4B1AAB4B1AAB4B1AAB4B1AAB4B1AA\
B4B1AAB4B1AAB4B1AAB1AEA7B2AFA8B4B1AAB5B2ABB6B3ACB5B2ABB5B2ABB4B1AA
B4B0A7B6AFA5B6AFA5B6AFA5B7B0A6B7B0A6B7B0A6B8B1A7ACA59BAAA399A7A096A59E94A49D93\
A69F95A8A197A8A49BA29F9AA7A3A0B3AFACBEBAB7BCB8B5B2AEABAFABA8B4B0AD
BFBBB8B7B3B0A9A5A2979390807C7964605D48444133322E181A15131812121711151A14191E18\
161B150D120C0409030F140E161B151F241E272C262B302A2F342E343933383D39
2D2D2F29282D26252A27262B2B2A2F2E2D322D2C312C2B302F2E332C2B3028272C2423281F1E23\
1D1C211B1A1F191A1E16171B14181B161A1D161A1D161A1D15191C13171A121619
0D11140D11140C10130B0F120A0E11090D10090D10090D10090D10090D10090D100A0E110D1114\
10141713171A14181B090D10090D10090D10090D10090D10090D10090D10090D10
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10\
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10
090D10090D10090D10090D10090D10090D10090D10090D100A0F13070E14050C12040B11040B11\
050C12070E14080F1510171D0A1117050C12040B11060D13080F15080F15090E14
0B0B130C0B130C0B130C0B130C0B130C0B130C0B130C0B130C0B130C0B130C0B130C0B130C0B13\
0C0B130C0B130C0B110B0C10090D10090D10090D10090D10090D10090D10090D10
060A0D060A0D05090C04080B03070A010508000407000405000201000302000403020605040807\
060A09070B0A080C0B0B0F0E0A0E0D090D0C090D0C0A0E0D0C100F0D1110111310
11100E110D0A120E0B2824215D5956908C899995928783808E8A878E8A878E8A878E8A878E8A87\
8E8A878E8A878E8A87
A19E97A3A099A6A39CA8A59EAAA7A0ACA9A2ACA9A2ACA9A2AFACA5AFACA5B0ADA6B0ADA6B1AEA7\
B2AFA8B2AFA8B3B0A9B5B2ABB5B2ABB5B2ABB5B2ABB5B2ABB5B2ABB5B2ABB5B2AB
B5B2ABB5B2ABB5B2ABB5B2ABB5B2ABB5B2ABB5B2ABB5B2ABB5B2ABB5B2ABB5B2ABB5B2ABB5B2AB\
B5B2ABB5B2ABB5B2ABB4B1AAB4B1AAB3B0A9B3B0A9B4B1AAB6B3ACB8B5AEB9B6AF
B3AFA6B3AFA6B4B0A7B5B1A8B6B2A9B7B3AAB7B3AAB8B4ABB3AFA6B2AEA5B1ADA4AFABA2ACA89F\
A9A59CA7A39AA5A09ABEBAB7AEADABACABA9BBBAB8C7C6C4C6C5C3C1C0BEC2C1BF
8988867574725554523736341F1E1C100F0D05040200000010120F050A06000200000200000200\
0C110D1D221E282D291B201C212622282D29292E2A262B27242925262B272A2E2D
3030322E2D322C2B302E2D323231363433383231362F2E33302F342F2E332E2D322B2A2F27262B\
2322271F1E231C1D2112131711151813171A14181B14181B13171A111518101417
0D11140D11140B0F120A0E110A0E110A0E110A0E110B0F12090D10090D10090D100A0E110D1114\
10141713171A14181B090D10090D10090D10090D10090D10090D10090D10090D10
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10\
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10
090D10090D10090D10090D10090D10090D10090D10090D100A0F13090E12070C10060B0F060B0F\
070C10090E120A0F1312171B0C1115070C10060B0F080D110A0F130A0F130A0D12
0B0C110C0B110C0B110C0B110C0B110C0B110C0B110C0B110C0B110C0B110C0B110C0B110C0B11\
0C0B110C0B110C0B110B0C100B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
05060806070908090B0A0B0D0D0E100F10121112141213150D0F0E0D0F0E0F1110121413141615\
161817181A19191B1A121413121413111312111312111312131514151716171715
17161417131024201D49454278747194908D918D8A84807D8C88858C88858D89868E8A878F8B88\
908C89918D8A928E8B
ABA8A1AAA7A0A9A69FA8A59EA9A69FACA9A2AEABA4B0ADA6AFACA5AFACA5B0ADA6B1AEA7B1AEA7\
B2AFA8B3B0A9B3B0A9B5B2ABB5B2ABB5B2ABB5B2ABB5B2ABB5B2ABB5B2ABB5B2AB
B5B2ABB5B2ABB5B2ABB5B2ABB5B2ABB5B2ABB5B2ABB5B2ABB5B2ABB5B2ABB5B2ABB5B2ABB5B2AB\
B5B2ABB5B2ABB5B2ABB7B4ADB6B3ACB4B1AAB3B0A9B4B1AAB7B4ADBBB8B1BDBAB3
B8B4ABB8B4ABB6B2A9B5B1A8B4B0A7B2AEA5B1ADA4B1ADA4B6B2A9B9B5ACBDB9B0BFBBB2BEBAB1\
BAB6ADB4B0A7AFACA552514D272725050304040402131112151513110F100E0E0C
0F0D0E0B0B090A08090B0B09110F101212101210110F0F0D0A0C0B0D120E1216151217130D1110\
070C080307060106020D11101A1F1B2B2F2E3439353337362F34302C302F2C302F
3131332F2E332F2E33313035333237302F3429282D232227302F34313035313035302F342C2B30\
27262B2221261E1F231213171014170F13160E12150B0F12080C0F04080B020609
090D10080C0F070B0E05090C05090C060A0D070B0E070B0E090D10090D10090D100A0E110D1114\
10141713171A14181B090D10090D10090D10090D10090D10090D10090D10090D10
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10\
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10
090D10090D10090D10090D10090D10090D10090D10090D100B0E13090E12080B10060B0F070A0F\
070C100A0D120A0F1313161B0C1115080B10060B0F090C110A0F130B0E130A0D12
0B0C110C0B110C0B110C0B110C0B110C0B110C0B110C0B110C0B110C0B110C0B110C0B110C0B11\
0C0B110C0B110C0B100C0C0E0B0D0C0C0C0E0B0D0C0C0C0E0B0D0C0C0C0E0B0D0C
0F0F1112141319191B2123222B2B2D32343339393B3C3E3D4B4B4B474948424242383A39303030\
2729282121211D1F1E181818171918171717161817171717181A191B1B1B1C1C1A
2423212723203E3A376B6764918D8A9B979494908D8E8A87918D8A908C898F8B888E8A878D8986\
8C88858B87848B8784
A7A49DA8A59EA9A69FAAA7A0ACA9A2ADAAA3AEABA4AFACA5AFACA5AFACA5B0ADA6B1AEA7B1AEA7\
B2AFA8B3B0A9B3B0A9B7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4AD
B7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB5B2ABB6B3ACB7B4ADB7B4ADB6B3AC\
B4B1AAB1AEA7AFACA5B3B0A9B1AEA7ADAAA3ABA8A1ADAAA3B2AFA8B9B6AFBDBAB3
B5B2ABB3B0A9B1AEA7B1AEA7B2AFA8B5B2ABB9B6AFBCB9B2ACA9A2B0ADA6B8B5AEBDBAB3BBB8B1\
ACA9A298958E8986813B3B391D1F1E0A0A0C0D0F0E1616180F1110070709030504
0E0E100D0F0E0E0E100D0F0E0E0E100D0F0E0E0E100D0F0E0B0F100B0F0E0B0F100B0F0E0B0F10\
0B0F0E0B0F100B0F0E161A1B1B1F1E2428292E3231363A3B373B3A3236372E3233
333237333237323136323136313035302F34302F342F2E333332373130352E2D322A292E252429\
2120251E1D221B1C20090A0E070B0E070B0E070B0E070B0E070B0E070B0E070B0E
070B0E070B0E070B0E070B0E070B0E070B0E070B0E070B0E0A0E1104080B0C10130B0F12020609\
1216191F2326111518090D10090D10090D10090D10090D10090D10090D10090D10
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10\
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10
090D10090D10090D10090D10090D10090D10090D10090D10070B0E0A0E110E0F130B0F12090A0E\
060A0D0B0C100C10131B1C2005090C06070B070B0E06070B101417141519000004
0B0A0F0C0B100C0B100D0C110F0E13100F14100F141110150E0D120C0B100B0A0F09080D08070C\
08070C09080D0A090E0606060808060B090A0C0C0A100E0F121210151314151513
1513141717151E1C1D2525232F2D2E3636343D3B3C3F3F3F4745464242423D3B3C3434342D2B2C\
2626262321222020201513141212121210111414141B191A1E1E1E201E1F1F1E1C
262221312D2A4945426D69668E8A879C989596928F8B8784918D8A908C898F8B888E8A878C8885\
8B87848A8683898582
A7A49DA8A59EA9A69FAAA7A0ACA9A2ADAAA3AEABA4AFACA5AFACA5B0ADA6B0ADA6B1AEA7B2AFA8\
B2AFA8B3B0A9B3B0A9B7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4AD
B7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB1AEA7B2AFA8B3B0A9B5B2ABB9B6AF\
BDBAB3C0BDB6C2BFB8AFACA5B5B2ABBCB9B2C1BEB7C0BDB6BAB7B0B1AEA7AAA7A0
BBB8B1B9B9B1BCB9B4BDBDB5C0BDB8B8B8B0B0ADA8A5A59DC6C3BEB2B2AA98959076766E595651\
3B3B3326231E1514101E201F0B0C0E00000207080A1011130E0F11090A0C0A0B0D
0D0E100D0E100D0E100D0E100D0E100D0E100D0E100D0E100B0F100B0F100B0F100B0F100B0F10\
0B0F100B0F100B0F10141819191D1E2226272B2F303135363135362E32332A2E2F
313035313035302F342F2E332F2E332E2D322D2C312D2C312A292E28272C2524292120251D1C21\
19181D16151A131418090A0E070B0E070B0E070B0E070B0E070B0E070B0E070B0E
070B0E070B0E070B0E070B0E070B0E070B0E070B0E070B0E0A0E1104080B0C10130B0F12020609\
1216191F2326111518090D10090D10090D10090D10090D10090D10090D10090D10
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10\
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10
090D10090D10090D10090D10090D10090D10090D10090D1008090D0A0B0D0C0D110B0C0E08090D\
08090B0B0C100E0F111F20241213150E0F130D0E100B0C10161719191A1E08090B
0D0C110C0C0E0B0A0F0A0A0C09080D08080A07060B06060809080D09090B09080D0A0A0C0B0A0F\
0E0E101110151212141817151817151918161A19171C1B191D1C1A1E1D1B1E1D1B
22211F21201E201F1D1E1D1B1B1A18191816181715171614121011110F100F0D0E0E0C0D0E0C0D\
0F0D0E100E0F110F101816171A18191B191A1C1A1B1D1B1C1E1C1D1E1C1D1F1E1C
2622213F3B3865615E8783809995929C9895979390918D8A8F8B888F8B888E8A878D89868C8885\
8B87848B87848A8683
A8A59EA9A69FAAA7A0ABA8A1ADAAA3AEABA4AFACA5B0ADA6B0ADA6B0ADA6B1AEA7B1AEA7B2AFA8\
B3B0A9B3B0A9B4B1AAB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4AD
B7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADBDBAB3BAB7B0B5B2ABB1AEA7AEABA4\
AEABA4AFACA5B0ADA6BFBCB5BBB8B1B5B2ABB1AEA7B0ADA6B2AFA8B7B4ADBAB7B0
B8B7B2AFB0AAAAA9A5ACADA7B4B3AFB3B4AEAAA9A59FA09A51504C42433D302F2B20211B191814\
15161014130F1313110B0C0E010508000407070B0E0C10130A0E11090D100B0F12
0B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F12\
0B0F120B0F120B0F12121619171B1E1F2326262A2D292D30292D3025292C23272A
26252A26252A2524292423282423282322272221262221261D1C211B1A1F19181D16151A121116\
0F0E130C0B100A0B0F090A0E070B0E070B0E070B0E070B0E070B0E070B0E070B0E
070B0E070B0E070B0E070B0E070B0E070B0E070B0E070B0E0A0E1104080B0C10130B0F12020609\
1216191F2326111518090D10090D10090D10090D10090D10090D10090D10090D10
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10\
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10
090D10090D10090D10090D10090D10090D10090D10090D100607090A0A0A0B0B0D0A0A0A08080A\
0909090D0D0F111111151517171717161618111111111113161616111113020202
1010120F0F0F0F0F110F0F0F0F0F110E0E0E0E0E100E0E0E1010121010100F0F110F0F0F111113\
1313131515171616161B1A181D19161D19161D19161D19161D19161C18151C1815
1B17141B17141A1613191512191512181411171310171312201C1D1F1B1C1E1A1B1D191A1E1A1B\
1F1B1C211D1E221E1F1B1718211D1E2824252A26272A26272D292A3531323D3938
48444364605D878380999592989491928E8B94908D9A96938D89868D89868D89868C88858C8885\
8C88858B87848B8784
A9A69FA9A69FAAA7A0ACA9A2ADAAA3AFACA5B0ADA6B0ADA6B1AEA7B1AEA7B2AFA8B2AFA8B3B0A9\
B4B1AAB4B1AAB5B2ABB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4AD
B7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB4B1AAB5B2ABB6B3ACB9B6AFBBB8B1\
BEBBB4C1BEB7C2BFB8B9B6AFB5B2ABB0ADA6AFACA5B4B1AABFBCB5CBC8C1D0D0C8
9E9F9A7C7D784F504B2F302B1F201B1516110809040001000D0E090A0B06090A050B0C070F100B\
11120D0F100B0B0D0A0C10110D11141014171216190E1215090D10070B0E090D10
0B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F12\
0B0F120B0F120B0F12101417161A1D1D21242125282024271E22251C20231B1F22
17161B16151A16151A151419141318141318131217131217131217121116100F140E0D120B0A0F\
08070C06050A040509090A0E070B0E070B0E070B0E070B0E070B0E070B0E070B0E
070B0E070B0E070B0E070B0E070B0E070B0E070B0E070B0E0A0E1104080B0C10130B0F12020609\
1216191F2326111518090D10090D10090D10090D10090D10090D10090D10090D10
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10\
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10
090D10090D10090D10090D10090D10090D10090D100B0C0E0707070909090A0A0A090909080808\
0A0A0A0F0F0F1414143232324C4C4C5555555252525656564D4D4D3131311C1C1C
1313131414141616161A1A1A1D1D1D2020202323232424241D1D1D1B1B1B181818151515131313\
1212121212121312101814111915121915121A16131A16131B17141B17141B1714
1814111915121C1815201C1924201D2723202A26232C2825292524292526282425272324282425\
2925262B27282C28292A2627312D2E363233353132322E2F3935364A46475A5655
817D7C8F8B889B97949793908B878486827F8F8B889C98958C88858C88858C88858B87848B8784\
8B87848B87848B8784
AAA7A0AAA7A0ABA8A1ADAAA3AEABA4B0ADA6B1AEA7B1AEA7B1AEA7B2AFA8B2AFA8B3B0A9B4B1AA\
B4B1AAB5B2ABB5B2ABB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4AD
B7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB4B1AAB5B2ABB6B3ACB6B3ACB3B0A9\
AEABA4A8A59EA5A29BAEABA4B7B4ADC4C1BACCC9C2CAC7C0BEBBB4AEABA4A2A29A
90918C6A6C673A3C371719140A0C0706080301030000010013151012140F11130E12140F12140F\
0E100B0507020001000D111413181C171C2014191D0D1216090E12060B0F050A0E
0A0F130A0F130A0F130A0F130A0F130A0F130A0F130A0F130B0E130B0E130B0E130B0E130B0E13\
0B0E130B0E130B0E130F121716191E1C1F241D2025181B2014171C13161B15181D
0F0E130F0E130E0D120E0D120D0C110C0B100C0B100B0A0F0F0E130E0D120D0C110B0A0F09080D\
07060B06050A040509090A0E070B0E070B0E070B0E070B0E070B0E070B0E070B0E
070B0E070B0E070B0E070B0E070B0E070B0E070B0E070B0E0A0E1104080B0C10130B0F12020609\
1216191F2326111518090D10090D10090D10090D10090D10090D10090D10090D10
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10\
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10
090D10090D10090D10090D10090D10090D10090D100B0C0E0707070A09070B0A080A0907090806\
0D0C0A1413111B1A1823222053525065646266656372716F5857551C1B19010000
1515131616141919171C1C1A1F1F1D2323212525232626241B1B19191917171715141412131311\
1212101212101312101C18151E19151F1A16221D19241F1B26211D28231F292420
2C27232B26222B26222B26222B26222B26222A25212A25222B25252B25272C26282E282A312B2D\
352F313832343A34363731333B35373D3739393335383234433D3F5A54566D6767
9E9A999F9B989D999695918E8C88858985828D8986928E8B8C88858C88858B87848B87848A8683\
8A8683898582898582
AAA7A0ABA8A1ACA9A2ADAAA3AFACA5B0ADA6B1AEA7B2AFA8B2AFA8B3B0A9B3B0A9B4B1AAB5B2AB\
B5B2ABB6B3ACB6B3ACB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4AD
B7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB4B1AAB6B3ACB9B6AFBBB8B1BCB9B2\
BBB8B1B9B6AFB7B4ADC3C0B9BEBBB4B3B0A9A09D9685827B68655E4E4B443D3C37
20211C11130E0305000204000D0F0A1A1C171F211C1E201B0E100B0A0C07060803080A050E100B\
141611181A15171C1804080B0C11151015190B1014080D110A0F13090E1204090D
0A0F130A0F130A0F130A0F130A0F130A0F130A0F130A0F130B0E130B0E130B0E130B0E130B0E13\
0B0E130B0E130B0E13101318171A1F1C1F241A1D2212151A0C0F140D1015101318
111015100F14100F140F0E130E0D120E0D120D0C110D0C110D0C110D0C110C0B100B0A0F0A090E\
09080D08070C07080C090A0E070B0E070B0E070B0E070B0E070B0E070B0E070B0E
070B0E070B0E070B0E070B0E070B0E070B0E070B0E070B0E0A0E1104080B0C10130B0F12020609\
1216191F2326111518090D10090D10090D10090D10090D10090D10090D10090D10
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10\
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10
090D10090D10090D10090D10090D10090D10090D100B0C0E0909090B0A080C0B090B0A080C0B09\
11100E1A191721201E5F5E5C9B9A98A9A8A6A7A6A4BCBBB99897954544421B1A18
191917191917191917181816181816181816181816171715141412141412141412151513181816\
1B1B191E1E1C21201C221E1B241F1B26211D2924202C27232F2A26312C28332E2A
322D29322D29322D29322D29322D29312C28312C28312C293F39393E383A3B3537393335383234\
373133383234383234312B2D3630323D3739453F41514B4D655F617F797B918B8B
9692919793909894919A96939B979496928F8F8B888985828E8A878D89868C88858B8784898582\
87838086827F86827F
ABA8A1ACA9A2ADAAA3AEABA4B0ADA6B1AEA7B2AFA8B3B0A9B3B0A9B3B0A9B4B1AAB4B1AAB5B2AB\
B6B3ACB6B3ACB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4AD
B7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADB7B4ADAFACA5ADAAA3ADAAA3AEABA4B2AFA8\
B9B6AFC0BDB6C5C2BB8D8A837B78715E5B543E3B34232019120F080A0700060500
12130E0D0F0C0B0D0A0C0E0B0F110E10120F0D0F0C090B081F211E1719160D0F0C070906070906\
090B08090B08070B0A03070A090E12090E1203080C050A0E0C11150A0F1301060A
0A0F130A0F130A0F130A0F130A0F130A0F130A0F130A0F130B0E130B0E130B0E130B0E130B0E13\
0B0E130B0E130B0E13111419181B201D2025191C210E1116070A0F080B100D1015
111015111015100F14100F140F0E130E0D120E0D120D0C110C0B100B0A0F0B0A0F0B0A0F0B0A0F\
0A090E0A090E090A0E090A0E070B0E070B0E070B0E070B0E070B0E070B0E070B0E
070B0E070B0E070B0E070B0E070B0E070B0E070B0E070B0E0A0E1104080B0C10130B0F12020609\
1216191F2326111518090D10090D10090D10090D10090D10090D10090D10090D10
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10\
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10
090D10090D10090D10090D10090D10090D10090D100B0C0E0B0B0B0D0C0A0E0D0B0D0C0A0E0D0B\
1413111E1D1B2625237F7E7CB9B8B6B7B6B4ABAAA8C9C8C6A5A4A24948461D1C1A
21211F20201E1F1F1D1E1E1C1D1D1B1C1C1A1B1B191A1A1821211F222220232321262624292927\
2E2E2C32323035343034302D36312D37322E3934303B36323C37333E39353E3935
3B36323C37333E3935413C38443F3B47423E4A45414B4643453F3F443E40443E40443E40453F41\
4741434943454A44465751535C5658676163746E70837D7F928C8E9F999BA6A0A0
928E8D94908D9793909995929A969396928F918D8A8D8986918D8A908C898D89868B8784888481\
85817E837F7C827E7B
ABA8A1AAAAA2ADAAA3ACACA4B0ADA6AFAFA7B2AFA8B1B1A9B3B0A9B1B1A9B4B1AAB3B3ABB5B2AB\
B4B4ACB7B4ADB5B5ADB7B4ADB5B5ADB7B4ADB5B5ADB7B4ADB5B5ADB7B4ADB5B5AD
B7B4ADB5B5ADB7B4ADB5B5ADB7B4ADB5B5ADB7B4ADB5B5ADD2D1CCBBBAB593928E6665603D3C38\
1E1D180B0A060302000807030807020908040908030A09050C0B060D0C080E0D09
12121011131011131011131012141114161315171416181510120F0E100D0D0F0C0E100D111310\
10120F0C0E0B0709080C10131114190C0F1403060B06090E0F12170B0E13000106
0B0E130B0E130B0E130B0E130B0E130B0E130B0E130B0E130B0E150B0E150D0D150B0E150D0D15\
0B0E130D0E130B0E1315161B1A1D22202126191D200E0F1305090C08090D0E0F13
0D0E120C0D110C0D120B0C100A0B100A0B0F090A0F090A0E090A0F090A0E090A0F090A0E090A0F\
090A0E090A0F090A0E070B0E060B0E060B0E060B0E060B0E060B0E060B0E060B0E
060B0E060B0E060B0E060B0E060B0E060B0E060B0E060B0E0A0E110408090C10110B0F10020607\
1216171F2324111516090D0E090D0E090D0E090D0E090D0E090D0E090D0E090D0E
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10\
090D10090D10090D10090D10090D0E0B0C10090D0E0B0C10090D0E0B0C10090D0E
0B0C10090D0E0B0C10090D0E0B0C10090D0E0B0C100B0C0E0E0C0D0F0E0C0F0E0C0E0D0B100F0D\
16151321201E2A2927A3A2A0D7D6D4C4C3C1B0AFADD2D1CFB3B2B05857552E2D2B
2928262A29272A29272B2A282D2C2A2E2D2B2E2D2B2F2E2C3B3A383A39373A39373B3A383C3B39\
3F3E3C41403E4342404F4B48504B47504B47504B47514C48514C48514C48514C48
58534F58534F57524E57524E57524E57524E57524E56514E5551505A5657646061726E6F827E7F\
918D8E9E9A9BA5A1A2A4A0A1A5A1A2A8A4A5ACA8A9ACA8A9A7A3A49C9899949091
9D9C9A9B9A969695938E8D89898886898884908F8D97969291908E8F8E8A8C8B89898884858482\
81807C7F7E7C7D7C78
A6A69CADAFA4B5B5ABB6B8ADB3B3A9AFB1A6B1B1A7B3B5AAB0B0A6AFB1A6B0B0A6B1B3A8B4B4AA\
B7B9AEBBBBB1BCBEB3B7B7ADB1B3A8AFAFA5B1B3A8B8B8AEB8BAAFB3B3A9ABADA2
B9B9AFB6B8ADB5B5ABB5B7ACB8B8AEB7B9AEB4B4AAAFB0AAAFB1AE989A99717274474948262729\
1214130A0B0D090B0A0B0C0E0B0D0C0B0C0E0B0D0C0B0C0E0B0D0C0B0C0E0B0D0C
1010101111111212121313131414141515151515151616161A1A1A1414140E0E0E0C0C0C0E0E0E\
0F0F0F0F0F0F0D0D0D0B0C100B0C100B0C100B0C100B0C100B0C100B0C100B0C10
0B0C100B0C100B0C100B0C100B0C100B0C100B0C100B0C1110101A0F0F190E0C170C0C160C0A15\
0C0C140E0D150E0E1615141A1E1F2426252A212224141416090A0C09090B0D0E10
090C11090C11090C13090C11090C13090C11090C13090C11070A11070A0F070A11070A0F070A11\
070A0F070A11060B0F00060900060900080B01090C030B0E050D10060E11060E11
000609030B0E081013081013040C0F030B0E060E110911131216170608070B0D0C1012110C0E0D\
1A1C1B2224231214130B0D0C0A0C0B090B0A090B0A0A0C0B0B0D0C0D0F0E0C100F
0A0E0F090F0F080E0E070D0D050B0B040A0A030909030909070D0D070D0D080E0E080E0E090F0F\
0A10100A10100C10110B0C0E0B0D0C0B0B0D0A0C0B0A0A0C080A0909090B080A09
0A0A0C0A0C0B0C0C0E0C0E0D0E0E100E100F101012111111100E0F110D0E0E0A0B0D090A120E0F\
1D191A2824252F2B2CB8B4B5BAB6B7B8B4B5BAB6B7C6C2C3B7B3B4726E6F282425
353132332F30312D2E2E2A2B2D292A2E2A2B302C2D312D2E3E3A3B403C3D433F40454142474344\
46424345414244403F4944414944404B46424D4844514C4855504C5954505B5652
504B47514C48544F4B57524E5A55515E5955605B57615D5A6968666F6D6E7775768280818B898A\
929091979596999798A6A4A5A7A5A6A6A4A5A5A3A4A3A1A29F9D9E9C9A9B999999
9C9E9D989A979496959294919395949294918E908F8A8C899193928C8E8B848685797B786D6F6E\
6264615A5C5B565855
ADAFA4AEB0A5ACAEA3A8AA9FA3A59AA5A79CACAEA3B3B5AAADAFA4B0B2A7B4B6ABB6B8ADB5B7AC\
B1B3A8ACAEA3A8AA9FB8BAAFB4B6ABB0B2A7B0B2A7B4B6ABB7B9AEB9BBB0B8BAAF
B2B4A9B5B7ACB9BBB0B8BAAFAEB0A5999B907F81766B6E67383A392D31341D21240F1316060A0D\
04080B070B0E0A0E11090D10090D10090D10090D10090D10090D10090D10090D0E
0F0F111111111313131616161A1A1A1C1C1C1E1E1E1F1F1F1919191414140E0E0E0C0C0C0D0D0D\
0F0F0F0E0E0E0D0D0D0C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B10
0C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B11100E190F0D1A0E0C190C0A150C0A15\
0D0C140E0D150F0E1416151B1F1E232626282121231313130909090909090D0E10
090C11080D13080D13080D13080D13080D13080D13080D13060B11060B11060B11060B11060B11\
060B11060B11060B0F091114091113081012081012070F11070F11060E10060E10
00030500060801090B020A0C020A0C01090B01090B040A0A080C0B000100040603060805010300\
10120F1C1E1B0D0F0C10120F0F110E0D0F0C0C0E0B0B0D0A0A0C090A0C09090E0A
0D11100C12120C12120C12120C12120C12120C12120C1212040A0A040A0A040A0A050B0B060C0C\
070D0D070D0D080C0D0B0D0C0C0C0C0D0D0D0E0E0E0F0F0F101010111111111111
0A0A0A0A0A0A0909090909090909090808080808080808080A0607090506100C0D1C1819201C1D\
201C1D282425353132C0BCBDC0BCBDBBB7B8BAB6B7C5C1C2C0BCBD8F8B8C555152
2E282A332D2F3A3436413B3D453F41453F41443E40423C3E3C36383E383A423C3E484244504A4C\
5751535D5759615B5B58535057524E56514D55504C544F4B544F4B544F4B55504C
66615D68635F6C6763726D6978736F7E7975827D79837F7C8F8E8C8D8D8D8D8D8D909090989898\
A3A3A3AFAFAFB7B7B7A5A5A5A5A5A5A6A6A6A5A5A5A4A4A4A1A1A19F9F9F9C9E9D
A0A2A1979B9A8C908F8387867B7F7E727675676B6A6064635054534B4F4E424645373B3A2A2E2D\
1F2322161A19121615
A9ABA0AAACA1ABADA2AAACA1AAACA1AEB0A5B6B8ADBDBFB4A7A99EABADA2B0B2A7B6B8ADBABCB1\
BDBFB4BEC0B5BFC1B6ABADA2B0B2A7B6B8ADB9BBB0B8BAAFB7B9AEB7B9AEB8BAAF
BDBFB4ABADA28C8E83696B6044463B21231804060000020005070603070A02060903070A04080B\
070B0E0A0E110C1013090D10090D10090D10090D10090D10090D10090D10090D0E
0D0D0F1010101616161C1C1C2222222727272A2A2A2B2B2B1919191313130D0D0D0B0B0B0D0D0D\
0E0E0E0E0E0E0C0C0C0C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B10
0C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B110F0D180E0C190D0B160C0A150C0A15\
0D0C140F0E16100F1517161C201F242626282020221212120808080909090D0E10
090D10080D11080D11080D11080D11080D11080D11080D11060B0F060B0F060B0F060B0F060B0F\
060B0F060B0F060B0F080E0E080E0E070D0D070D0D060C0C050B0B050B0B050B0B
0D13130C12120C12120E14141117171117170E14140C100F1214110C0E0912140F11130E0B0D08\
1E201B2D2F2A1F211C11130E10120D0E100B0C0E09090B06070904060803030804
0A0E0D090F0F090F0F0A10100A10100B11110B11110B1111080E0E080E0E090F0F090F0F0A1010\
0B11110B11110D11120E100F1010101212121414141616161919191A1A1A1B1B1B
2626262525252424242222222121211F1F1F1E1E1E1E1E1E231F20141011130F101D191A1B1718\
1C18193F3B3C6D696AC7C3C4C7C3C4BFBBBCBAB6B7C3BFC0C9C5C6B2AEAF908C8D
4842444943454943454A44464B45474C46484D47494E484A605A5C5D5759595355565052544E50\
554F5157515358525265605D68635F6D6864746F6B7B7672827D7987827E8A8581
98938F9994909B96929E9995A19C98A49F9BA6A19DA6A29FAAA9A7A5A5A59F9F9F999999969696\
969696989898999999ADADADACACACABABABA9A9A9A5A5A5A1A1A19D9D9D9A9C9B
6365645A5E5D4F53524448473B3F3E3034332529281D21200E12110D11100B0F0E090D0C070B0A\
040807020605010504
A8AA9FACAEA3B2B4A9B5B7ACB5B7ACB2B4A9B0B2A7AEB0A5BDBFB4B8BAAFB2B4A9ADAFA4ABADA2\
ADAFA4B1B3A8B4B6ABBDBFB4C0C2B7BABCB1A2A4997B7D72515348323429222419
13150A0B0D020305000305000C0E03191B1025271C2A2D261416151216191115181014170F1316\
0E12150D11140D1114090D10090D10090D10090D10090D10090D10090D10090D0E
0B0B0D1010101818182121212929292F2F2F3333333434341818181212120C0C0C0A0A0A0C0C0C\
0E0E0E0D0D0D0C0C0C0C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B10
0C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B110E0C170E0C170D0B160C0A150D0C14\
0E0D15100F1511101519181D2222242626282020201111110707070909090D0F0E
090D10080D10080D11080D10080D11080D10080D11080D10060B0F060B0E060B0F060B0E060B0F\
060B0E060B0F070B0E060807060805070906080A07090B080A0C090B0D0A0C0E0B
0C0E0B080A070507040608050A0C090A0C090709060305020305000103000A0C07090B06040601\
1B1D182A2C27181A150D0F0A0D0F0A0D0F0A0C0E090A0C07080A05060803050704
0D11100C12120C12120B11110B11110A10100A10100A10100F15150F1515101616101616111717\
1218181218181418191214131414141515151717171818181A1A1A1B1B1B1C1C1C
1A1A1A1A1A1A1919191818181717171616161616161515152C28291E1A1B221E1F2C2829211D1E\
1F1B1C585455A29E9FC7C3C4C8C4C5C3BFC0BCB8B9C1BDBECAC6C7C5C1C2B7B3B4
BEB8BAB1ABAD9D97998B8587837D7F847E808B8587918B8D938D8F958F919892949D9799A29C9E\
A7A1A3ACA6A8AEA8A8AEA9A6ADA8A4ADA8A4ACA7A3AAA5A1A7A29EA5A09CA39E9A
A19C98A29D99A39E9AA49F9BA6A19DA7A29EA9A4A0A8A4A1A1A09E9F9F9F9A9A9A9090907E7E7E\
6868685454544848482525252424242121211C1C1C1616160F0F0F0A0A0A050706
1719181115140C100F0A0E0D0A0E0D080C0B030706000302020605030706060A09080C0B0C100F\
0E1211111514121615
B2B3ABB2B3ABB1B2AAB1B2AAAFB0A8ABACA4A5A69EA1A29AA5A69EA7A8A0AAABA3AEAFA7B2B3AB\
B5B6AEB7B8B0B8B9B1CACBC3C7C8C0B9BAB29A9B936F706844453D26271F171810
0F100810110912130B15160E15160E0E0F070304000002000C0E0D080C0F060A0D05090C060A0D\
080C0F0C10130E1215090D10090D10090D10090D10090D10090D10090D10090D0E
0B0B0D1010101919192323232B2B2B3030303333333434341717171212120C0C0C0A0A0A0B0B0B\
0D0D0D0C0C0C0B0B0B0C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B10
0C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B110D0C140D0B160C0A150C0B130D0C14\
0F0E161110161211161C1B202323252727291F1F1F1010100606040808060D0F0E
090D0E090D0E090D10090D0E090D10090D0E090D10090D0E070B0E070B0C070B0E070B0C070B0E\
070B0C070B0E090B0A0D0E090E0D080E0D080F0E090F0E090F0E090F0E090F0E09
12110C0E0D080B0A050A09040C0B060F0E0911100B11100B0D0E090F100B1A1B161B1C171A1B16\
33342F393A351C1D1811120D12130E14151016171216171215161113140F111310
161A191519181418171216151115140F13120E12110D11100D11100E12110E12110F1312101413\
101413111514111514131514141414131313131313131313131313131313131313
0E0E0E0F0F0F0F0F0F1010101111111212121212121313131713141915162E2A2B403C3D312D2E\
2B2728656162B4B0B1C1BDBEC4C0C1C3BFC0BFBBBCBFBBBCC4C0C1C4C0C1C1BDBE
CDC9CAC0BCBDABA7A89793948C88898B8788908C8D959192A4A0A1A7A3A4ACA8A9B0ACADB2AEAF\
B2AEAFB0ACADAEAAA9A7A3A0A8A4A1A9A5A2AAA6A3AAA6A3A8A4A1A6A29FA5A19E
A9A5A2A8A4A1A7A3A0A7A3A0A6A29FA5A19EA4A09DA4A09D9C9B99999999939393878787737373\
5C5C5C4646463939391414141313131212121010100C0C0C070707030303000201
0A0C0B060A09050908080C0B0D11101014130F13120D11101115141014130F13120D11100B0F0E\
090D0C070B0A060A09
B0B1A9ACADA5AAABA3ABACA4B1B2AAB7B8B0BABBB3BBBCB4B2B3ABB9BAB2C2C3BBC7C8C0C1C2BA\
B2B3ABA1A29A95968E4D4E46494A4240413935362E2B2C24272820292A222C2D25
0F10080E0F070E0F0712130B1819111B1C141A1B131719140D0E10090D1005090C03070A03070A\
060A0D0B0F120E1215090D10090D10090D10090D10090D10090D10090D10090D0E
0C0C0E1111111A1A1A2222222828282B2B2B2B2B2B2A2A2A1616161111110B0B0B0909090A0A0A\
0C0C0C0B0B0B0A0A0A0C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B10
0C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B110C0B130C0B130B0A120C0B130D0C14\
0F0E141211161313151E1E202424242727271E1E1C0E0E0C0505030808060E0E0C
0B0D0C090D0C090D0E090D0C090D0E090D0C090D0E090D0C070B0C070B0A070B0C070B0A070B0C\
070B0A070B0C090B08100D06100C030F0B020E0A010D09000C08000B07000A0600
0F0B020F0B020E0A010C08000D0900161209231F162C292234332E36373142413D43443E484743\
5C5D5753524E24251F1C1B171E1F1922211D24251F26252124251F22211D20211C
1416131216151115140F13120E12110D11100C100F0B0F0E0B0F0E0B0F0E0C100F0C100F0D1110\
0E12110E1211111312171717161616161616151515141414131313131313121212
1818181919191A1A1A1B1B1B1D1D1D1F1F1F202020202020252122221E1F292526312D2E2F2B2C\
3F3B3C848081CFCBCCBDB9BAC0BCBDC2BEBFC1BDBEBFBBBCBEBABBBEBABBBDB9BA
C9C5C6C7C3C4C5C1C2C2BEBFBEBABBBBB7B8B9B5B6B7B3B4AEAAABAFABACB0ACADB0ACADAEAAAB\
AAA6A7A6A2A3A39FA0ACA8A7AEAAA7B0ACA9B1ADAAB0ACA9ADA9A6AAA6A3A7A3A0
9E9A979995928F8B88837F7C76726F6A6663605C595958562D2D2D2727271D1D1D1313130B0B0B\
060606040404040404121212131313151515171717181818181818171717161817
1618171115140E12110E12111014131115140E12110A0E0D090D0C090D0C080C0B080C0B070B0A\
060A09060A09060A09
A8A9A3A9AAA4AEAFA9B4B5AFB9BAB4B6B7B1ABACA6A2A39DB6B7B1B4B5AFADAEA89E9F9984857F\
656660494A4437383241423C3A3B3530312B2A2B25292A24292A24282923272822
1A1B1510110B0506000001000405000E0F091718121A1C17191A1C15191C1115180E12150B0F12\
0A0E110A0E110A0E11090D10090D10090D10090D10090D10090D10090D10090D0E
0D0D0F1212121919191F1F1F2222222222221F1F1F1D1D1D1616161010100A0A0A0808080A0A0A\
0C0C0C0B0B0B0909090C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B10
0C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B110B0A120B0A120B0A120C0B110D0C12\
100F141211161414162020222525252727271D1D1B0D0D0B0405000708030E0E0C
0B0D0A0B0D0A0B0D0C0B0D0A0B0D0C0B0D0A0B0D0C0B0D0A090B0A090B08090B0A090B08090B0A\
090B08090B0A0A0B060B07000E0800100A00130D01150F031711051913071A1408
110B001711051B15091913071B15092B25194741355D564C63605962625A6E6B666E6E6675726D\
82827A68656026261E27241F27271F2C29242D2D252E2B2629292127241F23221D
131512141613151714161815171916181A17191B18191B181C1E1B1D1F1C1D1F1C1E201D1F211E\
1F211E20221F20221F262626262626262626272727272727272727282828282828
1F1F1F2020202020202020202020202121212121212121213C3839353132363233433F405A5657\
7D797AAEAAABD8D4D5BFBBBCBFBBBCC1BDBEC2BEBFC0BCBDBDB9BABCB8B9BDB9BA
A8A6A7ABA9AAB1AFB0B6B4B5B7B5B6B5B3B4B1AFB0AFADAEB3B1B2B2B0B1AFADAEAFADAEB1AFB0\
B6B4B5BCBABBBFBDBEB7B6B4B3B2B0AAA9A79C9B998A89877776746766645E5D5B
47464441403E3736342A29271C1B190F0E0C0403010100001A1A1A1515150F0F0F0B0B0B0B0B0B\
1010101616161B1B1B0606060707070909090B0B0B0C0C0C0C0C0C0B0B0B0A0C0B
1315140D1110090D0C080C0B090D0C080C0B040807000403000403010504030706070B0A0A0E0D\
0D11100F1312111514
AAABA6B1B2ACBCBDB8C0C1BBB4B5B093948E696A654C4D472728232627212627222829232C2D28\
32332D393A353D3E382E2F2A2F302A33342F3C3D3743443F40413B343530282923
0D0E090F100A13140F1819131A1B1614150F090A0500010007080A070B0E090D100A0E110A0E11\
090D10070B0E060A0D090D10090D10090D10090D10090D10090D10090D10090D0E
0E0E101212121818181D1D1D1E1E1E1B1B1B1717171313131515151010100A0A0A080808090909\
0B0B0B0B0B0B0909090C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B10
0C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B100B0A100B0A100B0A100B0A0F0D0C11\
1010121313151414142121212626242727251C1D180D0E090405000708030E0F0A
0C0D080B0D080C0C0A0B0D080C0C0A0B0D080C0C0A0B0D080A0A08090B060A0A08090B060A0A08\
090B060A0A080B0A05110B00150D001D1307241C0F2E2418352D203D33273F372A
574D415F574A685E52675F526B61557F776AA69C90C3BBB0B3AFA6B2AFA8BAB7B0BCB9B2C1BEB7\
CBC8C1A29F9856534C28251E2A27202D2A232E2B242C292227241D211E171E1B14
22231E232520262624292B262E2E2C30322D343432343631343432333530353533353732363634\
3638333838363838363737373737373939393B3B3B3D3D3D3F3F3F414141414141
4747474646464545454444444343434141414040404040402E2A2B3C38395B5758898586B4B0B1\
CAC6C7C4C0C1B6B2B3C4C0C1C0BCBDC0BCBDC2BEBFC2BEBFBEBABBBEBABBC0BCBD
C9C7C8C6C6C6C5C3C4C2C2C2C2C0C1C2C2C2C5C3C4C6C6C6A09E9F8E8E8E727071505050373536\
2424241C1A1B1818180B090A0D0D0B110F1011110F110F100C0C0A080607040402
0B090A0B0B090D0B0C0E0E0C110F101212101412131414140B0B0B0D0D0D0F0F0F111111111111\
1010100E0E0E0C0C0C1919191919191818181717171414141010100D0D0D0A0C0B
0F11100A0E0D090D0C0B0F0E0F13121115141014130D11100C100F0C100F0B0F0E0A0E0D080C0B\
070B0A060A09060A09
ADADABB0B1ACB3B3B1B0B1ACA0A09E7E7F7A5555533839341717151E1F1A28282631322D363634\
3536313232302F302B3434323637323939373A3B363A3A38383934363634343530
10100E10110C0F0F0D0E0F0A0E0E0C0D0E090C0C0A0B0D0A0B0C0E090D10090D10090D10090D10\
090D10090D10090D100E12150D11140B0F120A0E11090D100A0E110B0F120C1011
1616181212121717171E1E1E1919190B0B0B0A0A0A1515150E0E0E0E0E0E0E0E0E0E0E0E0E0E0E\
0E0E0E0E0E0E0E0E0E0C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B10
0C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B10100F14100F140F0E130C0B100A090E\
0D0D0F1414161A1A1A1F1F1F2B2B292B2B291A1B160E0F0A0E0F090E0F09080903
0A0B050B0C060B0A060708020504000506000A09050E0F090B0A060C0D070D0C080B0C060A0905\
0C0D0713120E1B18111D150A2118092A1E103128193C3022433A2B4B3F314D4435
64584A685F50706456716859796D5F898071A5998BB8AEA2C3BCB2C0BCB3B6B2A9B2AEA5C1BDB4\
C7C3BAA19D946E6A612D2920302C23332F26343027322E252D292027231A221F18
1F1E1923241E2B2A2630312B35343034352F34332F31322C3534303637313A39353B3C363F3E3A\
3E3F39403F3B3E3F3A3C3C3A3E3E3E4141414444444343434141413D3D3D3B3B3B
4242424444444545454343433E3E3E3C3C3C3E3E3E404040454142514D4E706C6D9A9697B7B3B4\
BFBBBCC1BDBEC3BFC0BCB8B9C2BEBFC3BFC0BFBBBCC1BDBEC9C5C6CAC6C7C3C1C2
CACACAC3C5C4BCBCBCB5B7B6B1B1B1AAACABA3A3A39C9E9D8888887779785E5E5E4143422B2B2B\
1D1F1E1818181618170E0E0E0D0F0E0E0E100D0F0E0E0E100D0F0E0E0E100D0F0E
0C0C0E0B0D0C0C0C0E0B0D0C0C0C0E0B0D0C0C0C0E0C0C0C0E0E0E0D0D0D0B0B0B0A0A0A0A0A0A\
0B0B0B0D0D0D0E0E0E1010100D0D0D0B0B0B0C0C0C1010101111110F0F0F0B0D0C
0B0D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C\
090D0C090D0C090D0C
9F9F9D8585835F5F5D3A3A3820201E10100E06060401010010100E16161420201E2B2B29323230\
3636343636343636343C3C3A3E3E3C41413F43434144444244444242424041413F
10100E10100E0F0F0D0E0E0C0E0E0C0D0D0B0C0C0A0B0D0C0B0C0E090D10090D10090D10090D10\
090D10090D10090D100D11140C10130B0F12090D10090D100A0E110B0F120C1011
1414161313131919192020201919190B0B0B0A0A0A1313130E0E0E0E0E0E0E0E0E0E0E0E0E0E0E\
0E0E0E0E0E0E0E0E0E0C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B10
0C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B100D0C110D0C110D0C110A0A0C08080A\
0C0C0C1313131919172A2A282F302B2829241617110C0D070E0F070D0E06070800
14140C15150D16160E13130B10100811110916160E1A1A1203030009090111110917170F1B1B13\
20201827271F2F2B22423A2F4A3E305246385D5143695D4F7367597C7062807466
988C7E9E9284A4988AA39789A19587A69A8CB3A799BDB3A7B0A99FB5B1A8B3AFA6AEAAA1B7B3AA\
C3BFB6B2AEA5938F86504C4348443B3D3930353128322E2537332A3F3B32444037
312E2733322D393833403F3A4645404A49444B4A454C4B464A49444A49444B4A454A4944494843\
47464145443F44433F3E3E3C3F3F3F4040404141414444444747474949494B4B4B
3C3C3C3D3D3D4141414949495555556161616B6B6B7070709B9798A19D9EB5B1B2CFCBCCDCD8D9\
D5D1D2CAC6C7C6C2C3CCC8C9CDC9CAC8C4C5C0BCBDBFBBBCC0BCBDB8B4B5AAA8A9
9797978A8C8B7678776163624C4E4D3739382325241719181416151113120B0D0C060807030504\
040605060807080A090D0E100D0E100D0E100D0E100D0E100D0E100D0E100D0E10
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0E0E0E0D0D0D0B0B0B0A0A0A0A0A0A\
0B0B0B0D0D0D0E0E0E1010100D0D0D0B0B0B0C0C0C1010101111110F0F0F0B0D0C
0B0D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C\
090D0C090D0C090D0C
2C2C2C2121211111110707070606060C0C0C1212121616160F0F0F1212121818181E1E1E232323\
2727272A2A2A2B2B2B2C2C2C2E2E2E313131353535373737383838383838383838
1010101010100F0F0F0E0E0E0E0E0E0D0D0D0C0C0C0B0D0C0B0C0E090D10090D10090D10090D10\
090D10090D10090D100C10130B0F120A0E11090D10090D100A0E110C10130D1112
1212141616161E1E1E2222221919190C0C0C0909090F0F0F0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E\
0E0E0E0E0E0E0E0E0E0C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B10
0C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B100D0D0F0E0E100E0E100C0C0E0B0B0D\
0F0F0F1818181E1E1C2828262425201718120A0B03090A0210110913140C101207
0202000704000A07000A07000A07000D0A0113100718150C1F1C132A271E3A372E48453C514E45\
57544B5D5A51625E5380786D857B6F8B8175948A7E9D9387A59B8FACA296AFA599
B3A99DBAB0A4C0B6AABEB4A8B7ADA1B2A89CB2A89CB6ACA0A69F95B3ACA2B6AFA5ADA69CAEA79D\
BBB4AABDB6ACB4ADA36760565C554B4C453B3E372D3831273B342A433C3247433A
514E47504D464E4B444B484147443D44413A423F38403D3646433C47443D48453E48453E48453E\
46433C45423B41403B5C5C5A5A5A5A5858585757575A5A5A5F5F5F656565696969
8D8D8D8F8F8F959595A2A2A2B1B1B1B8B8B8B6B6B6B1B1B1C7C3C4C1BDBEC2BEBFCCC8C9CFCBCC\
C6C2C3BFBBBCBFBBBCB3AFB0ABA7A89995968581827874756A6667504C4D353334
1D1F1E171B1A1216151014131014130E1211090D0C0509080206050509080A0E0D0E1211111514\
1216151115141115140B0F100B0F120B0F120B0F120B0F120B0F120B0F120B0F12
090D10090D10090D10090D10090D10090D10090D100B0C0E0E0E0E0D0D0D0B0B0B0A0A0A0A0A0A\
0B0B0B0D0D0D0E0E0E1010100D0D0D0B0B0B0C0C0C1010101111110F0F0F0B0D0C
0B0D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C\
090D0C090D0C090D0C
0C0C0C111111191919212121232323202020191919141414171717161616141414121212111111\
1010101111111111111414141616161818181B1B1B1E1E1E202020212121222222
1010101010100F0F0F0E0E0E0E0E0E0D0D0D0C0C0C0B0C0E0B0C10090D10090D10090D10090D10\
090D10090D10090D100B0F120B0F120A0E11090D100A0E110B0F120D11140E1213
1111131A1A1A2424242424241818180C0C0C0909090D0D0D0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E\
0E0E0E0E0E0E0E0E0E0C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B10
0C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B100F0F11101012111113101010111111\
1616141F1F1D27282333342F26272114150D090A020C0D0514160B181A0F18180C
3B392D413F3349473B4F4D415553475C5A4E6563576C6A5E807E728D8B7FA19F93B0AEA2B9B7AB\
BDBBAFC0BEB2C2BEB2B5ADA2B6AEA3B7AFA4B8B0A5BAB2A7BBB3A8BCB4A9BCB4A9
AFA79CB5ADA2BBB3A8BBB3A8B6AEA3B2AA9FB1A99EB2AA9FB1A89FBAB3A9BAB3A9B0A99FACA59B\
B3ACA2B7B0A6B3ACA2C3BCB2C0B9AFBAB3A9B2ABA1A8A1979F988E989187948D83
918D84928F8896938C9C9992A4A19AACA9A2B3B0A9B7B4ADB8B5AEBBB8B1BFBCB5C4C1BAC8C5BE\
CBC8C1CCC9C2CDCAC5BEBDBBBDBDBDBEBEBEC1C1C1C6C6C6CCCCCCD2D2D2D6D6D6
CACACAC8C8C8C9C9C9CDCDCDCCCCCCBBBBBB9D9D9D868686534F50423E3F343031322E2F332F30\
332F30393536423E3F454142423E3F3D393A3D393A4642434A4647393536211F20
0A0C0B050908040807070B0A0C100F0E12110D11100B0F0E101413111514121615121615101413\
0B0F0E060A090307080B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F12
090D10090D10090D10090D10090D10090D10090D10090D100D0E100D0D0D0B0B0B0A0A0A0A0A0A\
0B0B0B0D0D0D0E0E0E1010100D0D0D0B0B0B0C0C0C1010101111110F0F0F0B0D0C
0B0D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C\
090D0C090D0C090D0C
1A1A1C1B1B1D1B1B1D1A1A1C18181A18181A19191B1B1B1D2121231D1D1F18181A1212140D0D0F\
0A0A0C08080A08080A0D0D0F0E0E100F0F11101012121214141416161618171719
1010121010120F0F110E0E100E0E100D0D0F0C0C0E0B0C0E0B0C10090D10090D10090D10090D10\
090D10090D10090D100A0E110A0E11090D10090D100A0E110C10130E12150F1314
1212142020202929292323231414140B0B0B0A0A0A0D0D0D0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E\
0E0E0E0E0E0E0E0E0E0C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B10
0C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0C0E0E0E0E101010101010121212\
1919172323212B2C273C3D382C2D271B1C1415160E191B101F211624261B28281C
3230243C382C4844385450445E5A4E6965597470647C786C8E8A7E999589A9A599B3AFA3B7B3A7\
B6B2A6B4B0A4B4B0A4C5BEB4C3BCB2C1BAB0BEB7ADBBB4AAB8B1A7B6AFA5B5AEA4
B2ABA1B5AEA4B7B0A6B7B0A6B6AFA5B6AFA5B9B2A8BCB5ABBDB4ABBDB5AABAB2A7B5ADA2B5ADA2\
B7AFA4B1A99EA79F94B9B1A6BBB3A8BCB4A9BBB3A8B4ACA1A9A1969E968B968F85
9A968D9B978E9E9A91A39F96A9A59CB0ACA3B6B2A9BAB6ADACA89FAEAAA1B3AFA6B8B4ABBDB9B0\
C0BCB3C2BEB5C1BEB7CAC9C7CBCBCBCDCDCDCFCFCFD0D0D0CFCFCFCDCDCDCBCBCB
DADADAD0D0D0C3C3C3B8B8B8ABABAB9393937474745C5C5C3935362C28292420212824252D292A\
2D292A322E2F3A36373935363834353733343D393A4D494A5753544B4748343233
1115140D13110A100E0B110F0D13110D13110B110F070D0B050B09050B09040A08040A08030907\
040A08040A08040A0A0A0F120A0F130A0F130A0F130A0F130A0F130A0F130A0F13
080D11080D11080D11080D11080D11080D11080D11090D100D0E100D0D0D0B0B0B0A0A0A0A0A0A\
0B0B0B0D0D0D0E0E0E1010100D0D0D0B0B0B0C0C0C1010101111110F0F0F0B0D0C
0B0D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C\
090D0C090D0C090D0C
0707090E0E101616181D1D1F2222242626282C2C2E3131332525272323252020221C1C1E19191B\
18181A1717191717191010120E0E100D0D0F0B0B0D0B0B0D0C0C0E0D0D0F0E0E10
1010121010120F0F110E0E100E0E100D0D0F0C0C0E0B0C0E0B0C10090D10090D10090D10090D10\
090D10090D10090D10090D10090D10080C0F090D100A0E110C10130F1316101415
1515172626262D2D2D2020200F0F0F0909090C0C0C0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E\
0E0E0E0E0E0E0E0E0E0C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B10
0C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0C0E0707090A0A0A0D0D0D0F0F0F121210\
1A1A182425202D2E282D2E2824251D22231B2C2E23393B3043453A5153465E5E52
716F627B776B878377928E829C988CA5A195AEAA9EB5B1A5B9B5A9C0BCB0C8C4B8CBC7BBC8C4B8\
C4C0B4C2BEB2C1BDB1B9B5ACB7B4ABB7B2ACB4B1A8B3AEA8B1AEA5B0ABA5AEABA2
B8B3ADB5B2A9B4AFA9B0ADA4B1ACA6B2AFA6B6B1ABB8B4ABBCB5ABB7AFA4B2AA9FB5ADA2BDB5AA\
BEB6ABB4ACA1A8A095BBB3A8BBB3A8BAB2A7B9B1A6B9B1A6BAB2A7BBB3A8BAB4A8
C8C1B9C6C2B9C6C2B9C5C1B8C4C0B7C3BFB6C3BFB6C2BEB5CDC9C0CDC9C0CECAC1CECAC1CDC9C0\
CBC7BEC9C5BCC6C3BCCFCECCCACACAC2C2C2B6B6B6A5A5A5929292828282797979
5D5D5D4D4D4D3939392929292121211B1B1B1414140E0E0E100C0D130F10231F203C38394C4849\
4C48494945464A4647555152524E4F494546403C3D3F3B3C3D393A2C2829161415
010504000503000503040A080C12101117151218161117150E14120D13110B110F0A100E0B110F\
0D13111117151319190A0F120A0F130A0F130A0F130A0F130A0F130A0F130A0F13
080D11080D11080D11080D11080D11080D11080D11090D100D0E100D0D0D0B0B0B0A0A0A0A0A0A\
0B0B0B0D0D0D0E0E0E1010100D0D0D0B0B0B0C0C0C1010101111110F0F0F0B0D0C
0B0D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C\
090D0C090D0C090D0C
1717192222242E2E303232342D2D2F2424261D1D1F1A1A1C272729272729272729262628252527\
24242623232522222419191B1616181212140E0E100B0B0D0A0A0C0A0A0C0A0A0C
1010121010120F0F110E0E100E0E100D0D0F0C0C0E0B0C0E0B0C10090D10090D10090D10090D10\
090D10090D10090D10080C0F080C0F080C0F090D100A0E110D11140F1316111516
19191B2B2B2B3030301D1D1D0909090707070D0D0D1111110E0E0E0E0E0E0E0E0E0E0E0E0E0E0E\
0E0E0E0E0E0E0E0E0E0C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B10
0C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0C0E0B0B0D0E0E0E111111141414191917\
21211F2D2E29353630595A545758505F60587072677C7E73828477919386A3A397
AAA89BB2AFA0BAB7A8C0BDAEC2BFB0C4C1B2C8C5B6CCC9BAB8B5A6BBB8A9BCB9AAB9B6A7B4B1A2\
B1AE9FB2AFA0B3AFA3B3B0A7B1B1A9B3B0ABB0B0A8B1AEA9AFAFA7B0ADA8AEAEA6
B5B2ADB0B0A8B0ADA8ACACA4AFACA7ADADA5AEABA6AEABA4B9B2A8B3ABA0B0A89DB4ACA1BBB3A8\
BDB5AAB9B1A6B5ADA2B8B0A5B6AEA3B5ADA2B4ACA1B6AEA3BBB3A8C0B8ADC2BCB0
B2ABA3B2AEA5B5B1A8B9B5ACBAB6ADBAB6ADB8B4ABB7B3AACCC8BFCAC6BDC7C3BAC2BEB5BCB8AF\
B5B1A8B0ACA3ABA8A16968666161615555554444443232322020201212120A0A0A
1E1E1E1616160B0B0B0303030101010606060D0D0D1212120501020A06071C1819383435474344\
4541423F3B3C3D393A1915161D191A1C18191915161E1A1B242021211D1E141213
1519181016140B110F090F0D080E0C050B090006040002000B110F090F0D070D0B050B09040A08\
0309070309070309090A0F120A0F130A0F130A0F130A0F130A0F130A0F130A0F13
080D11080D11080D11080D11080D11080D11080D11090D100D0E100D0D0D0B0B0B0A0A0A0A0A0A\
0B0B0B0D0D0D0E0E0E1010100D0D0D0B0B0B0C0C0C1010101111110F0F0F0B0D0C
0B0D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C\
090D0C090D0C090D0C
12101316141719171A19171A19171A1E1C1F2826293230332A282B2B292C2B292C2B292C29272A\
27252824222522202329292B2626282020221A1A1C151517131315121214121214
1010121010120F0F110E0E100E0E100D0D0F0C0C0E0B0C0E090D10090C11090C11090C11090C11\
090C11090C11090D10080C0F080C0F080C0F080C0F0A0E110D1112101417111516
1A1B1D2D2D2D3131311B1B1B0606060606060E0E0E1313130E0E0E0E0E0E0E0E0E0E0E0E0E0E0E\
0E0E0E0E0E0E0E0E0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E1313131616161A1A1A1E1E1E222220\
2B2B2937383340413BBEBFB9BBBCB6BFC0B8C7C8C0C1C3B8B6B8ADBABCB1CACABE
BBB9ACC1BEAFC5C2B3C5C2B3C1BEAFBDBAABBBB8A9BCB9AAC2BFB0C2BFB0C0BDAEBBB8A9B6B3A4\
B5B2A3B9B6A7BDB9ADBAB6ADB9B6AFB9B4AEB6B3ACB5B0AAB3B0A9B3AEA8B1AEA7
B2ADA7B1AEA7B2ADA7B3B0A9B6B1ABB5B2ABB2ADA7AFABA2B8B4A8B4AEA0B1AB9DB3AD9FB4AEA0\
B5AFA1B8B2A6BDB7ABB6B0A4B8B2A6BBB4AABDB6ACBDB6ACBBB4AAB8B1A7B4B0A7
CBC8BFC1C1B7B4B1AA9C9C9283807965655B504D4640403628251E24241A221F181A1A1014110A\
0A0A000502000100000D0D0B090B0A070908050706060807090B0A0D0F0E101211
0608070A0C0B0F11100F11100D0F0E0C0E0D0D0F0E1010101A1A1C121214110F12161618161417\
0B0B0D0503060404060E0C0F121214110F1209090B0806090B0B0D0B090C030305
020605010504010504060A090E1211131716141817131716080C0B0A0E0D0D11100F1312101413\
0F13120E12110D11120A0F120A0F120A0F120A0F120A0F120A0F120A0F120A0F12
080D10080D10080D10080D10080D10080D10080D10090D100D0E100D0D0D0B0B0B0A0A0A0A0A0A\
0B0B0B0D0D0D0E0E0E1010100D0D0D0B0B0B0C0C0C1010101111110F0F0F0C0C0C
0B0D0C090D0C0B0D0C090D0C0B0D0C090D0C0B0D0C090D0C0B0D0C090D0C0B0D0C090D0C0B0D0C\
090D0C0B0D0C090D0C
140E101610121812141C1618201A1C231D1F2620222822242D27292D27292D27292D27292D2729\
2D27292D27292C28292422232020201B1B1B1515151010100D0D0D0A0A0A0A0A0A
0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0D0E10070A11060A13060A13060A13060B11\
060B11060B11060B0F03080C050A0D060B0E070D0D0C12121218161218180E1213
1F20222E2E302D2D2F18181A0C0C0E1111131313150C0C0E0F0F110E0E100D0D0F0B0B0D0A0A0C\
0B0B0D0C0C0E0B0D0C0B100C0A100C090F0B090F0B080E0A080E0A080E0A080E0A
090F0B070D09040A06030905050B070A100C1016121419150E100D10100E1616141D1D1B222220\
2C2C2A4444425C5D58C5C6C1C4C5C0C2C3BEC0C1BCBDBEB9BBBCB7B9BAB5B9B9B1
B8B6A9BDBAABC1BEAFC5C2B3C5C2B3C2BFB0BEBBACBBB8A9BCB9AABDBAABBEBBACBFBCADBFBCAD\
BFBCADBEBBACBFB9ABBCB3AABBB2A9BBB1A8B8AFA6B7ADA4B4ABA2B4AAA1B2A9A0
BEB4ABBAB1A8B9AFA6B9B0A7BCB2A9BAB1A8B7ADA4B0AA9EB5B4A0B2B49EB2B49FB1B39EB1B2A0\
B0B19FAFB0A0AFB0A2B1B2A4AEAEA2AEAEA4B5B5ABC0C0B8C5C5BDC2C1BCBDBCB7
C3C6BFBAC0B6A1A49D767C72595C55474D43383B34252B211A1D16141A100F120B080E04070A03\
050B01090C05080D07090D0C090D0E090D0E090D0E090D0E090D0E090D0E090D0E
090D0E080C0D070B0C070B0C080C0D090D0E0B0F100D1112080C0F070C10080B10070C10070A0F\
060B0F070A0F060B0F0D10150B10140B0E13090E120A0D120A0F130C0F140D1114
040507060807080A09080A09080A09080A090A0C0B0C0E0D0D0F0E0D0F0E0D0F0E0D0F0E0D0F0E\
0D0F0E0D0F0E0D0F0E090D0E090D0E090D0E090D0E090D0E090D0E090D0E090D0E
090D0E090D0E090D0E090D0E090D0E090D0E090D0E090D0E1012111010100E0E0E0D0D0D0C0C0C\
0D0D0D0E0E0E0F0F0F2222220505050000002323231616160606061A1A1A000000
090909090B0A0B0B0B0B0D0C0C0C0C0A0C0B0A0A0A080A090B0B0B0A0C0B0C0C0C0D0F0E0F0F0F\
0F1110111111101211
21181B201A1C241B1E241E20281F222822242B22252A24262D24272B25272D24272B25272D2427\
2B25272D24272B25271F1D1E1C1C1C1717171313130F0F0F0C0C0C0B0B0B0A0A0A
0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0D0E10070A13060A15060A15060A13060A13\
060B11060B11060B0F0C11150F14170F15150B11110A100E0E1412141A18191D1C
292A2C2F2F312525271010120505070B0B0D0D0D0F0707091010121010120F0F110E0E100F0F11\
101012121214121413080E0A061008080F08061008080F08071109091009071109
060D06040E06070E070711090D140D111B131920191C231C2628231819141F1F1D2E2F2A1F1F1D\
1415104C4C4A9D9E99BEBEBCBEBFBABEBEBCBDBEB9BCBCBABCBDB8BBBBB9BCBBB6
C5C3B7C2BFB0BEBBACBAB7A8B8B5A6B9B6A7BBB8A9BDBAABB8B5A6B9B6A7B9B6A7B9B6A7B8B5A6\
B6B3A4B4B1A2B5AFA3B7AFA4B8AEA5B8AEA5B7ADA4B6ACA3B6ACA3B5ABA2B5ABA2
A49A91A1978EA1978EA59B92ADA39AB4AAA1B7ADA4B6AEA1ABAA96A8AC95A9AC97A9AC97AAAD9A\
ABAE9BACAF9EACAEA0CED0C3C5C7BCBCBDB5B6B7B1B2B3ADA9AAA59C9D9890928D
646963616860505750353C34242B241F261E181F180E150D141B1410170F0B120B070E06040B04\
050C04070E07080F08080E0C080E0E080E0E080E0E080E0E080E0E080E0E080E0E
080E0E070D0D060C0C060C0C070D0D080E0E0A10100C11140E13170B13160C1117081013080D13\
040C0F050A10020A0D060B11040C0F050A1001090C02070D00080B01060C01060A
1112141616161717171414140F0F0F0C0C0C0D0D0D1111110E0E0E0E0E0E0E0E0E0E0E0E0E0E0E\
0E0E0E0E0E0E0D0F0E0B0D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C1010100F0F0F0E0E0E0C0C0C0C0C0C\
0D0D0D0E0E0E0F0F0F1E1E1E1A1A1A0C0C0C2121211C1C1C0A0A0A2222221D1D1D
0D0D0D0E0E0E0E0E0E0F0F0F0E0E0E0D0D0D0C0C0C0B0B0B0A0A0A0A0A0A090909080808070707\
070707060606060606
272123252122262022252122251F21242021251F21231F20221C1E211D1E221C1E211D1E221C1E\
211D1E221C1E211D1E1816171515151212120F0F0F0D0D0D0B0B0B0B0B0B0B0B0B
0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0D0E10080B14070B16070B14070B14070B14\
070C12070C12070C10070C10090E11090F0F070D0D050B09080E0C141A18202423
2E2F3127272917171908080A0606080E0E101414161414160A0A0C0A0A0C09090B09090B0B0B0D\
0D0D0F0F0F11101211080D09080F080A0F090A110A0C110B0C130C0E130D0E150E
1A1F191A211A1C211B1D241D20251F212821232822242923171914191A142829243B3C363E3F3A\
4A4B4580817CBDBEB8B8B9B4B8B9B3B9BAB5BABBB5BBBCB7BCBDB7BCBDB8BEBEB6
BFBDB1BEBAAEBCB8ACBBB7ABBCB8ACC0BCB0C4C0B4C7C3B7C1BDB1C1BDB1C1BDB1C0BCB0BEBAAE\
BBB7ABB8B4A8B6B2A6BDB6AEBEB5AEBDB4ADBCB3ACBBB2ABBAB1AAB9B0A9B9B0A9
BBB2ABBBB2ABBDB4ADC1B8B1C2B9B2BDB4ADB4ABA4ABA49ABEBFAFBCBFAABCBFACBBBEABBABDAC\
B9BBADB8BAADB8BAAF73746C6A6B655E5F595556514D4E4941413F30302E222421
1C211D1C231C151B17091009050B070910090B110D070E070F15110D140D090F0B060D06050B07\
060D06090F0B0A100C080E0C080E0E080E0E080E0E080E0E080E0E080E0E080E0E
080E0E070D0D060C0C060C0C070D0D080E0E0A10100C12120A0F12090E110A0D12080D10080B10\
060B0E06090E050A0D0D10150D12150F12170F14171013180E13160E11160D1114
0506080A0A0A0D0D0D0D0D0D0B0B0B0B0B0B0E0E0E1111110E0E0E0E0E0E0E0E0E0E0E0E0E0E0E\
0E0E0E0E0E0E0D0F0E0B0D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C0F0F0F0E0E0E0D0D0D0C0C0C0C0C0C\
0D0D0D0F0F0F1010100B0B0B4444444747475454544C4C4C111111000000000000
0F0F0F0F0F0F0E0E0E0D0D0D0C0C0C0B0B0B0A0A0A090909161616151515151515151515141414\
141414131313131313
211F20201E1F1E1C1D1C1A1B191718171516151314141213110F10110F10110F10110F10110F10\
110F10110F10110F101010100F0F0F0D0D0D0B0B0B0A0A0A0B0B0B0B0B0B0C0C0C
0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0D0E10090C13080C15080C15080C15080D13\
080D13080D11080D1002070A000404000505070D0B0D13111117151A201E242827
38393B2727291313150A0A0C0B0B0D0E0E101111131414160C0C0E0C0C0E0A0A0C0A0A0C0A0A0C\
0B0B0D0D0D0F0E0E0E0B0D0A0C0E090D0F0A0F110C11130E131510141611151712
0D0F0A0F110C1315101719141A1C171C1E191D1F1A1D1F1A1D1E182D2E262B2C2427282056574F\
A2A39BC0C1B9B0B1A9B6B7AFB7B8B0B7B8B0B8B9B1B8B9B1B9BAB2BABBB3BBBBB1
B7B5A9BBB7ABBEBAAEC1BDB1C2BEB2C0BCB0BDB9ADBBB7ABBCB8ACBCB8ACBCB8ACBCB8ACBAB6AA\
B8B4A8B6B2A6B4B0A5A7A29CA8A39FAAA5A1ACA7A3AFAAA6B2ADA9B4AFABB5B0AC
BEB9B5BFBAB6BFBAB6BAB5B1A9A4A08D88846C676355524B1A1A0E17190B1416080F1103090B00\
04060001020000010018191314151011110F1414121818181616160C0C0E020403
1115140F15110B110F060C08050B09090F0B0B110F0B110D0A100E090F0B070D0B060C08060C0A\
080E0A0A100E0B110F080E0C080E0E080E0E080E0E080E0E080E0E080E0E080E0E
080E0E070D0D060C0C060C0C070D0D080E0E0A10100D1112090A0C0A0B0D0B0C0E0C0D0F0E0F11\
0F1012111214111214040507060709090A0C0C0D0F0D0E100C0D0F0B0C0E0A0B0D
0C0C0C0909090707070909090E0E0E1111110F0F0F0C0C0C0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E\
0E0E0E0E0E0E0D0F0E0B0D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C0E0E0E0E0E0E0D0D0D0C0C0C0D0D0D\
0E0E0E1010101111113B3B3BA9A9A9B9B9B9BBBBBBB1B1B15252521616161A1A1A
1616161515151313131111111010100F0F0F0F0F0F0F0F0F0D0D0D0E0E0E0F0F0F111111121212\
141414151515161616
1B1D1C191B1A1719181315141012110D0F0E0A0C0B090B0A090B0A090B0A090B0A090B0A090B0A\
090B0A090B0A090B0A0C0C0C0B0B0B0A0A0A0909090909090A0A0A0C0C0C0D0D0D
0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0D0E10090C13090C15090C15090C13090C13\
090C13090C11090D100E12150206070004051014131C201F1E231F1F2420242925
3B3D3C262626161616161616141414090909040404080808171717161616141414121212111111\
1111111111111212120D0C0A0E0D090F0E0A11100C13120E151410161511171612
14130F1716121D1C1823221E2928242D2C282F2E2A302F2A3D3E3643453A33352A2C2E2365675C\
B9BBB0CED0C5AEB0A5B9BBB0B9BBB0B8BAAFB8BAAFB7B9AEB6B8ADB6B8ADB7B7AB
BFBDB1BFBDB1BEBCB0BCBAAEBAB8ACB7B5A9B5B3A7B3B1A5BFBDB1BFBDB1C0BEB2C1BFB3C0BEB2\
BFBDB1BDBBAFBCB9B0B4B3AFB5B4B2B6B5B3B7B6B4B8B7B5B9B8B6B9B8B6BAB9B7
BFBEBCBAB9B7B1B0AEA3A2A08E8D8B72716F545351403F3B24251D22231B1E1F17191A1214150F\
0F100A0B0C07090A050808060707050B0B0B1515151F1F212323251D1C2115161A
1216170E12110A0E0F090D0C070B0C050908060A0B090D0C080C0D080C0B070B0C070B0A080C0D\
090D0C0A0E0F0B0F0E090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C
090D0C080C0B070B0A070B0A080C0B090D0C0B0F0E0F111010100E11100E11100E12110F12110F\
13121013121014131112110F13121013121013121012110F11100E100F0D0F0E0C
1B1B1B1313130C0C0C0E0E0E1515151717171010100808080E0E0E0E0E0E0E0E0E0E0E0E0E0E0E\
0E0E0E0E0E0E0D0F0E0B0D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C0D0D0D0D0D0D0C0C0C0C0C0C0D0D0D\
0F0F0F111111121212333333AFAFAFB5B5B5A7A7A7A5A5A54D4D4D1111111C1C1C
1E1E1E1C1C1C1919191717171616161717171818181919191A1A1A1B1B1B1C1C1C1D1D1D1E1E1E\
1F1F1F202020202020
161A191319171216150E14120C100F090F0D070B0A050B090A0E0D090F0D0A0E0D090F0D0A0E0D\
090F0D0A0E0D0A0E0D0B0D0C0B0B0B0A0A0A0909090909090A0A0A0C0C0C0D0D0D
0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E100C0C140A0D140A0D140A0D140A0D14\
0A0D120A0E110A0E0F1317180307060105041015111A1F1B171C181A1F1B282A27
3232322323232525253737373636361E1E1E1212121A1A1A181818161616151515131313121212\
1313131313131514121713101814111A15121A16131C17141C18151E19161E1A17
322D2A312D2A322D2A312D2A322D2A312D2A322D2A312E293333293A3C2F56584B818376A2A497\
B0B2A5B6B8ABBBBDB0BABCAFBABCAFB9BBAEB8BAADB7B9ACB6B8ABB6B8ABB5B7AA
C2C2B8C1BEB5BCB9B0BAB7AEBCB9B0C2BFB6C9C6BDCECBC2B9B6ADB9B6ADB9B6ADB9B6ADB8B5AC\
B5B2A9B3B0A7AFAFA7BDBDBBB6B7B9ACADAF9E9FA190919382838578797B727375
4B4C4E4041433031332324261B1C1E1617191213150E100F0E0E0C0E0F0A0D0E090C0D080B0B09\
0A0A080A0A0A0909090F0F110D0D0F0D0C1113121719181D17161C0D0C12030208
101115080C0D060A0B090D0E090D0E0408090408090A0E0F070B0C070B0C070B0C080C0D080C0D\
080C0D090D0E090D0E090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C
090D0C080C0B070B0A070B0A080C0B090D0C0B0F0E0F110E0F0E0A100D08100B080E0B060D0805\
0B08030B060309060119141116130E140F0C110E09110C09100D08110C09110D0A
0807050707070707070909090A0A0A0C0C0C0C0C0C0C0C0C0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E\
0E0E0E0E0E0E0D0F0E0B0D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C0C0C0C0C0C0C0B0B0B0C0C0C0D0D0D\
0F0F0F121212131313444444BDBDBDC3C3C3B7B7B7B9B9B96B6B6B2828281E1E1E
1A1A1A1818181515151414141414141616161919191B1B1B222222222222222222232323232323\
232323232323232323
0E14120C15120C121009120F090F0D060F0C060C0A040D0A0B110F09120F0B110F09120F0B110F\
09120F0B110F0B110F0C0E0D0C0C0C0B0B0B0A0A0A0A0A0A0B0B0B0C0C0C0D0D0D
0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E100D0E130D0D150D0D150D0E130D0E13\
0D0E120D0E120D0E101415170B0D0C0C0E0D171916181A171618132C2E294C4E49
5E5E5C5656546565637E7E7C71716F4242402727252C2C2A1C1C1A1B1B191B1B191C1C1A1E1E1C\
21211F232321262523302B28302B28322A28312C29332B29312C29332B29312C29
2F27252E2926312927322D2A3A32303F3A37473F3D494440525246646658919385C0C2B4CACCBE\
B7B9ABB0B2A4BCBEB0B8BAACB8BAACB8BAACB9BBADBABCAEBABCAEBBBDAFBBBDB0
BFBFB7BFBFB7C0C0B8BEBEB6B9B9B1B2B2AAABABA3A7A79FCBCBC3CBCBC3C9C9C1C6C6BEC2C2BA\
BDBDB5B8B8B0B4B5B0606163575B5E4B4F523B3F422A2E311B1F220F1316080C0F
171B1E0F131605090C00040703070A090D100E12151014170E0F110F0F11101012111113121116\
12111613121713121717161C15141A15141A1A191F1D1C221918200D0C14010006
0F101408090D07080C0F1014101115090A0E0A0B0F121317090A0E090A0E0A0B0F0A0B0F0A0B0F\
090A0E08090D07080A0B0D0C0B0D0A0B0D0A0B0D0A0B0D0A0B0D0A0B0D0A0B0D0A
0B0D0A0A0C09090B08090B080A0C090B0D0A0D0F0C10100E13100B15100A18100D17120C1A120F\
19140E1C14111B1610120A070F0A04100805100B05170F0C1D181228201D2C2723
2A29273636363D3D3D2D2D2D1010100000000606061414140E0E0E0E0E0E0E0E0E0E0E0E0E0E0E\
0E0E0E0E0E0E0D0F0E0B0D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C0B0B0B0B0B0B0B0B0B0C0C0C0D0D0D\
101010121212141414454545ADADADB3B3B3AEAEAEB8B8B87E7E7E3F3F3F1D1D1D
2626262424242121212020202222222626262A2A2A2D2D2D2222222424242727272B2B2B303030\
343434373737383838
050E0B050E0B040D0A030C09030C09020B08020B08010A07060F0C060F0C060F0C060F0C060F0C\
060F0C060F0C080E0C0E100F0E0E0E0C0C0C0B0B0B0A0A0A0B0B0B0C0C0C0D0D0D
0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E100E0D130D0E130E0D130D0E120E0D12\
0D0E100E0E100D0F0E1B1B1B181A17222220292B2624252025272251524D858681
B5B6B1ABACA7B7B7B5C5C6C19F9F9D52534E2222201F201B2D2D2B2E2F2A2F2F2D33342F373735\
3C3D3841413F44433F4843404A424049413F49413F48403E48403E48403E48403E
3D3533433B39514947665E5C8078769A9290B0A8A6BBB6B2BABAB0C4C6B8C0C2B5B0B2A4AEB0A3\
BDBFB1C0C2B5B5B7A9B4B6A9B5B7A9B7B9ACB9BBADBBBDB0BEC0B2C0C2B5C1C3B6
BFC0BAC5C6C0CAC9C5C1C2BCA9A8A480817B5958543F403A25242022231D201F1B191A1413120E\
0A0B050504000001000A0E11070F120A0F150911140C11170B13160D12180C1417
0B10160810130A0F150B131610151B0C1417090E1404090D0E0F140E0D130E0D130D0C120C0B11\
0C0B110B0A120B0A1205040C05040C09081013121A1C1B231C1B2313121A09080E
100F1406070B07060B0F1014100F1407080C08070C1011150A090E0A0B0F0C0B100B0C100B0A0F\
08090D08070C0506080C0C0A0B0D080C0C0A0B0D080C0C0A0B0D080C0C0A0B0D08
0C0C0A0A0C070A0A08090B060B0B090B0D080E0E0C11100C221D1927201A2C251F332C263A332D\
403933453E3848413B443D37443D3748413B514A445F5852726B65837C768B8682
91908EA4A4A4A5A5A57878783232320404040505051919190E0E0E0E0E0E0E0E0E0E0E0E0E0E0E\
0E0E0E0E0E0E0D0F0E0B0D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C0B0B0B0B0B0B0B0B0B0B0B0B0D0D0D\
1010101313131414147D7D7DC6C6C6B7B7B7AFAFAFC7C7C7B9B9B9A0A0A0838383
4444444242424040403F3F3F4141414646464C4C4C5050505B5B5B6060606767677272727D7D7D\
8787878E8E8E939393
060F0C060F0C050E0B050E0B050E0B07100D09120F0A1310000603000805020B08050E0B07100D\
08110E08110E0A100E1A1C1B0909090E0E0E1515150B0B0B0E0E0E1616160C0C0C
1111111010100E0E0E0B0B0B0A0A0A0A0A0A0A0A0A0A0A0C0E0D120F0E130F0D120C0B100C0A0F\
0E0E101614171B1B1B1C1A1B1E1E1C25242226272228272337383261605B888983
AEAFA9AAABA5B4B5B0BBBCB69A9B965C5D572E2F2A22231D2D2E2930312B353631393A343A3B36\
393A343738333635314D48455149475149474D454348403E443C3A443C3A463E3C
4A4240534B49635B59766E6C8C8482A49C9AB9B1AFC5C0BCC9C9BFC2C4B7BABCB1B4B6A9B5B7AC\
BBBDB0C4C6BBCACCBFBBBDB2BEC0B3BFC1B6BFC1B4C3C5BAC5C7BAC1C3B8B9BBB0
BDBEB9BFC1BCB7B7B59EA09B8383816769644B4B4932342F20201E1B1D181515130E100B0B0B09\
0A0C070C0C0A0B0F0E0A0F13071015080F17071015080F17071015080F17071015
080F17071015080F17071015080F17071015080F170A0E170B0B150C0A150C0B130C0B130C0B13\
0C0B130C0A150C0B1308070F0B0A120B0A12201F2734333B1D1C2402010908070D
09080D09090B0B090C0A0A0C0C0A0D0C0C0E0D0B0E0C0C0E0F0D100E0E100E0C0F0D0D0F0D0B0E\
0B0B0D0C0A0D0B0B0B0E0D090C0D070A09050809030A09050C0D07100F0B12130D
0E0D0910110B15141018191319181415161013120E100F0A26211B322B253D3630413A34413A34\
463F39534C465E57515D56505D565060595367605A746D67857E78968F899E9995
B0AFADA4A4A4B2B2B29292921C1C1C1212120101011212120C0C0C0C0C0C0C0C0C0C0C0C0C0C0C\
0C0C0C0C0C0C0B0D0C0B0D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C
0509080509080509080509080509080509080509080509080909090D0D0D1010100F0F0F0C0C0C\
0D0D0D1515151C1C1C919191ADADADBEBEBEB7B7B7B3B3B3B6B6B6A8A8A8929292
5B5B5B5454544F4F4F5050505858586060606363636262626262626767676E6E6E7575757A7A7A\
7C7C7C7B7B7B7A7A7A
060C0A030C09030907000906010705000805020806010A070E14120B14110C121009120F0A100E\
060F0C080E0C070D0B0305040000000202020C0C0C0404040B0B0B1616160E0E0E
0F0F0F0E0E0E0D0D0D0C0C0C0C0C0C0D0D0D0F0F0F101010131114201E23312F343B393C383639\
2E2C2D2220211A1917141311191814201F1B23221D28272246463E83837BBBBBB3
BABBB5AFB0AAB0B1ABB6B7B19E9F9966676135363021221C3839333A3B353D3E3841423C464741\
4B4C4650514B53524D423D3A4A4542574F4D605B586C646275706D827A78888380
9E9694A8A3A0BAB2B0C4BFBCC8C0BEBEB9B6B5ADABACA7A3B6B6AEB8B9B1BCBDB5BDBEB6BBBCB4\
B4B5ADADAEA6A8A9A1C9CAC2C5C6BEBBBCB4AEAFA7A1A29A93948C82837B757670
5658555A5C595153523A3C392224231315120608070001001416151214110F11100C0E0B0B0D0C\
0B0D0A0D0F0E0C1011081013071015080F17071015080F17071015080F17071015
080F17071015080F17071015080F17071015080F170A0E170B0B170C0A170C0A150C0A150C0A15\
0C0A150C0A150C0B1319182017161E1110181D1C222B2A3016151B020107100F14
0B090C0B090A0B090A0B090A0A08090A08090A08090A08090D0B0C0C0A0B0B090A090708070506\
0604050402030403010D0C080D0C070E0D0811100B14130E1918131C1B161F1E19
12110C1615101E1D182625202C2B262F2E29302F2A312E2958534F65605A756D6A7C7771807875\
847F7990888598938DB1A9A6B3AEA8BCB4B1C2BDB7CCC4C1D0CBC5D6CECBD6D1CD
CECDCBCFCFCFD9D9D99C9C9C0D0D0D0404040000001B1B1B0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C\
0C0C0C0C0C0C0B0D0C0D0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E
070B0A070B0A070B0A070B0A070B0A070B0A070B0A070B0A0B0B0B0E0E0E1010100F0F0F0E0E0E\
1111111A1A1A222222909090ACACACC0C0C0C2C2C2C7C7C7D2D2D2CECECEBEBEBE
BEBEBEB3B3B3A3A3A39797978D8D8D8484847A7A7A7373736E6E6E6A6A6A616161555555464646\
363636282828212121
1115140F15130F13120C12100D11100C12100F13120E14120A0E0D070D0B060A09030907040807\
050B09080C0B0A0E0D0D0F0E0909091616161A1A1A0B0B0B0E0E0E191919101010
111111111111111111111111131313151515171717191919201E212722262B262A2C272B292428\
272324272324282423373332312D2A33302B423F385A57507A7770A5A29BC5C5BB
B8B9B1AAABA3A9AAA2B7B8B0B3B4AC92938B6E6F675D5E5646473F45463E45463E4849414E4F47\
56574F5E5F5764635E85817E8C888597928F9E9A97A7A29FAEAAA7B9B4B1BFBBB8
C9C4C1C3BFBCBDB8B5B7B3B0B7B2AFBAB6B3C1BCB9C5C1BEC4C3BEC7C8C2CCCDC7CECFC9C8C9C3\
BCBDB7AFB0AAA7A8A2585953575852575852595A54595A5452534D48494341423D
4749484A4E4D4044452529280E1213080C0B0B0F100C100F060A0B070B0A080C0D090D0C0A0E0F\
0C100F0D11120E12130A0F130810130A0F150810130A0F150810130A0F15081013
0A0F150810130A0F150810130A0F150810130A0F150A0F150B0B150C0A170C0A170C0A170C0A15\
0C0A150C0B130C0B130D0C14111016100F151F1E232D2C3118171C09080D1A1A1C
0C0A0B0F0B0A0F0B0A100C0B110D0C110D0C120E0D120E0D0B07060D0908100C0B1511101A1615\
1E1A19221E1D24201D24211C27241D2D2A233330293A37303E3B34423F38434039
5E5B546360596B68617370697A77707F7C75817E77827F7AA09D98ABA8A3B9B4B1C0BDB8C3BEBB\
C6C3BECEC9C6D4D1CCD1CCC9D0CDC8D1CCC9CDCAC5CBC6C3C5C2BDC1BCB9BDB9B6
BAB9B7C2C2C2CBCBCB8888880101010909090707071515150D0D0D0D0D0D0D0D0D0D0D0D0D0D0D\
0D0D0D0D0D0D0C0E0D0D0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C0B0B0B0D0D0D0E0E0E0E0E0E101010\
1616161F1F1F272727C6C6C6D0D0D0C8C8C8AAAAAA8F8F8F7D7D7D676767505050
5151514A4A4A4040403737372E2E2E2525251B1B1B1414140C0C0C0C0C0C0C0C0C0C0C0C0C0C0C\
0C0C0C0C0C0C0B0B0B
090B0A080A09070908060807070908090B0A0A0C0B0B0D0C0B0D0C080A09040605010302010302\
040605080A090B0D0C1E1E1E2121213131312D2D2D1616161818182424241C1C1C
1919191818181818181818181919191C1C1C1E1E1E201E1F2B262A292428241F231F1B1C1E1A1B\
252120312D2C3B37344C48453E3B3645423B706D66A19E97B7B4ABB2AFA6A8A59C
B2B2AAA6A79FA6A79FB4B5ADBBBCB4B1B2AAA5A69EA2A39BAAABA3AAABA3A9AAA2AAABA3ACADA5\
B0B1A9B4B5ADB7B8B0AFAEA9B3B2AEB8B7B3BAB9B5BAB9B5BCBBB7C0BFBBC4C3BF
BFBEBAC3C2BEC7C6C2C0BFBBA8A7A381807C5554503938341E1E1C1A1A181414120C0C0A070705\
0303010202000101000808060C0C0A1C1C1A3535334848464F4F4D51514F525453
4D5152525657484C4F292D2E0E1215080C0D101417161A1B04080B05090A080C0F0B0F100D1114\
0D11120D11140D11140B0F120A0F120B0E130A0F120B0E130A0F120B0E130A0F12
0B0E130A0F120B0E130A0F120B0E130A0F120B0E130B0E130B0B150C0A170C0A170C0A150C0A15\
0C0B130C0B130C0B110201070C0B1013121725252731313118181803030312110F
231F1C25221D2926212D2A25322F2A37342F3B38333D3A353F3C3745423D504D485F5C576F6C67\
7D7A758986818F8C87A7A49DACA9A2B3B0A9BAB7B0C0BDB6C4C1BAC5C2BBC6C3BC
B7B4ADB9B6AFBCB9B2BFBCB5C1BEB7C1BEB7C0BDB6C0BDB8AEADA9B3B2B0B7B6B4B8B7B5B7B6B4\
B8B7B5BDBCBAC3C2C0C3C2C0C1C0BEC0BFBDC0BFBDC4C3C1CAC9C7D0CFCDD4D3D1
C9C9C9CBCBCBC9C9C98686860F0F0F1F1F1F0808080000000E0E0E0E0E0E0E0E0E0E0E0E0E0E0E\
0E0E0E0E0E0E0D0F0E0C0E0D0A0E0D0A0E0D0A0E0D0A0E0D0A0E0D0A0E0D0A0E0D
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C0B0B0B0B0B0B0C0C0C0D0D0D111111\
1818182020202626260000000202020A0A0A0707070808081111111414140F0F0F
0D0D0D0E0E0E1010101212121515151616161414141313130F0F0F0E0E0E0D0D0D0D0D0D0E0E0E\
0F0F0F111111131313
121011110F100F0D0E0D0B0C0C0A0B0D0B0C0D0B0C0E0C0D121011100E0F0D0B0C0B090A0D0B0C\
110F101715161A18192929293333334545453838381919191B1B1B2B2B2B242424
1F1F1F1E1E1E1D1D1D1D1D1D1E1E1E2020202222222422232521222E282A3731333D37393F393B\
403A3A433D3D46413E433E3B46413D615C56938E88BCB8AFC4C0B7B4B0A7A4A296
B0B0A6A9ABA0A7A99EAAACA1AAACA1A9ABA0AFB1A6B8BAAFB3B5AAB5B7ACB8BAAFBABCB1BBBDB2\
BABCB1B8BAAFB6B7AFB9BCB5BCBEB9BFC1BCC0C2BDBEC0BBBEC0BBC1C3BEC4C6C1
C8CAC5C4C6C1BCBEB9ABADA88E908B656762393B361C1E1B2626261F1F211616180D0D0F0A0A0C\
0C0C0E1111131515171010121111132121233D3D3F4E4E504D4D4F4B4B4D4D4E50
3A3E414146493B40441F2427050A0E00020500050904090C080D11090E110B10140D12150D1216\
0C11140B10140B0F120B0F120B0F100D0E120B0F100D0E120B0F100D0E120B0F10
0D0E120B0F100D0E120B0F100D0E120B0F100D0E120D0E120C0B130C0A150C0A150C0A150C0B13\
0C0B110C0B110C0B1010101215151515151524242232332E1C1D180A0B061A1914
2A27202E2A213531283E3A3148443B514D4457534A5B574E524E4558544B635F56726E65827E75\
908C839B978EA29E95B6B2A9B9B5ACBEBAB1C3BFB6C6C2B9C7C3BAC7C3BAC6C2B9
CBC7BECBC7BECAC6BDC8C4BBC6C2B9C3BFB6C0BCB3BEBBB6B9B9B9B6B7B9B3B4B6AEAFB1ACADAF\
AFB0B2B6B7B9BCBDBFC2C3C5C1C2C4BFC0C2BCBDBFBABBBDB8B9BBB7B8BAB6B7B9
B7B7B7BDBDBDBEBEBE7B7B7B0606061D1D1D1313130E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E\
0E0E0E0E0E0E0D0F0E0A0C0B080C0B080C0B080C0B080C0B080C0B080C0B080C0B
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C0C0C0C0B0B0B0C0C0C0F0F0F141414\
1A1A1A1E1E1E1F1F1F0C0C0C1212121212120A0A0A050505060606070707050505
0808080909090C0C0C0C0C0C0B0B0B0A0A0A0909090909091010100E0E0E0B0B0B080808050505\
040404030303030303
140E10120E0F110B0D0F0B0C0F090B0F0B0C110B0D110D0E0E080A100C0D181214221E1F312B2D\
3E3A3B4B4547514D4E6260616D6D6D7676765555552222221A1A1A2626261E1E1E
2727272727272727272828282A2A2A2D2D2D3030303331322B27282E282A312B2D332D2F373131\
403A3A4C474455504C635E5A79746E9A958FB0ACA3AFABA2A5A198AAA69BB6B4A8
A9A99FA8AA9FA7A99EA4A69BA1A398A4A69BAFB1A6B9BBB0A7A99EAAACA1AEB0A5B2B4A9B3B5AA\
B0B2A7ADAFA4A9ACA3B7BCB5B3BAB3ACB1AB9CA39C8C918B7C837C757A74717871
474C46313831161B15040B040308020A110A131812171C180B0C100C0B110C0B110C0B110B0A10\
0A090F08070D07060C0B0A1009080E1B1A203B3A404A494F444349403F4544454A
2C2F34353A3E34393D22272B1015190B10140C11150C11150D12160C11150C11150B10140B1014\
0A0F130A0F130B0E130D0E100D0F0E0E0E100D0F0E0E0E100D0F0E0E0E100D0F0E
0E0E100D0F0E0E0E100D0F0E0E0E100D0F0E0E0E100E0D120C0B130C0A150C0A150C0B130C0B11\
0C0B100C0B100C0C0E12121210100E0E0E0C262722494A444A4B434A4B43626258
5F5D516460546B675B7470647E7A6E8783778E8A7E918D81AFAB9FB0ACA0B4B0A4B8B4A8BDB9AD\
C2BEB2C5C1B5C7C3B8BEBAB1BFBBB2C1BDB4C2BEB5C2BEB5C2BEB5C1BDB4C0BCB3
BBB7AEBBB7AEBAB6ADBAB6ADB9B5ACB9B5ACB8B4ABB7B4AFC3C4C6BDC2C5B9BCC1B5BABDB6B9BE\
BABFC2C1C4C9C4C9CCBEC1C6C2C7CAC9CCD1CDD2D5CDD0D5C7CCCFC0C3C8BABEC1
CACBCDD2D2D2D4D4D48888880000000505050D0D0D2424240F0F0F0F0F0F0F0F0F0F0F0F0F0F0F\
0F0F0F0F0F0F0E100F0B0D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C
0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E1111111111111212121616161B1B1B\
1C1C1C1A1A1A1717170404040808080A0A0A0909090808080B0B0B101010141414
1111111212121212120E0E0E0909090505050505050707070909090C0C0C0F0F0F141414191919\
1E1E1E212121232323
0B02050B050711080B150F111E1518251F212D24272F292B453C3F494345554C4F615B5D72696C\
7E787A8B82858F898B9D9B9CA8A8A8A9A9A9787878363636272727313131292929
3737373838383B3B3B3F3F3F4444444A4A4A4F4F4F535152585455565052514B4D4E484A514B4B\
5F5959736E6B817C789E9995A9A49EB7B2ACB8B4ABA8A49B99958AA29E93B5B3A7
A9A99FA7A99EA5A79CA1A3989FA1969EA095999B9094968BB8BAAFB8BAAFB7B9AEB5B7ACB2B4A9\
AFB1A6ADAFA4AAADA4676E66606A62555C553F4941282F28121C14070E07000A02
1017100B150D0D140D101A12161D160E18100108010002000C0D12100F1714131B17161E17161E\
14131B100F170D0C140C0B130908101D1C2441404851505848474F424149484850
14171E1B20261A1F2510151B090E140B10160B1016080D130B10160A0F15070C12060B11060B11\
080D130A0F150D10150E0E100E0E0C0F0D0E0E0E0C0F0D0E0E0E0C0F0D0E0E0E0C
0F0D0E0E0E0C0F0D0E0E0E0C0F0D0E0E0E0C0F0D0E0E0E100C0B110C0B130C0B130C0B110C0B11\
0C0B100C0C0E0C0C0C0C0C0A0E0F0A191A1448494182837B919388929489A7A79B
B5B3A6B8B5A6BCB9AAC0BDAEC5C2B3CAC7B8CDCABBCFCCBDC5C2B3C4C1B2C3C0B1C1BEAFBFBCAD\
BEBBACBCB9AABCB8ACBFBBB0BEBAB1BCB8AFBAB6ADB9B5ACB9B5ACBAB6ADBAB6AD
B9B5ACB9B5ACBAB6ADBCB8AFBEBAB1C2BEB5C4C0B7C3C2BDB3B7B8AFB7BAAFB4BAADB5B8AFB4BA\
ACB4B7ACB1B7A8B0B3ADB2B8AEB6B9B4B9BFBAC2C5C4C9CFCCD4D7D5DAE0DADFE3
D1D2D4C6C6C6C4C4C48D8D8D0D0D0D0B0B0B0000000E0E0E101010101010101010101010101010\
1010101010100F11100F11100D11100D11100D11100D11100D11100D11100D1110
1115141115141115141115141115141115141115141115141A1A1A1A1A1A1C1C1C212121242424\
2222221818181010101313131313131313131111110C0C0C0909090C0C0C111111
0505050808080B0B0B0B0B0B0A0A0A0D0D0D1515151C1C1C1515151717171A1A1A1D1D1D1E1E1E\
1D1D1D1C1C1C1A1A1A
3A35323F3A374B46435A55526C67647D78758B8683938E8BACA7A4ADA8A5AEA9A6AFAAA7AEA9A6\
ACA7A4AAA5A2A8A4A1A09F9DAFAFADB4B4B28484824444423B3B394E4E4C494947
4848464A4A484F4F4D5555535E5E5C6666646D6D6B73726E8E8A87999592A9A5A2B4B0ADB7B4AF\
B4B1ACB1AEA7B0ADA6B0ADA6A3A0999E9B92A7A49BAEABA2ACA9A0A7A49BA6A39A
B6B6AEAEAFA7A3A49C9A9B9392938B83847C6869614F5048292A2224251D1B1C1411120A090A02\
050600030400010400131814141A18151B191218160D13110A100E0A100E0D1311
0B110F0309070002000006040A100E0F15130C1210070B0C101116100F170F0E160D0C140D0C14\
0E0D15100F1711101816151D0E0D1519182033323A37363E21202812111914131B
13141815191C15161A0A0E110B0C100F13161213170B0F120B0C10060A0D05060A010508040509\
070B0E0E0F131112140E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E
0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E100C0B110C0B130C0B130C0B110C0B11\
0C0B100C0C0E0C0C0C17171522231E3A3B3576776FB6B7AFBCBEB3ABADA2B1B2A4
B3B2A0B3B2A0B3B2A0B3B2A0B2B19FB2B19FB2B19FB2B0A1C0BEAFBFBDAEBFBDAEBEBCAFBEBCAF\
BDBBAEBDBBAEBDBBAFBFBCB3BBBBB1B9B6ADB5B5ABB6B3AAB5B5ABB9B6ADB8B8AE
B8B5ACB6B6ACBAB7AEBABAB0BFBCB3C2C2B8C7C4BBC7C8C2CACECFC9CED2CBD0D4CBD0D4C8CDD1\
BFC4C8B3B8BCABB0B4A0A5A9888D9162676B3B404421262A161B1F171C201C2023
1213150000001919193131310707072C2C2C1A1A1A161616101010101010101010101010101010\
101010101010101010131512131512131512131512131512131514131514131514
181A1918191B18191B18191B18191B18191B18191B18191B2121232121212422252929292D2B2E\
26262619171A0D0D0D110F1212121219171A2121212624272929293331343B3B3D
4747494C4C4E51505553535556555A5E5E606C6B707676787B7A7F838385908F949E9EA0AAA9AE\
B3B3B5B8B7BCB9B9BB
3D3D334B4B415E5E546F6F657A7A7085857B90908698988EAAAAA0ACACA2AFAFA5B1B1A7B1B1A7\
AEAEA4ABABA1A8A89EA4A59DA7A8A0A0A19985867E62635B4B4C444A4B4351524A
56574F56574F5758505C5D5565665E71726A7C7D7583857A8D8D819B9C8EAAAB9DAFB0A2ACACA0\
AAAA9EADADA1B2B2A6A9A99FA6A69CA3A39BA3A39BA6A69EA6A69EA3A39BA09F9A
AFB0AB9F9F9D8A8A887A7A786E6E6C60605E4E4E4C40403E1E1E1C1A1A181414120E0E0C0C0C0A\
0D0D0B0F0F0D11111116171B20212621222715161B0B0C110C0D120E0F140D0E13
05060B06070C07080D090A0F0A0B100C0D120D0E130E0F1409080E0B0A100E0D13100F15100F15\
0F0E140C0B110A090F0B0A1016151B25242A2D2C322A292F22212719181E141416
12110F100F0A0F0C070A09040C09040B0A05100D08100F0A15120D0E0D0816130E05040017140F\
1D1C1703000013120E0B0C0E090D10090D10090D10090D10090D10090D10090D10
090D100A0E110B0F120C10130C10130A0E11080C0F070A0F0A091108070F07060E07060C09080E\
0C0B100D0D0F0D0D0D0D0D0B0C0D0837383285867EB3B4ACAEB0A5A5A79CABAD9F
ABAC9AAEB09BB2B49FB6B8A3BABBA9BDBEACBEBFAFBEBFB1B6B6AAB5B5A9B9B9AFC0C0B8C4C4BC\
C0C0B8BBBAB5B8B9B3B0B3AAABB1A7AAADA4AAB0A6B1B4ABB2B8AEB5B8AFB1B7AD
C1C4BBB8BEB4B6B9B0B8BEB4C1C4BBC0C6BCB9BCB3B0B3ACBFC1C0B5B6B8A9AAACA2A3A59FA0A2\
9C9D9F9697999091937C7D7F6F707247484A28292B212224151618101113222325
1313130909091212122828282B2B2B1A1A1A161616212121131313131313131313131313131313\
13131313131313131119181417161114130F13120E13120E1615131917181B191A
1B191C1B191E1A171E1A171E1B18211D1A231F1C25211E272D2B302C2A2D2D282E282629262127\
1F1D201C171D171518211C222220232B262C312F323C373D4341444B464C4D4B50
5958605B5B6361616B69697171717B7979817F7F8982828A9696A09999A19E9EA8A5A5ADABABB5\
AFAFB7B2B2BCB3B3BB
8284768B8D7F9597899C9E909FA193A2A496A8AA9CADAFA1A7A99BA7A99BA6A89AA5A799A3A597\
A2A496A0A294A0A294A8AA9FACAEA3AAACA19B9D9286887D797B70797B707F8176
82847986887D8B8D82929489999B909EA095A2A499A4A699A4A796ABAE9DB3B6A5B6B9A8B6B9A8\
B5B7A9B8BAACBABCAFC9CBC0BFC0B8AFB0A89FA09A8E8F897E7F796E6F6A646560
40403E3434342727272020201E1E1E1919190F0F0F0505051616161414141111110E0E0E0E0E0E\
0F0F0F1111111212140C0B111918201E1D2515141C0D0C140D0C140E0D150C0B13
15141C14131B121119100F170E0D150C0B130A091109081009080D09090B0A090E0A0A0C09080D\
07070905040904040607060B0D0D0F141318151517100F1409090B050409050304
13100B15110816120918140B1C180F201C13231F16252118211D14211D14312D242E2A21433F36\
4642391A160D1D1C170F10120C11150C11150B10140B10140A0F130A0F130A0F13
0B10140B10140B10140A0F130A0F13090E12080D11090C1112121A13111C13121A100F170E0D13\
0D0C110F0F111212121C1C1C27272551524D8B8C86ADAEA6AFB0A8ADAFA4B3B5A8
B3B6A3B1B49FAFB29FADB09DACAF9EACAF9EAEB0A2AEB0A3B9BBB0B8B9B1BABBB5BDBEB9BEBFBA\
BBBBB9B7B7B5B5B7B4CFD4CDC8D0C5C1C8C0BCC4B9BAC1B9B8C0B5B3BAB2AFB7AC
9EA59D91998E838A827A8277777E76727A6F686F675F645D3A3C393333332A2A2A262626252525\
2424242020201D1D1D1F1F1F2222221111110909091414140E0E0E0404040F0F0F
1111110606060C0C0C2323232828281818180F0F0F141414161616171717171717181818191919\
1A1A1A1A1A1A1B1B191F1C17221F1826231E2A27222D29262D29262C28292B2728
2D282C2D282E2E29302E28322F29352F2935302A38302A3618131A221D23332E34464147565157\
615C6267626869646A716C727570767B767C847F858D888E9691979C979D9E9BA2
A5A4ACA6A6B0A8A8B2ABABB5AEAEB8B1B1BBB4B4BEB5B5BFB2B2BCB2B2BCB3B3BDB3B3BDB1B1BB\
AFAFB9ADADB7ACACB6
A6A89AA9AB9DABAD9FAAAC9EA7A99BA6A89AA8AA9CAAAC9E9D9F919C9E909C9E909C9E909D9F91\
A0A294A2A496A4A69894968B999B909FA196A1A398A0A297A1A398A4A69BA7A99E
97998E9C9E93A3A59AA9ABA0A9ABA0A5A79C9FA1969B9D90AEB0A2A9AB9DA5A799A3A597A4A698\
A3A598A1A3989FA0986C6D6563645E54554F464742383934292A251B1B1911110F
1919191212120B0B0B0C0C0C1111111313131010100B0B0B0D0D0D0D0D0D0E0E0E0E0E0E0F0F0F\
10101011111112121419181D25242A28272D1D1C221211170E0D130C0B1108070D
09080E09080E09080E0A090F0A090F0A090F0B0A100B0A0F111113101010101012101010111113\
1212121414161616160707090A0A0A0E0E100F0F0F0F0F111111111717191D1C1A
24211A28241B2E2A213531283C382F413D3444403746423969655C69655C7A766D77736A848077\
706C6326221912110C0F10120C11150B10140A0F13090E12080D11070C10070C10
0E13170C11150A0F13080D11070C10070C10080D11090C1104040C0A09110E0D150E0D150C0B11\
0D0C111414161C1C1C1B1B1B3F3F3D70716C969791A6A79FA9AAA2A8A9A1A7A99E
B4B7A6B0B3A0ACAF9EAAAD9CACAEA0B3B5A8BBBDB0C1C3B8CDCEC6CDCEC8CCCDC8C9C9C7C6C6C4\
C4C4C4C2C2C2C0C2C17277716A7169616861596058545B544F564E495049444B43
353C35282F271A211A1219111219121219110E150E0B100A0F110E0B0B0B050505030303050505\
0707070707070505050909091111110606060404041717171616160A0A0A0F0F0F
1B1B1B1010101616163030303D3D3D3333332626262424241F1F1F202020212121232323252525\
27272729292929292724211C25221B27241F2926212C2825302C29322E2F343031
2F2A2E302B31312C33312C332F29332B252F27212D251F29544F55605B5F746F73898488999498\
A29DA1A5A0A4A5A0A4BAB5B9BBB6BABCB7BBBDB8BCBFBABEC0BBBFC1BCC0C0BEC3
C1C0C6C0C0C8C0C0C8C0C0C8C0C0C8C0C0C8C0C0C8C0C0C8B5B5BDB6B6BEB7B7BFB8B8C0B9B9C1\
B8B8C0B7B7BFB6B6BE
A2A496A2A496A1A395A0A2949FA193A0A294A3A597A5A799A9AB9DAAAC9EAAAC9EABAD9FAAAC9E\
A9AB9DA7A99BA6A89BA6A89DA4A69BA1A3989FA1969B9D9295978C8D8F8487897E
A0A297A2A499A3A59AA1A398999B908E90858284797A7C713F413432342723251A1D1F141D1F14\
1C1E1314150D0C0D0716171212130E0F0F0D0F0F0D1111111111110E0E0E0A0A0A
1616161111110D0D0D0D0D0D1111111414141212120F0F0F0A0A0A0C0C0C0D0D0D0F0F0F101010\
0F0F0F0E0E0E0E0E0E1313151D1D1F1D1D1F101012050507040406060608040406
0B0B0D0C0C0E0C0C0E0D0D0F0E0E100E0E100F0F110F0F0F0707070808060B0B0910100E181816\
21211F2929272E2E2C3F3F3D4646444F4F4D5858566262606D6D6B7B7B79858480
9E9B94A39F96AAA69DB1ADA4B7B3AABAB6ADBBB7AEBBB7AEB4B0A7AFABA2BAB6ADB2AEA5B6B2A9\
908C832F2B220B0A0515161811161A1015190F14180E13170C11150B10140B1014
151A1E13181C11161A0E13170D12160E13170F141812151A14141C1C1B232221292120261E1D22\
1F1E2328282A31313149494980807EB7B8B3C9CAC5C8C9C3C5C6BEBDBEB6B3B5AA
8F9184818375686A5D4E50433A3C312E3025292A222829211718121B1C171717150D0D0D070707\
070709070709030406191D1C1319150D130F0A100C090F0B080E0A050B07020804
0D130F070D09010703000602050B07090F0B0B110D0A0F0B1416151212120F0F0F0E0E0E0F0F0F\
1212121414141515152929292B2B2B1212120000000C0C0C0F0F0F0808080F0F0F
1616160D0D0D1515153131314747474545453838383131313A3A3A3B3B3B3D3D3D404040434343\
4646464949494A4A4855524D504D4649464146433E4A4643534F4C5E5A59656162
6F6A6E7974788B868CA09BA2B3AEB5C1BBC5CBC5CFCFCAD1C0BBC1C4C0C1CAC5C9CECACBCEC9CD\
CAC6C7C5C0C4C1BDBEC2BDC1C1BDBEC1BCC0C0BCBDBFBABEBEBABBBDB8BCBBB9BC
B7B7B9B6B7BBB6B7BBB6B7BBB6B7BBB6B7BBB6B7BBB6B7BBB7B8BCB8B9BDBABBBFBBBCC0BBBCC0\
BABBBFB9BABEB8B9BD
A7A99CA5A79AA4A699A5A79AA8AA9DABADA0ADAFA2AEB0A3A1A396A3A598A4A699A3A5989FA194\
989A8D9092858B8D809D9F949B9C949A9B939D9E969FA0989E9F9797989091928A
9D9E96999A9291928A86877F797A726B6C64606159595A522F312622241913140C10110914150F\
14150F0B0C070001000F0F0D0D0D0B0B0B0B0E0E0E121214141416131217111113
1313151010100C0C0C0B0B0B0C0C0C0D0D0D0C0C0C0A0A0A0E0E0E0E0E0E0F0F0F1010100F0F0F\
0D0D0D0C0C0C0A0A0A1D1D1B24242221211F1313110A0A0810100E1717151A1A18
18181617171516161414141213131111110F10100E0F100B0203000607010E0F09191A14282923\
37383244453F4C4D474B4C4654554F61625C6C6D677677717F807A898A84908F8A
A7A49DAAA7A0ADAAA3B1AEA7B2AFA8B1AEA7B0ADA6AEABA4B8B5AEB2AFA8BCB9B2B6B3ACBEBBB4\
9B98913A373015140F1A1B1D171B1E171B1E161A1D15191C14181B13171A13171A
171B1E171B1E161A1D15191C15191C161A1D171B1E171B1E17181D1C1B21212026201F241E1D22\
201F242727292E2E2E5D5D5D8D8D8BB0B1ACAAABA698999493948E8F908A85867E
7A7B736B6C6452534B38393123241E16171111120D10110C19191722222220202011111308080A\
0B0A0F0C0B1006070B0C1011090D0E060A0B070B0C0C10110F13140F13140D1112
181C1D161A1B1418191418191418191216170E12130B0F100F11100F0F0F0E0E0E0C0C0C0B0B0B\
0D0D0D1111111414141A1A1A2525251212120000000B0B0B1515151515151D1D1D
2626262020202626263D3D3D5252525555554949493E3E3E3D3D3D3E3E3E414141444444484848\
4B4B4B4E4E4E4F4F4D4C48454B48434B48434E4B4654504D5D59566561606A6665
888485908B8F9F9A9EAFAAB0BDB8BEC7C2C9CDC8CFD0CBD1CAC5C9C9C5C4C6C2C3C3BFBEC0BCBD\
BDB9B8BBB7B8B9B5B4BAB6B7BBB7B6BCB8B9BFBBBAC1BDBEC3BFBEC5C1C2C4C3C1
C0C0BEBFBFBDBEBEBCBDBDBBBBBBB9B9B9B7B8B8B6B7B7B5BDBDBBBBBBB9B8B8B6B3B3B1ADADAB\
A6A6A4A0A09E9D9D9B
A8AA9DA5A79AA4A699A5A79AA8AA9DA9AB9EA7A99CA4A6999FA194A2A497A7A99CABADA0ADAFA2\
ABADA0A8AA9DA6A89D9FA0989C9D9597989093948C8F9088898A8282837B7D7E76
5B5C5456574F4B4C443F403833342C292A2222231B1E1F1717181211120C0C0D0711120D191A15\
1B1B191313110909090F0F0F0C0C0E09090B09080D0B0A0F0B0A1009080E05040A
1414161313131111111111111111111212121414141515151212121111111010100F0F0F0E0E0E\
0E0E0E0D0D0D0D0D0B2425202A2B2524251F11120C040500040500090A040A0B05
0809030A0B050F100A14150F1B1C1620211B2526202728223D3E364244394B4C44585A4F676860\
75776C80817987897E9798909FA196A7A8A0ACAEA3ACADA5ABADA2ABACA4ACADA5
ADADA5AFACA5B0ADA6AFACA5AEABA4ACA9A2AAA7A0A9A69FAAA7A0A3A099ABA8A1A3A099ACA9A2\
8E8B8435322B16151114161513171A13171A13171A13171A13171A13171A13171A
0F131611151813171A161A1D181C1F181C1F171B1E191A1E15141918171C1D1C2126252A302F34\
3A3A3C4343454747473636364A4A484E4E4C3637321F201B1E1F1A23241F23241F
1A1B1616171211120D0D0E090E0E0C1414121B1B1B2020200D0D0D1C1C1E1E1E200D0D0F030207\
08070C09080D0201060A0B0F05090C02050A03070A070A0F0A0E110A0D12090D10
04070C060A0D080B10090D10080B1005090C02050A0102061212141313131313131010100E0E0E\
0F0F0F1515151A1A1A1717173C3C3C464646454545585858666666696969717171
8080807C7C7C7F7F7F8A8A8A9696969797978D8D8D8282826B6B6B6C6C6C6F6F6F727272757575\
7878787B7B7B7C7C7A96928F9E9B96ABA8A3B7B4AFBEBAB7BFBBB8BCB8B7B9B5B4
CBC7C8CCC8C9CCC8C9CBC6CAC9C4C8C4BFC3C0BBC1BDB8BCC5C1C0C3BFBCC0BCBBBDB9B6BCB8B7\
BDB9B6BFBBBAC1BDBAC8C4C3C6C2BFC4C0BFC1BDBABDB9B8BAB6B3B7B3B2B6B2AF
B5B4AFB2B3ADAFAEA9A9AAA4A5A49FA0A19B9D9C979A9B9595948F94958F93928D90918B8D8C87\
88898385847F81827C
A4A69BA2A499A0A297A3A59AA6A89DA5A79C9EA095989A8FAAACA1A8AA9FA4A69BA1A398A0A297\
A0A297A2A499A3A59A94958D8B8C86797A7460615B4647412F302A20211B181913
13140E11120C0D0E08090A040405000102000001000001000C0D080D0E0912130E1B1B19222220\
2121211818180F0F11121214100F140E0D1311101615141A17161E16151D131218
0606080707070707070606060606060707070A0A0A0D0D0D1212121111110F0F0F0E0E0E0E0E0E\
111111141414161614191A1425261E292A22202119191A121B1C141F20181E1F17
3839313C3D3543443C4D4E4658595162635B6A6B636E70658D8F8491938697998E9EA093A5A79C\
AAAC9FAEB0A5B0B2A5A2A499A6A89BAAACA1A9AB9EA4A69B9FA1949EA0959EA095
A7A79FA7A6A1A6A5A0A5A49FA5A49FA6A5A0A7A6A1A8A7A2AEADA8A9A8A3B1B0ABA7A6A1ADACA7\
91908B3D3C372625211F21201F2022202123222325232426252628262729262729
23242628292B2F303235363838393B38393B3536383334363E3E4039393B3737393E3E404B4B4D\
5454565555575252521F1F1F1F1F1D1818160A0A08000000000000040402090907
1616161313131010100C0C0C09090907070707070907070912121427262B2D2C311D1C21131218\
1A191F1B1A201110161011160D0E13090911090A0F0C0C140F10150E0E160C0D12
0909110A0B100D0D150E0F1410101813141916161E191A1F08080A0B0B0B0D0D0D0B0B0B090909\
0C0C0C1313131A1A1A5555558A8A8AA4A4A4A3A3A3B0B0B0B9B9B9B9B9B9C1C1C1
C8C8C8C8C8C8C9C9C9CBCBCBCECECECFCFCFC9C9C9C1C1C1C2C2C2C3C3C3C5C5C5C7C7C7CACACA\
CDCDCDCFCFCFD0D0CEC6C2BFC9C5C2CECAC7D1CDCAD1CDCACDC9C6C9C5C2C5C1BE
BEBAB9C0BCBBC3BFBEC7C3C4CBC7C8CFCBCCD2CECFD3CFCECBC7C4CAC7C2C9C5C2C8C5C0C7C3C0\
C6C3BEC6C2BFC6C3BEB7B3B0B4B1ACAFABA8A8A5A0A19D9A9A979295918E93908B
9390879090848F8D8189897D8684788080747F7D717B7B6F7674687575697A786C7A7A6E7E7C70\
7C7C707E7C707C7C70
AEB0A5ACAEA3ACAEA3B0B2A7B5B7ACB4B6ABACAEA3A4A69B7C7E736F7166595B504143382E3025\
23251A1F21161E1F170F100A11120C11120D0E0F090A0B060B0C0610110C161711
060702090A040D0E0911120C1415101617111617121516110909070F0F0D18181620201E232323\
1B1B1B0F0F110505070B0A0F08070C07060E0908100D0C140F0E160D0B160B0A12
1212141313131313131111110E0E0E0E0E0E1111111313131111110F0F0F0D0D0D0C0C0C0E0E0E\
1414141A1A1A1E1E1C393A32515346696B60787A6D85877C97998CA3A59AA6A89B
ACAEA3ADAFA2AFB1A6B1B3A6B3B5AAB5B7AAB6B8ADB7B9ACAEB0A3AFB1A4B1B3A6B2B4A7B1B3A6\
AEB0A3AAAC9FA8AA9D9A9C8F9D9F92A0A2959FA1949D9F929D9F92A0A295A4A69B
9FA09A9E9F999E9D999D9E98A1A09CA5A6A0AAA9A5ACADA7B5B4B0B3B4AEC2C1BDBBBCB6C5C4C0\
ADAEA862615D4F504B3D3D3D3D3F3E40404241434244444645474648484A484A49
4E4E505355545E5E606668676B6B6D696B6A6666686363634E4E503D3D3D2A2A2C2121211F1F21\
18181808080800000009090906060609090910100E13131310100E0E0E0E111111
09090B0B0B0D0D0C11101012111113111113111015100F140B0A0F2524292E2D321E1D22141318\
1C1B201D1C221211170F0E160A0A1208070F0808100D0C140F0F17100F170D0D15
14131B1111190F0E1609091107060E0808100F0E16141319101012141414181818181818171717\
1B1B1B2424242C2C2C909090C5C5C5D8D8D8C8C8C8C4C4C4C3C3C3C1C1C1C9C9C9
BFBFBFC3C3C3C4C4C4C3C3C3C4C4C4C6C6C6C5C5C5C2C2C2C7C7C7C7C7C7C9C9C9CBCBCBCDCDCD\
CFCFCFD1D1D1D2D2D0EBE7E6E1DDDAD0CCC9C0BCB9B6B2AFB4B0ADB7B3B0BAB6B3
A5A19EA09C999894938D8986837F7C7B777475716E726E6B7C79747F7C7583807B87847D888580\
87847D84817C827F7883807B84817A85827D86837C88858089867F8A87828B887F
89877B8987788886798886778785788684758684778684758A887B8A887989877A888677858376\
8280717F7D707D7B6C
ACADA5A6A79FA2A39BA3A49CA5A69E9D9E968C8D857D7E7662635B57585046473F34352D25261E\
1C1D15191A1218191115161114151011110F0F100B0E0E0C0E0F0A0F0F0D0F100B
0C0C0A0D0E090F0F0D10110C10100E10110C0F0F0D0E0E0C0C0C0A0B0B09141412232321272727\
1D1D1D131315101012100F141D1C210E0D150000070B0A120E0D150907120F0E16
1313151313131212121111110F0F0F0E0E0E0D0D0D0D0D0D0F0F0F0B0B0B0C0C0C121212131313\
10101016161621221D26281D5A5C4E85877A87897B838578909284A0A295A3A597
A8AA9DAAAC9EADAFA2B0B2A4B3B5A8B3B5A7B0B2A5AEB0A3B8BAADB3B5A8AFB1A4ADAFA2ADAFA2\
ABADA0A7A99CA3A598999B8E9B9D909D9F929FA194A1A396A1A396A0A295A0A297
A2A39DA1A39EA2A2A0A1A39EA2A2A0A1A39EA2A2A0A1A39EA4A4A2A1A39E9A9A9892948F90908E\
8486816969674C4C4A3C3C3A4343414B494A4D4D4B4E4C4D4D4D4B4F4D4E50504E
5553545A5A58626061626260605E5F59595757555655555343434331312F2D2D2D1818161A1A1A\
1717170000001313130D0D0D0D0D0D0D0D0D0D0D0D0C0C0E0C0C0C0B0B0D0B0B0D
1413181110150A090F05040909080D100F140F0E1309080D1514191D1C21242426212123252527\
37373933323718171C100F1509081006030C08070F1310191918201A172015141C
19161F17161E1310190B0A1207040D08070F0F0C1515141A1010121414141C1C1C1F1F1F191919\
151515232323373737B8B8B8BABABABDBDBDC0C0C0C3C3C3C4C4C4C5C5C5C5C5C5
BEBEBEBEBEBEBEBEBEBEBEBEBFBFBFC1C1C1C4C4C4C5C5C5C6C6C6C1C1C1BEBEBEC3C3C3C9C9C9\
C7C7C7BBBBBBAFAFADBDB9B8C5C1BEC7C3C0BAB6B3A5A19E9D9996A7A49FB5B2AD
A09D9893908B8D89868F8C8786837E73706B6F6C6778756E817E77817E7583807985827986837C\
88857C8A87808A877E8B88818B887F8B88818C89808C89828C89808D8A838D8B7F
8F8B7F8F8C7B8D8A7B8C89788A8778888574878475868372868374868372868374858271858273\
858271848172848170
8D8E887E7F7768696356574F46474133342C1D1E180D0E061D1E181A1B1315161011120A11120C\
14150D1819131B1C1611110F10100E0E0E0C0C0C0A0B0B090B0B090C0C0A0D0D0B
0C0C0A0C0C0A0D0D0B0E0E0C0E0E0C0D0D0B0C0C0A0C0C0A14141218191423241F2D2D2B262624\
12121204040402020400000215141919181E16151B2322281E1D250D0C140B0A10
08080A0909090A0A0A0B0B0B0C0C0C0D0D0D0E0E0E0E0E0E1414140E0E0E0D0D0D0F0F0F0F0F0F\
1212122222223435305F6156888A7CA6A89AA2A496999B8DA2A496AAAC9EA9AB9D
A4A698A3A597A3A597A6A89AABAD9FAFB1A3B2B4A6B2B4A7B0B2A5ADAFA2ABADA2ACAEA1AFB1A6\
B0B2A5AEB0A5ABADA0A5A79CA5A79AA5A79CA4A699A2A4999FA1949C9E939B9C94
9D9F9A989A978E908D8183807375726668655D5F5C575956292B282B2D2A2729261F211E1F211E\
20221F161815080A073A39373E3D3B434240444341434240434240454442484745
3E3D3B3F3E3C3D3C3A3534322B2A28232220201F1D201F1D0E0E0C0000000D0D0B0808060A0A08\
1919170F0F0F1E1E1E0A0A0A0A0A0A0A0A0C0A0A0C0A0A0C09090B09090B09080D
0000040403090B0A100F0E131110151312171312171212142B2B2D2D2D2F6A6A6C8C8C8C7A7A7A\
8C8C8C7B7B7B1D1D1F1B181F1A171E18151E1310170C091206030A020008010005
0100070200060D0A1314111816131C16131A17141D18151C3B3B3D3535352C2C2C202020141414\
1A1A1A3B3B3B5F5F5FBCBCBCBDBDBDBFBFBFC1C1C1C2C2C2C2C2C2C2C2C2C1C1C1
C7C7C7C6C6C6C5C5C5C4C4C4C4C4C4C5C5C5C7C7C7C8C8C8C1C1C1BDBDBDB9B9B9B2B2B2A1A1A1\
8181815858583B3B3B1A1615282421474340716D6A94908D9E9A978E8B867C7974
8885808C89848F8C858E8B8488857E85827989867D918E8584817885837786847888867A8A887C\
8B897D8C8A7E8D8B7F8B897D8B897D8B897D8B897D8C8A7E8C8A7E8C8A7E8C8A7D
8C897A8C89788B88778B88778B88778B88778B88778B8877868372868372868372858271858271\
848170848170848170
2627221B1C1610110C0B0C060F100B12130D11120D0E0F090809040809030708030809030A0B06\
0D0E0810110C12130E11110F1010100E0E0E0D0D0D0C0C0C0C0C0C0D0D0D0E0E0E
0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0D0D0D0D0D0B01020006070114150F21221D20211C\
1717151818162121212020202424260C0C0E00000400000405040A00000507060C
0B0B0D0C0C0C0D0D0D0F0F0F1010101111111313131313130404040909091515151F1F1F1E1E1E\
1B1B1B25252535363177796E919386A0A2959A9C8F9496899B9D909FA1949A9C8F
A9AB9EA9AB9EABADA0B0B2A5B3B5A8B2B4A7ABADA0A5A79AB7B9AEB4B6ABB1B2AAB1B3A8B3B4AC\
B3B5AAB0B1A9ADAFA4B0B1A9AAACA19FA0989092877E7F776D6F645F6058575852
4143403B3F3E333736282C2B1D21201317160B0F0E060A09070B0A0A0E0D080C0B030706060A09\
121615171B1A1618151514121915121A161318141114100D130F0C1713101A1613
16120F16120F15110E100C090B07040B07040F0B0811100C1E1F1A050601262722191A15000100\
0506010404020000000B0B0B0B0B0D0B0A0F0B0A0F0B0A0F0B0A0F0B0A0F0B0A0F
07060B0D0C111211161312170E0D120B0B0D0F0F111414142424242828268A8A88BDBDBB9B9C97\
B8B9B4ABACA7272725060407120D131C171E1F1A201B161D1B161C231E252A252B
221D24221D231E192019141A140F16140F1519141B1C1A1F0B0B0D1010101A1A1A2525252E2E2E\
4646467373739C9C9CBEBEBEBFBFBFC0C0C0C2C2C2C2C2C2C1C1C1C0C0C0BFBFBF
BFBFBFBEBEBEBCBCBCBBBBBBBBBBBBBBBBBBBCBCBCBDBDBDC0C0C0C1C1C1C5C5C5C5C5C5BBBBBB\
A1A1A17E7E7E656565403C3B3B3736403C3B56525176726F8B87848F8C878A8782
89867F95928B9B988F8C8980726F666664587270648583768B897C8B897C8C8A7D8E8C7F8F8D80\
908E81918F829290838E8C7F8E8C7F8E8C7F8E8C7F8E8C7F8D8B7E8D8B7E8D8B7C
8885748B85758B85758C86768D87778D87778E88788E88788A84748A84748A8474898373888272\
878171868070868070
10110C0A0B060304000203000809040F100B13140F13140F13140F13140F13140F13140F11120D\
10110C0E0F0A0D0D0B1313131212121111110F0F0F0F0F0F101010111111121212
1111111111111010100F0F0F0F0F0F0F0F0F10101011110F282923282A1F33342C4A4B435D5E58\
6C6D677E7F7A8F908B9B9B9980807E3F3F3F101010161618202022201F24272729
1212141212121212121212121212121212121212121212121E1E1E1F1F1F2626262C2C2C2D2D2D\
3333334A4A4A64646285867E91938896988D9193889294899A9C919C9E9397998E
A5A79CA8AA9FAEB0A5B4B6ABB3B5AAA5A79C8E90857D7F7438393133342E2C2D27282923252620\
21221C1A1B151516100A0B050A0B050B0C060A0B05090A04070802050600020400
0B100C0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E1014131216150F13120B0F0E121615\
1E22212125241C1E1D0706020A06030A06030703000400000501000A06030F0B08
24201D2B272436322F413D3A4C484558545165615E6E6B6694938E7C7D77A1A29C76777220211C\
1D1E1920201E0F0F0D0D0D0F0D0D0F0E0D120E0D120F0E130F0E14100F15100F15
19181D1211160D0C110B0B0D09090B0909091313131F1F1D4647426A6B66B6B7B1C8C9C3AAABA3\
C6C7BFC3C4BC6E6D682B27282F2A2E312C30302B2F2E292D2F2A2E3530343C373B
3D383C3F3A3E3F3A3E3D383C3A35393C373B423D414742464240415050506F6F6F919191A6A6A6\
B1B1B1C1C1C1D1D1D1BDBDBDBEBEBEC0C0C0C1C1C1C2C2C2C2C2C2C1C1C1C0C0C0
C6C6C6C5C5C5C4C4C4C3C3C3C4C4C4C5C5C5C7C7C7C8C8C8BEBEBEBEBEBEC2C2C2C9C9C9D1D1D1\
D2D2D2CDCDCDC7C7C7CDC9C8C0BCBBA39F9E7A76755B57545B575479767197948D
94918A96938A9B998D88867A4F4D412422153D3B2E7573648A88798A89778B897A8C8B798D8B7C\
8D8C7A8E8C7D8F8E7C8B897A8B8A788B897A8A89778A88798988768987788A8776
8E88788E88788D87778D87778D87778C86768C86768C86768C86768C86768B85758A8474888272\
878171868070868070
12130E0F100B0D0E090C0D080D0E090D0E090B0C07090A050607020809040C0D080F100B11120D\
12130E11120D11110F1010100F0F110E0E100D0D0F0D0D0F0F0F11101012111113
0F0F110E0E100D0D0F0C0C0E0D0D0F0F0F1111111313131114150D16180B282A1F4D4F44707267\
84867B8F9088989993A7A8A38485803B3B390B0B09111111151515050505000000
1111111111111212121414141515151717171818181818182F2F2F2222221717171414141D1D1D\
38383867676790908EA4A59FA4A59D9FA09897989096978F999A9297989091928A
A2A39B9FA0989D9E969E9F979C9D959091897B7C746A6B652A2B262424221D1D1B181816141412\
0F0F0D0808060202000303010505030B0B0910100E1515131919171C1C1A1C1E1B
1014130F15150F15150F15150F15150F15150F15150F15150E14140C1212070D0D050B0B0E1414\
171D1D1117170608070605010C0703100B07130E0A17120E1E191527221E2F2A26
26211D322D29443F3B55504C635E5A6F6A667A7571807D789695908D8E86B4B5AD73746E050601\
0001000808060000000B0B0D0B0B0D0C0B100D0C110E0D130F0E16100F17100F15
1110150505070202040B0B0B1212121313111A1B16252620393A3291928ABBBDB2A9ABA0A5A79A\
A9AB9E9EA09297978D383431312B2B2A24242B2525332D2D3D3737443E3E464040
443E3E4E48485852525D57575751514D4747443E3E3E3A395A58595E5E5E747474979797B0B0B0\
B5B5B5B2B2B2B1B1B1BABABABCBCBCBEBEBEC1C1C1C2C2C2C3C3C3C3C3C3C2C2C2
BBBBBBBBBBBBBBBBBBBCBCBCBDBDBDC0C0C0C3C3C3C4C4C4C1C1C1BDBDBDB8B8B8B6B6B6B8B8B8\
BCBCBCBEBEBEBEBEBED2CECFD9D5D6D0CCCBA9A5A475716E5854515E5B56706D66
928F86878579908E828A887B4240330301002927188C8B798B8A788B8A768B8A788C8B778C8B79\
8D8C788D8C7A8D8C788C8B798C8B778B8A788A89758A8977898874888775898675
958F7F958D80938B7E91897C8E86798C84778A8275898174888073888073867E71857D70837B6E\
81796C80786B80786B
0001000304000809040E0F0A12130E13140F13140F12130E090A050A0B060C0D080D0E090E0F0A\
0E0F0A0D0E090D0D0B0C0C0C0B0B0D0A0A0C0A0A0C0A0A0C0C0C0E0E0E100F0F11
0E0E100C0C0E0B0B0D0B0B0D0E0E101212141616181919171C1E132C2E2054564887897BABAD9F\
B5B7AAB3B5AAB3B4ACB5B6AE92938D4849431516111A1B162425201E1E1C1F1F1D
1D1D1D1E1E1E2020202424242727272A2A2A2D2D2D2E2E2E2A2A2A2828282E2E2E3E3E3E4D4D4D\
5D5D5D7575758A8A88898A8582837D767772696A6461625D5A5B555455504F504A
343530272822191A151617111B1C171E1F1918191411120D1D1D1D1A1A1A161618161616171719\
1717171313151010101E1E201D1D1D1A1A1C1616161111130B0B0B060608020305
090D0E080E0E070D0D060C0C050B0B040A0A040A0A040A0A1218181218180D1313090F0F131919\
232929282E2E24282734302D3C373345403C4E494557524E625D596E696576716D
8D888496918DA29D99AAA5A1ACA7A3ADA8A4ADA8A4AEABA6A8A8A0AFB0A8C7C8C074756D10110B\
0D0E0915151315151307070908080A09080D0A090F0B0A120D0C140E0D150E0D13
1212140C0C0C12121221211F21211F1516111516102021193C3E33A3A598C0C2B5B2B4A6C8CABC\
BDC0AFABAE9DCDCEC086837C7B76726E69666C6763736E6B7A75717B767378736F
8B86838C87838C87848E8985948F8CA19C98B2ADAABEBAB7C3C2C0B5B5B5B0B0B0BBBBBBC5C5C5\
C7C7C7C8C8C8CACACABCBCBCBEBEBEC0C0C0C1C1C1C2C2C2C2C2C2C1C1C1C0C0C0
BFBFBFBEBEBEBEBEBEBEBEBEC0C0C0C2C2C2C4C4C4C6C6C6CCCCCCCCCCCCCDCDCDCDCDCDCCCCCC\
C9C9C9C6C6C6C4C4C4C7C3C4CDC9CAD1CDCCCCC8C7BBB7B4A3A09B8E8B86827F76
9A978E8A887C929083908E7F4A48390403002F2E1C94938194937F94937F94937F94937F94937F\
95948095948095948095948094937F93927E92917D91907C8F8E7A8E8D798F8C7B
8F897B8F877A8C8477898174857D7081796C7F776A7D7568776F62776F62756D60736B5E71695C\
6F675A6D65586D6558
1717151818161818161414120E0E0C08080603030101010017171516161414141211110F0E0E0C\
0C0C0A0B0B090A0A080F0F0F0F0F110E0E100E0E100F0F11111113131315141416
1717191616181515171616181A1A1C2020222727292B2B293133264C4F3E7A7D6CA3A695B1B4A3\
ADAFA1ABAD9FB1B3A6A9ABA09899915D5E562627211C1D171E1F1921221D30312C
31312F3131313131313131313131313131313131313131313434343838384B4B4B656565717171\
6B6B6B5F5F5F5B5B5B3C3C3A3536312C2C2A2425201B1B1914151010100E11120D
20201E1516110B0B090D0E091919171F201B1B1B191414120303050202040201060606080C0B10\
101012100F140E0E100302070606080A090E0E0E1012111615151716151A161719
0D11120D13130E1414101616111717131919141A1A151B1B0309090A1010090F0F0208080B1111\
2E3434575D5D717574918D8A999490A29D99A9A4A0ADA8A4B2ADA9B9B4B0BEB9B5
B9B4B0BDB8B4C1BCB8C1BCB8BEB9B5BBB6B2BAB5B1BAB7B2ADADA5B8BAAFB1B2AA4E4F47050600\
0708030000000202000B0B0D0C0C0E0D0C110F0E1411101812111913111C141319
1F1F211F1F1D2A2A28343530292A251D1E183031295254499C9E91BCBEB0BEC1B0B6B9A6C1C4B1\
BFC2ADBDC0ABD1D2C0D4D1C8CEC9C3C2BDB9B6B1ABAAA5A19F9A9495908C8F8A84
605B575D58525B56525E59536C676388837DA8A39FBDBAB5C7C6C4C2C2C2C3C3C3C5C5C5BFBFBF\
B4B4B4B2B2B2B9B9B9C4C4C4C4C4C4C4C4C4C3C3C3C1C1C1BEBEBEBBBBBBB9B9B9
CDCDCDCCCCCCC9C9C9C7C7C7C6C6C6C6C6C6C7C7C7C7C7C7BEBEBEC2C2C2C7C7C7CCCCCCCDCDCD\
CDCDCDCDCDCDCDCDCDCAC6C7C3BFC0BCB8B7BDB9B8C1BDBABCB9B4AEABA6A09D94
9491888F8D81929083868475535240272612403F2B7A796584836F84836F84836F83826E83826E\
83826E83826E83826E81806C807F6B7F7E6A7D7C687C7B677A7965797864797665
716B5D71695E6F675C6D655A6A6257675F54655D52645C515F574C5E564B5C54495A5247574F44\
554D42534B40524A3F
0606060909090C0C0C0D0D0D0F0F0F1111111515151919190D0D0D0C0C0C0C0C0C0C0C0C0E0E0E\
10101013131314141417171917171916161816161818181A1A1A1C1C1C1E1D1D1F
24242623232523232524242629292B31313338383A3D3D3B909388A9AD9EC8CCBDD4D8C9C3C7B9\
B0B4A6B5B8ADC7CABFBDC0B7CFD2C9BCBFB892958E757772575954434540494B46
3939393636363232342C2C2C2525271F1F1F1B1B1D1919192020221010100606080B0B0B101012\
0C0C0C0505070404041010100D0D0D0C0C0C0D0D0D0B0B0B0909090D0D0B141412
0C0C0A0909070C0C0A1919172626242526211515130404020F0F0D0E0E0C100F0D1414121C1B19\
2020202220212020201715181616181614191413181311160F0E140D0A110A090E
0B0F100B0F100A0E0F0A0E110A0E110A0E110A0E110A0E1103060B11151815191C0B0F10131718\
474B4C919594C7C9C6AEADA9B5B2ADB9B6B1B9B6B1B6B3AEB2AFAAB1AEA9B1AEA9
C2BFBAC4C1BCC7C4BFC7C4BFC7C4BFCBC8C3D2CFCAD5D4CFC9CAC2D5D6CEB7B8B24E4F491F201A\
27282311110F14141214141415151716151A18171C1A191F1B1A201D1C221E1D22
1B1B1920211C2F2E293637312D2D2533342C6C6C62ABADA0ADADA16F71634849392E3120151604\
1E210E333520282919424034514C46645F59706B6576716B7B7670837E788B8680
9F9A94A19C969C97918B86806C676148433D2A251F1815100908062D2D2B6868669C9C9AB3B3B1\
BABAB8C7C7C5D8D8D6CBCBC9CACAC8C8C8C6C4C5C0BFBFBDBABBB6B5B5B3B2B3AE
9C9D989A9B9697969292938E8F8E8A8C8D888B8A868A8B869B9A9697989393928E8A8B86858480\
82837E8685818988848B87848B87848C878487847F847F7B7E7B767D78727B786F
757168807E72848075716F625754454B493A5855466765565E5B4A5C5B495D5A495C5B495C5948\
5B5A485C59485B5A4857544355544255524152513F514E3D4F4E3C4E4B3A4D4A3B
524C40524A3F51493E50483D4F473C4E463B4D453A4C44394C44394B43384A4237473F34443C31\
423A2F40382D3F372C
0F0F110F0F111010121010121111131212141313151313151515171111130D0D0F0E0E10111113\
1212140F0F110A0A0C1B1C1E1A1B1D191A1C18191B191A1C1C1D1F1F2022212224
242527262729292A2C2E2F3133343638393B3B3C3E3D3F3E838884989D97B0B5AFBABFB9B6BBB5\
B1B6B0B3B8B2B9BEB8B5BAB6ACB1AD989D997A7F7B5A5F5B424743363B37343837
2C2D2F2A2B2D27282C2324261E1F231A1B1D17181C1516180F10140F10120E0F130C0D0F0A0B0F\
090A0C07080C07080C0F10140E0F130B0C100A0B0F090A0C0A0B0D0C0E0D0D0F0E
17191615171412140F21231E30322D1A1D160A0C071F20180A0A002122120F0D001A1B0D2C2A1E\
2222183A37303F3E390F0B080D0B0C0F0A0E0D0B100F0A110E0B14100A140F0C13
0F0E130E0F110E0F130E0F140E0E160D0D170D0D170C0C160B0B171F1F291818200000040C0D0F\
555756A0A29FC1C3BEACADA7B5B6B0BABBB5B8B9B3BABBB5BFC0BABDBEB8B5B6B0
C2C3BDC0C1BBBCBDB7B7B8B2B1B2ACACADA7A8A9A3A6A7A1A2A49F9D9F9A8789845C5E592D2F2A\
1214111315121E201D151714181A191B1D1C1C1E1D1E201F2325242B2D2C333331
2726212C2C22302D242E2E2438352C54544A838175A4A498ABA99D7575695C5A4D4041331C1A0D\
28291B4846393C3A2D4A473E625F5679766D817E7586837A939087A09D94A6A39A
A4A198A29F969C99908D8A8175726957544B3B382F2A272013120E3635316B6A66979692ACABA7\
B4B3AFBFBEB9CBCAC5BFBFB7BDBDB5B9B9B1B5B5ABB2B2AAB0B0A6AFAFA7AEAEA4
A3A3979FA0929B998C9293858F8D808A8B7D8B897C898A7C939184909183908E818C8D7F8C8A7D\
87887A8886798785798B877C89857C867F777F7B727C756D77736A777068757168
7E776F76716B6F686267625C665F59605B555D555257524C5D564C565246534D41514D41575145\
5955495D574B5B574B514B3F4F4B3F514B3F4F4B3F514B3F4F4B3F514B3F514B3F
534C42524B4150493F4E473D4C453B4A43394942384841374F483E4D463C494238443D333F382E\
3A3329362F25342D23
0F0D100F0D100E0C0F0E0C0F0D0B0E0C0A0D0C0A0D0B090C0C0A0D0B090C0B090C0C0A0D0E0C0F\
0F0D100F0D100D0D0F2123222527262B2D2C313332353736373938373938363837
3D3F3E3C3E3D393B3A3537362F31302A2C2B2527262224231E2221303433474B4A575B5A5E6261\
636766696D6C6F73724C504F494D4C4044433034331E22211216150E12110F1312
1415171415191213171011150F10140D0E120B0C100B0C10111216111216111216111216101115\
1011151011151011150E0F140F10151011161112161011150F10120E100F0D0F0E
0001000A0C070507020D100931342D42453E40433C47493E5E5F4D72715C696854797864807E6F\
7E7C6F8C8A7E716E6714110C15111016121317121617121917111B16101C131019
151318131315121116111016110F1A110F1C12101E13111F0C0A1816142114121D0F0E142C2C2E\
696967A0A19CB7B8B2C6C9C2C4C7C0B7B9B4A2A59E9395908F928B888A857F827B
7E807B767972686A6555585141433E2F322B20221D191B161A1C171B1D1A1B1D1A181A17161815\
1A1C192325222B2D2A2628252A2C292D2F2C2F312E2F312E323431383A373E3F3A
5050465553475E5C506E6C60878579A6A498C4C2B6D6D4C8C6C4B8A6A498A09E928A887C58564A\
5553476A685C5D5B4F848276918F839D9A91A5A397ADAAA1B3B1A5ACA9A0A09E92
8C8980918F8398958C9C9A8E9B988F93918589867D83807773706B78777285827D8D8D85928F8A\
91918996938C97978D97948B929288908E8289897D868478818175817F73817F72
8987788786748784738584728784738887758C89788C8B797B7867797866787564747361726F5E\
6D6C5A6C69586B6857646152655F53635D51605A4E5F584E5F584E5F5850605951
57504A5A534D5D55525E56535C545259514F564D4E544C4A5C554F5A534959524A595248585149\
544D434C453D453E34564F47554E44544D45524B415049414F483E4E473F4D463C
373028373026373028362F25362F27352E24352E26352E241D160E1E170D1F1810211A10221B13\
241D13251E16261F15
120E0D120E0D120E0D120E0D120E0D120E0D110D0C110D0C14100F151110151110130F0E0E0A09\
0C08070C08070B0A082A2A2830322F3B3D3A444643484A4746484540423F3C3E3B
3E403D3C3E3B383A37313330282A271E201D1416130F110E10120F121411161815171916141613\
0F110E090B080608050D0F0C0F110E10120F0E100D0A0C09080A07090B080B0D0C
0C0D0F0C0D0F0D0E100D0E100E0F110F10120F10120F10120C0D0F0C0D0F0C0D0F0D0E100E0F11\
0E0F110F10120F10120A0B0F0C0D110E0F131112161112160F10120C0E0D0A0C0B
0E100D22241F1D1F1A26292262655E9699909DA09797998C9A9B89A3A28DA6A591B8B7A3B1AFA0\
B8B6A9BCBAAE737069100D08120E0D151112161115161118140F16120C160E0B12
1412151111130F0E130D0C120D0B160F0D1A12101E141220181623110F1C0F0D181C1B21353537\
4D4D4B5D5E59646560484A454A4C4742444131332E2426231D1F1A121411060803
10120F10120D0F110E0E100B0C0E0B0B0D080A0C090A0C071315101416111B1D182D2F2A434540\
52544F54565151534E4749444C4E4951534E545651545651555752585A555D5E58
5C5C525E5C5068665A838175A3A195BBB9ADC1BFB3BFBDB1C9C7BBBBB9ADCBC9BDC0BEB28D8B7F\
8B897DA8A69AA3A195767468716F6268665A6866597573677F7D707371655F5D50
727064777568807E728886798E8C80908E81908E828F8D81908D84908D86928D879592899A958F\
9592898C887F807E728E8A7F8B897D888479848276827E727F7D70807C70807C70
7A7768767362726C5C696655645E4E5D5A495C5646585544645E4E615E4D635D4D615E4D635D4D\
615E4D625C4C605D4C656253636051605C505C584C59554A57534857534A565249
4B46404E49434F4A464B464247423F484340514C495A55524C474147433A403B353C382F3B3630\
39352C342F29312D241D18121D19101D18121D19101D18121D19101E19131E1A11
1F1A141F1B12201B15211D14221D17221E15231E18231F16443F3946423949443E4E4A41544F49\
58544B5C57515E5A51
110906120A07130B08140C09160E0B170F0C18100D18100D140C09170F0C1A120F19110E150D0A\
130B08160E0B18130F0E0F0911140D181B141D20191D2019181B1411140D0C0F08
0C0F080D10090F120B0F120B0D1009080B0403060001020012110D0E0D090D0C0A11100C181715\
1C1B1718171514130F11100E14130F171614181713181715181713181715181715
1010100F11101011131113121213151315141415171416150D0E100D0F0E0D0E100D0F0E0D0E10\
0D0F0E0D0E100D0E100D0E100D0E100E0F130F10120F101210121110121110120F
11130E1F221B21241D3E413885887FB5B8AFB7BAB1B1B3A6B4B5A3B2B19CB7B6A2C5C4B0B1AFA0\
BFBDB0C0BEB257544B0F0C07110D0A14100F161213161117130E140F0A110A080D
1513141212120F0F110D0C110E0D15110F1A1513201715231C1A27100E1913111C28272D303032\
2323211616141516113537344547445355545658555557564F514E3F41402E302D
14161514161313151412141111131210120F0F11100E100D0A0C07070904080A0510120D1B1D18\
1D1F1A1618130D0F0A2E302B3537323E403B4345404547424749444A4C474E4F49
55554B5755495F5D51727064878579908E8288867A7C7A6E85837779776B8D8B7F85837759574B\
6260548C8A7E918F83A3A1949290817A78696F6D5E7D7B6C9391829795868F8D7E
8E8C7D8F8D7E908E7F918F80918F80918F80908E7F908E81959186948D838B847A7F786E766F65\
70695F635C52564F45575046564F45554E44544D43544E42554F43565044575143
5751435751415751415852425953435A54445B55455C5646494333484232464030443E2E423C2C\
3F39293E38283D37272F2C1D2A28192521151E1C0F181409121004100C030E0B02
1E19131B181116110D0C09040C07041D19163D383556524F807B77726F6A625D5957544F5B5652\
65625D726D697976719E99959F9C97A39E9AA7A49FACA7A3B0ADA8B4AFABB5B2AD
AEA9A5ADAAA5AEA9A5ADAAA5AEA9A5ADAAA5AEA9A5AEABA69D98949C99949E99959F9C97A19C98\
A19E99A49F9BA3A09B
1E150C1E150C1D140B1C130A1A1108191007180F06180F060D0400100700140B02160D04170E05\
1910071C130A1E170D0B0B010A0C010A0C01090B00070900040600010300000200
050700080A000C0E030F110612140912140911130812120A1C191416110D120D0A17120E211C19\
27221E25201D201B1718131017120E18131018130F19141117120E15100D110D0A
0E0D0B0D0D0B0D0D0D0D0D0B0D0D0D0C0C0A0C0C0C0C0C0A141414141412131313121210111111\
10100E1010100F0F0F1414141212120F0F110E0E0E0F0F0F121210161614191A15
1A1B161E1F192D2E2664665BA7A99EB7B9AEABADA2B1B3A5BFC1ACB8B7A2B5B4A0BCBBA7A4A293\
B1AFA2B3B1A54D4A4116130E1713101915141A1617191516161115130E140F0D10
16151313131112121211111312111715141C1816231A182517152214121D23212C3B3A4038383A\
1D1D1B0E0E0C13131125252535353544444648484848484A434343353537242424
2020221E1E1E1A1A1C1616161111130C0C0C08080A070707171715191A151C1D181C1D181B1C17\
191A151819141819141D1E1925262130312C393A353E3F3A43443F4849444C4D47
5E5E546462566D6B5F7674687C7A6E7D7B6F78766A7472669492868684789694888E8C80636155\
6B695D9290849492859795868E8D7B7D7C6A706F5D7675638B8A78989785999886
9998869897859796849796849897859A99879C9B899E9B8A9A94869A92878981766F675C625A4F\
6860556F675C6F675C60584D5F574C5C54495A5247585045585045585045595144
554D40544D3D524B3B5049394D4636494232463F2F453E2E4D46364B4434484131443D2D3F3828\
3B3424383121352F1F2A2819262717262417222315232115212115232017222218
201D16202018221F1A1F1E19282421403F3B67636282817F8985827B7A766D696664635F6B6764\
76757186827F8C8B87928E8B91908C9793909998949F9B98A2A19DA7A3A0A7A6A2
B9B5B2B6B5B1B7B3B0B4B3AFB4B0ADB0AFABB1ADAAAFAEAAAEAAA7ABAAA6ACA8A5A8A7A3A7A3A0\
A3A29EA4A09DA1A09C
4C4034473D3145392D3E34283A2E2232281C3024182C22163125192A2014261A0E21170B22160A\
1D1307190D011109001A180B1416081112040D0F010C0D000C0E000F1002101204
0F10020E10020F10020D0F010E0F010D0F010E0F01100E021F181219100B1107050F0601110705\
1108030D03010700001D13111A110C170D0B180F0A1A100E1B120D180E0C150D0A
130F0C10110C100F0D0E0F0A0D0C0A0B0C070B0A080A0B060F0E0C0D0E090E0D0B0D0E090E0D0B\
0D0E090E0D0B0D0D0B100F0D0E0E0C0D0B0C0C0C0A0E0D0B10110C151410161711
2B2A2530312947473D7D7F72B0B0A4A7A99C97978BA5A69697968295947F8988748C8B797B796A\
7F7D6E8583763D3B2F1B18111A171219151217131216121115111214101112110F
0E0D090E0F0A0F0F0D11111112111613121814121D14121F201E2B24222D34333B403F45343436\
1B1B1B1212101B1B191E1E20242426262427202022201E212323252220231A1A1C
09070A09090B0C0A0D0E0E10110F121313151513161515150302000B0C0614130F13140E0E0D09\
0C0D071514101D1E182A292531322C3D3C384546404D4C4854554F5D5C5863625D
625F566B695D7775697D7B6F807E7283817589877B8F8D818280747A786C918F838D8B7F605E52\
65635789877B8A887B9695839E9D889E9D899796819695819D9C87A09F8B9D9C87
91907C908F7A8F8E7A8F8E798F8E7A91907B93927E95927F8A8373998F83978D8181776B6F655B\
6A605661574D53493F4F453B4D4339483E3442382E3E342A3A3026382E25372D23
372F22362E21352D20322A1D2E2619292114241C0F221A0D1A12051C140721190C2820132E2619\
352D203A32253B3527454336444638494A3C4E504356564A5D5F5465655B676860
8080788586808C8B868E8F8A92918D999997A8A7A5B2B2B2B2B0B1AEAEAEABA9AAAAAAAAAEACAD\
AFAFAFB0AEAFADADADABA9AAAAAAAAABA9AAABABABACAAABABABABACAAABABABAB
A4A2A3A2A2A2A19FA09E9E9E9C9A9B9999999997989797979D9B9C9B9B9B9B999A999999999798\
979797979596959595
6C5F4F695D4D6659496054445C4F3F564A3A534636504434574A3A4B3F2F4336264337274A3D2D\
4A3E2E423525342B1A33301F2D2E1C292816222311201F0D1D1E0C1F1E0C1E1F0D
1413010F10000E0D00090A000B0A000B0C00100F00141102190F061B0E081B0D0A1F120C241613\
291C162B1D1A2B1E18281A1722150F1C0E0B1C0F09211310241711241613201511
18130F15140F17131014130E15110E13120D15110E12110C0E0A070D0C07110D0A11100B16120F\
1716111B17141A19151A16131C1B17231F1E25242029252226252025221B212117
302D244545395654486A6B5D8482757B7C6E6F6D6077756667665273725E62614F676654646253\
595748615F524442362C292029261F24211C201C191E1A171F1B1A211D1C21201C
1B1A151D1E1621221C25252327272926252A24232B23212C2C2A35302E3934333B2F2E34202022\
1212120F0F0D13131115131619171C1813190E0C11110C1217151A1D181E17151A
221D231E1C211C171D151318110C120A080D080309040203120E0B19191124211C22221A1E1B16\
1919111F1C1722221A27241F2B2B2335322D3A3A3243403B4A4A4257544F5E5B54
66635A6D6B5F7775697D7B6F817F738684788D8B7F939185959387918F83A8A69A99978B615F53\
656357979589A5A39689887493937B99988395957D94937E96967E92917C898971
A2A18CA1A1899F9E899D9D859C9B869B9B839B9A859B9984978E7F9F9385938779766A5C62564A\
574B3F3F332722160A281B1225180F22150D1E11091B0E06190C04180B05160C03
2D241B332B203F372C4D453A5A5247655D526C64596F675C6E665B736B607B7368867E73928A7F\
9D958AA59D92A9A397A2A296A2A698A5A79AA9ACA1B0B2A7B5B8AFBCBDB5BEC1BA
B1B2ACB2B4AFB4B4B2B3B5B2B0B0AEAAACABA6A6A6A2A3A5A4A3A8A2A3A8A3A2A8A5A6ABA8A7AD\
A5A6ABA09FA5999A9FA6A5ABA5A6ABA4A3A9A2A3A8A1A0A69E9FA49E9DA39D9EA3
A7A6ACA5A6ABA6A5ABA4A5AAA4A3A9A2A3A8A2A1A7A0A1A69F9EA49E9FA4A09FA59FA0A5A09FA5\
A0A1A6A1A0A6A0A1A6
685B48685B48675A47675A47665946655845645744645744584B384F422F4E412E6053407B6E5B\
8D806D8C7F6C837866837E6A7C7B677675616E6D596665515F5E4A5A5945575642
4F4E3A4D4C384A49354A49354E4D395655415F5E4A67615165584F63544D5B4C4550413A43342D\
3728212F20192B1C152718111F10091708011506001A0B041E0F081E0F081B0E08
150E08120F08120F0A13100914110C14110A15120D15120B1A17121D1A13211E1926231C2B2823\
312E2734312C37342F35322D3D3A35494641524F4A54514C4E4B444542393F3D31
5452467B796C817F72716F607573647877656E6D5B6D6C5A6564527E7D696B6A587574627C7A6B\
686657706E616F6D6049473B4441383E3B3438352E36332E3835303C39343D3D35
3B3B313E403545463E4B4C464D4D4B4B4B4D47464C43424A2B2A322D2C3428272D1D1C2116151A\
19191B1C1C1C1D1B1C1813171F1A20201B2119141A161117161117110C12070208
110C12100B11100B11100B11100B110F0A100F0A100F0B0C0B0803110E071A17101E1B141C1912\
18150E14110A13100938352E3D3A33423F3847443D4D4A4356534C615E576A675E
7B796D7D7B6F807E7285837788867A8B897D8B897D8B897D9593878C8A7E9492866D6B5F201E12\
211F1362605482807196958198988096967E92927A96967E9E9E869D9D8594947C
90907891917993937B95957D97977F9999819A9A829B9984A8A18F9A9182796D5F5D5445716559\
9F9589BCB0A4B8AEA4BAADA4B8AEA5B9ACA6B8ADA7BCAEABBDB2AEC1B3B0C1B6B2
B5ACA5B5AEA6B7AEA7B6AFA7B5ACA5B1AAA2AEA59EAAA39BB0A7A0AFA8A0B0A7A0AFA8A0B1A8A1\
B0A9A1B1A8A1AEAAA1AFB0A8AAB0A6A8ABA2A2A89EA1A49D9DA29B9FA19C9CA19B
ABADAAA5A9A8A2A3A59FA3A4A4A5A7A3A7A8A5A6AAA1A4A9ABABB5A4A7B0A1A1AB9EA1AAA4A4AE\
A6A9B2A9A9B3A7AAB3A3A3ADA1A4ADA3A3ADA1A4ADA3A3ADA1A4ADA3A3ADA1A4AD
9C9CA69A9DA69D9DA79B9EA79E9EA89DA0A99F9FA99DA0A9A1A1AB9FA2ABA1A1AB9FA2ABA1A1AB\
9FA2ABA1A1AB9FA2AB
695D47685C46665A4464584262564060543E5E523C5D513B584C36564A34594D37665A44796D57\
8C806A978B759A8F798984708B89748987727E7C6773715C6B695462604B5A5843
66644F49473256543F65634E59574268665174725D5853405F5347705F576C5B5356453D4E3D35\
56453D5241394231293C2B2328170F1B0A021F0E062211091D0C041C0B0320130A
160F07130F06130E081612091A150F1B170E1A150F18140B0F0A0414100719140E201C13312C26\
433F3647423C413C36413C3646413B4D4842534F46524E454844393834292B271B
5F5B4F7673647F7C6D726F5E6E6B5A7976637976636D6A57706F5D706F5D706F5D6F6E5C6D6B5C\
6B695A68665966645759574A4F4D414442363F3C33413E3744413A44413A404036
43443642443641433642433B494A454C4C4C4241463433392120281D1C2418171D131217100F14\
111113141414171516231E22221C20100A0E0E080C1E181C1913170C060A140E12
0D070B0D070B0E080C110B0F130D11130D11100A0E0D0709110C081612091D19101F1B121E1A11\
1F1B12231F1628241B28241B3C382F48443B4642394A463D5C584F6B675E6E6A61
73716579776B8280748B897D918F83918F838F8D818D8B7F8B897D828074A4A29663615518160A\
2422164745398C8A7B9D9C8897977F95957D98988097977F93937B93937B97977F
A5A58D9A9A828E8E768B8B739191799999819D9D859F9D889E97859A938390867A433B2E675D53\
C2BAAFB0A69CB7AEA5B5AAA4B4ABA6B5AAA8B4AAA8B4A8A8B3A9A8B3A7A7B2A8A7
B5ADABB2ADAAB4ACAAB0ABA8B1A9A7AEA9A6AFA7A5ADA8A5B0A8A6AEA9A6B0A8A6AEA9A6B0A8A6\
AEA9A6B0A8A6ADA9A6A7A9A6A4AAA6A5AAA6A4AAA6A5A9A8A4AAA8A5A9AAA4AAAA
A2A6A9A1A6A9A2A5AAA1A6ACA2A5ACA1A6ACA2A5AEA1A5AEA0A2AF9FA2B1A0A2B19FA2B1A0A2B1\
9FA2B1A0A2B19FA2B19EA0AF9DA0AF9EA0AF9DA0AF9EA0AF9DA0AF9EA0AF9DA0AF
9C9EAD9B9EAD9D9FAE9DA0AF9EA0AF9EA1B0A0A2B19FA2B1A4A6B5A3A6B5A4A6B5A3A6B5A4A6B5\
A3A6B5A4A6B5A3A6B5
62563E60563D5F533B5B5138594D35554B3254483051472E675B43786E5593876FA79D84B2A68E\
B2A88FAFA38BAAA28BADA892AAA893A9A792A9A792A6A48FA09E899F9D88A09E89
9D9B868D8B769D9B86A3A18C8886718886718F8D787C756385796B9B8B7E9B8A80827265705F55\
7363567362586A5A4D4E3D334131243D2C2249392C503F354D3D304A392F493D31
3A3128322E232B271C2521161F1B101B170C1713081410051410051814091A160B1C180D282419\
3834293B372C3531264C483D423E333531282A261B252116221E121E1A0E1C190A
605D4E7572617E7B6A74715E726F5C7E7C677F7D6874725D72715F72715F737260737260716F60\
6F6D5E6D6B5E6C6A5D7270636A685B615F525C5A4E5D5B4F5E5C505C5A4E57584A
6A6B595457443C3E303032272A2B2523232118181A100F1417161C15141C121117100F150F0E13\
101012131313151314252122302A2C211B1D0F090B0C0608040000080204221C1E
201A1C201A1C1E181A191315130D0F100A0C100A0C120C0C120D0715110817130A18140B17130A\
1612091612091612093E3A314B473E504C434A463D4C483F5A564D67635A6A665D
76746879776B7F7D7185837789877B8C8A7E8C8A7E8C8A7E9A988C89877B9E9C90605E52161408\
1210041D1B0F48463993927E93937B93927D93937B9897829E9E869F9E899C9C84
9998839E9E86A5A48FA9A991A7A691A0A088969580908E79948E7E9791838680743A34286A6359\
BFB8AEA29B93AFA8A2AEA6A3AEA6A4AEA5A6AEA5A8AEA5A8AFA6ABAFA6ABAFA6AB
ABA6AAAAA6A7AAA5A9AAA6A7A9A4A8A9A5A6A8A3A7A8A4A5AAA5A9AAA6A7AAA5A9AAA6A7AAA5A9\
AAA6A7AAA5A9A7A7A99FA3A49CA4A69CA4A69CA4A69CA4A79CA4A79CA3A99CA3A9
A1A8B0A1A8B0A1A8B2A1A7B3A1A7B3A1A7B3A1A7B5A1A7B5A1A7B7A1A6B9A1A6B9A1A6B9A1A6B9\
A1A6B9A1A6B9A1A6B9A7ACBFA7ACBFA7ACBFA7ACBFA7ACBFA7ACBFA7ACBFA7ACBF
A9AEC1A9AEC1AAAFC2AAAFC2ABB0C3ACB1C4ACB1C4ADB2C5AAAFC2AAAFC2AAAFC2AAAFC2AAAFC2\
AAAFC2AAAFC2AAAFC2
6D634A6A6349695F46635C4260563D5A5339594F36554E34655B426F684E80765D857E64887E65\
8A8369958B729C947DA29D8997927F96917EA09B889F9A87948F7C948F7C9E9986
B8B3A0B0AB98B5B09DA29D8A706B58544F3C4B46333932205C5040736656786A5D6154444D3F32\
4C3F2F51433650433365574A5F52426254476F6252786A5D7467576C5E51675B4D
6C6457686256635D515E584C595347565044544E42544E423D372B3E382C393327322C20342E22\
3C362A3D372B363024272115231D111F180E1C160A181206100A00060000060000
6E69567E7965837E6A7A755F77725C7F7A647F7A6473715C747361757364767465767465767465\
757364737162727061706E5F6C6A5B6967586A685B6D6B5E706E61706E616C6D5D
6D6F5A454833232615181A0D15160E0C0D080909090F0E13100F15111016111016111016121116\
131315141414151314110B0B2920212A2122211819211819130A0B090001170E0F
0600000600000600000700000A0102100708170E0F1D1513211A1220190F20190F231C12261F15\
261F15231C1220190F3831273F382E413A30413A304A43395F584E716A60767267
8C8A7E8D8B7F8E8C80908E8292908494928696948897958999978B8583779290846B695D363428\
2C2A1E2523172E2C1FA3A290ADAC97ACAB979E9D889998849D9C879897838A8974
82816D85846F88877387867182816D7C7B66797864797864726F607E7A6E6A665B2622176A665D\
BDB8B295908CABA6A3A6A0A0A6A0A2A7A1A5A8A1A8AAA3ABABA3AEACA4AFABA5AF
A6A5ADA5A6ABA6A6AEA6A7ACA7A7AFA7A8ADA7A7AFA8A9AEA9A9B1A9AAAFA9A9B1A9AAAFA9A9B1\
A9AAAFA9A9B1A7AAB1A1A8B0A0A9B0A0A9B0A0A9B0A0A9B2A0A9B2A0A8B3A0A8B3
A7AFBCA7AEBEA7AEBEA7AEC0A7AEC0A7AEC0A7AEC1A7AEC1A9AFC5A9AFC5A9AFC5A9AFC5A9AFC5\
A9AFC5A9AFC5A9AFC5ADB3C9ADB3C9ADB3C9ADB3C9ADB3C9ADB3C9ADB3C9ADB3C9
AFB5CBAFB5CBAFB5CBB0B6CCB1B7CDB2B8CEB2B8CEB2B8CEADB3C9ADB3C9ADB3C9ADB3C9ADB3C9\
ADB3C9ADB3C9ADB3C9
7A745C787258746E566F694F69634B645E44605A425E583E5E58405D573D5B553D5A543A5F5941\
6B654B7A745C857F69807967716B5B736D5D857F6F878171767060726C5C7D7767
5751415E58486D6757746E5E6D67576E6858756F5F766F5D756959847967897D6D7C715F726656\
756A587A6E5E796E5C756959716654706454756A58796D5D746957695D4D5E5544
5B5444625C4C6D6759787262807A6C8680708C8678908A7AAAA496A9A3939F998B908A7A898375\
8A84748781737F796B7D7769777163716B5F6C6658686254625C4C5A5444534E3B
534E3A5B56405B5640504C334A462D4C482F48442B3E3923757261757364777566787667797768\
7876677775667674656967586A68596D6B5C71705E7775667B7A687D7B6C7C7E69
52543E2A2E150E110011140315170C0F100A1111111D1D1F11101512111714131916151B16151A\
16151A151517151412312C29433B38413936443C395A524F5A524F48403D453D3A
544C494F47444B434050484558504D5B5350574F4C504943474038423B313D362C3B342A3B342A\
393228332C222E271D241D13251E14292218342D234B443A6A6359847D73918A80
878378868478878579878579858377838175817F737F7D717775696664586E6C60636155474539\
3D3B2F302E221F1D10201E0F403F2D5352404D4C3A4C4B395857455B5A4852513F
605F4D5C5B4958574557564458574558574556554353514247473B58584E4A4A4213130B666560\
BAB9B591908EADABAEA3A1A6A3A0A7A5A2ABA6A3AEA8A4B2AAA6B5ACA8B7ABA9B7
ABADBAAAAEBAABAFBBACB0BCADB1BDAEB2BEAFB3BFB0B4C0AEB2BEAEB2BEAEB2BEAEB2BEAEB2BE\
AEB2BEAEB2BEACB2BEAFB7C4AEB7C6AEB7C6AEB7C6AEB7C8AEB7C8AEB6C9AEB6C9
AFB7CCAFB7CCAFB7CEAFB7CEAFB6D0AFB6D0AFB6D2AFB6D2B1B8D2B1B8D2B1B8D2B1B8D2B1B8D2\
B1B8D2B1B8D2B1B8D2AAB1CBAAB1CBAAB1CBAAB1CBAAB1CBAAB1CBAAB1CBAAB1CB
A6ADC7A7AEC8A7AEC8A8AFC9A9B0CAA9B0CAAAB1CBAAB1CBA9B0CAA9B0CAA9B0CAA9B0CAA9B0CA\
A9B0CAA9B0CAA9B0CA
79745E767259726D576D695067624C615D445D58425B573E48432D4642294A452F59553C6B6650\
757158736E586D6854736C5C6860536C64577D75687F776A6F675A635B4E645C4F
645C4F645C4F5E5649635B4E746C5F7B73667870637A7363746C59766E59746C59706853726A57\
776F5A756D5A6F6752776F5C71695469614E645C47655D4A635B465A523F4F4835
4F48366059477972628F88769E9787A8A18FB0A999B6AF9DACA595AFA896A9A2929A9381938C7C\
948D7B928B7B8C8575A19A8A888171665E514D4636484131534C3A645D4B706956
5A53405C564059533D514B334D472F4D472D4842283F3B22767360767465777566797768797768\
7977687776647776647A79677A796779786677766274736172715D71705E6F715B
40422A262A0F151902181B08191B0E0F10080C0C0A13131511101512111714131915141A151419\
1413181313151312102D2620443B34403730382F284A413A584F485C534C675E57
524942483F38463D36564D466C635C7168615F564F4B423B584F46524A3F4A4237433B3040382D\
3D352A3A3227383025352D222C2419282015342C214C4439665E537D756A898377
7D796E7D7B6F7E7C707D7B6F79776B7270646B695D6765596D6B5F615F535D5B4F615F534E4C40\
403E3239372B1B190D201E11444233605E4F5E5C4D5553445856475D5B4C5A5849
4B493A444233413F304745364F4D3E4D4B3C403E2F3132243E4035464940444740181A15636562\
B8BAB997989AB0B1B6A7A7AFA7A7B1A9A8B6ABAABAACABBDAEACC1B0AEC3AEAFC3
AEB5C7ADB6C7AEB7C8AFB8C9B0B9CAB1BACBB2BBCCB3BCCDAEB7C8AEB7C8AEB7C8AEB7C8AEB7C8\
AEB7C8AEB7C8AEB6C9B3BBCEB1BCD0B1BCD0B1BCD0B1BCD2B1BCD2B1BBD4B1BBD4
B0BAD5B0BAD5B0B9D6B0B9D6B0B9D8B0B9D8B0B9DAB0B9DAAEB7D6AEB7D4AEB7D4AEB7D4AEB7D4\
AEB7D4AEB7D4AEB7D4A7B0CDA7B0CDA7B0CDA7B0CDA7B0CDA7B0CDA7B0CDA7B0CD
A3ACC9A3ACC9A4ADCAA4ADCAA5AECBA6AFCCA6AFCCA7B0CDA8B1CEA8B1CEA8B1CEA8B1CEA8B1CE\
A8B1CEA8B1CEA8B1CE
78786076765E72725A6D6D5567674F62624A5E5E465C5C445858404C4C3445452D52523A6B6B53\
7D7D658080687C7A65999385968E83928A7F91897E8D857A7F776C6C64595D554A
574F44574F444A42375A52478B8378A0988D9B9388A29A8D9F988597927C908A748F8A74958F79\
95907A8E8872847F6978725C726D5767614B5C57415D5741605B455B553F504A34
5C55426D6654857E6C958E7C9D9684A09987A59E8CA9A290A19A88ABA492AEA795A9A290A7A08E\
ADA694B0A997ADA694989181867F6F706959635C4A67604E79725F8D867399937D
847E68827C647F79617E785E807A60827D607F7A5D7A765D7976637977687A78697B796A7B796A\
7A78697877657776647C7B697A796572715D6564505655414B4A36464531444630
34371C2E3315272B121E210C17190B12130B0F0F0D0F0F0F0F0E130F0E14100F15111016121116\
141318151517161513322B236C64598880757F776C7C74697870657B73688D857A
9F978C90887D857D728A8277928A7F877F74665E5348403530281D31291E322A1F322A1F362E23\
41392E51493E5C5449564E4341392E2F271C31291E3E362B494136534B405A5448
5E5A4F5D5B4F5D5B4F5B594D58564A5351454E4C404B493D4D4B3F4B493D413F334C4A3E3C3A2E\
312F234442362B291D222014333124444236484639413F333C3A2D3E3C30434134
4F4D41403E31302E222C2A1D343226413F3249473B49493F595E574E554E5C625E353B375F6565\
B2B7BAA0A5A9ACB0B9ACB0BBADB0BFADB0C1AFB2C5B0B2C9B1B3CAB2B4CDB0B4CD
AFB7CEACB8CEACB8CEADB9CFADB9CFAEBAD0AEBAD0AEBAD0ABB7CDABB7CDABB7CDABB7CDABB7CD\
ABB7CDABB7CDABB7CDACB6CFACB6CFACB6D1ACB6D1ACB5D2ACB5D2ACB5D4ACB5D4
ADB6D7ADB6D7ADB5D9ADB5D9ADB5DAADB5DAADB5DCADB5DAABB4D5ABB4D3ABB4D5ABB4D3ABB4D5\
ABB4D3ABB4D5ABB4D3AEB7D8AEB7D6AEB7D8AEB7D6AEB7D8AEB7D6AEB7D8AEB7D6
AEB7D8AEB7D6AEB7D8AFB8D7B0B9DAB1BAD9B1BADBB1BAD9AFB8D9AFB8D7AFB8D9AFB8D7AFB8D9\
AFB8D7AFB8D9AFB8D7
7E806A7C7E68787A647476606F715B6A6C5667695365675172745E62644E52543E4F513B5C5E48\
6B6D5773755F7776628C867A938A818D847B80776E837A718D847B8279706A6158
847B72867D746B62596E655C9990879E958C877E758B8376A29D899A987F98947B96947B98947B\
939178918D748D8B72848067807E6576725967654C69654C6C6A5166624957523C
4C453258513F655E4C68614F655E4C625B49665F4D6B645268614F77705E827B69827B69857E6C\
8D8674918A788F8876736C5A716A58716A5877705E837C6A8E8774968F7C99937D
89836D837D657F7961837D63888268898467878265858166807D6A807E6F807E6F807E6F7F7D6E\
7C7A6B7A796779786676756173725E6C6B575F5E4951503B4948334948334A4C34
4346294D523443472E23261110120414160B1A1B16151515100F14100F1411101613121818171C\
1E1D22242426282725665F559B9386B4AC9FB1A99CB9B1A4B9B1A4AFA79AAFA79A
CAC2B5BBB3A6A79F92938B7E7D75685C5447352D201911041F170C261E132D251A2F271C342C21\
473F34655D527D756A655D52484035322A1F342C213F372C433B30473F344B4539
433F343F3D313A382C3634283634283A382C3E3C3042403439372B4240343432264240342F2D21\
2A281C5D5B4F5351452A281C17150916130A2E2C20413E354442364A473E565448
45423949473B4D4A41504E4257544B6765597B786F8889817A817A57605B767F7C525B5A586062\
A9B1B4AAB1B9A6ADB7B1B7C5B1B6C9B1B6CAB1B6CCB2B6D1B2B6D1B2B6D3B0B7D3
AFBBD5ADBBD5ADBBD5ACBAD4ACBAD4ABB9D3ABB9D3ABB9D3ACBAD4ACBAD4ACBAD4ACBAD4ACBAD4\
ACBAD4ACBAD4ACBAD4ACB7D3ACB7D5ACB7D5ACB7D5ACB7D7ACB7D7ACB6D9ACB6D9
B0BADEB0BADEB0B9E0B0B9E0B0B9E2B0B9E2B0B9E4B0B9E2AFB9DDAFBADAAFB9DCAFBADAAFB9DC\
AFBADAAFB9DCAFBADAB5BFE2B5C0E0B5BFE2B5C0E0B5BFE2B5C0E0B5BFE2B5C0E0
B3BDE0B4BFDFB4BEE1B5C0E0B6C0E3B6C1E1B7C1E4B7C2E2B2BCDFB2BDDDB2BCDFB2BDDDB2BCDF\
B2BDDDB2BCDFB2BDDD
7D7F697B7D67787A647476606F71596B6D55686A52666850383A223A3E253D412A3E422B383B26\
2B2E191B1E0B1112020703001C150B1F180E191208332C225E574D686157554C43
2A21183C3429352C234C44398E857CA29A8F978F84A69E9199948098967D9B99829D9B8298967F\
93917896947D9E9C83918F78918F7687856E78765D74725B76745B6A685159543E
504A3457503D5C554257503D4F48364C4533534C3A5A54445B55456C66567A74647B75657D7767\
817E6D868070817E6D847F6C767360696451615C4966614D726D597F7A6686816D
938E788B856F857F6988826C8C866E8B856D88826885816886837085847286837284837183806F\
7F7E6C7E7B6A7B7A66807D6A807F6B807E6979786376745F77766182806B8A8A72
6C6F547A7F616668502B2F180809000E10031818100F100B1615131515151715161A1A1A232122\
2C2C2C3634353C3B36322F2032301B120F00050200302F1D575546585647504E41
4846394E4C405652475A564B5B544A565044524C404F493D453F334A44384A44383F392D373125\
413B2F5F594D797268645D53494238373026423B31544D435E574D645D536B645C
7571686D6A616461585F5C53625F566E6B627C79708582798481789390877E7B7286837A6A675E\
636057A6A39AA7A49B8D8A835350492B282135322B403D36302D2623201927241D
23201956534C97948DBFBCB5C6C3BCBCB9B2B7B4ADB6B6AE898E87596059858B87626B6A50585A\
A3ACB1B1BBC4A2ACB8B0BCCCB0BBCFAFBAD0AFB9D2B1B8D4B0B7D4B0B7D4AEB7D4
B3C1DCB1C1DBB0C0DAAFBFD9AEBED8ADBDD7ACBCD6ACBCD6B1C1DBB1C1DBB1C1DBB1C1DBB1C1DB\
B1C1DBB1C1DBB1C0DDB4C1E1B4C1E1B4C1E1B4C1E1B4C1E3B4C1E3B4C1E4B4C1E4
B6C3E6B6C2E8B6C2E8B6C2E8B6C2EAB6C2EAB6C2ECB6C2EAB8C5E8B8C5E7B8C5E7B8C5E7B8C5E7\
B8C5E7B8C5E7B8C5E7B5C2E4B5C2E4B5C2E4B5C2E4B5C2E4B5C2E4B5C2E4B5C2E4
AFBCDEAFBCDEB0BDDFB1BEE0B1BEE0B2BFE1B3C0E2B3C0E2AFBCDEAFBCDEAFBCDEAFBCDEAFBCDE\
AFBCDEAFBCDEAFBCDE
807B6885806C85806C7F7A6479775E75735A66664A56563A4040263D40253F432C4245303C402F\
2E32232125171C1E111313071C1C101B1B0F19190D3432255A584B6763575E584C
423C30403A2C4B4338665E51867C729A9084A2988CA39C8C9C97839C97819C97839C97819C9783\
9C97819C97839C978196917D8E897385806C7F7A647C776376715B6C675365604A
534D335852385D573F5D57415A55415954415C56465D5A4B6966576E6C5D7C7A6D8A8B7D909181\
8B8E7D868777838675898A786669545D5F4A61634E5A5C476665517F7E6A888572
88857489837389837388827288817188817187807087806E88837085826F86816E827F6C837E6B\
807D6A807B687E7C67817C68807E69817C687C7A657B76627A7863817C6883816C
4F4F3790927A57573F0E1000302F1B22231103010028291B302E2215150B1F1C1326261E232019\
3A3A324A474027271B2D31181E2506000500222A122D36214F5A495B6759657167
4B554D585E5A6A6F6B6969675C5B596D6966787370625D59504C415753475B574B504C4039352A\
332F24504C41757168646057524D4745403A4F4A466964607C77737B7672726D69
87847F83807B7D7A757A77727B7873827F7A8986818F8C87AAA7A29D9A95827F7AA4A19C6A6762\
514E49BBB8B3AEABA6A4A19C53504B1C19142A27223F3C37312E29211E1925221D
2E2B263A37327F7C779C9994BFBCB7B3B0ABC4C1BCAFACA59E9B9248483E797A72696B68565B5E\
A0A9AEBBC7D3A7B7C6AABBCFAABAD1AABAD3ABBBD5ADBBD6AEBCD9B0BBD9AEBCD9
B0BFDCAFC0DCAFC0DCAFC0DCAFC0DCAFC0DCAFC0DCAFC0DCB5C6E2B5C6E2B5C6E2B5C6E2B5C6E2\
B5C6E2B5C6E2B5C6E2B8C7E6B8C7E8B7C6E7B6C5E6B6C5E6B5C4E5B4C3E4B4C3E4
B3C2E3B4C2E5B5C3E6B6C4E7B5C3E6B4C2E5B2C0E3B0C0E2B3C3E4B1C4E4B1C4E4B1C4E4B1C4E4\
B1C4E4B1C4E4B1C4E4AFC2E2AFC2E2AFC2E2AFC2E2AFC2E2AFC2E2AFC2E2B1C1E2
B3C3E4B4C3E4B3C2E3B2C1E2B2C1E2B1C0E1B0BFE0B0BFE0B0BFE0B0BFE0B0BFE0B0BFE0B0BFE0\
B0BFE0B0BFE0B0BFE0
817A68867F6C857E6B7F79617A765D77735868674958573936361A3A3D22464832505340525647\
4E5244494C43474A4146483D4D4F42494B3E44463956564A7273657A786B6D695D
6B65576D67597971648C84779D9387A1978B9990819089779D96849C97839C97839C97839C9783\
9C97839C97839C97839B9682938E7A8A8571847F6B807B677A7561716C5869644E
605B3E645F4268624869634B67624C66614E6663526865566E6C5F6465575B5B4F585A4D5D6153\
6B6F607D81738B8F80797E6A5B604A535842555A444E513C5C5F4A7E7D6B8A8977
8B88798B88798D877B8C867A8C84798B83788B83788B83768B86738A857189847088836F86816D\
85806C847F6B837E6A817C68837E6A827D697F7A667C77637C7763807B6782806B
57553E8E8E766867522F2E1943422E41402C302F1D504F3D3B392A3735263E3C2F413F323D3B2F\
4240343B382F1E1F0F0E14001F29071A2507707E6482917C8E9F8F84958B7D8E88
9FAFAE8C9A9B8B9499959AA09FA0A5A8A7AD9F9CA38480816E6B626D6B5E6C6A5D636154525044\
4B493D5B584F7370677A77707B7871817D7A8F8B88A09C99ACA8A5B0ACABAFABAA
BCB8B5B9B5B2B5B1AEB2AEABB3AFACB7B3B0BCB8B5C0BCB99D9996A9A5A2A29E9BB5B1AE635F5C\
3C3835A8A4A1B1ADAABDB9B68985824743401C1815120E0B191512221E1B272320
1A161319151245413E676360ACA8A5A7A3A0B2AEABABA8A1A29B914D493D7B786F6C6D68545A5A\
A1AAB1B8C6D1A7B8C8ADBFD5ABBFD7ACC0DBADC1DCB0BFDCB1C0DDB3C1DEB2C1DE
B3C2DFB2C3DFB2C3DFB2C3DFB2C3DFB2C3DFB2C3DFB2C3DFB5C6E2B5C6E2B5C6E2B5C6E2B5C6E2\
B5C6E2B5C6E2B5C6E2B7C7E8B7C7E8B6C6E7B6C6E7B5C5E6B4C4E5B4C4E5B3C3E4
B2C2E3B3C3E4B4C4E5B5C5E6B5C5E6B3C3E4B2C2E3AFC2E2B1C4E4B0C5E4B0C5E4B0C5E4B0C5E4\
B0C5E4B0C5E4B0C5E4AEC3E2AEC3E2AEC3E2AEC3E2AEC3E2AEC3E2AEC3E2AEC3E2
B3C3E4B3C3E4B2C2E3B2C2E3B1C1E2B0C0E1B0C0E1AFBFE0AFBFE0AFBFE0AFBFE0AFBFE0AFBFE0\
AFBFE0AFBFE0AFBFE0
857E6C89826F89826F827C647F7B627D795E6F6E50605F414F4F335A5D426A6C56737663767A6B\
767A6C75786F75786F6F716674766B6F716666685B6E6E627D7D717E7C6F6E6C5F
7C786C827E728D8779989284A09989A29B8B9D9485968F7D9E97859D98849D98849D98849D9884\
9D98849D98849D9884A09B879A9581928D798B867285806C7F7A6677725E716C56
615B41615C3F615B41605A425E59435B5643565342545142504E4147483A3C3C302E302325291B\
23271924271C242819575C48585D47757A668C917D8588758386738E8D7B8A8977
908D7E8F8C7D918B7D908A7C90887B90887B8F877C8F877A8F8A778E89758D88748C87738A8571\
89847088836F87826E837E6A847F6B847F6B817C687D78647C77637F7A66807E69
5B594280806874735E4D4C374A493552513D5756446766546260517977687F7D707B796C7E7C70\
6F6D61545148464739272B12343D20313B227B87718D9B8A93A39896A6A391A3A3
8D9FA3798790798591939BA8A1A7B59EA0AD9C9BA9A09FA5797971747265716F626F6D60676559\
5F5D51646158706D647A77708C8982A39F9CB2AEABB6B2AFB7B3B0BCB8B7C1BDBC
B2AEABB1ADAAAFABA8ADA9A6ACA8A5ADA9A6AEAAA7AFABA89F9B98AFABA8AFABA8BEBAB776726F\
504C49A5A19EADA9A6A9A5A2AFABA88C888548444125211E312D2A3C383535312E
393532231F1C25211E45413EAFABA8ACA8A5ABA7A4B4B1AAA29B91514D417A776E71726D4F5555\
A3ACB3B6C4CFAABBCBB2C4DAB0C4DCB1C5E0B2C6E1B5C4E1B6C5E2B8C6E3B7C6E3
B5C4E1B4C5E1B4C5E1B4C5E1B4C5E1B4C5E1B4C5E1B4C5E1B5C6E2B5C6E2B5C6E2B5C6E2B5C6E2\
B5C6E2B5C6E2B5C6E2B8C8E9B7C7E8B7C7E8B6C6E7B5C5E6B5C5E6B4C4E5B4C4E5
B1C1E2B2C2E3B4C4E5B5C5E6B5C5E6B4C4E5B3C3E4B0C3E3B2C5E5B1C6E5B1C6E5B1C6E5B1C6E5\
B1C6E5B1C6E5B1C6E5AFC4E3AFC4E3AFC4E3AFC4E3AFC4E3AFC4E3AFC4E3AFC4E3
B4C4E5B3C3E4B3C3E4B2C2E3B1C1E2B1C1E2B0C0E1B0C0E1B0C0E1B0C0E1B0C0E1B0C0E1B0C0E1\
B0C0E1B0C0E1B0C0E1
8B84728F88758E877488826A8581688480657877596A694B6B6B4F7B7E638C8E788E917E8C9081\
8E928490938A90938A9FA098A3A59A9FA09897998E9A9A90A1A1959D9B8F908E81
8480748C887C928C7E908A7C938C7C9C9585A59C8DA69F8D9E99869E99859E99859E99859E9985\
9E99859E99859E9985A19C889D988497927E908B77898470827D697C776378735D
625C425C573A565036524C34504B354C473343402D3D3A293634253B3C2E3F3F333C3E333A3D32\
3A3D3434372E2C2F24191D0C2F3420656A568B907C8B8E7B8A8D7A91907E868573
928F80918E7F938D7F928C7E928A7D928A7D91897C91897C908B788F8A768E89758D88748B8672\
8A857189847088836F847F6B86816D87826E837E6A7E79657C77637D78647E7C67
7F7D66919179999883807F6A67665272715D858472848371605E4F8886778785787D7B6E8A887C\
78766A5B584F6061536265505B6049444C37737E6E909D9399A8A5B0C2C4B3C4CC
AEC0CCACBDCDB0BFD2B2BED4929AB15C627A5E63799597A471706C706E61727063767467727064\
6C6A5E706D647B786F807D76928F88A8A4A1B1ADAAADA9A6A8A4A1A8A4A3ABA7A6
AEAAA7AEAAA7AEAAA7ADA9A6ABA7A4A9A5A2A7A3A0A5A19EB0ACA9AAA6A39E9A97B6B2AFA19D9A\
8F8B88B6B2AFA4A09D95918EB4B0ADB1ADAA7F7B785C585564605D716D6A6D6966
797572514D4A2D2926413D3ABDB9B6B7B3B0A8A4A1B9B6AFA39C9256524678756C767772484E4E\
A5AEB5B4C2CDADBECEB4C6DCB2C6DEB3C7E2B3C7E2B7C6E3B8C7E4B9C7E4B9C8E5
B5C4E1B4C5E1B4C5E1B4C5E1B4C5E1B4C5E1B4C5E1B4C5E1B5C6E2B5C6E2B5C6E2B5C6E2B5C6E2\
B5C6E2B5C6E2B5C6E2B9C9EAB8C8E9B8C8E9B7C7E8B6C6E7B6C6E7B5C5E6B5C5E6
B0C0E1B1C1E2B3C3E4B4C4E5B5C5E6B4C4E5B3C3E4B1C4E4B3C6E6B2C7E6B2C7E6B2C7E6B2C7E6\
B2C7E6B2C7E6B2C7E6B0C5E4B0C5E4B0C5E4B0C5E4B0C5E4B0C5E4B0C5E4B0C5E4
B5C5E6B4C4E5B4C4E5B3C3E4B2C2E3B2C2E3B1C1E2B1C1E2B1C1E2B1C1E2B1C1E2B1C1E2B1C1E2\
B1C1E2B1C1E2B1C1E2
8B84728F88758E877488826A8682698783687C7B5D6F6E5069694D7D80658A8C7680837075796A\
777B6D7C7F767C7F7684877E878A81878A8384877E878880898B8086867C7E7E72
7C7A6D908C809E988A979183928C7C9892829F9888A099879E99869E99859E99859E99859E9985\
9E99859E99859E99859F9A869E99859A9581938E7A8C877385806C817C68807B65
706A52655F455A543C58523A5B56405D584455523F4E4B3A4745364A4B3D46463A3B3D323A3D36\
4649424B4D484649403C4031464A39656958787C6B787B6A8A8D7CA6A495A7A596
928F7E928F7E938D7D938D7D938C7C928B7B928B7B918A7A908B788F8A768E89758D88748B8672\
8A857189847088836F86816D89847089847086816D807B677C77637C77637B7964
8280698989719A99848D8C776F6E5A7A7965908F7D878674656354898778828073747265828074\
79776B69665D7A786C535444494A3A3F43356E756D9CA6A59BA9ACB3C4CEAABBCB
B7C9DFBFD3ECC5D6F4C2D1F097A6C74C597B4E587B9FA5BB70706E7674677C7A6D817F727B796D\
7573677E7B728D8A81A09D96A7A49DB0ACA9B5B1AEB4B0ADB1ADAAAEAAA9ADA9A8
B5B1AEB6B2AFB6B2AFB6B2AFB3AFACB0ACA9ACA8A5AAA6A3B4B0ADA6A29F999592AFABA8B6B2AF\
B2AEABB9B5B2A39F9CACA8A5B1ADAAA8A4A18D898675716E736F6C86827F989491
8F8B8866625F393532423E3BB9B5B2B3AFACA5A19EB3B0A9A39C925C584C77746B7C7D78414747\
A7B0B7B1BFCAB1C2D2B3C5DBB1C5DDB2C6E1B2C6E1B6C5E2B7C6E3B8C6E3B8C7E4
B3C2DFB2C3DFB2C3DFB2C3DFB2C3DFB2C3DFB2C3DFB2C3DFB5C6E2B5C6E2B5C6E2B5C6E2B5C6E2\
B5C6E2B5C6E2B5C6E2B9C9EAB9C9EAB8C8E9B8C8E9B7C7E8B6C6E7B6C6E7B5C5E6
AFBFE0B0C0E1B2C2E3B4C4E5B5C5E6B5C5E6B4C4E5B2C5E5B3C6E6B2C7E6B2C7E6B2C7E6B2C7E6\
B2C7E6B2C7E6B2C7E6B0C5E4B0C5E4B0C5E4B0C5E4B0C5E4B0C5E4B0C5E4B0C5E4
B5C5E6B5C5E6B4C4E5B4C4E5B3C3E4B2C2E3B2C2E3B1C1E2B1C1E2B1C1E2B1C1E2B1C1E2B1C1E2\
B1C1E2B1C1E2B1C1E2
8982708C85728A8370847E66837F668682677D7C5E7170526F6F538083687F816B5F624F3F4334\
363A2C373A3134372E31342D333530353732363932383933393A323A3A3238382E
4240346D6B5E9592839E988A9B95859D97879E978797907E9F9A869F9A869F9A869F9A869F9A86\
9F9A869F9A869F9A869D98849E99859D988498937F908B778B86728984708A856F
7C765E6C664C5D573F5E58406B665076715B73715C6E6B586B695A77786A7C7C7274756D757772\
7F817E7D7F7E71736E7175677074637B7F6E787C6B696C5B7376658684757D7B6C
949180949180958F7F958F7F958E7E948D7D948D7D938C7A918C78908B778F8A768E89758C8773\
8B86728A857189847088836F8B86728C877388836F827D697C77637A7561797762
77755E7D7D658D8C778A897479786484836F9392808C8B795A58496D6B5C6B695C605E51656357\
6664586562596D6B5F615F535250444849436266658F979A7F8C959FAFBF95A7BF
8FA2C095A9CA90A4C9A0B3DBA3B5DD697AA55E6D98A6AFCC75767879776A7D7B6E7F7D707A786C\
777569838077959289AEABA4ADAAA3AEAAA7B1ADAAB6B2AFB8B4B1B6B2B1B4B0AF
AEAAA7AEAAA7AEAAA7ADA9A6ABA7A4A8A4A1A6A29FA4A09DA8A4A1ACA8A5ACA8A5ADA9A6AEAAA7\
A9A5A2A9A5A2ABA7A4B1ADAAA6A29FA39F9CA39F9C918D8A76726F706C697B7774
8783806D696657535056524FB1ADAAB2AEABB2AEABB3B0A9A49D93615D5175726982837E3B4141\
AAB3BAAEBCC7B4C5D5B2C4DAB0C4DCB1C5E0B1C5E0B5C4E1B6C5E2B7C5E2B7C6E3
B3C2DFB2C3DFB2C3DFB2C3DFB2C3DFB2C3DFB2C3DFB2C3DFB5C6E2B5C6E2B5C6E2B5C6E2B5C6E2\
B5C6E2B5C6E2B5C6E2BACAEBBACAEBB9C9EAB9C9EAB8C8E9B7C7E8B7C7E8B6C6E7
AEBEDFAFBFE0B2C2E3B4C4E5B5C5E6B6C6E7B5C5E6B3C6E6B4C7E7B3C8E7B3C8E7B3C8E7B3C8E7\
B3C8E7B3C8E7B3C8E7B1C6E5B1C6E5B1C6E5B1C6E5B1C6E5B1C6E5B1C6E5B1C6E5
B6C6E7B6C6E7B5C5E6B5C5E6B4C4E5B3C3E4B3C3E4B2C2E3B2C2E3B2C2E3B2C2E3B2C2E3B2C2E3\
B2C2E3B2C2E3B2C2E3
8D86749089768E877488826A88846B8B876C8382647877597B7B5F8A8D7280826C4E513E212516\
13170913160D10130C1E231D1E231F1F242021262222241F21241D24251D27291E
18180C5452458A88799B98899B9887A09D8CA29D8A9B9683A09B87A09B87A09B87A09B87A09B87\
A09B87A09B87A09B879D9884A09B87A29D899D988496917D928D79938E7A96917B
88826A736D555E58405D573F6D69507D78627E7C67797663838172969789A2A298A0A19BA7A9A6\
B9BABCB9BABEABADAC9DA0979A9E8FA3A798A0A49596988AA2A496AFAD9E9D9B8C
9895849895849A958299948199928098917F98917F98917E95907C948F7B938E7A928D79908B77\
8F8A768E89758D88748984708C87738E89758A8571837E6A7C7763797460777560
8D8B749898809F9E89A09F8AA3A28EA9A894ABAA98AAA997A09E8FA3A192B2B0A3B6B4A7AFADA1\
BAB8ACC0BDB4B3B0A7AEAAA19E99938F8E8C878B8E9EA5AF7B8797A9B8CFA9BDD8
B0C4E7B3C9F09DB4DEA5BCE8B6CBFA7C91C05A6C9C929FC17D818479776A7472657A786B817F73\
88867A959289A3A097ABA8A1ABA8A1ACA8A5ADA9A6AEAAA7B0ACA9B2AEADB3AFAE
B9B5B2B8B4B1B7B3B0B6B2AFB4B0ADB4B0ADB3AFACB3AFACA6A29FB1ADAAB5B1AEA9A5A2A9A5A2\
A9A5A2A19D9AB2AEABA6A29FA4A09DADA9A6B9B5B2B1ADAA94908D7E7A77777370
928E8B8B878495918E86827FB3AFACB4B0ADC1BDBAAFACA5A49D93656155747168868782363C3C\
ABB4BBACBAC5B6C7D7B3C5DBB1C5DDB2C6E1B3C7E2B6C5E2B7C6E3B9C7E4B8C7E4
B5C4E1B4C5E1B4C5E1B4C5E1B4C5E1B4C5E1B4C5E1B4C5E1B5C6E2B5C6E2B5C6E2B5C6E2B5C6E2\
B5C6E2B5C6E2B5C6E2BBCBECBACAEBBACAEBB9C9EAB8C8E9B8C8E9B7C7E8B7C7E8
ADBDDEAFBFE0B1C1E2B4C4E5B5C5E6B6C6E7B6C6E7B4C7E7B5C8E8B4C9E8B4C9E8B4C9E8B4C9E8\
B4C9E8B4C9E8B4C9E8B2C7E6B2C7E6B2C7E6B2C7E6B2C7E6B2C7E6B2C7E6B2C7E6
B7C7E8B6C6E7B6C6E7B5C5E6B4C4E5B4C4E5B3C3E4B3C3E4B3C3E4B3C3E4B3C3E4B3C3E4B3C3E4\
B3C3E4B3C3E4B3C3E4
958E7C98917E968F7C908A72908C739490758D8C6E82816374745886896E7F816B505340272B1C\
2327192B2E252C2F28292D2C262A2B262A2B262A2925272422241F2526202B2C24
2E2E2467675B99978A9F9D8E9996859E9B88A29F8C9F9A87A09B87A09B87A09B87A09B87A09B87\
A09B87A09B87A09B879E9985A39E8AA5A08CA29D899B968298937F9B96829F9A86
9A947E807A62645E465F59416D69507D79607D7B647876618887757E7F715A5A52282924121315\
1D1E2323232D1B1C212D302922261823271925291A353729686A5C9896879A9889
9C99889C99889D98859D98859D96849C95829C95829B948198937F98937F96917D95907C948F7B\
928D79918C78908B778A85718D88748F8A768B8672837E6A7C776378735F76745F
83816A9191798F8E798F8E799F9E8A9F9E8A9695839998868381727F7D6E9F9D90B2B0A3A6A498\
B6B4A8C0BDB4A29E95B2ABA5B0ABA7B6B4B5ABACB1B3B7C3788093A1AFC9A0B3D1
97ABD0AEC4EDA2B9E5A8BEEDBAD0FF849ACB677BADA7B6D78C90937E7C6F7371647F7D70969488\
A7A599B5B2A9BEBBB2B3B0A9B9B6AFBDB9B6BAB6B3B4B0ADB1ADAAB4B0AFB9B5B4
B5B1AEB4B0ADB2AEABB0ACA9AFABA8B0ACA9B1ADAAB1ADAAB1ADAAB0ACA9ADA9A6A09C99B3AFAC\
BDB9B6A8A4A1B4B0ADB2AEABB2AEABB0ACA9AEAAA7B1ADAAB6B2AFB7B3B0B6B2AF
A9A5A2ADA9A6CAC6C3ACA8A5B4B0ADAFABA8C2BEBB9F9C95A59E94686458737067888984333939\
ACB5BCABB9C4B8C9D9B5C7DDB3C7DFB4C8E3B5C9E4B8C7E4B9C8E5BBC9E6BAC9E6
B8C7E4B7C8E4B7C8E4B7C8E4B7C8E4B7C8E4B7C8E4B7C8E4B5C6E2B5C6E2B5C6E2B5C6E2B5C6E2\
B5C6E2B5C6E2B5C6E2BBCBECBBCBECBACAEBB9C9EAB9C9EAB8C8E9B7C7E8B7C7E8
ADBDDEAEBEDFB1C1E2B4C4E5B6C6E7B6C6E7B6C6E7B4C7E7B5C8E8B4C9E8B4C9E8B4C9E8B4C9E8\
B4C9E8B4C9E8B4C9E8B2C7E6B2C7E6B2C7E6B2C7E6B2C7E6B2C7E6B2C7E6B2C7E6
B7C7E8B7C7E8B6C6E7B5C5E6B5C5E6B4C4E5B3C3E4B3C3E4B3C3E4B3C3E4B3C3E4B3C3E4B3C3E4\
B3C3E4B3C3E4B3C3E4
A69F8D9F988598917E958F77938F76908C71878668807F6178785C86896E92947E525542222617\
262A1C1D2017282D2723292930353923282B13181B1B1F1E22272326282331342D
27291E5B5D508485779596869C9B8991907C94937FB1AF9AA29D89A29D89A29D89A29D89A29D89\
A29D89A29D89A29D89A39E8AA29D89A19C88A09B879F9A869E99859D98849D9884
9B94818D87716B654F605A427672597E7A6175735A7B796279786495968856564E1B1B1915161A\
2626303635431B1B2521232021241925281D2327192123168587799593849B998A
9C99889B98879D98859C97839C95829C96809B957F9B957F9A958199948098937F97927E95907C\
948F7B938E7A928D798F8A768C87738C87738E897587826E7B76627974607D7B66
92907992927A94937E9695809897839A99859C9B899D9C8A9997887B796A9E9C8FB0AEA1AFADA1\
B6B4A8ABA89FB4B0A7B7B0AAB4ACAAB9B4B8B9B8C0A1A5B18890A391A0B7B0C1DF
B0C2E6A6BCE3ABC0EBB2C7F4A0B5E28095C47A8CBC8E9BBB9195967C7A6D767467918F82A9A79B\
AEACA0B2AFA6BDBAB1B9B6AFB9B6AFB8B4B1B7B3B0B7B3B0B6B2AFB5B1B0B5B1B0
B7B3B0B7B3B0B6B2AFB5B1AEB5B1AEB4B0ADB3AFACB3AFACB3AFACB3AFACB2AEABB1ADAAB1ADAA\
B0ACA9AFABA8AFABA8ADA9A6ADA9A6ADA9A6ADA9A6ADA9A6ADA9A6ADA9A6ADA9A6
B1ADAAB1ADAAB2AEABB3AFACB3AFACB4B0ADB5B1AEB5B2ABABA49A6460546E6B629E9F9A2E3434\
B1BAC1A9B7C2B5C6D6B7C9DFB5C9E1B5C9E4B5C9E4B8C7E4B8C7E4B9C7E4B8C7E4
B1C0DDB0C1DDB0C1DDB0C1DDB0C1DDB0C1DDB0C1DDB0C1DDB4C5E1B4C5E1B5C6E2B6C7E3B7C8E4\
B8C9E5B9CAE6BACBE7BBCBECBBCBECBBCBECBBCBECBBCBECBBCBECBBCBECBBCBEC
B0C0E1B2C2E3B5C5E6B7C7E8B9C9EABACAEBBACAEBB8CBEBB7CAEAB6CBEAB6CBEAB6CBEAB6CBEA\
B6CBEAB6CBEAB6CBEAB4C9E8B4C9E8B3C8E7B3C8E7B2C7E6B1C6E5B1C6E5B0C5E4
B2C2E3B2C2E3B3C3E4B3C3E4B3C3E4B4C4E5B4C4E5B4C4E5B4C4E5B4C4E5B3C3E4B2C2E3B1C1E2\
B0C0E1AFBFE0AEBEDF
A19A889C9582968F7C938D75938F76908C718887698382646F6F537B7E63898B754F523F282C1D\
2F332522251C272C2610151920272D32373D2F3438242A2A262A292A2F2B2A2D26
3031296B6D60959688A2A391A9A8969E9D8991907B9A9984A09E89A29D89A29D89A29D89A29D89\
A29D89A29D89A29D89A39E8AA39E8AA29D89A19C88A09B879F9A869F9A869E9985
A09986968F7C756F596761497874597D795E77755C807E678786729697896D6D656A6A6A818189\
76758358566B24233126282725281F282B2226291E24261B8A8C7F9A988BA09E8F
9D9A899C99869E99859D98829D97819D977F9C967E9C967E9B96809A958199948097927E96917D\
95907C938E7A938E7A908B778C87738D88748F8A7687826E7B76627974607D7B66
93917A93937B94937E9695809998849B9A869C9B899D9C8A9B998A7D7B6CA09E91B2B0A3B1AFA3\
B8B6AAACA9A0B6B2A9BFB8B2BBB3B0BDB7B9BAB7BE9EA0AC7C83937783998898B2
92A3C1899CBD8DA1C696AACF8FA1C97D8FB78392BB9BA7C18E908F7674676E6C5F8F8D80B1AFA3\
BBB9ADBAB7AEBDBAB1B9B6AFB9B6AFB8B4B1B8B4B1B7B3B0B6B2AFB6B2B1B5B1B0
B7B3B0B7B3B0B6B2AFB6B2AFB5B1AEB4B0ADB4B0ADB3AFACB3AFACB3AFACB2AEABB2AEABB1ADAA\
B0ACA9B0ACA9AFABA8ADA9A6ADA9A6ADA9A6ADA9A6ADA9A6ADA9A6ADA9A6ADA9A6
B1ADAAB2AEABB2AEABB3AFACB4B0ADB4B0ADB5B1AEB5B2ABACA59B6561556F6C639E9F9A2D3333\
B0B9C0A9B7C2B6C7D7BACCE2B8CCE4B8CCE7B8CCE7BBCAE7BBCAE7BCCAE7BBCAE7
B9C8E5B8C9E5B8C9E5B8C9E5B8C9E5B8C9E5B8C9E5B8C9E5B3C4E0B4C5E1B4C5E1B5C6E2B6C7E3\
B7C8E4B8C9E5B8C9E5BCCCEDBCCCEDBCCCEDBCCCEDBCCCEDBCCCEDBCCCEDBCCCED
B3C3E4B4C4E5B7C7E8B9C9EABACAEBBACAEBBACAEBB7CAEAB7CAEAB6CBEAB6CBEAB6CBEAB6CBEA\
B6CBEAB6CBEAB6CBEAB5CAE9B5CAE9B5CAE9B4C9E8B3C8E7B2C7E6B2C7E6B2C7E6
B5C5E6B5C5E6B5C5E6B5C5E6B4C4E5B4C4E5B4C4E5B4C4E5B4C4E5B3C3E4B3C3E4B3C3E4B2C2E3\
B2C2E3B1C1E2B1C1E2
A19A889E97849A938099937B99957C9894799291738F8E707E7E62888B7093957F585B48323627\
373B2D262920262B27363D43202932272E36262D33121A1D2228282E3231111610
252821696C61939587989B88A4A593A6A8939A9C86989880A19F8AA39E8AA39E8AA39E8AA39E8A\
A39E8AA39E8AA39E8AA49F8BA49F8BA39E8AA39E8AA29D89A29D89A19C88A19C88
A49D8BA29B8888826C78725A807C617E7A5D78775B85836A91907C8B8C7E59585362626480808C\
7372846260784544562D2E302A2D262B2E27292C232A2C21909285A19F92A6A495
9E9B8A9E9B88A09B879F9A849F99819E987E9E987E9E98809C97819C97839B968299948098937F\
96917D95907C95907C928D798E89758E89758F8A7688836F7B76627974607D7B66
94927B94947C95947F9897829A99859C9B879E9D8B9E9D8B9E9C8D807E6FA3A194B5B3A6B4B2A6\
BCBAAEB0ADA4B9B5ACC5BEB6C0B9B3C0BBB8BDBBBEA3A6AD7F85916D7987717E91
5A698051617B54647E5E6D8A5D6B8658668167728E82899B9B9B998280737A786B99978ABDBBAF\
C7C5B9BFBCB3BAB7AEBAB7B0B9B6AFB9B5B2B8B4B1B7B3B0B7B3B0B6B2B1B6B2B1
B8B4B1B7B3B0B7B3B0B6B2AFB5B1AEB5B1AEB4B0ADB4B0ADB4B0ADB3AFACB3AFACB2AEABB1ADAA\
B1ADAAB0ACA9B0ACA9AFABA8AFABA8AFABA8AFABA8AFABA8AFABA8AFABA8AFABA8
B2AEABB2AEABB3AFACB3AFACB4B0ADB5B1AEB5B1AEB6B3ACADA69C676357716E659FA09B2C3232\
AFB8BFA9B7C2B7C8D8B7C9DFB5C9E1B5C9E4B5C9E4B8C7E4B8C7E4B9C7E4B8C7E4
B7C6E3B6C7E3B6C7E3B6C7E3B6C7E3B6C7E3B6C7E3B6C7E3B4C5E1B4C5E1B5C6E2B5C6E2B6C7E3\
B6C7E3B7C8E4B7C8E4BCCCEDBCCCEDBCCCEDBCCCEDBCCCEDBCCCEDBCCCEDBCCCED
B7C7E8B8C8E9B9C9EABBCBECBBCBECBACAEBB9C9EAB6C9E9B6C9E9B5CAE9B5CAE9B5CAE9B5CAE9\
B5CAE9B5CAE9B5CAE9B5CAE9B5CAE9B5CAE9B4C9E8B3C8E7B2C7E6B2C7E6B2C7E6
B8C8E9B7C7E8B6C6E7B5C5E6B4C4E5B3C3E4B2C2E3B1C1E2B1C1E2B1C1E2B2C2E3B2C2E3B3C3E4\
B3C3E4B3C3E4B4C4E5
A69F8DA59E8BA49D8AA49E86A4A087A4A085A1A082A09F817B7B5F878A6F91937D52554225291A\
2B2F2120231A272C2830373F272F3A6A717BB0B7BFBCC3C9C6CED0A4AAA8474C48
26292272756A999B8D909380979984A4A690A3A58DA3A38BA2A08BA49F8BA49F8BA49F8BA49F8B\
A49F8BA49F8BA49F8BA5A08CA5A08CA5A08CA5A08CA5A08CA49F8BA49F8BA49F8B
A39C8AACA5939E9784908A72918D7285816478775B828067908F7B8C8D7F47464127262B2B2A38\
2F2D4347446148465C3132362C2F282C2F282C2F282F302896988DA6A498A9A798
A19E8DA09E89A29D87A19D84A19B81A19B81A09A80A09A809F9A849E99859D98849C97839A9581\
99948098937F97927E938E7A8F8A768F8A76908B7788836F7B76627974607D7B66
95937C95957D9796819998839B9A869D9C889F9E8CA09F8DA19F90838172A6A497B8B6A9B7B5A9\
BEBCB0B2AFA6BCB8ADC3BCB2BEB7ADBFBAB4C0BFBBB4B5B79A9FA389929B86929E
9EAAB897A4B498A4B49EAABA9FA8B79EA5B5A9AFBDBDC0C7B2B1ACA19F929C9A8DB0AEA1C5C3B7\
C7C5B9BDBAB1B6B3AABBB8B1BAB7B0BAB6B3B9B5B2B8B4B1B8B4B1B7B3B2B7B3B2
B9B5B2B8B4B1B8B4B1B7B3B0B6B2AFB6B2AFB5B1AEB5B1AEB5B1AEB4B0ADB4B0ADB3AFACB2AEAB\
B2AEABB1ADAAB1ADAAB0ACA9B0ACA9B0ACA9B0ACA9B0ACA9B0ACA9B0ACA9B0ACA9
B3AFACB3AFACB4B0ADB4B0ADB5B1AEB6B2AFB6B2AFB7B4ADAFA89E696559747168A0A19C2A3030\
ADB6BDA9B7C2BACBDBBACCE2B8CCE4B8CCE7B8CCE7BBCAE7BBCAE7BCCAE7BBCAE7
B6C5E2B5C6E2B5C6E2B5C6E2B5C6E2B5C6E2B5C6E2B5C6E2B7C8E4B7C8E4B8C9E5B8C9E5B8C9E5\
B8C9E5B8C9E5B8C9E5BCCCEDBCCCEDBCCCEDBCCCEDBCCCEDBCCCEDBCCCEDBCCCED
B9C9EABACAEBBBCBECBCCCEDBBCBECBACAEBB8C8E9B5C8E8B5C8E8B4C9E8B4C9E8B4C9E8B4C9E8\
B4C9E8B4C9E8B4C9E8B3C8E7B3C8E7B2C7E6B1C6E5B1C6E5B0C5E4AFC4E3AFC4E3
B7C7E8B6C6E7B5C5E6B3C3E4B1C1E2AFBFE0AEBEDFADBDDEADBDDEAEBEDFAEBEDFB0C0E1B1C1E2\
B2C2E3B3C3E4B3C3E4
A7A08EA8A18EAAA390AAA48CA9A58CAAA68BAAA98BABAA8C84846893967B9EA08A595C49262A1B\
2C30222B2E253C413D29323929333F727A85B0B9C2AEB5BBAEB6B98F9595393F3B
292E277B8175A9AD9E9CA18D999C879FA38C9DA1889FA189A2A08BA49F8BA49F8BA49F8BA49F8B\
A49F8BA49F8BA49F8BA7A28EA7A28EA7A28EA7A28EA7A28EA8A38FA8A38FA8A390
A19A8AB3AC9CB0A996A8A28AA6A287908C6F7877597C7B5F8E8D789B9C8E53524D1E1D23252434\
3F3C5758547545425D3132372C2E292D2F2A2F322B35362E9C9E93A8A69AA8A697
A3A08FA3A18CA49F89A4A087A49E84A39E81A39E81A29C82A19C86A09B879F9A869E99859C9783\
9B96829A958199948095907C918C78918C78918C788984707B766278735F7C7A65
97957E97977F9998839B9A859D9C889F9E8AA1A08EA2A18FA3A192858374A8A699B9B7AAB8B6AA\
C0BEB2B4B1A8BDB9AEC0BAACBDB7A9BCB8ACBFBFB5BCBEB9B3B7B6ABB4B3ABB5B7
A5AEB3A3ACB1A5ACB2ABB0B4AAAEB1A8A9ABABABABB3B2AEBCB9B0B7B5A8B8B6A9C0BEB1C3C1B5\
BEBCB0B9B6ADB8B5ACBBB8B1BBB8B1BAB6B3BAB6B3B9B5B2B8B4B1B8B4B3B7B3B2
B9B5B2B9B5B2B8B4B1B8B4B1B7B3B0B6B2AFB6B2AFB5B1AEB5B1AEB5B1AEB4B0ADB4B0ADB3AFAC\
B2AEABB2AEABB1ADAAB2AEABB2AEABB2AEABB2AEABB2AEABB2AEABB2AEABB2AEAB
B3AFACB4B0ADB4B0ADB5B1AEB6B2AFB6B2AFB7B3B0B7B4ADB0A99F6C685C76736AA1A29D292F2F\
ABB4BBA9B7C2BCCDDDC1D3E9BFD3EBBFD3EEBFD3EEC2D1EEC2D1EEC3D1EEC2D1EE
BECDEABDCEEABDCEEABDCEEABDCEEABDCEEABDCEEABDCEEABBCCE8BBCCE8BBCCE8BBCCE8BBCCE8\
BACBE7BACBE7BACBE7BACAEBBACAEBBACAEBBACAEBBACAEBBACAEBBACAEBBACAEB
B8C8E9B9C9EABACAEBBBCBECBACAEBB9C9EAB7C7E8B4C7E7B5C8E8B4C9E8B4C9E8B4C9E8B4C9E8\
B4C9E8B4C9E8B4C9E8B0C5E4B0C5E4AFC4E3AFC4E3AEC3E2ADC2E1ADC2E1ACC1E0
B4C4E5B3C3E4B2C2E3B0C0E1AEBEDFADBDDEABBBDCAABADBAABADBABBBDCACBCDDADBDDEAEBEDF\
AFBFE0B0C0E1B0C0E1
A49D8BA7A08DAAA390ABA58DA8A48BA9A58AAAA98BADAC8E89896D94977C999B854F523F181C0D\
191D0F13160D2025214E57604B54635E66734E57601C232B1820232A2F321B211F
171C15676D619CA0919FA490A3A691A1A58E9A9E859FA189A3A18CA5A08CA5A08CA5A08CA5A08C\
A5A08CA5A08CA5A08CA8A38FA8A38FA9A490A9A490AAA591AAA591ABA692ABA693
A49D8DB8B1A1BAB3A0B6B098B4B0959B977A7B7A5C7A795D91907B93948642413D1C1B214B4A5C\
8885A29F9BC07774913030382D2F2C30322D3639323E3F39A4A69BABA99DA7A596
A5A291A5A38EA7A28CA6A287A6A086A5A083A5A082A5A083A39E88A39E8AA29D89A09B879F9A86\
9D98849C97839C978397927E938E7A928D79928D798984707C776378735F7C7A65
9997809898809A99849C9B869E9D89A1A08CA2A18FA3A290A3A192858374A8A699BAB8ABB9B7AB\
C0BEB2B4B1A8BDB9AEBFB9A9BFBAA7BEBBAABDBEB0BCBEB3BBBEB5BAC1BABCC2BE
B1B7B3B3B9B5B9BBB6BEBFB9C2BFB6C1BDB2C1BBAFC0BAACB6B2A6BAB8ABC0BEB1C1BFB2BDBBAF\
B9B7ABB9B6ADBCB9B0BCB9B2BCB9B2BBB7B4BBB7B4BAB6B3B9B5B2B9B5B4B8B4B3
BAB6B3BAB6B3B9B5B2B9B5B2B8B4B1B7B3B0B7B3B0B6B2AFB6B2AFB6B2AFB5B1AEB5B1AEB4B0AD\
B3AFACB3AFACB2AEABB3AFACB3AFACB3AFACB3AFACB3AFACB3AFACB3AFACB3AFAC
B4B0ADB5B1AEB5B1AEB6B2AFB7B3B0B7B3B0B8B4B1B8B5AEB2ABA16F6B5F79766DA1A29D272D2D\
A9B2B9A9B7C2BECFDFB9CBE1B7CBE3B7CBE6B7CBE6BAC9E6BAC9E6BBC9E6BAC9E6
BBCAE7BACBE7BACBE7BACBE7BACBE7BACBE7BACBE7BACBE7BCCDE9BCCDE9BBCCE8BBCCE8BACBE7\
B9CAE6B9CAE6B9CAE6B8C8E9B8C8E9B8C8E9B8C8E9B8C8E9B8C8E9B8C8E9B8C8E9
B4C4E5B6C6E7B7C7E8B8C8E9B9C9EAB8C8E9B7C7E8B4C7E7B4C7E7B3C8E7B3C8E7B3C8E7B3C8E7\
B3C8E7B3C8E7B3C8E7B1C6E5B0C5E4B0C5E4AFC4E3AEC3E2AEC3E2ADC2E1ADC2E1
B3C3E4B2C2E3B1C1E2B0C0E1AFBFE0AEBEDFADBDDEADBDDEACBCDDADBDDEADBDDEADBDDEAEBEDF\
AEBEDFAFBFE0AFBFE0
A59E8CA9A28FAEA794AEA890AAA68DAAA68BACAB8DB1B09279795D7E81668587714B4E3B282C1D\
31352721241B2126220C151E293241424C5839434D1E2730121B201820221C2522
383F386A70668B8F80979C88A5A893A3A7909CA087A5A78FA4A28DA6A18DA6A18DA6A18DA6A18D\
A6A18DA6A18DA6A18DA9A490A9A490AAA591ABA692ACA793ADA894ADA894AEA996
ACA595BCB5A5BAB3A1B7B19BB9B59AA29E818180617D7C6092917C84857731302C1A19214C4A5F\
7C79989590B87B789732323C2F312E3638333F423B494A44ADAFA4AFADA1A8A697
A7A493A7A590A8A38DA8A489A8A288A7A285A7A284A6A184A5A08AA5A08CA39E8AA29D89A19C88\
9F9A869E99859D9884999480948F7B938E7A938E7A8A85717C776378735F7C7A65
9A98819A9A829B9A859D9C87A09F8BA2A18DA3A290A4A391A2A091848273A7A598B9B7AAB8B6AA\
C0BEB2B4B1A8BDB9ADBDB8A5C4BFA9C6C4AFC1C2B0BCBFAEBBBFB1BCC2B6BFC5B9
B0B6AAB4B8AAB9BAACBDBAABC3BCAAC6BEA9C6BBA5C0B8A3BBB8A7BDBBAEBFBDB0BEBCAFBDBBAF\
BDBBAFBDBAB1BCB9B0BDBAB3BCB9B2BCB8B5BBB7B4BAB6B3BAB6B3B9B5B4B9B5B4
BBB7B4BAB6B3BAB6B3B9B5B2B8B4B1B8B4B1B7B3B0B7B3B0B7B3B0B6B2AFB6B2AFB5B1AEB4B0AD\
B4B0ADB3AFACB3AFACB5B1AEB5B1AEB5B1AEB5B1AEB5B1AEB5B1AEB5B1AEB5B1AE
B5B1AEB5B1AEB6B2AFB6B2AFB7B3B0B8B4B1B8B4B1B9B6AFB3ACA2706C607B786FA2A39E262C2C\
A7B0B7A9B7C2C0D1E1B2C4DAB0C4DCB0C4DFB0C4DFB3C2DFB3C2DFB4C2DFB3C2DF
B5C4E1B4C5E1B4C5E1B4C5E1B4C5E1B4C5E1B4C5E1B4C5E1B9CAE6B9CAE6B8C9E5B7C8E4B6C7E3\
B5C6E2B4C5E1B4C5E1B5C5E6B5C5E6B5C5E6B5C5E6B5C5E6B5C5E6B5C5E6B5C5E6
B0C0E1B1C1E2B3C3E4B5C5E6B7C7E8B7C7E8B6C6E7B4C7E7B3C6E6B2C7E6B2C7E6B2C7E6B2C7E6\
B2C7E6B2C7E6B2C7E6B4C9E8B4C9E8B4C9E8B3C8E7B2C7E6B1C6E5B1C6E5B1C6E5
B4C4E5B4C4E5B4C4E5B4C4E5B3C3E4B3C3E4B3C3E4B3C3E4B3C3E4B2C2E3B2C2E3B2C2E3B1C1E2\
B1C1E2B0C0E1B0C0E1
AAA390AFA895B4AE98B3AD95AFAB92AEAA8FB1B094B6B5999695799E9E84AFB19B949681949786\
B2B4A6A3A5979C9F969CA1A4A8AFB5A1A6AC979CA0A2A7AAA7ADABA3A8A4A8ADA6
93968D9FA3959A9D8C999C89A6A893A1A38D9A9C84A9A991A4A28DA6A18DA6A18DA6A18DA6A18D\
A6A18DA6A18DA6A18DA9A490AAA591ABA692ACA793ADA894AEA995AFAA96AFAA97
B5AE9EBFB8A8B8B19FB4AE98B9B59CA5A186868567828165908E798B897A4B4B43393738403E49\
35324339354E2E2B3E34343633342E3C3D3547493E525248B4B4A8B3B1A4AAA796
A8A592A8A691A9A48EA9A58CA9A389A8A288A8A386A7A285A6A18BA5A08AA49F8BA39E88A19C88\
A09B859F9A869E998399948095907A948F7B948F798A85717C776178735F7E7963
9A98819B99829D9B849F9D88A19F8AA3A08DA5A28FA6A392A29F8E848273A6A495B8B6A9B7B5A8\
BFBDB1B3B1A5BBB9ACB8B5A4C4C1AECCCBB7CAC9B7C1C2B2BFC1B3C0C4B6C2C6B8
C0C2B5C1C3B5C2C0B1C0BDACC5BEABCBC3AECCC1ABC6BEABCAC7B8C6C4B8C0BEB2BEBCB0C2C0B4\
C6C3BAC0BDB4B8B5ACBDBAB3BDBAB3BCB9B4BBB8B3BBB7B4BAB6B3B9B5B2B9B5B2
BBB7B4BBB7B4BAB6B3B9B5B2B9B5B2B8B4B1B7B3B0B7B3B0B7B3B0B7B3B0B6B2AFB5B1AEB5B1AE\
B4B0ADB3AFACB3AFACB5B1AEB5B1AEB5B1AEB5B1AEB5B1AEB5B1AEB5B1AEB5B1AE
B5B1AEB5B1AEB6B2AFB7B3B0B7B3B0B8B4B1B9B5B2B9B6B1B2AEA3726E627C7970A2A39E262A2B\
A7AEB6ACB6C2C4D1E2BCCDE1BCCCE5BBCCE6BBCCE6BCCCE6BCCCE6BDCBE6BCCCE6
B9CAE4B9CAE4B9CAE4B9CAE4B9CAE4B9CAE4B9CAE4B9CAE4B6C7E1B5C6E0B4C5DFB3C4DEB2C3DD\
B1C2DCB0C1DBB0C1DBB3C4E0B3C4E2B3C4E2B3C4E2B3C4E2B3C4E2B3C4E2B3C4E2
ACBDDBAEBFDDB1C2E0B3C4E2B5C6E4B6C7E5B6C7E5B6C7E5B3C6E4B3C6E4B3C6E4B3C6E4B3C6E4\
B3C6E4B3C6E4B3C6E4B9CCEAB9CCEAB8CBE9B8CBE9B7CAE8B6C9E7B6C9E7B7C7E8
B6C6E8B7C5E8B8C6E9B8C6E9B9C7EAB9C7EAB9C7EAB9C7EAB9C7EAB9C7EAB8C6E9B7C5E8B6C4E7\
B5C3E6B4C2E5B3C1E4
ABA690ACA791ADA990AFAB92B1AD94B3AF96B4B097B5B1989D99809D9B82A19F88A5A38CA9A792\
ABA994ADAB96ACAB97A9A79AA7A79BA8A69AA7A599A7A598A6A497A5A394A5A394
A09F8DA09F8DA29F8CA3A08DA4A28DA6A48FA6A48FA7A590A8A38FA8A38FA9A490AAA591AAA591\
ABA692ACA793ACA793AAA591ABA692ACA793ADA894AFAA96B0AB97B1AC98B2AD99
B0AB98B6B19EBCB7A3BCB7A3B0AB959C978185806A77725C86816D7976636966555B574B534F44\
534F4658534F5C57514A463A4F4C3D5956456865547C7968918E7DA3A08DB0AB98
AEA995ADA894ACA793ABA690A9A48EA8A38DA7A28CA6A289A6A18BA5A188A49F89A39F86A19C86\
A09C839F9A849E9A819C9781938F769B96808F8B728E8973817D6469644E8F8B72
9D977F9F9780A29A83A49C87A6A08AA9A28FAAA591ACA794A5A08D8F8C7B9E9D8BBAB8A9B9B7A8\
B8B6A9BDBEB0BEBCAFBDBBAFBDBBAFBEBCB0BFBDB1BFBCB3BEBEB4BFBFB5BFBFB5
C1C1B7C1C1B7C3C0B7C3C1B5C4C0B5C4C0B4C6C0B4C4C0B5C3C0B7C3C0B7C2BFB6C1BEB5C1BEB5\
C0BDB6BFBCB5BFBCB5BDBAB3BDBAB3BCB9B2BBB8B1BBB8B3BAB7B2B9B6B1B9B6B1
B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0\
B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0
B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B6B1B2B0A48684786B6B63A8A9A42C2D2F\
9699A0BBC1CDBCC3D5C0C8DDBEC9DFBDC9E1BBCAE1BACAE1BACAE1BACBDFBACBDF
BDCFE3BBD0E3BBD0E3BBD0E3BBD0E3BBD0E3BBD0E3BBD0E3B1C6D9B2C7DAB3C8DBB4C9DCB4C9DC\
B3C8DBB2C7DAB1C6DBB4C8E0B4C8E1B4C8E1B5C9E2B5C9E2B5C9E2B6CAE3B6CAE3
B3C7E0B3C7E0B3C7E0B3C7E0B3C7E0B3C7E0B3C7E0B5C6E0B7C6E3B7C5E2B7C5E2B5C3E0B4C2DF\
B3C1DEB2C0DDB2C0DDBBC9E6BBC9E6BBC9E6BAC8E5B9C7E4B8C6E3B8C6E3B8C5E5
B9C5EBB9C5EFB9C5EFB8C4EEB7C3EDB6C2ECB6C2ECB6C2ECAEBAE4AFBBE5B0BCE6B1BDE7B2BEE8\
B3BFE9B4C0EAB4C0EA
ACA88FADA990AEAA91AFAB92B1AD94B3AF96B4B097B5B198A8A48BA9A58CABA78EADA990AEAA91\
AEAA91AEAA91ADA990ACA793ACA793ABA692ABA692AAA591A9A490A9A490A8A38F
A49F8BA49F8BA5A08CA6A18DA7A28EA8A38FA8A38FA9A490A8A38FA9A490A9A490AAA591ABA692\
ABA692ACA793ACA793ABA692ABA692ACA793AEA995AFAA96B1AC98B2AD99B2AD99
B3AE9AB7B29EBCB7A3BDB8A4B9B4A0B0AB97A6A18D9F9A86ADA894ABA692AAA591A9A490ACA793\
B2AD99B8B39FBCB7A3B9B4A0B6B19DB3AE9AB0AB97B0AB97B3AE9AB6B19DB9B4A0
AEA995AEA995ADA894ABA692AAA591A8A38FA7A28EA7A28CA6A18BA5A188A4A087A39F86A19D84\
A09C839F9B829E9A819C987F938F769B977E8F8B728F8B72827E6569654C908A72
9F987EA2987FA49983A79C86A8A08BABA38EACA592ADA693A6A18E908D7AA09D8CBBBAA8BAB8A9\
B8B6A7BDBEAEBCBDAFBDBAB1BEBBB4BEBBB4BFBCB5C0BDB6C0BDB6C1BEB7C1BEB7
C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C2BFB8C1BEB7C1BEB7\
C0BDB6BFBCB5BFBCB5BDBAB3BDBAB3BCB9B2BBB8B1BBB8B1BAB7B0B9B6AFB9B6AF
B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0\
B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0
B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B6B1B2B0A48785796C6C64A9AAA52D2C31\
9699A0BEC0CDBEC4D4C0C5D9BEC6DBBCC7DDB9C8DDB9C8DDB8C9DDB8C9DBB8C9DB
B8CBDCB6CBDCB6CBDEB6CBDCB6CBDEB6CBDCB6CBDEB6CBDCB7CCDFB8CDDEB9CEE1BACFE0BACFE2\
B9CEDFB8CDE0B7CCDFBBCFE7BBCFE7BBCFE7BACEE6BACEE6BACEE6BACEE6BACEE6
BCD0E8BCD0E8BCD0E8BCD0E8BCD0E8BCD0E8BCD0E8BECFE9BCCAE5BBC9E4BDC8E6BBC9E4BCC7E5\
BAC8E3BBC6E4B9C7E2B8C3E1B5C3DEB7C2E0B4C2DDB5C0DEB3C1DCB4BFDDB2BFDF
B8C1E8B6C2EAB7C0E9B4C0E8B6BFE8B3BFE7B4BDE6B2BEE6AFB8E1ADB9E1B0B9E2AFBBE3B2BBE4\
B1BDE5B3BCE5B2BEE6
ADA990AEAA91AFAB92B0AC93B2AE95B3AF96B4B097B4B097B3AF96B3AF96B4B097B3AF96B2AE95\
B0AC93ADA990ACA88FADA894ACA793ACA793ABA692AAA591AAA591A9A490A9A490
A5A08CA5A08CA6A18DA6A18DA7A28EA8A38FA8A38FA8A38FA9A490A9A490AAA591AAA591ABA692\
ACA793ACA793ADA894ACA793ACA793ADA894AFAA96B0AB97B2AD99B3AE9AB3AE9A
B8B39FB9B4A0BAB5A1BBB6A2BCB7A3BDB8A4BEB9A5BEB9A5B2AD99B4AF9BB8B39FBBB6A2BDB8A4\
BCB7A3BBB6A2BAB5A1C3BEAABFBAA6B8B39FB2AD99ADA894AAA591A9A490A9A490
AFAA96AFAA96AEA995ACA793ABA692A9A490A8A38FA8A38DA7A28CA6A289A5A188A4A087A29E85\
A19D84A09C839F9B829D9980938F769C987F908C738F8B72827E656A664D918B73
9F987EA2987FA49983A79C86A8A08BABA38EACA592ADA693A7A28F918E7BA19E8DBBBAA8BAB8A9\
B8B6A7BDBEAEBBBCAEBEBBB2BEBBB4BFBCB5BFBCB5C0BDB6C1BEB7C1BEB7C2BFB8
C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C2BFB8C1BEB7C1BEB7\
C0BDB6BFBCB5BFBCB5BDBAB3BDBAB3BCB9B2BBB8B1BBB8B1BAB7B0B9B6AFB9B6AF
B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0\
B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0
B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B6B1B2B0A489877B6E6E66AAABA62D2C31\
95989FBDBFCCBFC5D5C1C6DABFC7DCBDC8DEBAC9DEBAC9DEB9CADEB9CADCB9CADC
B7C9DDB7C9DDB7C9DFB7C9DDB7C9DFB7C9DDB7C9DFB7C9DDB3C5DBB4C6DAB6C8DEB7C9DDB7C9DF\
B6C8DCB4C6DCB3C5DBB9CBE3B9CAE4B8C9E3B7C8E2B5C6E0B4C5DFB3C4DEB3C4DE
B5C6E0B5C6E0B5C6E0B5C6E0B5C6E0B5C6E0B5C6E0B5C6E0B2C1DEB2C1DEB3C0E0B3C2DFB4C1E1\
B4C3E0B5C2E2B4C3E0B4C1E1B2C1DEB3C0E0B1C0DDB1BEDEB0BFDCB0BDDDAFBEDD
B5C2E2B4C3E4B4C1E3B3C2E3B3C0E2B1C0E1B2BFE1B0BFE0B0BDDFAFBEDFB0BDDFB0BFE0B2BFE1\
B1C0E1B3C0E2B2C1E2
AFAB92AFAB92B0AC93B1AD94B2AE95B3AF96B4B097B4B097B6B299B6B299B6B299B5B198B4B097\
B1AD94AEAA91ADA990AEA995ADA894ADA894ACA793ABA692ABA692AAA591AAA591
A7A28EA7A28EA7A28EA7A28EA8A38FA8A38FA8A38FA8A38FAAA591AAA591ABA692ABA692ACA793\
ADA894ADA894AEA995ADA894AEA995AFAA96B0AB97B2AD99B3AE9AB4AF9BB5B09C
BAB5A1B9B4A0B8B39FB8B39FB8B39FBAB5A1BCB7A3BDB8A4BDB8A4BEB9A5BFBAA6BEB9A5BBB6A2\
B6B19DB0AB97ACA793B3AE9AB2AD99B0AB97B0AB97B1AC98B3AE9AB5B09CB7B29E
B1AC98B0AB97AFAA96AEA995ACA793ABA692AAA591A9A48EA7A28CA7A38AA6A289A4A087A39F86\
A19D84A09C83A09C839E9A819490779D9980908C73908C73837F666A664D918B73
A0997FA39980A59A84A89D87A9A18CACA48FADA693AEA794A9A49193907DA29F8EBCBBA9BBB9AA\
B8B6A7BDBEAEBBBCAEBFBCB3BFBCB5C0BDB6C0BDB6C1BEB7C2BFB8C2BFB8C3C0B9
C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C2BFB8C1BEB7C1BEB7\
C0BDB6BFBCB5BFBCB5BDBAB3BDBAB3BCB9B2BBB8B1BBB8B1BAB7B0B9B6AFB9B6AF
B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0\
B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0
B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B6B1B3B1A58B897D72726AACADA82D2C31\
93969DBDBFCCC0C6D6C5CADEC3CBE0C1CCE2BECDE2BECDE2BDCEE2BDCEE0BDCEE2
BBCDE3BBCDE3BBCDE5BBCDE3BBCDE5BBCDE3BBCDE5BBCDE3B1C3DBB2C4DAB3C5DDB4C6DCB4C6DE\
B3C5DBB2C4DCB1C3DBB8C9E3B7C8E2B6C7E3B4C5DFB2C3DFB0C1DBAFC0DCAEBFD9
ACBDD9ACBDD7ACBDD9ACBDD7ACBDD9ACBDD7ACBDD9ACBDD9ACBDDBACBDDBAEBDDEAEBFDDB0BFE0\
B0C1DFB2C1E2B2C3E1B6C5E6B5C6E4B5C4E5B3C4E2B4C3E4B2C3E1B2C1E2B1C2E0
B6C6E0B4C5DFB5C5DFB3C4DEB3C3DDB2C3DDB2C2DCB1C2DCB3C3DDB2C3DDB3C3DDB3C4DEB4C4DE\
B3C4DEB4C4DEB3C4DE
B1AD94B1AD94B2AE95B2AE95B3AF96B3AF96B4B097B4B097B1AD94B2AE95B3AF96B4B097B3AF96\
B2AE95B0AC93AFAB92AEA995AEA995ADA894ADA894ACA793ABA692ABA692AAA591
A9A490A9A490A9A490A9A490A8A38FA8A38FA8A38FA8A38FAAA591ABA692ABA692ACA793ADA894\
ADA894AEA995AEA995AFAA96B0AB97B1AC98B2AD99B4AF9BB5B09CB6B19DB7B29E
B5B09CB6B19DB7B29EB8B39FB8B39FB8B39FB7B29EB6B19DBAB5A1BBB6A2BBB6A2BCB7A3BDB8A4\
BEB9A5BFBAA6C0BBA7BDB8A4BCB7A3BBB6A2B9B4A0B8B39FB7B29EB8B39FB8B39F
B3AE9AB2AD99B1AC98B0AB97AEA995ADA894ACA793ABA690A8A38DA8A48BA7A38AA5A188A4A087\
A29E85A19D84A19D849E9A819591789E9A81918D74918D748480676B674E928C74
A19A80A49A81A69B85A99E88AAA28DADA590AEA794AFA895ABA69395927FA4A190BDBCAABBB9AA\
B8B6A7BDBEAEBBBCAEBFBCB3C0BDB6C0BDB6C1BEB7C2BFB8C2BFB8C3C0B9C3C0B9
C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C2BFB8C1BEB7C1BEB7\
C0BDB6BFBCB5BFBCB5BDBAB3BDBAB3BCB9B2BBB8B1BBB8B1BAB7B0B9B6AFB9B6AF
B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0\
B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0
B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B6B1B3B1A58D8B7F75756DAEAFAA2C2B30\
91949BBCBECBC1C7D7C3C8DCC1C9DEBFCAE0BCCBE0BCCBE0BBCCE0BBCCDEBBCCE0
BCCCE5BCCCE5BCCCE6BCCCE5BCCCE6BCCCE5BCCCE6BCCCE5BACAE4BBCBE4BDCDE7BECEE7BECEE8\
BDCDE6BBCBE5BACAE4C1D0EDC0CFECBECDECBDCCE9BBCAE9B9C8E5B8C7E6B7C6E3
B5C4E3B5C4E1B5C4E3B5C4E1B5C4E3B5C4E1B5C4E3B4C5E3B4C4E5B2C5E5B5C5E7B4C7E7B7C7E9\
B6C9E9B9C9EBB8CBEBB5C5E7B3C6E6B4C4E6B1C4E4B3C3E5B0C3E3B1C1E3AFC2E0
B1C3DBAFC4D7B0C2D6AEC3D6AFC1D5ACC1D4AEC0D4ABC0D3B0C2D6AEC3D6B0C2D6AEC3D6B0C2D6\
AEC3D6AFC1D5ADC2D5
B3AF96B3AF96B3AF96B3AF96B3AF96B3AF96B3AF96B3AF96AEAA91AFAB92B1AD94B2AE95B3AF96\
B2AE95B1AD94B0AC93AFAA96AFAA96AEA995AEA995ADA894ACA793ACA793ABA692
ABA692ABA692AAA591AAA591A9A490A8A38FA8A38FA8A38FABA692ACA793ACA793ADA894AEA995\
AEA995AFAA96AFAA96B1AC98B1AC98B2AD99B4AF9BB5B09CB7B29EB8B39FB8B39F
B1AC98B4AF9BB8B39FBBB6A2BDB8A4BDB8A4BBB6A2BAB5A1B5B09CB4AF9BB1AC98B0AB97B1AC98\
B4AF9BB8B39FBAB5A1B5B09CB4AF9BB3AE9AB2AD99B0AB97AEA995ACA793ACA793
B4AF9BB4AF9BB3AE9AB1AC98B0AB97AEA995ADA894ADA892A9A48EA8A48BA7A38AA6A289A4A087\
A39F86A29E85A19D849F9B829692799E9A81928E75918D748581686C684F938D75
A29B81A59B82A79C86AA9F89ABA38EAEA691AFA895B0A996ADA895979481A5A291BEBDABBCBAAB\
B8B6A7BDBEAEBBBCAEC0BDB4C1BEB7C1BEB7C2BFB8C3C0B9C3C0B9C4C1BAC4C1BA
C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C2BFB8C1BEB7C1BEB7\
C0BDB6BFBCB5BFBCB5BDBAB3BDBAB3BCB9B2BBB8B1BBB8B1BAB7B0B9B6AFB9B6AF
B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0\
B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0
B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B6B1B3B1A58F8D81787870B0B1AC2C2B30\
90939ABCBECBC2C8D8C1C6DABFC7DCBDC8DEBAC9DEBAC9DEB9CADEB9CADCB9CADE
BACAE3BACAE4BACAE4BACAE4BACAE4BACAE4BACAE4BACAE4BBCBE5BCCCE6BDCDE7BECEE8BECEE8\
BDCDE7BCCCE6BBCAE7BECDECBECDECBDCCEBBCCBEABAC9E8B9C8E7B8C7E6B8C7E6
BAC9E8BAC9E8BAC9E8BAC9E8BAC9E8BAC9E8BAC9E8BAC9EAB3C6E7B3C6E7B3C5E9B4C7E8B4C6EA\
B5C8E9B5C7EBB5C8E9B0C2E6AFC2E3AFC1E5AEC1E2ADBFE3ADC0E1ACBEE2ACBFDF
AABED6AABFD2A9BED1A9BED1A8BDD0A7BCCFA7BCCFA6BBCEAABFD2AABFD2A9BED1A9BED1A8BDD0\
A7BCCFA7BCCFA7BCCF
B4B097B4B097B4B097B4B097B4B097B3AF96B3AF96B3AF96B1AD94B2AE95B3AF96B4B097B4B097\
B3AF96B1AD94B0AC93B0AB97AFAA96AFAA96AEA995ADA894ADA894ACA793ACA793
ACA793ACA793ABA692AAA591A9A490A8A38FA8A38FA7A28EACA793ACA793ADA894ADA894AEA995\
AFAA96AFAA96B0AB97B2AD99B2AD99B3AE9AB5B09CB6B19DB8B39FB9B4A0B9B4A0
B8B39FB8B39FB9B4A0BAB5A1BCB7A3BCB7A3BDB8A4BDB8A4C7C2AEC5C0ACC2BDA9BFBAA6BDB8A4\
BBB6A2BBB6A2BAB5A1B8B39FB9B4A0BBB6A2BCB7A3BDB8A4BDB8A4BDB8A4BCB7A3
B5B09CB5B09CB4AF9BB2AD99B1AC98AFAA96AEA995AEA993AAA58FA9A58CA8A48BA7A38AA5A188\
A4A087A39F86A29E85A09C839692799F9B82938F76928E758581686C684F948E76
A29B81A59B82A79C86AA9F89ABA38EAEA691AFA895B0A996AEA996989582A6A392BFBEACBCBAAB\
B9B7A8BDBEAEBABBADC1BEB5C1BEB7C2BFB8C2BFB8C3C0B9C4C1BAC4C1BAC5C2BB
C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C2BFB8C1BEB7C1BEB7\
C0BDB6BFBCB5BFBCB5BDBAB3BDBAB3BCB9B2BBB8B1BBB8B1BAB7B0B9B6AFB9B6AF
B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0\
B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0
B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B6B1B4B2A6908E827A7A72B2B3AE2C2B30\
8F9299BCBECBC3C9D9C6CBDFC4CCE1C2CDE3BFCEE3BFCEE3BECFE3BECFE1BECFE3
BDCBE6BDCBE8BDCBE8BDCBE8BDCBE8BDCBE8BDCBE8BDCBE8BAC8E5BBC9E6BCCAE7BDCBE8BDCBE8\
BCCAE7BBC9E6BAC8E5BAC7E7BAC7E7BAC7E7BAC7E7B9C6E6B9C6E6B9C6E6B9C6E6
BBC8E8BBC8E8BBC8E8BBC8E8BBC8E8BBC8E8BBC8E8BAC9EAB3C5E9B2C6E9B1C5EAB1C5E8B0C4E9\
B0C4E7B0C4E9AFC3E6B1C5EAB0C4E7B0C4E9AFC3E6AEC2E7AEC2E5ADC1E6ADC1E2
ACC2DAACC2D7ACC2D7ABC1D6AAC0D5A9BFD4A9BFD4A9BFD4ACC2D7ABC1D6ABC1D6AAC0D5A9BFD4\
A8BED3A7BDD2A7BDD2
B5B198B5B198B5B198B4B097B4B097B4B097B3AF96B3AF96B6B299B6B299B7B39AB6B299B5B198\
B3AF96B0AC93AFAB92B0AB97B0AB97AFAA96AEA995AEA995ADA894ACA793ACA793
ADA894ADA894ACA793ABA692AAA591A8A38FA8A38FA7A28EACA793ACA793ADA894AEA995AEA995\
AFAA96B0AB97B0AB97B2AD99B3AE9AB4AF9BB5B09CB7B29EB8B39FB9B4A0BAB5A1
C2BDA9BFBAA6BAB5A1B7B29EB5B09CB5B09CB7B29EB9B4A0B5B09CB6B19DB9B4A0BBB6A2BCB7A3\
BCB7A3BBB6A2BAB5A1BAB5A1BAB5A1BBB6A2BAB5A1B9B4A0B7B29EB5B09CB3AE9A
B6B19DB5B09CB4AF9BB3AE9AB1AC98B0AB97AFAA96AEA993AAA58FA9A58CA8A48BA7A38AA5A188\
A4A087A39F86A29E85A09C8397937A9F9B82938F76928E758682696D6950948E76
A29B81A69C83A89D87ABA08AACA48FAEA691B0A996B1AA97AFAA97989582A7A493BFBEACBDBBAC\
B9B7A8BDBEAEBABBADC1BEB5C1BEB7C2BFB8C3C0B9C3C0B9C4C1BAC5C2BBC5C2BB
C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C2BFB8C1BEB7C1BEB7\
C0BDB6BFBCB5BFBCB5BDBAB3BDBAB3BCB9B2BBB8B1BBB8B1BAB7B0B9B6AFB9B6AF
B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0\
B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0
B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B6B1B4B2A6918F837C7C74B2B3AE2B2A2F\
8E9198BBBDCAC4CADACFD4E8CDD5EACBD6ECC8D7ECC8D7ECC7D8ECC7D8EAC7D8EC
C4D2EDC4D2EFC4D2EFC4D2EFC4D2EFC4D2EFC4D2EFC4D2EFC2D0EDC3D1EEC4D2EFC5D3F0C5D3F0\
C4D2EFC3D1EEC2D0EDC1CFECC1CFECC1CFECC2D0EDC2D0EDC2D0EDC3D1EEC3D1EE
C0CEEBC0CEEBC0CEEBC0CEEBC0CEEBC0CEEBC0CEEBBFCEEDBDD0F1BBCFF2BACEF3B9CDF0B8CCF1\
B7CBEEB6CAEFB6CAEDB6CAEFB6CAEDB6CAEFB5C9ECB4C8EDB3C7EAB3C7ECB3C7E8
B4C9E6B4C9E4B4C9E4B3C8E3B2C7E2B1C6E1B1C6E1B1C6E1B3C8E3B3C8E3B2C7E2B1C6E1B0C5E0\
AFC4DFAEC3DEADC2DD
B4B097B4B097B4B097B4B097B4B097B4B097B4B097B4B097B4B097B4B097B3AF96B2AE95B2AE95\
B1AD94B0AC93B0AC93AEA995AEA995ADA894ACA793ACA793ABA692AAA591AAA591
A8A38FA8A38FA8A38FA8A38FA8A38FA8A38FA8A38FA8A38FA8A38FA9A490AAA591ABA692ADA894\
AEA995AFAA96B0AB97B2AD99B3AE9AB4AF9BB5B09CB7B29EB8B39FB9B4A0BAB5A1
BAB5A1BAB5A1BBB6A2BCB7A3BCB7A3BDB8A4BEB9A5BEB9A5BCB7A3BCB7A3BCB7A3BCB7A3BCB7A3\
BCB7A3BCB7A3BCB7A3BAB5A1BAB5A1BAB5A1BAB5A1BAB5A1BAB5A1BAB5A1BAB5A1
B8B39FB7B29EB6B19DB5B09CB3AE9AB2AD99B1AC98B0AB95B0AB95AEAA91ACA88FAAA68DA6A289\
A4A087A29E85A09C83A29E8598947BA09C83938F76928E758581686B674E928C74
A19A80A59B82A89D87ACA18BADA590AFA792AFA895AFA895B2AD9A989582A3A08FBCBBA9BDBBAC\
BBB9AABFC0B0BABBADBFBCB3BFBCB5C0BDB6C1BEB7C1BEB7C2BFB8C3C0B9C3C0B9
C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C1BEB7C1BEB7C0BDB6BFBCB5BFBCB5\
BEBBB4BDBAB3BDBAB3BFBCB5BFBCB5BEBBB4BDBAB3BDBAB3BCB9B2BBB8B1BBB8B1
B9B5B2B9B5B2B8B4B1B7B3B0B7B3B0B6B2AFB5B1AEB5B1AEB9B5B2B9B5B2B9B5B2B9B5B2B9B5B2\
B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2
B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B4AFB7B5A98F8D817E7E76A4A5A0403F44\
85888FB8BAC7C7CDDDC4C9DDC4CCE1C6D1E7C6D5EAC7D6EBC5D6EAC3D4E6C2D3E7
C3D1EBC5D0ECC6D1EDC6D1EDC7D2EEC8D3EFC8D3EFC9D4F0C7D2EEC7D2EEC7D2EEC7D2EEC7D2EE\
C7D2EEC7D2EEC7D2EEC7D2EEC6D1EDC6D1EDC5D0ECC4CFEBC4CFEBC3CEEAC3CEEA
C5D0ECC4CFEBC4CFEBC3CEEAC2CDE9C2CDE9C1CCE8BFCDEABDCDEEBACDEEBACCF0B9CCEDB8CAEE\
B8CBECB7C9EDB7CAEBB7C9EDB6C9EAB6C8ECB5C8E9B4C6EAB4C7E8B3C5E9B3C6E7
B5C8E9B4C7E8B4C7E8B3C6E7B2C5E6B2C5E6B1C4E5B1C4E5B1C4E5B0C3E4B0C3E4AFC2E3AEC1E2\
AEC1E2ADC0E1ADC0E1
B4B097B4B097B4B097B4B097B4B097B4B097B4B097B4B097B4B097B4B097B3AF96B2AE95B2AE95\
B1AD94B0AC93B0AC93AEA995AEA995ADA894ACA793ACA793ABA692AAA591AAA591
A8A38FA8A38FA8A38FA8A38FA8A38FA8A38FA8A38FA8A38FA8A38FA9A490AAA591ABA692ADA894\
AEA995AFAA96B0AB97B2AD99B3AE9AB4AF9BB5B09CB7B29EB8B39FB9B4A0BAB5A1
BAB5A1BAB5A1BBB6A2BCB7A3BCB7A3BDB8A4BEB9A5BEB9A5BCB7A3BCB7A3BCB7A3BCB7A3BCB7A3\
BCB7A3BCB7A3BCB7A3BAB5A1BAB5A1BAB5A1BAB5A1BAB5A1BAB5A1BAB5A1BAB5A1
B8B39FB7B29EB6B19DB5B09CB3AE9AB2AD99B1AC98B0AB95B0AB95AEAA91ACA88FAAA68DA6A289\
A4A087A29E85A09C83A29E8598947BA09C83938F76928E758480676B674E928C74
A0997FA59B82A89D87ACA18BADA590AFA792AFA895AFA895B2AD9A989582A3A08FBCBBA9BDBBAC\
BBB9AABFC0B0BABBADBFBCB3BFBCB5C0BDB6C1BEB7C1BEB7C2BFB8C3C0B9C3C0B9
C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C1BEB7C1BEB7C0BDB6BFBCB5BFBCB5\
BEBBB4BDBAB3BDBAB3BFBCB5BEBBB4BEBBB4BDBAB3BCB9B2BCB9B2BBB8B1BBB8B1
B9B5B2B9B5B2B8B4B1B7B3B0B7B3B0B6B2AFB5B1AEB5B1AEB9B5B2B9B5B2B9B5B2B9B5B2B9B5B2\
B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2B9B5B2
B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B4AFB7B5A98F8D817E7E76A4A5A0403F44\
85888FB7B9C6C6CCDCBBC0D4BCC4D9BDC8DEBDCCE1BECDE2BDCEE2BCCDDFBCCBE0
C2CEE6C2CEE8C3CFE9C3CFE9C4D0EAC5D1EBC5D1EBC6D2ECC6D2ECC6D2ECC6D2ECC6D2ECC6D2EC\
C6D2ECC6D2ECC6D2ECC6D2EAC6D2EAC5D1E9C4D0E8C4D0E8C3CFE7C2CEE6C2CEE6
C4D0E8C4D0E8C3CFE7C2CEE6C2CEE6C1CDE5C0CCE4BECCE6BDCCEBBCCCEDBBCBECBACAEBBACAEB\
B9C9EAB8C8E9B8C8E9B8C8E9B8C8E9B7C7E8B6C6E7B6C6E7B5C5E6B4C4E5B4C4E6
B6C6EAB5C4EBB5C4EBB4C3EAB3C2E9B3C2E9B2C1E8B2C1E8B2C1E8B1C0E7B1C0E7B0BFE6AFBEE5\
AFBEE5AEBDE4AEBDE4
B4B097B4B097B4B097B4B097B4B097B4B097B4B097B4B097B4B097B4B097B3AF96B2AE95B2AE95\
B1AD94B0AC93B0AC93AEA995AEA995ADA894ACA793ACA793ABA692AAA591AAA591
A8A38FA8A38FA8A38FA8A38FA8A38FA8A38FA8A38FA8A38FA8A38FA9A490AAA591ABA692ADA894\
AEA995AFAA96B0AB97B2AD99B3AE9AB4AF9BB5B09CB7B29EB8B39FB9B4A0BAB5A1
BAB5A1BAB5A1BBB6A2BCB7A3BCB7A3BDB8A4BEB9A5BEB9A5BDB8A4BDB8A4BDB8A4BDB8A4BDB8A4\
BDB8A4BDB8A4BDB8A4BBB6A2BBB6A2BBB6A2BBB6A2BBB6A2BBB6A2BBB6A2BBB6A2
B9B4A0B8B39FB7B29EB6B19DB4AF9BB3AE9AB2AD99B1AC96B0AB95AEAA91ACA88FAAA68DA6A289\
A4A087A29E85A09C83A19D8497937A9F9B82928E75918D748480676A664D918B73
A0997FA49A81A89D87ABA08AACA48FAEA691AEA794AEA794B2AD9A989582A3A08FBCBBA9BDBBAC\
BBB9AABFC0B0BABBADBFBCB3BFBCB5C0BDB6C1BEB7C1BEB7C2BFB8C3C0B9C3C0B9
C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C1BEB7C1BEB7C0BDB6BFBCB5BFBCB5\
BEBBB4BDBAB3BDBAB3BEBBB4BEBBB4BDBAB3BDBAB3BCB9B2BBB8B1BBB8B1BAB7B0
B9B5B2B9B5B2B8B4B1B7B3B0B7B3B0B6B2AFB5B1AEB5B1AEB8B4B1B8B4B1B8B4B1B8B4B1B8B4B1\
B8B4B1B8B4B1B8B4B1B8B4B1B8B4B1B8B4B1B8B4B1B8B4B1B8B4B1B8B4B1B8B4B1
B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B4AFB8B6AA908E827F7F77A4A5A0403F44\
85888FB7B9C6C6CCDCBABFD3B9C1D6BAC5DBBAC9DEBCCBE0BBCCE0BBCCDEBCCBDE
C0CCE2C2CCE5C2CCE5C3CDE6C4CEE7C4CEE7C5CFE8C5CFE8C7D1EAC7D1EAC7D1EAC7D1EAC7D1EA\
C7D1EAC7D1EAC7D2E8C7D2E6C7D2E6C6D1E5C5D0E4C5D0E4C4CFE3C3CEE2C3CEE2
C5D0E4C5D0E4C4CFE3C3CEE2C3CEE2C2CDE1C1CCE0C0CCE2BECCE7BECBEBBDCAEABCC9E9BCC9E9\
BBC8E8BAC7E7BAC7E7BAC7E7BAC7E7B9C6E6B8C5E5B8C5E5B7C4E4B6C3E3B6C3E5
B7C4E7B7C3E9B6C2E8B6C2E8B5C1E7B4C0E6B4C0E6B3BFE5B3BFE5B3BFE5B2BEE4B2BEE4B1BDE3\
B0BCE2B0BCE2AFBBE1
B4B097B4B097B4B097B4B097B4B097B4B097B4B097B4B097B4B097B4B097B3AF96B2AE95B2AE95\
B1AD94B0AC93B0AC93AEA995AEA995ADA894ACA793ACA793ABA692AAA591AAA591
A8A38FA8A38FA8A38FA8A38FA8A38FA8A38FA8A38FA8A38FA8A38FA9A490AAA591ABA692ADA894\
AEA995AFAA96B0AB97B2AD99B3AE9AB4AF9BB5B09CB7B29EB8B39FB9B4A0BAB5A1
BAB5A1BAB5A1BBB6A2BCB7A3BCB7A3BDB8A4BEB9A5BEB9A5BEB9A5BEB9A5BEB9A5BEB9A5BEB9A5\
BEB9A5BEB9A5BEB9A5BCB7A3BCB7A3BCB7A3BCB7A3BCB7A3BCB7A3BCB7A3BCB7A3
B9B4A0B9B4A0B8B39FB6B19DB5B09CB3AE9AB2AD99B2AD97B0AB95AEAA91ACA88FAAA68DA6A289\
A4A087A29E85A09C83A09C8397937A9F9B82928E75908C73837F6669654C908A72
9F987EA39980A79C86ABA08AACA48FADA590ADA693ADA693B2AD9A989582A3A08FBCBBA9BDBBAC\
BBB9AABFC0B0BABBADBFBCB3BFBCB5C0BDB6C1BEB7C1BEB7C2BFB8C3C0B9C3C0B9
C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C1BEB7C1BEB7C0BDB6BFBCB5BFBCB5\
BEBBB4BDBAB3BDBAB3BDBAB3BDBAB3BCB9B2BCB9B2BBB8B1BAB7B0BAB7B0B9B6AF
B9B5B2B9B5B2B8B4B1B7B3B0B7B3B0B6B2AFB5B1AEB5B1AEB7B3B0B7B3B0B7B3B0B7B3B0B7B3B0\
B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0
B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B4AFB9B7AB918F83808078A4A5A03F3E43\
84878EB6B8C5C5CBDBC3C8DCC2CADFC2CDE3C1D0E5C2D1E6C2D3E7C3D4E6C4D3E6
C4D1E4C5D0E4C6D1E5C6D1E5C7D2E6C8D3E7C8D3E7C9D4E8C8D3E7C8D3E7C8D3E7C8D3E7C8D3E7\
C8D3E7C8D3E7C8D3E5C8D4E4C8D4E4C8D4E4C7D3E3C6D2E2C5D1E1C5D1E1C5D1E1
C6D2E2C6D2E2C6D2E2C5D1E1C4D0E0C3CFDFC3CFDFC3CEE0C2CCE5C2CBE8C2CBE8C1CAE7C0C9E6\
BFC8E5BFC8E5BFC8E5BEC7E4BEC7E4BEC7E4BDC6E3BCC5E2BBC4E1BBC4E1BBC4E3
BBC4E5BAC3E4BAC3E4B9C2E3B8C1E2B8C1E2B7C0E1B7C0E1B7C0E1B6BFE0B6BFE0B5BEDFB4BDDE\
B4BDDEB3BCDDB3BCDD
B4B097B4B097B4B097B4B097B4B097B4B097B4B097B4B097B4B097B4B097B3AF96B2AE95B2AE95\
B1AD94B0AC93B0AC93AEA995AEA995ADA894ACA793ACA793ABA692AAA591AAA591
A8A38FA8A38FA8A38FA8A38FA8A38FA8A38FA8A38FA8A38FA8A38FA9A490AAA591ABA692ADA894\
AEA995AFAA96B0AB97B2AD99B3AE9AB4AF9BB5B09CB7B29EB8B39FB9B4A0BAB5A1
BAB5A1BAB5A1BBB6A2BCB7A3BCB7A3BDB8A4BEB9A5BEB9A5BEB9A5BEB9A5BEB9A5BEB9A5BEB9A5\
BEB9A5BEB9A5BEB9A5BCB7A3BCB7A3BCB7A3BCB7A3BCB7A3BCB7A3BCB7A3BCB7A3
BAB5A1BAB5A1B9B4A0B7B29EB6B19DB4AF9BB3AE9AB3AE98B0AB95AEAA91ACA88FAAA68DA6A289\
A4A087A29E85A09C83A09C839692799E9A81918D748F8B72827E6569654C908A72
9E977DA2987FA69B85AA9F89ABA38EADA590ACA592ADA693B2AD9A989582A3A08FBCBBA9BDBBAC\
BBB9AABFC0B0BABBADBFBCB3BFBCB5C0BDB6C1BEB7C1BEB7C2BFB8C3C0B9C3C0B9
C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C1BEB7C1BEB7C0BDB6BFBCB5BFBCB5\
BEBBB4BDBAB3BDBAB3BDBAB3BCB9B2BCB9B2BBB8B1BAB7B0BAB7B0B9B6AFB9B6AF
B9B5B2B9B5B2B8B4B1B7B3B0B7B3B0B6B2AFB5B1AEB5B1AEB7B3B0B7B3B0B7B3B0B7B3B0B7B3B0\
B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0
B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B4AFBAB8AC929084808078A5A6A13F3E43\
83868DB5B7C4C3C9D9CCD1E5CAD2E7C8D3E9C5D4E9C6D5EAC6D7EBC7D8EAC9D9E9
C9D5E5CBD4E3CBD4E3CCD5E4CDD6E5CED7E6CED7E6CED7E6CBD4E3CBD4E3CBD4E3CBD4E3CBD4E3\
CBD4E3CBD4E3CBD4E3CBD5E1CAD4DECAD4DEC9D3DDC8D2DCC8D2DCC7D1DBC7D1DB
C9D3DDC8D2DCC8D2DCC7D1DBC6D0DAC6D0DAC5CFD9C5CEDDC6CCE2C5CBE5C5CBE5C4CAE4C3C9E3\
C3C9E3C2C8E2C2C8E2C2C8E2C1C7E1C1C7E1C0C6E0BFC5DFBFC5DFBEC4DEBEC4DE
BDC3DBBDC3DBBCC2DABCC2DABBC1D9BAC0D8BAC0D8B9BFD7B9BFD7B9BFD7B8BED6B8BED6B7BDD5\
B6BCD4B6BCD4B5BBD3
B4B097B4B097B4B097B4B097B4B097B4B097B4B097B4B097B4B097B4B097B3AF96B2AE95B2AE95\
B1AD94B0AC93B0AC93AEA995AEA995ADA894ACA793ACA793ABA692AAA591AAA591
A8A38FA8A38FA8A38FA8A38FA8A38FA8A38FA8A38FA8A38FA8A38FA9A490AAA591ABA692ADA894\
AEA995AFAA96B0AB97B2AD99B3AE9AB4AF9BB5B09CB7B29EB8B39FB9B4A0BAB5A1
BAB5A1BAB5A1BBB6A2BCB7A3BCB7A3BDB8A4BEB9A5BEB9A5BFBAA6BFBAA6BFBAA6BFBAA6BFBAA6\
BFBAA6BFBAA6BFBAA6BDB8A4BDB8A4BDB8A4BDB8A4BDB8A4BDB8A4BDB8A4BDB8A4
BBB6A2BAB5A1B9B4A0B8B39FB6B19DB5B09CB4AF9BB3AE98B0AB95AEAA91ACA88FAAA68DA6A289\
A4A087A29E85A09C839F9B829591789D9980908C738F8B72817D6468644B8F8971
9E977DA2987FA59A84A99E88AAA28DACA48FACA592ACA592B2AD9A989582A3A08FBCBBA9BDBBAC\
BBB9AABFC0B0BABBADBFBCB3BFBCB5C0BDB6C1BEB7C1BEB7C2BFB8C3C0B9C3C0B9
C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C1BEB7C1BEB7C0BDB6BFBCB5BFBCB5\
BEBBB4BDBAB3BDBAB3BCB9B2BBB8B1BBB8B1BAB7B0B9B6AFB9B6AFB8B5AEB8B5AE
B9B5B2B9B5B2B8B4B1B7B3B0B7B3B0B6B2AFB5B1AEB5B1AEB6B2AFB6B2AFB6B2AFB6B2AFB6B2AF\
B6B2AFB6B2AFB6B2AFB6B2AFB6B2AFB6B2AFB6B2AFB6B2AFB6B2AFB6B2AFB6B2AF
B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B4AFBBB9AD939185818179A5A6A13F3E43\
83868DB4B6C3C2C8D8CDD2E6CAD2E7C6D1E7C1D0E5C0CFE4C0D1E5C1D2E4C2D2E2
C6D2E0C9D3DDC9D3DFCAD4DECBD5E1CBD5DFCCD6E2CCD6E0C7D1DDC7D1DBC7D1DDC7D1DBC7D1DD\
C7D1DBC7D1DDC7D1DBC7D1DAC6D1D7C6D1D7C5D0D6C4CFD5C4CFD5C3CED4C3CED4
C5D0D6C4CFD5C4CFD5C3CED4C2CDD3C2CDD3C1CCD2C2CAD5C3C8DCC4C6DDC4C6DDC3C5DCC2C4DB\
C2C4DBC1C3DAC1C3DAC1C3DAC0C2D9C0C2D9BFC1D8BEC0D7BEC0D7BDBFD6BDBFD4
BCBFCEBBBFCBBBBFCBBABECAB9BDC9B9BDC9B8BCC8B8BCC8B8BCC8B7BBC7B7BBC7B6BAC6B5B9C5\
B5B9C5B4B8C4B4B8C4
B4B097B4B097B4B097B4B097B4B097B4B097B4B097B4B097B4B097B4B097B3AF96B2AE95B2AE95\
B1AD94B0AC93B0AC93AEA995AEA995ADA894ACA793ACA793ABA692AAA591AAA591
A8A38FA8A38FA8A38FA8A38FA8A38FA8A38FA8A38FA8A38FA8A38FA9A490AAA591ABA692ADA894\
AEA995AFAA96B0AB97B2AD99B3AE9AB4AF9BB5B09CB7B29EB8B39FB9B4A0BAB5A1
BAB5A1BAB5A1BBB6A2BCB7A3BCB7A3BDB8A4BEB9A5BEB9A5C0BBA7C0BBA7C0BBA7C0BBA7C0BBA7\
C0BBA7C0BBA7C0BBA7BEB9A5BEB9A5BEB9A5BEB9A5BEB9A5BEB9A5BEB9A5BEB9A5
BCB7A3BBB6A2BAB5A1B9B4A0B7B29EB6B19DB5B09CB4AF99B0AB95AEAA91ACA88FAAA68DA6A289\
A4A087A29E85A09C839E9A819591789C987F8F8B728E8A71817D6467634A8E8870
9D967CA1977EA59A84A89D87A9A18CABA38EABA491ABA491B2AD9A989582A3A08FBCBBA9BDBBAC\
BBB9AABFC0B0BABBADBFBCB3BFBCB5C0BDB6C1BEB7C1BEB7C2BFB8C3C0B9C3C0B9
C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C1BEB7C1BEB7C0BDB6BFBCB5BFBCB5\
BEBBB4BDBAB3BDBAB3BBB8B1BBB8B1BAB7B0BAB7B0B9B6AFB8B5AEB8B5AEB7B4AD
B9B5B2B9B5B2B8B4B1B7B3B0B7B3B0B6B2AFB5B1AEB5B1AEB5B1AEB5B1AEB5B1AEB5B1AEB5B1AE\
B5B1AEB5B1AEB5B1AEB5B1AEB5B1AEB5B1AEB5B1AEB5B1AEB5B1AEB5B1AEB5B1AE
B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B4AFBCBAAE939185818179A5A6A13F3E43\
82858CB3B5C2C2C8D8CDD2E6C8D0E5C2CDE3BBCADFB9C8DDB7C8DCB8C9DBB9C9D9
C0CAD6C1CAD3C1C9D4C2CBD4C3CBD6C4CDD6C4CCD7C4CDD6C0C8D3C0C9D2C0C8D3C0C9D2C0C8D3\
C0C9D2C0C8D3C0C9D2C0C9CEC0C9CEBFC8CDBFC8CDBEC7CCBDC6CBBDC6CBBCC5CA
BEC7CCBEC7CCBDC6CBBDC6CBBCC5CABBC4C9BBC4C9BBC2CABDC0D1BEBFD4BDBED3BDBED3BCBDD2\
BBBCD1BBBCD1BABBD0BABBD0BABBD0B9BACFB9BACFB8B9CEB7B8CDB7B8CDB6B8C7
B4B7BCB4B8B9B4B8B9B3B7B8B2B6B7B1B5B6B1B5B6B1B5B6B0B4B5B0B4B5B0B4B5AFB3B4AEB2B3\
ADB1B2ADB1B2ADB1B2
B4AF99B4B097B4AF99B4B097B4AF99B4B097B4AF99B4B097B4AF99B4B097B3AE98B2AE95B2AD97\
B1AD94B0AB95B0AB95AEA995ACAA95ADA894AAA893ACA793A9A792AAA591A8A691
A8A38FA6A48FA8A38FA6A48FA8A38FA6A48FA8A38FA6A48FA8A38FA7A590AAA591A9A792ADA894\
ACAA95AFAA96AEAC97B2AD99B1AF9AB4AF9BB3B19CB7B29EB6B49FB9B4A0BAB5A1
BAB5A1BAB5A1BBB6A2BCB7A3BCB7A3BDB8A4BEB9A5BEB9A5C0BBA7C0BBA7C0BBA7C0BBA7C0BBA7\
C0BBA7C0BBA7C0BBA7BEB9A5BEB9A5BEB9A5BEB9A5BEB9A5BEB9A5BEB9A5BEB9A5
BCB7A3BBB6A2BAB5A1B9B4A0B7B29EB6B19DB5B09CB4AF9BB0AB95AEAA91ACA791AAA68DA6A18B\
A4A087A29D87A09C839E99839490779C97818F8B728E8973807C6367624C8E8870
9D967A9F987CA29B81A69F85A9A18AAAA48EABA58FABA491B2AD9A9A9484A3A08FBCBAABBEBAAE\
BBB9ACC1BFB2BCBAAEBDBDB3BDBDB5BEBEB6BFBFB7BFBFB7C0C0B8C1C1B9C1C1B9
C1C1B9C1C1B9C1C1B9C1C1B9C1C1B9C1C1B9C1C1B9C1C1B9C1BEB7C1BEB7C0BDB6BFBCB5BFBCB5\
BEBBB4BDBAB3BDBAB3BBB8B1BBB8B1BAB7B0B9B6AFB9B6AFB8B5AEB7B4ADB7B4AF
B9B6B1B9B5B2B8B4B1B7B3B0B7B3B0B6B2AFB5B1AEB5B1AEB5B1AEB5B1AEB5B1AEB5B1AEB5B1AE\
B5B1AEB5B1AEB5B1AEB5B1AEB5B1AEB5B1AEB5B1AEB5B1AEB5B1AEB5B1AEB5B1AE
B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B3B0B7B4AFBCB9B0949286838079A6A5A33F3E43\
82858CB2B6C2C1C7D7CDD4E7C7D2E6C0CCE2B8C9DDB5C6DAB3C6D7B3C6D7B4C6D4
B5C1CDB8C2CCB9C1CCB9C3CDBBC3CEBAC4CEBCC4CFBBC5CFBAC2CDB9C3CDBAC2CDB9C3CDBAC2CD\
B9C3CDBAC2CDB9C3CCB9C3CCB9C4CAB8C3C9B8C3C9B7C2C8B6C1C7B6C1C7B5C0C6
B7C2C8B7C2C8B6C1C7B6C1C7B5C0C6B4BFC5B4BFC5B3BDC7B5BBCBB7BACDB6B8CDB6B9CCB5B7CC\
B4B7CAB4B6CBB3B6C9B3B5CAB3B6C9B2B4C9B2B5C8B1B3C8B0B3C6B0B2C7AFB2C1
ADB2B8ADB3B3ACB1B4ABB1B1ABB0B3AAB0B0A9AEB1A9AFAFA9AEB1A9AFAFA8ADB0A7ADADA7ACAF\
A6ACACA5AAADA5ABAB
B6B19DB6B19BB5B09CB4AF99B4AF9BB3AE98B2AD99B2AD97B4AF9BB3AE98B2AD99B1AC96AFAA96\
AEA993ADA894ACA793AAA893A9A893A9A792A7A691A8A691A6A590A6A48FA5A48F
A4A28DA3A28DA4A28DA3A28DA4A28DA3A28DA4A28DA3A28DA8A691A7A691A9A792A9A893AAA893\
AAA994ACAA95ABAA95AEAC97AEAD98B0AE99B0AF9AB3B19CB3B29DB5B39EB6B49F
BCB7A3BCB7A3BDB8A4BEB9A5BEB9A5BFBAA6C0BBA7C0BBA7C0BBA7C0BBA7C0BBA7C0BBA7C0BBA7\
C0BBA7C0BBA7C0BBA7C0BBA7C0BBA7BFBAA6BEB9A5BEB9A5BDB8A4BCB7A3BCB7A3
BCB7A3BDB8A4BDB8A4BCB7A3BBB6A2B9B4A0B6B19DB5B09CB2AD99B0AB95ADA894AAA58FA6A18D\
A39E88A09B879F9A84A19C8895907A9B9682908B75918C78837E6865604C87836A
9691739B9774A09B7BA39E80A39E81A29E83A5A08AA9A490A9A4919D9787A29C90B8B4A9C6BFB7\
BDB9B0B7B2ACBBB8B1B8B8B0B8BAAFB9BBB0BBBDB2BDBFB4BFC1B6C0C2B7C1C3B8
BDBFB4BEC0B5BFC1B6C0C2B7C0C2B7BFC1B6BEC0B5BDBEB6BFBFB7C1BEB9C0BDB8C0BDB8BFBCB7\
BEBBB6BEBBB6BDBAB5BBB8B3BBB8B3BAB7B2BAB7B2B9B6B1B8B5B0B8B5B0B7B4AF
B7B4AFB6B3AEB6B3AEB5B2ADB4B1ACB4B1ACB3B0ABB3B0ABB3B0ABB3B0ABB3B0ABB3B0ABB3B0AB\
B3B0ABB3B0ABB3AFACB1ADAAB2AEADB2AEADB3AFAEB4B0AFB4B0AFB5B1B0B5B1B0
B1ADACB2AEADB3AFAEB5B1B0B6B2B1B7B3B2B9B5B4B9B5B2B4AFA99D9A918885809E9D9B545358\
70737CB4BAC8BCC3D5C4CFE1C1CEE1BACBDDB3C8D9AFC4D5ACC3D1A8C2CFAAC2CE
B2C0CDB3BFCBB6C0CCB4C0CCB7C1CDB6C2CEB8C2CEB7C3CFB9C3CFB7C3CFB9C3CFB7C3CFB9C3CF\
B7C3CFB9C3CFB7C3D1B6C4D1B4C4D3B3C3D2B2C2D1B2C2D1B1C1D0B0C0CFB0C0CF
B4C4D3B4C4D3B3C3D2B3C3D2B2C2D1B1C1D0B1C1D0B0C0CFB0BDCEB0BDCEAFBCCFAEBBCCAEBBCE\
ADBACBACB9CCACB9CAACB9CCACB9CAABB8CBAAB7C8AAB7CAA9B6C7A8B5C8A8B5C6
A8B6C3A8B6C1A7B5C2A6B4BFA6B4C1A5B3BEA4B2BFA4B2BDA8B6C3A8B6C1A7B5C2A7B5C0A6B4C1\
A5B3BEA5B3C0A4B2BD
B6B19DB6B19DB5B09CB4AF9BB4AF9BB3AE9AB2AD99B2AD99B4AF9BB3AE9AB2AD99B1AC98AFAA96\
AEA995ADA894AAA893AAA893A8A792A8A792A7A691A6A590A6A590A5A48FA5A48F
A3A28DA3A28DA3A28DA3A28DA3A28DA3A28DA3A28DA3A28DA7A691A7A691A8A792A8A792A9A893\
AAA994AAA994ABAA95ADAC97AEAD98AFAE99B0AF9AB2B19CB3B29DB4B39EB5B49F
BCB7A3BCB7A3BDB8A4BEB9A5BEB9A5BFBAA6C0BBA7C0BBA7C0BBA7C0BBA7C0BBA7C0BBA7C0BBA7\
C0BBA7C0BBA7C0BBA7C0BBA7C0BBA7BFBAA6BFBAA6BEB9A5BDB8A4BDB8A4BCB7A3
BCB7A3BDB8A4BDB8A4BCB7A3BBB6A2B9B4A0B6B19DB5B09CB1AC98B0AB97ADA894AAA591A6A18D\
A29D89A09B879E9985A09B87948F7B9B96828F8A76908B77827D6965604C87836A
9491709997719F9C79A19E7DA19E7FA29E83A5A188A8A38FACA794A09A8CA49E92BCB5ABC8C1BB\
C1BAB4BCB4B1BFBAB6B9BAB2B8BBB0B9BCB1BABDB2BBBEB3BDC0B5BDC0B5BEC1B6
B9BCB1BABDB2BBBEB3BCBFB4BCBFB4BBBEB3BABDB2BABCB1BEBEB6BFBCB7BFBCB7BEBBB6BDBAB5\
BDBAB5BCB9B4BCB9B4BAB7B2BAB7B2BAB7B2B9B6B1B8B5B0B7B4AFB7B4AFB7B4AF
B9B6B1B9B6B1B8B5B0B8B5B0B7B4AFB6B3AEB6B3AEB5B2ADB2AFAAB2AFAAB2AFAAB2AFAAB2AFAA\
B2AFAAB2AFAAB2AFAAB1ADAAB1ADACB1ADACB2AEADB3AFAEB4B0AFB4B0AFB4B0AF
B5B1B0B5B1B0B6B2B1B7B3B2B8B4B3B9B5B4BAB6B5BAB6B3B8B3ADA29D978B8883A09F9D555459\
70737CB3B9C7BAC3D4C3CEE0BECDE0BACDDEB5CCDCB4CBDBB1CDD9B2CEDAB3CED9
BBCBDABECAD8BFCBD9C0CCDAC0CCDAC1CDDBC2CEDCC2CEDCC1CDDBC1CDDBC1CDDBC1CDDBC1CDDB\
C1CDDBC1CDDBC0CDDDBECEDEBDCEE0BCCDDFBCCDDFBBCCDEBACBDDBACBDDB9CADC
B9CADCB8C9DBB8C9DBB7C8DAB6C7D9B6C7D9B5C6D8B5C6D8B7C8DCB7C8DCB6C7DBB5C6DAB5C6DA\
B4C5D9B3C4D8B3C4D8B3C4D8B3C4D8B2C3D7B1C2D6B1C2D6B0C1D5AFC0D4AFC0D4
AFC0D4AFC0D4AEBFD3ADBED2ADBED2ACBDD1ABBCD0ABBCD0AEBFD3AEBFD3ADBED2ACBDD1ACBDD1\
ABBCD0AABBCFAABBCF
B6B19DB6B19DB5B09CB4AF9BB4AF9BB3AE9AB2AD99B2AD99B3AE9AB2AD99B1AC98B0AB97AEA995\
ADA894ACA793A9A792A9A792A8A792A7A691A7A691A6A590A5A48FA5A48FA4A38E
A2A18CA2A18CA2A18CA2A18CA2A18CA2A18CA2A18CA2A18CA6A590A7A691A7A691A8A792A9A893\
A9A893AAA994AAA994ADAC97AEAD98AFAE99B0AF9AB2B19CB3B29DB4B39EB5B49F
BCB7A3BCB7A3BDB8A4BEB9A5BEB9A5BFBAA6C0BBA7C0BBA7C1BCA8C1BCA8C1BCA8C1BCA8C1BCA8\
C1BCA8C1BCA8C1BCA8C1BCA8C0BBA7C0BBA7BFBAA6BEB9A5BEB9A5BDB8A4BDB8A4
BCB7A3BDB8A4BDB8A4BCB7A3BBB6A2B9B4A0B6B19DB5B09CB1AC98AFAA96ADA894A9A490A5A08C\
A29D899F9A869E99859F9A86938E7A9A95818E89758F8A76817C68645F4B858168
9390719895729D9A79A09D7CA09D7EA19D82A4A087A7A28EABA6939E988AA29C90B9B2A8C6BFB9\
BFB8B2BAB2AFBEB9B3BABCB1BABEB0BABEB0BABEB0BABEB0BBBFB1BBBFB1BBBFB1
B9BDAFBABEB0BBBFB1BCC0B2BCC0B2BBBFB1BABEB0BABCB1BBBBB3BDBAB3BCB9B2BCB9B2BBB8B1\
BAB7B0BAB7B0B9B6AFB9B6AFB9B6AFB8B5AEB8B5AEB7B4ADB6B3ACB6B3ACB5B2AB
B7B4ADB7B4ADB6B3ACB6B3ACB5B2ABB4B1AAB4B1AAB3B0A9B1AEA7B1AEA7B1AEA7B1AEA7B1AEA7\
B1AEA7B1AEA7B1AEA9AFABA8B0ACA9B0ACA9B1ADAAB2AEABB2AEABB3AFACB3AFAC
B0ACA9B0ACA9B1ADAAB1ADAAB1ADAAB2AEABB2AEABB2AFAABAB6ADA4A0978C8984A09F9D545358\
6F727BB2B8C6B8C1D2C1CCDEBECDE0BCCEE2B9D0E0BBD2E2BAD6E2BCD8E4BFDAE5
C2D4E2C5D2E2C5D2E2C6D3E3C7D4E4C8D5E5C8D5E5C8D5E5C6D3E3C6D3E3C6D3E3C6D3E3C6D3E3\
C6D3E3C6D3E3C6D3E3C5D5E5C4D5E7C3D4E6C3D4E6C2D3E5C1D2E4C1D2E4C0D1E3
BFD0E2BFD0E2BECFE1BECFE1BDCEE0BCCDDFBCCDDFBBCCE0BDCDE4BDCDE4BCCCE3BCCCE3BBCBE2\
BACAE1BACAE1B9C9E0B9C9E0B9C9E0B8C8DFB8C8DFB7C7DEB6C6DDB6C6DDB5C5DC
B5C5DCB5C5DCB4C4DBB4C4DBB3C3DAB2C2D9B2C2D9B1C1D8B2C2D9B2C2D9B2C2D9B1C1D8B0C0D7\
AFBFD6AFBFD6AFBFD6
B6B19DB6B19DB5B09CB4AF9BB4AF9BB3AE9AB2AD99B2AD99B2AD99B2AD99B1AC98AFAA96AEA995\
ACA793ABA692A9A792A8A691A7A691A6A590A6A590A5A48FA4A38EA4A38EA3A28D
A1A08BA1A08BA1A08BA1A08BA1A08BA1A08BA1A08BA1A08BA5A48FA6A590A6A590A7A691A8A792\
A8A792A9A893A9A893ADAC97AEAD98AFAE99B0AF9AB2B19CB3B29DB4B39EB5B49F
BCB7A3BCB7A3BDB8A4BEB9A5BEB9A5BFBAA6C0BBA7C0BBA7C2BDA9C2BDA9C2BDA9C2BDA9C2BDA9\
C2BDA9C2BDA9C2BDA9C2BDA9C1BCA8C1BCA8C0BBA7BFBAA6BFBAA6BEB9A5BEB9A5
BCB7A3BDB8A4BDB8A4BCB7A3BBB6A2B9B4A0B6B19DB5B09CB0AB97AEA995ACA793A8A38FA5A08C\
A19C889E99859D98849D9884918C7898937F8C87738E8975807B67625D49848067
918E6F9693709C99789E9B7C9E9A7D9F9B80A29E85A5A08CA7A28F9A94869D978BB4ADA3C0B9B1\
BAB3ADB6AFA9BBB6B0BBBDB0BABEB0BABEB0BABEB0B9BDAFB9BDAFB9BDAFB8BCAE
BBBFB1BCC0B2BDC1B3BEC2B4BEC2B4BDC1B3BCC0B2BCBEB1B9B9AFBBB8B1BAB7B0BAB7B0B9B6AF\
B8B5AEB8B5AEB7B4ADB8B5AEB7B4ADB7B4ADB6B3ACB5B2ABB5B2ABB4B1AAB4B1AA
B3B0A9B3B0A9B2AFA8B1AEA7B1AEA7B0ADA6AFACA5AFACA5AEABA4AEABA4AEABA4AEABA4AEABA4\
AEABA4AEABA4AEABA4AEABA6AEAAA7AFABA8AFABA8B0ACA9B1ADAAB1ADAAB2AEAB
B0ACA9B0ACA9B0ACA9B0ACA9B0ACA9B0ACA9B0ACA9B0ADA8B5B1A89F9B928885809E9D9B535257\
6E7178B1B7C3B8C1D2C1CCDEBECDE0BCCEE2BAD1E3BCD3E3BBD7E5BEDAE8C1DBE8
C0D1E1C3D0E0C4D1E1C5D2E2C5D2E2C6D3E3C7D4E4C7D4E4C4D1E1C4D1E1C4D1E1C4D1E1C4D1E1\
C4D1E1C4D1E1C2D2E2C3D4E6C2D3E5C2D3E5C1D2E4C0D1E3C0D1E3BFD0E2BFD0E2
C1D2E4C1D2E4C1D2E4C0D1E3BFD0E2BECFE1BECFE1BECFE3BBCBE4BBCBE5BACAE4BACAE4B9C9E3\
B8C8E2B8C8E2B7C7E1B7C7E1B7C7E1B6C6E0B6C6E0B5C5DFB4C4DEB4C4DEB3C3DD
B3C3DDB3C3DDB2C2DCB2C2DCB1C1DBB0C0DAB0C0DAAFBFD9AFBFD9AFBFD9AEBED8ADBDD7ADBDD7\
ACBCD6ABBBD5ABBBD5
B6B19DB6B19DB5B09CB4AF9BB4AF9BB3AE9AB2AD99B2AD99B1AC98B1AC98B0AB97AEA995ADA894\
ABA692AAA591A8A691A8A691A6A590A6A590A5A48FA4A38EA4A38EA3A28DA3A28D
A1A08BA1A08BA1A08BA1A08BA1A08BA1A08BA1A08BA1A08BA5A48FA5A48FA6A590A6A590A7A691\
A8A792A8A792A9A893ADAC97AEAD98AFAE99B0AF9AB2B19CB3B29DB4B39EB5B49F
BCB7A3BCB7A3BDB8A4BEB9A5BEB9A5BFBAA6C0BBA7C0BBA7C2BDA9C2BDA9C2BDA9C2BDA9C2BDA9\
C2BDA9C2BDA9C2BDA9C2BDA9C2BDA9C1BCA8C1BCA8C0BBA7BFBAA6BFBAA6BEB9A5
BCB7A3BDB8A4BDB8A4BCB7A3BBB6A2B9B4A0B6B19DB5B09CAFAA96AEA995ABA692A7A28EA49F8B\
A09B879E99859C97839C9783908B7796917D8B86728C87737E7965615C48827E65
908D6E9592719A97789D9A7B9D997C9D997EA09C83A49F8BA9A4919B95879D978BB3ACA2BFB8AE\
B9B2AAB7B0A8BCB8AFBCBCB0BABCAEBABCAEBABCAEB9BBADB9BBADB9BBADB9BBAD
B9BBADBABCAEBBBDAFBCBEB0BCBEB0BBBDAFBABCAEB9BBAEB8B8AEBAB7AEB9B6ADB9B6ADB8B5AC\
B7B4ABB7B4ABB6B3AAB6B3AAB6B3AAB5B2A9B5B2A9B4B1A8B3B0A7B3B0A7B2AFA6
B3B0A7B3B0A7B2AFA6B2AFA6B1AEA5B0ADA4B0ADA4AFACA3ACA9A0ACA9A0ACA9A0ACA9A0ACA9A0\
ACA9A0ACA9A0ACA9A2ACA9A4ADA9A6ADA9A6AEAAA7AFABA8AFABA8B0ACA9B0ACA9
B4B0ADB4B0ADB4B0ADB5B1AEB6B2AFB6B2AFB6B2AFB7B4AFAFABA099958A8380799A9997515055\
6D7077B2B8C4B9C2D1C1CCDEBDCCDFBACCE0B7CEE0B7CEE0B6D2E0B7D3E1BAD4E1
BCCFDEBFCFDFBFCFDFC0D0E0C1D1E1C1D1E1C2D2E2C2D2E2C0D0E0C0D0E0C0D0E0C0D0E0C0D0E0\
C0D0E0C0D0E0C0D0E0C2D3E5C0D2E6C0D2E6BFD1E5BED0E4BED0E4BDCFE3BDCFE3
BFD1E5BED0E4BED0E4BDCFE3BCCEE2BCCEE2BBCDE1BBCDE3B8C9E5B8C9E7B7C8E6B7C8E6B6C7E5\
B5C6E4B5C6E4B4C5E3B4C5E3B4C5E3B3C4E2B3C4E2B2C3E1B1C2E0B1C2E0B0C1DF
B0C1DFB0C1DFAFC0DEAFC0DEAEBFDDADBEDCADBEDCACBDDBACBDDBACBDDBABBCDAAABBD9AABBD9\
A9BAD8A8B9D7A8B9D7
B6B19DB6B19DB5B09CB4AF9BB4AF9BB3AE9AB2AD99B2AD99B1AC98B0AB97AFAA96AEA995ACA793\
ABA692AAA591A7A590A7A590A5A48FA5A48FA4A38EA3A28DA3A28DA2A18CA2A18C
A09F8AA09F8AA09F8AA09F8AA09F8AA09F8AA09F8AA09F8AA4A38EA4A38EA5A48FA5A48FA6A590\
A7A691A7A691A8A792ADAC97AEAD98AFAE99B0AF9AB2B19CB3B29DB4B39EB5B49F
BCB7A3BCB7A3BDB8A4BEB9A5BEB9A5BFBAA6C0BBA7C0BBA7C3BEAAC3BEAAC3BEAAC3BEAAC3BEAA\
C3BEAAC3BEAAC3BEAAC3BEAAC3BEAAC2BDA9C2BDA9C1BCA8C0BBA7C0BBA7BFBAA6
BCB7A3BDB8A4BDB8A4BCB7A3BBB6A2B9B4A0B6B19DB5B09CAEA995ADA894AAA591A7A28EA39E8A\
9F9A869D98849B96829A95818E897595907C8984708A85717C77635F5A46817C66
8E8A6D9390719996779B977A9B977C9C987F9F9A84A29D89ACA7949D97879F998BB3ADA1C0B9AF\
BBB4AABAB3A9BFBBB0B9BAACB8BAACB9BAACB9BBADBABBADB9BBADBABBADBABCAE
B6B7A9B6B8AAB8B9ABB8BAACB9BAACB7B9ABB7B8AAB6B7A9BBB9ADBAB7AEBAB7AEB9B6ADB8B5AC\
B8B5ACB7B4ABB7B4ABB5B2A9B4B1A8B4B1A8B3B0A7B2AFA6B2AFA6B1AEA5B1AEA5
B5B2A9B5B2A9B4B1A8B3B0A7B3B0A7B2AFA6B1AEA5B1AEA5A9A69DA9A69DA9A69DA9A69DA9A69D\
A9A69DA9A69DA9A69DABA8A3ABA8A3ACA8A5ACA9A4ADA9A6AEABA6AEAAA7AFACA7
ACA8A5ADAAA5AEAAA7B0ADA8B1ADAAB3B0ABB4B0ADB5B2ABB0ACA19B978B84817A9B9A96515153\
6D7077B1B7C3B8C1D0BFCADCBBCADFB7C9DDB3CADCB2C9DBB0CBDCB1CCDDB3CDDC
BCCFE0BECDE0BFCEE1BFCEE1C0CFE2C1D0E3C1D0E3C2D1E4C2D1E4C2D1E4C2D1E4C2D1E4C2D1E4\
C2D1E4C2D1E4C1D2E4C3D5E9C3D5E9C2D4E8C1D3E7C1D3E7C0D2E6BFD1E5BFD1E5
BCCEE2BBCDE1BBCDE1BACCE0B9CBDFB9CBDFB8CADEB8CAE2BACBE9BACAECB9C9EBB8C8EAB8C8EA\
B7C7E9B6C6E8B6C6E8B6C6E8B6C6E8B5C5E7B4C4E6B4C4E6B3C3E5B2C2E4B2C2E4
B2C2E4B2C2E4B1C1E3B0C0E2B0C0E2AFBFE1AEBEE0AEBEE0AFBFE1AFBFE1AEBEE0ADBDDFADBDDF\
ACBCDEABBBDDABBBDD
B6B19DB6B19DB5B09CB4AF9BB4AF9BB3AE9AB2AD99B2AD99B0AB97AFAA96AEA995ADA894ABA692\
AAA591A9A490A6A48FA6A48FA5A48FA4A38EA4A38EA3A28DA2A18CA2A18CA1A08B
9F9E899F9E899F9E899F9E899F9E899F9E899F9E899F9E89A3A28DA4A38EA4A38EA5A48FA6A590\
A6A590A7A691A7A691ADAC97AEAD98AFAE99B0AF9AB2B19CB3B29DB4B39EB5B49F
BCB7A3BCB7A3BDB8A4BEB9A5BEB9A5BFBAA6C0BBA7C0BBA7C4BFABC4BFABC4BFABC4BFABC4BFAB\
C4BFABC4BFABC4BFABC4BFABC3BEAAC3BEAAC2BDA9C1BCA8C1BCA8C0BBA7C0BBA7
BCB7A3BDB8A4BDB8A4BCB7A3BBB6A2B9B4A0B6B19DB5B09CAEA995ACA793AAA591A6A18DA29D89\
9F9A869C97839B96829994808D8874948F7B88836F8984707B76625E59457F7A64
8D896E928E719894779A967B9A967B9B977E9E9983A19C88A7A28F989282999385ADA799B9B3A7\
B5AFA3B4AEA2BAB6AAB8B6A9B7B8A8B9B7A8B9BAAABCBAABBBBCACBEBCADBCBDAD
BCBAABBBBCACBEBCADBDBEAEBFBDAEBCBDADBDBBACBCBAADBCBAAEBCBAAEBBB9ADBBB9ADBAB8AC\
B9B7ABB9B7ABB8B6AAB3B1A5B3B1A5B3B1A5B2B0A4B1AFA3B0AEA2B0AEA2B0AEA2
AFADA1AFADA1AFADA1AEACA0ADAB9FACAA9EACAA9EACAA9EA8A69AA8A69AA8A69AA8A69AA8A69A\
A8A69AA8A69AA8A59CAAA7A0AAA7A0AAA7A2ABA8A1ACA9A4ADAAA3ADAAA5ADAAA3
AAA7A2ABA8A1AEABA6B0ADA6B3B0ABB6B3ACB8B5B0B9B6ADBAB6AAA4A1928C8980A09F9A535353\
6D7075AFB6C0B5BECDBBC6DAB7C6DBB4C6DCB0C6DBB0C6DBAEC9DCB0CBDEB2CCDD
B8CADEB9CADEBACBDFBBCCE0BBCCE0BCCDE1BDCEE2BDCEE2C0D1E5C0D1E5C0D1E5C0D1E5C0D1E5\
C0D1E5C0D1E5C0D1E5C2D4EAC0D5EABFD4E9BFD4E9BED3E8BDD2E7BDD2E7BCD1E6
B8CDE2B8CDE2B7CCE1B7CCE1B6CBE0B5CADFB5CADFB4C8E1B7CAEAB6C8ECB6C8ECB5C7EBB4C6EA\
B4C6EAB3C5E9B3C5E9B3C5E9B2C4E8B2C4E8B1C3E7B0C2E6B0C2E6AFC1E5AFC1E5
AFC1E5AEC0E4AEC0E4ADBFE3ACBEE2ACBEE2ABBDE1ABBDE1AEC0E4ADBFE3ADBFE3ACBEE2ABBDE1\
ABBDE1AABCE0AABCE0
B6B19DB6B19DB5B09CB4AF9BB4AF9BB3AE9AB2AD99B2AD99B0AB97AFAA96AEA995ADA894ABA692\
AAA591A9A490A6A48FA6A48FA5A48FA4A38EA3A28DA3A28DA2A18CA1A08BA1A08B
9F9E899F9E899F9E899F9E899F9E899F9E899F9E899F9E89A3A28DA3A28DA4A38EA5A48FA5A48F\
A6A590A7A691A7A691ADAC97AEAD98AFAE99B0AF9AB2B19CB3B29DB4B39EB5B49F
BCB7A3BCB7A3BDB8A4BEB9A5BEB9A5BFBAA6C0BBA7C0BBA7C4BFABC4BFABC4BFABC4BFABC4BFAB\
C4BFABC4BFABC4BFABC4BFABC4BFABC3BEAAC2BDA9C2BDA9C1BCA8C0BBA7C0BBA7
BCB7A3BDB8A4BDB8A4BCB7A3BBB6A2B9B4A0B6B19DB5B09CADA894ACA793A9A490A6A18DA29D89\
9F9A869C97839A958198937F8C8773938E7A88836F8984707B76625D58447F7A64
8C886D918D729793789A967D99957C9A957F9D9884A09B879F9A878F8A778F8979A39D8FAFA99B\
ABA597ABA599B4AEA0B7B4A5B7B5A6B8B6A7BAB8A9BCBAABBEBCADBFBDAEC0BEAF
C4C2B3C5C3B4C6C4B5C7C5B6C7C5B6C6C4B5C5C3B4C4C2B3BDBBAEBDBBAFBCBAAEBCBAAEBBB9AD\
BAB8ACBAB8ACB9B7ABB3B1A5B2B0A4B2B0A4B1AFA3B0AEA2B0AEA2AFADA1AFADA1
A6A498A6A498A5A397A5A397A4A296A3A195A3A195A2A094A7A599A7A599A7A599A7A599A7A599\
A7A599A7A599A7A599A9A69DA9A69FAAA7A0AAA7A0ABA8A1ACA9A2ACA9A2ADAAA3
B9B6AFBAB7B0BDBAB3C0BDB6C4C1BAC8C5BECBC8C1CCCABEC5C2B3ADAA99939185A5A59D565654\
6D7075AEB5BFB3BCCBB8C3D7B4C3DAB2C4DCAFC5DCB0C6DDB0CBDEB2CDE2B3CEE1
B0C4DCB3C3DAB4C4DDB5C5DCB5C5DEB6C6DDB7C7E0B7C7DEBBCBE4BBCBE2BBCBE4BBCBE2BBCBE4\
BBCBE2BBCBE4BACCE2BCD0E8BCD1E6BBCFE7BBD0E5BACEE6B9CEE3B9CDE5B8CDE2
B8CCE4B8CDE2B8CCE4B7CCE1B6CAE2B5CADFB5C9E1B5C9E2B2C4E8B2C4EAB1C3EBB1C3E9B0C2EA\
AFC1E7AFC1E9AEC0E6AEC0E8AEC0E6ADBFE7ADBFE5ACBEE6ABBDE3ABBDE5AABCE2
AABCE4AABCE2A9BBE3A9BBE1A8BAE2A7B9DFA7B9E1A6B8DEABBDE5AABCE2AABCE4A9BBE1A8BAE2\
A8BAE0A7B9E1A7B9DF
BAB5A1B9B4A0B8B39FB7B29EB5B09CB4AF9BB3AE9AB2AD99B0AB97AFAA96AEA995ADA894ABA692\
AAA591A9A490A6A48FA4A28DA3A28DA2A18CA2A18CA1A08BA09F8AA09F8A9F9E89
9D9C879D9C879D9C879D9C879D9C879D9C879D9C879D9C879F9E89A09F8AA1A08BA2A18CA4A38E\
A5A48FA6A590A7A691A9A893AAA994ACAB96AEAD98B0AF9AB2B19CB4B39EB5B49F
BCB7A3BCB7A3BDB8A4BEB9A5BEB9A5BFBAA6C0BBA7C0BBA7C0BBA7C0BBA7C1BCA8C2BDA9C2BDA9\
C3BEAAC4BFABC4BFABC4BFABC4BFABC3BEAAC2BDA9C2BDA9C1BCA8C0BBA7C0BBA7
BDB8A4BDB8A4BEB9A5BDB8A4BBB6A2B8B39FB5B09CB4AF9BB0AB97AEA995ABA692A7A28EA29D89\
9E99859B968299948095907C8A8571918C7886816D86816D77725E57523E78735D
8D8970908C7394907798937D9C97819E9983A09B87A09B87A29D8A948F7C8781718A8474989282\
A49E8EA59F91A09A8AA29F8EA29F8EA3A08FA3A08FA4A190A5A291A5A291A6A392
AFAC9BAFAC9BAFAC9BAFAC9BAFAC9BAFAC9BAFAC9BAFAC9DB4B2A5B2B0A3AEAC9FACAA9DADAB9E\
B1AFA2B5B3A6B8B6A9AEAC9FADAB9EADAB9EACAA9DABA99CABA99CAAA89BAAA89B
A7A598A8A699A9A79AAAA89BABA99CACAA9DADAB9EADAB9EAAA89BAAA89BA8A699A7A598A5A396\
A3A194A2A093A19F93A29F96A29F96A29F96A29F96A29F96A29F96A29F96A29F96
A7A49BABA89FB2AFA6BAB7AEC0BDB4C3C0B7C5C2B9C5C3B7B4B1A0A6A390A5A39699998F545452\
5A5E61B3BAC4B6BFCEBCC7DBBAC9E0B8CAE2B6CCE4B7CDE5B4CFE4B5CFE6B5D0E5
AFC3DCB1C3DBB1C2DCB2C4DCB3C4DEB4C6DEB4C5DFB4C6DEBDCEE8BDCFE7BDCEE8BDCFE7BDCEE8\
BDCFE7BDCEE8BDCFE7BFD3ECBED4EBBDD3EBBDD3EABCD2EABBD1E8BBD1E9BAD0E7
B8CEE6B8CEE5B7CDE5B6CCE3B6CCE4B5CBE2B4CAE2B4C9E4B4C8EDB4C7EFB3C6F0B2C5EDB2C5EF\
B1C4ECB0C3EDB0C3EBB0C3EDB0C3EBAFC2ECAEC1E9AEC1EBADC0E8ACBFE9ACBFE7
ACBFE9ACBFE7ABBEE8AABDE5AABDE7A9BCE4A8BBE5A8BBE3A8BBE5A8BBE3A7BAE4A6B9E1A6B9E3\
A5B8E0A4B7E1A4B7DF
BAB5A1B9B4A0B8B39FB7B29EB5B09CB4AF9BB3AE9AB2AD99AFAA96AFAA96AEA995ACA793ABA692\
A9A490A8A38FA6A48FA3A18CA2A18CA2A18CA1A08BA09F8A9F9E899F9E899F9E89
9D9C879D9C879D9C879D9C879D9C879D9C879D9C879D9C879F9E899F9E89A09F8AA2A18CA3A28D\
A5A48FA6A590A6A590A9A893AAA994ACAB96AEAD98B0AF9AB2B19CB4B39EB4B39E
BCB7A3BCB7A3BDB8A4BEB9A5BEB9A5BFBAA6C0BBA7C0BBA7C0BBA7C0BBA7C1BCA8C2BDA9C2BDA9\
C3BEAAC4BFABC4BFABC4BFABC4BFABC3BEAAC2BDA9C2BDA9C1BCA8C0BBA7C0BBA7
BDB8A4BDB8A4BDB8A4BCB7A3BAB5A1B7B29EB4AF9BB3AE9AACA793ABA692A7A28EA39E8A9F9A86\
9A958197927E95907C948F7B898470908B7785806C85806C76715D56513D77725E
89846E8C8771908B75948F7998937D9B96809C97839C9783A29D8A96917E898373847E6E857F6F\
878171837D6D7E7868817E6D827F6E827F6E83806F848170848170858271858271
7F7C6B7F7C6B7F7C6B7F7C6B7F7C6B7F7C6B7F7C6B7F7C6B817F7082807384827589877A918F82\
9B998CA4A295A9A79AA8A699A8A699A7A598A7A598A6A497A5A396A5A396A4A295
B7B5A8B7B5A8B8B6A9B8B6A9B9B7AABAB8ABBBB9ACBBB9ACADAB9EADAB9EACAA9DAAA89BA8A699\
A7A598A5A396A5A3969C9A8E9C99909C99909C99909C99909C99909C99909C9990
99968D9A978E9D9A919F9C939F9C939E9B929C99909B998CA5A28F9996839B998A9393874F504B\
565A5DAEB5BFB1BAC9B8C3D7B5C4DBB4C6DEB1C7DFB2C8E0B0CAE1B0CAE3B1CBE2
B8CCE7BACBE5BBCCE8BBCCE6BCCDE9BDCEE8BDCEEABECFE9BECFEBBECFE9BECFEBBECFE9BECFEB\
BECFE9BECFEBBCD0E9B9CFE7B7CFE7B9CFE7B6CEE6B7CDE5B4CCE4B6CCE4B4CCE4
B8CEE6B5CDE5B7CDE5B4CCE4B5CBE3B3CBE3B4CAE2B2CAE6B4C8EDB1C7F0B3C6F0B0C6EFB1C4EE\
AFC5EEB0C3EDAEC4EDB0C3EDADC3ECAFC2ECACC2EBADC0EAABC1EAACBFE9AAC0E9
ACBFE9A9BFE8ABBEE8A8BEE7A9BCE6A7BDE6A8BBE5A6BCE5A8BBE5A5BBE4A7BAE4A4BAE3A5B8E2\
A3B9E2A4B7E1A2B8E1
B9B4A0B8B39FB7B29EB6B19DB4AF9BB3AE9AB2AD99B1AC98AEA995AEA995ADA894ABA692AAA591\
A8A38FA7A28EA5A38EA2A08BA1A08BA09F8AA09F8A9F9E899E9D889E9D889D9C87
9B9A859B9A859B9A859B9A859B9A859B9A859B9A859B9A859E9D889E9D889F9E89A1A08BA2A18C\
A4A38EA5A48FA5A48FA8A792A9A893ABAA95ADAC97AFAE99B1B09BB3B29DB4B39E
BCB7A3BCB7A3BDB8A4BEB9A5BEB9A5BFBAA6C0BBA7C0BBA7C0BBA7C0BBA7C1BCA8C2BDA9C2BDA9\
C3BEAAC4BFABC4BFABC4BFABC4BFABC3BEAAC2BDA9C2BDA9C1BCA8C0BBA7C0BBA7
BDB8A4BDB8A4BCB7A3BBB6A2B9B4A0B6B19DB3AE9AB1AC98A9A490A7A28EA49F8B9F9A869B9682\
97927E938E7A928D79928D7987826E8E8975837E6A837E6A746F5B55503C75705C
85806C88836F8C8773908B77948F7B96917D98937F98937FA8A38FA6A18DA39E8BA29D8AA19C89\
A29D8AA39E8BA39E8BA09B88A19C89A19C89A29D8AA39E8BA39E8BA49F8CA49F8C
9F9A879F9A879F9A879F9A879F9A879F9A879F9A879D9A899E9C8D9D9B8C9C9A8B9C9A8B9F9D8E\
A3A192A7A596AAA899A19F90A19F90A19F90A09E8F9F9D8E9E9C8D9E9C8D9E9C8D
9896879896879997889997889A98899A98899B998A9B998A9E9C8D9D9B8C9C9A8B9B998A9A9889\
989687979586979588969488969488969488969488969488969488969488969488
969488969488969488959387939185908E828D8B7F8B897C999782918F7A97968492928650514C\
565A5BADB4BCADB6C5B8C3D7B5C4DBB4C5DFB1C6E1B2C7E2B0CAE3B0CAE5B1CBE4
B4C9E6B6CAE5B6C9E7B7CBE6B8CBE9B8CCE7B9CCEAB9CDE8BCCFEDBCD0EBBCCFEDBCD0EBBCCFED\
BCD0EBBCCFEDBCD0EBB7CFE9B6D0E9B6CEE8B4CEE7B5CDE7B3CDE6B3CBE5B2CCE5
B5CDE7B4CEE7B4CCE6B3CDE6B3CBE5B1CBE4B2CAE4B0CAE5B1C7ECB0C8EEB0C6EDAFC7EDAFC5EC\
ADC5EBAEC4EBACC4EAADC3EAACC4EAACC2E9ABC3E9ABC1E8A9C1E7AAC0E7A8C0E6
A9BFE6A8C0E6A8BEE5A7BFE5A7BDE4A5BDE3A6BCE3A4BCE2A5BBE2A4BCE2A4BAE1A3BBE1A3B9E0\
A1B9DFA2B8DFA0B8DE
B8B39FB8B39FB7B29EB5B09CB4AF9BB2AD99B1AC98B1AC98ADA894ACA793ABA692AAA591A8A38F\
A7A28EA6A18DA3A18CA19F8A9F9E899F9E899E9D889D9C879D9C879C9B869C9B86
9A99849A99849A99849A99849A99849A99849A99849A99849C9B869D9C879E9D889F9E89A1A08B\
A2A18CA3A28DA4A38EA8A792A9A893AAA994ACAB96AFAE99B1B09BB2B19CB3B29D
BCB7A3BCB7A3BDB8A4BEB9A5BEB9A5BFBAA6C0BBA7C0BBA7C0BBA7C0BBA7C1BCA8C2BDA9C2BDA9\
C3BEAAC4BFABC4BFABC4BFABC4BFABC3BEAAC2BDA9C2BDA9C1BCA8C0BBA7C0BBA7
BCB7A3BCB7A3BBB6A2BAB5A1B7B29EB3AE9AB0AB97AEA995A7A28EA6A18DA29D899E99859A9581\
95907C928D79908B77908B7785806C8C8773817C68817C68726D59524D39736E5A
837E6A86816D8A85718E8975928D79948F7B96917D96917D8D8874948F7B9C9784A09B889F9A87\
A19C88A7A28FADA895A9A491A9A491AAA592AAA592ABA693ACA794ACA794ADA895
ADA895ADA895ADA895ADA895ADA895ADA895ADA895ADA895B0AD9CACAA9BA7A596A2A0919D9B8C\
9B998A9A98899997889D9B8C9D9B8C9C9A8B9C9A8B9B998A9A98899A9889999788
9593849593849694859694859694859694859694859694858F8D7E8E8C7D8E8C7D8D8B7C8C8A7B\
8B897A8A88798A8879918F82918F83918F83918F83918F83918F83918F83918F83
97958997958998968A99978B99978B99978B99978B9997889A988393917A9C9B89999A8C565751\
5A5E5FAEB5BDADB6C5BCC7DBBAC9E0B8C9E3B6CBE6B7CCE9B4CEE9B5CFEAB5CFEA
B2C7E4B3C6E4B3C6E6B4C7E5B5C8E8B6C9E7B6C9E9B6C9E7BACDEDBACDEBBACDEDBACDEBBACDED\
BACDEBBACDEDB9CEEBBBD3EFB9D3ECB9D3ECB8D2EBB7D1EAB7D1EAB6D0E9B6D0E9
B3CDE6B3CDE6B2CCE5B2CCE5B1CBE4B0CAE3B0CAE3AFC9E4AFC7E9AFC7EBAEC6EAAEC6EAADC5E9\
ACC4E8ACC4E8ABC3E7ABC3E7ABC3E7AAC2E6AAC2E6A9C1E5A8C0E4A8C0E4A7BFE3
A7BFE3A7BFE3A6BEE2A6BEE2A5BDE1A4BCE0A4BCE0A3BBDFA3BBDFA3BBDFA2BADEA2BADEA1B9DD\
A0B8DCA0B8DC9FB7DB
B7B29EB7B29EB6B19DB4AF9BB3AE9AB1AC98B0AB97B0AB97ABA692AAA591A9A490A8A38FA6A18D\
A5A08CA49F8BA19F8A9F9D889E9D889D9C879D9C879C9B869B9A859B9A859A9984
9897829897829897829897829897829897829897829897829A99849B9A859C9B869D9C879F9E89\
A09F8AA1A08BA2A18CA7A691A8A792A9A893ABAA95AEAD98B0AF9AB1B09BB2B19C
BCB7A3BCB7A3BDB8A4BEB9A5BEB9A5BFBAA6C0BBA7C0BBA7C0BBA7C0BBA7C1BCA8C2BDA9C2BDA9\
C3BEAAC4BFABC4BFABC4BFABC4BFABC3BEAAC2BDA9C2BDA9C1BCA8C0BBA7C0BBA7
BCB7A3BBB6A2BBB6A2B8B39FB5B09CB1AC98AEA995ABA692A8A38FA6A18DA39E8A9E99859A9581\
96917D928D79918C788E8975827D698A85717E79657F7A666F6A56504B37706B57
837E6B85806D8984718D8875918C79948F7C95907D96917E918C78999480A09B879E998597927E\
928D7795907C9A9581A09986A09986A19A87A29B88A29B88A39C89A49D8AA49D8A
9F98859F98859F98859F98859F98859F98859F98859E99869F9C8B9E9D8B9E9D8B9D9C8A9E9D8B\
9F9E8CA09F8DA1A08E9C9B899C9B899B9A889A99879A9987999886989785989785
9A99879A998799988699988699988699988699988699988692917F91907E91907E908F7D908F7D\
8F8E7C8F8E7C8F8D7E908E81908E81908E81908E81908E81908E81908E81908E81
918F82918F8292908393918495938697958899978A9A99879C9A8396947B9E9D899B9C8E575852\
595D5CABB2BAA8B1C0BCC7DBBAC8E2B8C9E5B6CBE8B7CCEBB4CDEBB5CEECB5CEEC
B5CCEBB7CCEBB7CBECB8CDECB9CDEEBACFEEBACEEFBACFEEB6CAEBB6CBEAB6CAEBB6CBEAB6CAEB\
B6CBEAB6CAEBB6CBEABAD2EEB8D2EDB8D2EDB7D1ECB6D0EBB6D0EBB5CFEAB5CFEA
B3CDE8B2CCE7B2CCE7B1CBE6B0CAE5B0CAE5AFC9E4AFC9E4AFC8E7AEC6E8AEC6E8ADC5E7ACC4E6\
ACC4E6ABC3E5ABC3E5ABC3E5AAC2E4AAC2E4A9C1E3A8C0E2A8C0E2A7BFE1A7BFE1
A7BFE1A6BEE0A6BEE0A5BDDFA4BCDEA4BCDEA3BBDDA3BBDDA3BBDDA2BADCA2BADCA1B9DBA0B8DA\
A0B8DA9FB7D99FB7D9
B7B29EB6B19DB5B09CB4AF9BB2AD99B1AC98B0AB97AFAA96A9A490A9A490A8A38FA6A18DA5A08C\
A39E8AA29D89A09E899E9C879C9B869C9B869B9A859A99849A9984999883999883
9796819796819796819796819796819796819796819796819998839998839A99849C9B869D9C87\
9F9E89A09F8AA09F8AA6A590A7A691A9A893ABAA95ADAC97AFAE99B1B09BB2B19C
BCB7A3BCB7A3BDB8A4BEB9A5BEB9A5BFBAA6C0BBA7C0BBA7C0BBA7C0BBA7C1BCA8C2BDA9C2BDA9\
C3BEAAC4BFABC4BFABC4BFABC4BFABC3BEAAC2BDA9C2BDA9C1BCA8C0BBA7C0BBA7
BBB6A2BBB6A2BAB5A1B7B29EB3AE9AAFAA96ABA692A9A490A6A18DA5A08CA19C889D9884999480\
948F7B918C788F8A768B8672807B6787826E7C77637C77636D68544E49356E6955
817B6B837D6D87826F8B86738F8A77928D7A938E7B948F7CA09B87A6A18DABA692A9A490A39E88\
9F9A84A19C86A5A08AA8A18EA8A18EA8A18EA9A28FAAA390ABA491ABA491ABA491
A7A08DA7A08DA7A08DA7A08DA7A08DA7A08DA7A08DA6A18DA29F8CA2A18FA3A290A4A391A5A492\
A6A593A7A694A7A6949B9A889A99879A9987999886989785989785979684979684
8F8E7C8F8E7C8E8D7B8E8D7B8D8C7A8C8B798C8B798C8B7991907E91907E91907E908F7D908F7D\
908F7D908F7D908F7D8F8D808F8D808F8D808F8D808F8D808F8D808F8D808F8D80
949285929083918F828F8D808F8D80908E81918F8292917F98967F918F76999884949587505149\
525655A5ACB4A3ACBBB8C3D7B5C3DDB4C5E1B1C6E3B2C7E6B0C9E7B0C9E7B1CAE8
B2C9E9B4C8E9B5C9EAB5C9EAB6CAEBB7CBECB7CBECB8CCEDB7CBECB7CBECB7CBECB7CBECB7CBEC\
B7CBECB7CBECB5CCECB3CCEAB3CDE8B3CDE8B2CCE7B1CBE6B0CAE5B0CAE5B0CAE5
B2CCE7B1CBE6B1CBE6B0CAE5AFC9E4AFC9E4AEC8E3AEC8E3AEC7E5ADC6E4ADC6E5ACC5E3ABC4E3\
ABC4E2AAC3E2AAC3E1AAC3E2A9C2E0A9C2E1A8C1DFA7C0DFA7C0DEA6BFDEA6BFDD
A6BFDEA5BEDCA5BEDDA4BDDBA3BCDBA3BCDAA2BBDAA2BBD9A2BBDAA1BAD8A1BAD9A0B9D79FB8D7\
9FB8D69EB7D69EB7D5
B6B19DB5B09CB4AF9BB3AE9AB1AC98B0AB97AFAA96AEA995A8A38FA8A38FA7A28EA5A08CA49F8B\
A29D89A19C889F9D889C9A859B9A859B9A859A9984999883989782989782989782
95947F95947F95947F95947F95947F95947F95947F95947F9897829897829998839B9A859C9B86\
9E9D889F9E899F9E89A6A590A6A590A8A792AAA994ACAB96AEAD98B0AF9AB1B09B
BCB7A3BCB7A3BDB8A4BEB9A5BEB9A5BFBAA6C0BBA7C0BBA7C0BBA7C0BBA7C1BCA8C2BDA9C2BDA9\
C3BEAAC4BFABC4BFABC4BFABC4BFABC3BEAAC2BDA9C2BDA9C1BCA8C0BBA7C0BBA7
BBB6A2BAB5A1B9B4A0B6B19DB2AD99ADA894A9A490A7A28EA39E8AA19C889E998599948095907C\
918C788D88748C87738A85717E796586816D7A75617B76626B66524C47336C6753
7C76667F7969837D6D8781718B86738E89768F8A778F8A778C87738F8A76928D7795907A97927C\
99947E9D9980A19D849D97819D97819E98829F99839F9983A09A84A19B85A19B85
A19B85A19B85A19B85A19B85A19B85A19B85A19B85A09B879A9784999886989785969583949381\
91907E8E8D7B8D8C7A989785979684979684969583959482959482949381949381
989785979684979684969583959482949381939280939280898876898876898876898876898876\
8988768A89778A89778C8A7D8C8A7D8C8A7D8C8A7D8C8A7D8C8A7D8C8A7D8C8A7D
979588959386939184908E818F8D80908E819290839392809290778B8A6E92917C8E8F7F4C4D45\
505453A5ACB4A5AEBDB8C3D7B5C3DDB4C5E1B1C6E3B2C7E6B0C9E8B0C9E8B1CAE9
AFC6E8B0C7E9B0C7E9B1C8EAB2C9EBB2C9EBB3CAECB3CAECB8CFF1B8CFF1B8CFF1B8CFF1B8CFF1\
B8CFF1B8CFF1B8CFEFB3CCEAB2CDE8B1CCE7B0CBE6B0CBE6AFCAE5AEC9E4AEC9E4
B0CBE6B0CBE6AFCAE5AFCAE5AEC9E4ADC8E3ADC8E3ACC7E2ACC7E2ACC7E2ABC6E3ABC6E1AAC5E2\
A9C4DFA9C4E1A8C3DEA8C3E0A8C3DEA7C2DFA7C2DDA6C1DEA5C0DBA5C0DDA4BFDA
A4BFDCA4BFDAA3BEDBA3BED9A2BDDAA1BCD7A1BCD9A0BBD6A0BBD8A0BBD69FBAD79FBAD59EB9D6\
9DB8D39DB8D59CB7D2
B6B19DB5B09CB4AF9BB3AE9AB1AC98B0AB97AFAA96AEA995A8A38FA7A28EA6A18DA5A08CA39E8A\
A29D89A19C889E9C879C99869A99859A9985999884989783989783979682979682
9594809594809594809594809594809594809594809594809796819897829A98839A99849D9B86\
9D9C879F9D889F9E89A6A48FA6A590A9A792AAA994ADAB96AEAD98B1AF9AB2B09B
BCB7A3BCB7A3BDB8A4BEB9A5BEB9A5BFBAA6C0BBA7C0BBA7C0BBA7C0BBA7C1BCA8C2BDA9C2BDA9\
C3BEAAC4BFABC4BFABC4BFABC4BFABC3BEAAC2BDA9C2BDA9C1BCA8C0BBA7C0BBA7
BBB6A2BAB5A1B8B39FB6B19DB1AC98ADA894A8A38FA6A18D9F9A869D98849A958196917D918C78\
8D88748A857188836F8984707D786485806C7974607A75616A65514B46326B6652
7873607B76637F7969837E6B87826F8A85728B86738C877497927E96917D95907A95907A98937D\
9B96809D98829D9882A09A84A09A84A19B85A19B85A29C86A39D87A39D87A49E88
A09A84A09A84A09A84A09A84A09A84A09A84A09A849F9A869C99869C9B879E9B8A9E9D899F9C8B\
9D9C889D9A899B9A8696938294937F95928193927E93907F92917D928F7E91907C
8E8B7A8C8B778C89788A89758A87768887738885748786728986758887738986758988748A8776\
8A89758B88778A89778A877889877A8A867A89877A8A867A89877A8A867A89877A
918D818F8D808E8A7E8C8A7D8E8A7E8F8D80949084969382908E7588876B918F7A8E8D7B4C4E43\
555754ADB2B6ADB5C0BEC6D9BCC8DEB9C9E3B9CAE6B8CBEBB7CBECB6CDEDB6CDED
BCCFF0BCCFF0BCCEF2BDD0F1BED0F4BFD2F3BFD1F5BFD2F3BFD1F5BFD2F3BFD1F5BFD2F3BFD1F5\
BFD2F3BFD1F5BFD2F3BACFECB8D0EAB9CEEBB7CFE9B8CDEAB5CDE7B7CCE9B4CCE6
B4C9E6B2CAE4B3C8E5B0C8E2B2C7E4AFC7E1B0C5E2AEC6E2AEC5E4AEC5E4ADC4E3ACC3E2ACC3E2\
ABC2E1AAC1E0AAC1E0AAC1E0AAC1E0A9C0DFA8BFDEA8BFDEA7BEDDA6BDDCA6BDDC
A8BDDCA8BDDCA7BCDBA6BBDAA6BBDAA5BAD9A4B9D8A4B9D8A4B9D8A4B9D8A3B8D7A2B7D6A2B7D6\
A1B6D5A0B5D4A0B5D4
B6B19DB5B09CB3AE9AB1AC98AFAA96ADA894ABA692ABA692AAA591A9A490A8A38FA5A08CA39E8A\
A19C889F9A869D9A879A978698978597968496958394938193928092917F91907E
8F8E7C908F7D908F7D91907E92917F92917F9392809392809693809795809A95819997829D9884\
9C9A859F9A869E9C87A39E8AA2A08BA6A18DA7A590ACA793ADAB96B1AC98B2AD99
B9B4A0B9B4A0BBB6A2BDB8A4BFBAA6C2BDA9C3BEAAC4BFABC0BBA7C0BBA7C0BBA7C0BBA7C0BBA7\
C0BBA7C0BBA7C0BBA7C1BCA8C2BDA9C2BDA9C2BDA9C1BCA8BFBAA6BDB8A4BCB7A3
BCB7A3BAB5A1B7B29EB3AE9AAEA995AAA591A7A28EA5A08C9F9A869D988499948095907C908B77\
8B867288836F86816D85806C7E7965847F6B75705C78735F6F6A564C4733635E4A
7D78647F7A66837E6B86816D8A85718B86728C87738C8773918C78918C78928D79948F7B95907C\
97927E98937F98937F9D98849D98849D98849E99859F9A86A09B87A09B87A09B87
9E99859E99859E99859E99859E99859E99859E99859E99859E99859C9A859D98859B99849C9784\
9997829B968398968198938096947F97927F95937E96917E93917C95907D92907B
908B788E8C778F8A778D8B768E89768B89748D88758A88738E89768C8A758D88758B89748C8774\
8987728B86738885728C86788A87788C86788A87788C86788A87788C86788A8778
908A7C8E8B7C908A7C8E8B7C908A7C8E8B7C908A7C908A7A97937A908E758E8C758E8D7958594B\
52534B9C9E9DA7ACB0B4BAC6B4BBCDB3BED4B4C0DAB4BFDDB2BFE1B0BEE1B0BEE1
B3BDE1B4BEE1B6C0E4B8C2E5BAC4E8BCC6E9BEC8ECBEC8EBBFC9EDBFC9ECBFC9EDBFC9ECBFC9ED\
BFC9ECBFC9EDBFC9ECC0CBE9BECCE7BFCAE8BCCAE5BDC8E6BAC8E3BBC6E4B9C7E2
BBC6E4B9C7E2BBC6E4B8C6E1B9C4E2B6C4DFB8C3E1B6C3E3B2C0E3B2C0E5B3C1E6B3C1E6B3C1E6\
B4C2E7B4C2E7B4C2E7AEBCE1AEBCE1AEBCE1AEBCE1AFBDE2AFBDE2AFBDE2B1BDE3
B1B9E0B2B7DFB2B7DFB1B6DEB0B5DDB0B5DDAFB4DCAFB4DCB0B5DDB0B5DDB0B5DDAFB4DCAEB3DB\
ADB2DAADB2DAADB2DA
B5B09CB4AF9BB3AE9AB0AB97AEA995ACA793AAA591AAA591A7A28EA6A18DA49F8BA29D89A09B87\
9E99859C9783999683999685989687969485959384949283929081918F80908E7F
8E8C7D8F8D7E8F8D7E908E7F918F80918F8092908192917F97927F98937F9994809B96829C9783\
9D98849F9A869F9A86A29D89A39E8AA5A08CA8A38FABA692AEA995B0AB97B1AC98
B5B09CB6B19DB8B39FBAB5A1BCB7A3BEB9A5C0BBA7C1BCA8C0BBA7C0BBA7C0BBA7C0BBA7C0BBA7\
C0BBA7C0BBA7C0BBA7C0BBA7C0BBA7C0BBA7C0BBA7BFBAA6BDB8A4BAB5A1B9B4A0
B8B39FB6B19DB3AE9AAFAA96AAA591A6A18DA39E8AA19C889B968299948095907C918C788C8773\
88836F847F6B837E6A817C687A7561817C68726D5975705C6C67534944305F5A46
7974607B76627F7A66837E6A86816D88836F88836F8984708D88748D88748E8975908B77918C78\
938E7A948F7B948F7B98937F9994809994809A95819B96829B96829C97839C9783
9B96829B96829B96829B96829B96829B96829B96829B96829A95819A95819A958199948098937F\
97927E97927E97927E95907C948F7B948F7B938E7A928D79928D79918C78918C78
8F8A768F8A768F8A768E89758D88748C87738C87738C87738D88748D88748D88748C87738B8672\
8A85718A85718A85728B85758B85778B85778B85778B85778B85778B85778B8577
8F897B8F897B8F897B8F897B8F897B8F897B8F897B8F8979938E788E8A718B89748B8A78575548\
4F51469A9A98A4A8ABA4A6B2A3A9B9A3A9BFA4ABC7A3ACCBA3ABCFA1AAD1A0A9D0
A9AED4A9AFD3A8ADD3A7ADD1A7ACD2A6ACD0A5AAD0A5ABCFAAAFD5AAB0D4AAAFD5AAB0D4AAAFD5\
AAB0D4AAAFD5AAB0D4AAB0D0A9B0CDA9AFCFA8AFCCA7ADCDA6ADCAA5ABCBA5ACC9
A5ABCBA5ACC9A4AACAA4ABC8A3A9C9A2A9C6A2A8C89FA8C9AAB2D9A9B2DBA9B2DBA9B2DBAAB3DC\
AAB3DCAAB3DCAAB3DCA3ACD5A3ACD5A4ADD6A4ADD6A4ADD6A4ADD6A4ADD6A5ACD6
AAABD7ABAAD6ABAAD6AAA9D5A9A8D4A9A8D4A8A7D3A8A7D3AFAEDAAFAEDAAFAEDAAEADD9ADACD8\
ACABD7ACABD7ACABD7
B3AE9AB2AD99B1AC98AFAA96ACA793AAA591A9A490A8A38FA39E8AA29D89A09B879E99859C9783\
9A958198937F95927F979483969485959384939182929081908E7F8F8D7E8F8D7E
8D8B7C8D8B7C8D8B7C8E8C7D8F8D7E908E7F908E7F908F7D96917E96917D97927E9994809A9581\
9C97839D98849D9884A09B87A19C88A39E8AA6A18DA9A490ACA793AEA995AFAA96
B1AC98B2AD99B4AF9BB6B19DB8B39FBAB5A1BCB7A3BDB8A4BEB9A5BEB9A5BEB9A5BEB9A5BEB9A5\
BEB9A5BEB9A5BEB9A5BFBAA6BFBAA6BFBAA6BFBAA6BDB8A4BAB5A1B8B39FB6B19D
B3AE9AB1AC98AEA995AAA591A5A08CA19C889E99859C978395907C948F7B918C788D887488836F\
847F6B817C687F7A667E796576715D7D78646E6955716C5868634F45402C5C5743
75705C77725E7B76627E7965817C68837E6A847F6B847F6B88836F8984708A85718C87738D8874\
8E8975908B77908B77948F7B948F7B948F7B95907C96917D97927E97927E97927E
96917D96917D96917D96917D96917D96917D96917D96917D96917D96917D95907C95907C948F7B\
938E7A938E7A928D79918C78918C78908B778F8A768F8A768E89758D88748D8874
8E89758E89758D88748D88748C87738B86728B86728A85718C87738C87738B86728B86728A8571\
8984708984708883708A84748A84768A84768A84768A84768A84768A84768A8476
8E887A8E887A8E887A8E887A8E887A8E887A8E887A8E88788E89758A8571878471888677545246\
4C4D47969696A0A3A8A0A2AF9EA3B69FA5BDA0A7C49FA8C99FA7CC9DA6CD9CA5CC
A3A8D0A3A8CEA2A7CFA2A7CDA1A6CEA0A5CBA0A5CD9FA4CAA4A9D1A4A9CFA4A9D1A4A9CFA4A9D1\
A4A9CFA4A9D1A4A9CFA1A7C9A1A7C7A0A6C8A0A6C69FA5C79FA5C59EA4C69EA4C4
9DA3C59DA3C39DA3C59CA2C29BA1C39AA0C09AA0C298A0C48D95BC8C95BE8C95BE8C95BE8C95BE\
8C95BE8C95BE8C95BE8E97C08E97C08E97C08E97C08E97C08E97C08E97C08F96C0
9194BF9192BE9192BE9091BD8F90BC8F90BC8E8FBB8E8FBB8F90BC8F90BC8E8FBB8E8FBB8D8EBA\
8C8DB98C8DB98B8CB8
B1AC98B0AB97AEA995ACA793AAA591A8A38FA6A18DA6A18DA29D89A19C889F9A869D98849B9682\
99948097927E94917E959281939182929081918F808F8D7E8E8C7D8D8B7C8C8A7B
8A88798B897A8B897A8C8A7B8D8B7C8D8B7C8E8C7D8E8D7B938E7B948F7B95907C96917D98937F\
9994809A95819B96829E99859F9A86A19C88A49F8BA7A28EAAA591ACA793ADA894
B0AB97B1AC98B3AE9AB5B09CB7B29EB9B4A0BBB6A2BCB7A3BDB8A4BDB8A4BDB8A4BDB8A4BDB8A4\
BDB8A4BDB8A4BDB8A4C0BBA7C0BBA7C0BBA7BFBAA6BDB8A4BAB5A1B7B29EB5B09C
B0AB97AEA995ABA692A7A28EA29D899E99859B9682999480928D79918C788E89758A857186816D\
837E6A807B677E79657C776375705C7C77636D6854706B5767624E443F2B5A5541
736E5A75705C7974607C77637F7A66817C68827D69827D6986816D87826E88836F8A85718B8672\
8C87738E89758E8975918C78918C78928D79928D79938E7A948F7B948F7B95907C
948F7B948F7B948F7B948F7B948F7B948F7B948F7B948F7B948F7B948F7B938E7A938E7A928D79\
918C78918C78908B77908B778F8A768F8A768E89758D88748D88748C87738C8773
8D88748C87738C87738B86728A85718A85718984708984708B86728A85718A857189847088836F\
88836F87826E87826F878171878173878173878173878173878173878173878173
8B85778B85778B85778B85778B85778B85778B85778B85758C877488837087847388867954514A\
4B4C479494969DA0A79C9EAD9A9FB39BA1BB9CA3C09BA3C79AA2C999A2CB98A1CA
9FA4CEA0A5CDA2A7CFA4A9D1A6ABD3A8ADD5AAAFD7ABB0D8AAAFD7AAAFD7AAAFD7AAAFD7AAAFD7\
AAAFD7AAAFD7AAAFD7A5ABCFA5ABCDA4AACEA4AACCA4AACEA4AACCA4AACEA3A9CB
A2A8CCA2A8CAA1A7CBA0A6C8A0A6CA9FA5C79EA4C89CA4C89EA6CD9DA6CF9DA6CF9CA5CE9CA5CE\
9BA4CD9BA4CD9BA4CD8891BA8891BA8790B98790B9868FB8868FB8858EB7868DB7
8285B08384B08283AF8283AF8182AE8081AD8081AD7F80AC7D7EAA7C7DA97C7DA97B7CA87A7BA7\
7A7BA7797AA6797AA6
AEA995AEA995ACA793AAA591A8A38FA6A18DA49F8BA39E8AA29D89A19C889F9A869D98849B9682\
99948097927E94917E93907F918F80908E7F8F8D7E8D8B7C8C8A7B8B897A8A8879
8886778886778987788987788A88798B897A8B897A8C8B79918C79928D79938E7A948F7B96917D\
97927E98937F9994809B96829C97839E9985A19C88A49F8BA7A28EA9A490AAA591
B0AB97B1AC98B3AE9AB5B09CB7B29EB9B4A0BBB6A2BCB7A3BBB6A2BBB6A2BBB6A2BBB6A2BBB6A2\
BBB6A2BBB6A2BBB6A2C1BCA8C1BCA8C1BCA8BFBAA6BDB8A4BAB5A1B6B19DB4AF9B
AFAA96ADA894AAA591A6A18DA19C889D98849A958198937F918C788F8A768D88748A857186816D\
837E6A807B677F7A667D786475705C7C77636D6854706B5767624E443F2B5B5642
726D5975705C78735F7C77637F7A66817C68827D69827D6986816D86816D88836F8984708A8571\
8C87738D88748E89758F8A76908B77908B77918C78928D79928D79938E7A938E7A
948F7B948F7B948F7B948F7B948F7B948F7B948F7B948F7B948F7B938E7A938E7A928D79918C78\
918C78908B77908B77908B77908B778F8A768F8A768E89758D88748D88748C8773
8B86728B86728A85718A857189847088836F88836F87826E89847089847088836F88836F87826E\
86816D86816D85806D857F6F857F71857F71857F71857F71857F71857F71857F71
8983758983758983758983758983758983758983758983758B857588827487837789867D55524D\
4C4C4C9493999C9EAA9899AB969BB1979DB7989EBE979FC4969EC5959EC7949DC6
9CA1CB9DA2CC9FA4CEA1A6D0A3A8D2A5AAD4A7ACD6A8ADD7A4A9D3A4A9D3A4A9D3A4A9D3A4A9D3\
A4A9D3A4A9D3A4A9D19EA3C99EA4C89EA3C99EA4C89EA3C99EA4C89FA4CA9FA5C9
9CA1C79CA2C69BA0C69AA0C49A9FC5999FC3989DC3969EC39FA7CE9DA6CD9DA6CD9CA5CC9BA4CB\
9AA3CA99A2C999A2C98B94BB8B94BB8A93BA8992B98891B88790B7868FB6878FB6
8388B08386AF8386AF8285AE8184AD8184AD8083AC8083AC8285AE8285AE8184AD8184AD8083AC\
7F82AB7F82AB7E81AA
ACA793ABA692AAA591A8A38FA5A08CA39E8AA29D89A19C88A19C88A09B879E99859C97839A9581\
98937F96917D93907D908D7C8F8D7E8E8C7D8C8A7B8B897A898778888677888677
8684758684758684758785768886778987788987788988768F8A778F8A76908B77928D79938E7A\
95907C96917D96917D9994809A95819C97839F9A86A29D89A5A08CA7A28EA8A38F
AFAA96B0AB97B2AD99B4AF9BB6B19DB8B39FBAB5A1BBB6A2BAB5A1BAB5A1BAB5A1BAB5A1BAB5A1\
BAB5A1BAB5A1BAB5A1C0BBA7BFBAA6BFBAA6BDB8A4BAB5A1B6B19DB3AE9AB1AC98
ACA793AAA591A7A28EA39E8A9E99859A958197927E95907C8E89758C87738A857187826E847F6B\
817C687F7A667E79657C7763746F5B7B76626C67536F6A5666614D433E2A595440
706B57736E5A76715D7A75617D78647F7A66807B67807B67847F6B847F6B86816D87826E88836F\
8A85718B86728C87738D88748D88748D88748E89758F8A76908B77908B77908B77
928D79928D79928D79928D79928D79928D79928D79928D79928D79918C78918C78908B778F8A76\
8F8A768E89758E89758F8A768F8A768E89758D88748D88748C87738B86728B8672
8A857189847089847088836F87826E87826E86816D86816D88836F87826E87826E86816D85806C\
85806C847F6B847F6C827C6C827C6E827C6E827C6E827C6E827C6E827C6E827C6E
86807286807286807286807286807286807286807286807288827686807487837A89867F555150\
4B4B4D9291999A9CA9AEAFC3ACB1C7ADB2CFAEB4D4ADB5DAACB4DBAAB3DCAAB3DE
A6ABD5A6ABD5A6ABD5A5AAD4A4A9D3A3A8D2A3A8D2A3A8D2A3A8D2A3A8D2A3A8D2A3A8D2A3A8D2\
A3A8D2A3A8D2A3A8D29CA1C99DA2C89DA2CA9EA3C99EA3CB9FA4CA9FA4CCA0A5CB
9CA1C99CA1C79BA0C89A9FC59A9FC7999EC4989DC5969EC58C94BB8A93BA8992B98891B88790B7\
858EB5848DB4848DB4858EB5858EB5848DB4828BB2818AB18089B07F88AF7F87AE
8186AE8184AD8184AD8083AC7F82AB7F82AB7E81AA7E81AA7C7FA87C7FA87B7EA77B7EA77A7DA6\
797CA5797CA5787BA4
AAA591AAA591A8A38FA6A18DA49F8BA19C88A09B879F9A869D98849C97839A958198937F96917D\
948F7B928D798F8C798F8C7B8D8B7C8C8A7B8A8879898778888677868475868475
8482738482738583748583748684758785768785768887758D88758D88748F8A76908B77918C78\
938E7A948F7B95907C97927E98937F9A95819D9884A09B87A39E8AA5A08CA6A18D
ABA692ACA793AEA995B0AB97B2AD99B4AF9BB6B19DB7B29EB8B39FB8B39FB8B39FB8B39FB8B39F\
B8B39FB8B39FB8B39FBBB6A2BAB5A1BAB5A1B8B39FB4AF9BB0AB97ADA894AAA591
A7A28EA5A08CA29D899E998599948095907C928D79908B7789847087826E85806C837E6A807B67\
7D78647B76627A756178735F716C5877725E68634F6B6652625D493F3A2656513D
6C67536E6955726D5976715D7974607A75617B76627B7662807B67807B67817C68837E6A847F6B\
86816D87826E87826E88836F88836F8984708984708A85718B86728B86728C8773
8D88748D88748D88748D88748D88748D88748D88748D88748D88748D88748D88748C87738B8672\
8A85718A85718A85718B86728B86728A85718A857189847088836F88836F87826E
88836F88836F88836F87826E86816D85806C85806C85806C86816D86816D86816D85806C847F6B\
837E6A837E6A837E6B817B6B817B6D817B6D817B6D817B6D817B6D817B6D817B6D
857F71857F71857F71857F71857F71857F71857F71857F73847D73827B73837E7886837E534F50\
48474C8E8D959597A4B5B6CAB4B9CFB4B9D6B5BBDBB4BCE0B4BCE3B2BBE4B1BAE3
ACB1DBACB1DBABB0DAABB0DAAAAFD9A9AED8A9AED8A8ADD7ACB1DBACB1DBACB1DBACB1DBACB1DB\
ACB1DBACB1DBACB1DBA7ACD6A7ACD4A8ADD7A9AED6AAAFD9ABB0D8ABB0DAACB1D9
A7ACD6A7ACD4A6ABD5A6ABD3A5AAD4A4A9D1A4A9D3A1A9D0A2AAD1A0AACE9FA9CD9DA7CB9CA6CA\
9AA4C899A3C798A2C68B95B98A94B88993B78791B58690B4848EB2838DB1838BB0
878CB2868BB1868BB1858AB08489AF8489AF8388AE8388AE7B80A67B80A67A7FA57A7FA5797EA4\
787DA3787DA3777CA2
A9A490A9A490A7A28EA5A08CA39E8AA19C889F9A869E998599948099948097927E95907C938E7A\
908B778F8A768C89768E8B7A8C8A7B8B897A8A8879888677878576868475858374
8381728381728482738482738583748684758684758786748C87748D88748E89758F8A76918C78\
928D79938E7A948F7B96917D97927E9994809C97839F9A86A29D89A49F8BA5A08C
A8A38FA9A490AAA591ADA894AFAA96B1AC98B3AE9AB3AE9AB8B39FB8B39FB8B39FB8B39FB8B39F\
B8B39FB8B39FB8B39FB6B19DB6B19DB5B09CB3AE9AAFAA96ABA692A7A28EA5A08C
A39E8AA19C889E99859A958195907C918C788E89758C8773847F6B837E6A817C687F7A667C7763\
7A756178735F77725E746F5B6D6854746F5B645F4B68634F5F5A463C3723524D39
68634F6A65516E6955726D5975705C77725E77725E78735F7C77637C77637D78647F7A66807B67\
827D69837E6A837E6A847F6B847F6B847F6B85806C86816D87826E87826E87826E
8A85718A85718A85718A85718A85718A85718A85718A85718A857189847089847088836F87826E\
87826E86816D86816D88836F87826E87826E86816D85806C85806C847F6B847F6B
88836F87826E87826E86816D85806C85806C847F6B847F6B86816D85806C85806C847F6B837E6A\
837E6A827D69827D6A807A6A807A6C807A6C807A6C807A6C807A6C807A6C807A6C
847E70847E70847E70847E70847E70847E70847E70847E7280796F7E7771807B77837F7C504C4D\
4443488A88939193A0999AAE979CB2989EB899A0BD97A0C1979FC4959EC5959EC5
A1A6CEA2A7CFA3A8D2A5AAD2A8ADD7AAAFD7ABB0DAACB1D9B1B6E0B1B6DEB1B6E0B1B6DEB1B6E0\
B1B6DEB1B6E0B1B6DEACB1DBADB2DAAEB3DDAFB4DCB0B5DFB1B6DEB2B7E1B2B7DF
ADB2DCADB2DAACB1DBACB1D9ABB0DAAAAFD7AAAFD9A7AFD6A7AFD4A6B0D4A4AED2A2ACD0A1ABCF\
9FA9CD9DA7CB9DA7CBA2ACD0A1ABCFA0AACE9EA8CC9CA6CA9BA5C999A3C799A3C7
98A0C59A9FC5999EC4999EC4989DC3979CC2979CC2969BC19499BF9499BF9499BF9398BE9297BD\
9196BC9196BC9196BC
AAA591A9A490A8A38FA6A18DA39E8AA19C88A09B879F9A8699948098937F96917D948F7B918C78\
8F8A768D88748A8774888574878576868475868475858374848273848273838172
8381728482738482738583748684758684758785768786748C87748D88748D88748E89758F8A76\
8F8A76908B77908B77938E7A948F7B96917D9994809C97839E9985A09B87A19C88
A6A18DA7A28EA8A38FABA692AEA995B0AB97B2AD99B3AE9AB2AD99B3AE9AB4AF9BB6B19DB6B19D\
B5B09CB4AF9BB4AF9BB3AE9AB2AD99B1AC98AFAA96ADA894ACA793AAA591AAA591
9F9A869E99859B968297927E938E7A8F8A768C87738A85717C77637D78647D78647C77637A7561\
77725E736E5A716C586A65516B66526B665267624E5F5A46544F3B494430423D29
635E4A65604C6964506D6854706B57736E5A746F5B746F5B7974607974607A75617B76627B7662\
7C77637D78647D786485806C85806C85806C85806C85806C85806C85806C85806C
85806C85806C85806C85806C85806C85806C85806C85806C898470898470898470898470898470\
89847089847089847088836F88836F88836F87826E86816D85806C85806C85806C
85806C85806C85806C85806C85806C85806C85806C85806C807B67807B677F7A667E79657E7965\
7D78647C77637C77647E78687E786A7E786A7E786A7E786A7E786A7E786A7E786A
807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6E807971817A747B7672817D7C585455\
403F44807F879D9FAB9899AB959AAE959BB3959CB8959EBD969FC096A0C396A0C4
9BA0C69CA1C79DA2CA9FA4CAA2A7CFA4A9CFA5AAD2A6ABD1A5AAD2A6ABD1A7ACD4A8ADD3A9AED6\
ABB0D6ACB1D9ACB1D7A7ACD4A7ACD2A8ADD5A8ADD3A8ADD5A9AED4A9AED6A9AED4
A4A9D1A4A9CFA4A9D1A4A9CFA4A9D1A4A9CFA4A9D1A2AACFA4ACD1A3ADD0A3ADD0A3ADD0A3ADD0\
A3ADD0A3ADD0A3ADD09EA8CB9EA8CB9EA8CB9EA8CB9EA8CB9EA8CB9EA8CB9EA8CB
9BA3C79AA2C69AA2C699A1C598A0C498A0C4979FC3979FC3939BBF929ABE929ABE9199BD9098BC\
9098BC8F97BB8F97BB
A6A18DA5A08CA39E8AA19C889F9A869D98849B96829A958195907C948F7B928D79908B778D8874\
8B8672898470868370858271838172838172828071817F70817F70807E6F807E6F
807E6F807E6F817F70817F708280718381728381728483718984718984708A85718A85718B8672\
8C87738C87738D8874918C78928D79948F7B96917D9994809B96829D98849E9985
A49F8BA5A08CA7A28EA9A490ACA793AEA995B0AB97B1AC98B1AC98B2AD99B3AE9AB4AF9BB5B09C\
B4AF9BB3AE9AB2AD99B0AB97B0AB97AEA995ABA692A9A490A6A18DA5A08CA49F8B
9C97839A958196917D928D798E89758B867289847088836F87826E86816D827D697F7A667C7763\
7B76627A75617A75616D68546D68546C675367624E5E5945524D3947422E403B27
615C48645F4B68634F6C6753706B57726D59746F5B746F5B746F5B75705C76715D77725E78735F\
7974607A75617A75617F7A667F7A667F7A667F7A667F7A667F7A667F7A667F7A66
86816D86816D86816D86816D86816D86816D86816D86816D86816D86816D86816D86816D86816D\
86816D86816D86816D847F6B847F6B837E6A827D69827D69817C68807B67807B67
807B67807B67807B67807B67807B67807B67807B67807B67817C68817C68807B67807B677F7A66\
7E79657E79657D78657B75657B75677B75677B75677B75677B75677B75677B7567
7C76687C76687C76687C76687C76687C76687C76687C766A888179847D77797470807C795C5859\
474749818086979AA3A0A2B19EA3B69DA3B99CA3BD9BA5C09BA4C19BA6C49BA6C6
9298BC9298BC9298BC9399BD9399BD9399BD949ABE949ABE8D93B78D93B78D93B78C92B68C92B6\
8C92B68B91B58B91B59AA0C4999FC3979DC1969CC0949ABE9298BC9096BA9096BA
989EC2989EC2979DC1969CC0959BBF949ABE9399BD9199BD9199BD909BBB8F99BC8F9ABA8E98BB\
8E99B98E98BB8D98B88C96B98C97B78C96B98B96B68B95B88A95B58A94B78A95B5
9199BD919ABB9098BC9099BA8F97BB8E97B88E96BA8D96B78E96BA8D96B78D95B98C95B68B93B7\
8B94B58A92B68A93B4
A09B87A09B879E99859C97839A958197927E96917D95907C908B778F8A768D88748B8672898470\
87826E86816D83806D817E6D807E6F7F7D6E7E7C6D7E7C6D7D7B6C7C7A6B7C7A6B
7C7A6B7C7A6B7D7B6C7E7C6D7E7C6D7F7D6E807E6F807F6D85806D85806C86816D87826E87826E\
88836F8984708984708F8A76908B77918C78938E7A95907C98937F9994809A9581
9E99859F9A86A19C88A39E8AA5A08CA7A28EA8A38FA9A490ABA692ACA793ADA894AEA995AEA995\
ADA894ABA692AAA591AAA591A8A38FA6A18DA39E8A9F9A869C97839A958198937F
97927E948F7B8E897589847085806C847F6B847F6B847F6B79746076715D716C586C675368634F\
67624E68634F68634F6A655169645067624E605B4757523E4A45313F3A2638331F
5D58445F5A46635E4A68634F6C67536F6A56716C58716C58706B57716C58726D59746F5B76715D\
78735F7974607A75617B76627B76627B76627B76627B76627B76627B76627B7662
7E79657E79657E79657E79657E79657E79657E79657E7965807B67807B67807B67807B67807B67\
807B67807B67807B677F7A667E79657E79657D78647C77637C77637B76627B7662
7B76627B76627B76627B76627B76627B76627B76627B76627E79657D78647D78647C77637B7662\
7B76627A75617A7562787262787264787264787264787264787264787264787264
77716377716377716377716377716377716377716377716580796F7C756D6E696374716C54504F\
42424279787D878A919EA0AC9BA1AF9AA1B39AA2B798A3B999A3BC98A4BE98A4BE
9FA6C39FA6C39EA5C29DA4C19DA4C19CA3C09BA2BF9BA2BFA3AAC7A2A9C6A1A8C5A0A7C49EA5C2\
9CA3C09BA2BF9BA1C19197B79197B99096B88F95B78E94B68D93B58C92B48C92B4
8B91B38A90B2898FB1878DAF848AAC8288AA8187A97E87A8868FB0848FAD848FAF838EAC818CAC\
808BA9808BAB7F8AA8818CAC818CAA808BAB7F8AA87E89A97D88A67C87A77C87A5
828DAD828DAB818CAC818CAA808BAB7F8AA87F8AAA7E89A78590B08590AE848FAF848FAD838EAE\
828DAB828DAD818CAA
9D98849C97839A958198937F96917D948F7B928D79918C788D88748C87738B867289847087826E\
86816D85806C827F6C807D6C7E7C6D7E7C6D7D7B6C7C7A6B7C7A6B7B796A7B796A
7B796A7B796A7C7A6B7C7A6B7D7B6C7E7C6D7E7C6D7F7E6C847F6C847F6B85806C85806C86816D\
87826E87826E88836F8F8A768F8A76908B77928D79948F7B95907C97927E97927E
98937F9994809A95819C97839D98849F9A86A09B87A19C88A49F8BA5A08CA6A18DA6A18DA5A08C\
A49F8BA29D89A19C88A49F8BA29D899F9A869B968297927E938E7A908B778F8A76
8F8A768C877386816D817C687D78647D78647E79657F7A667C77637A756177725E746F5B706B57\
6D68546A6551696450645F4B625D495F5A4658533F4F4A36443F2B3A3521342F1B
57523E5954405D5844625D4966614D68634F6A65516A65516D68546E69556F6A56716C58746F5B\
76715D77725E78735F797460797460797460797460797460797460797460797460
7A75617A75617A75617A75617A75617A75617A75617A75617A75617A75617A75617A75617A7561\
7A75617A75617A75617B76627B76627A756179746079746078735F77725E77725E
77725E77725E77725E77725E77725E77725E77725E77725E77725E77725E76715D76715D75705C\
746F5B746F5B736E5B777161777163777163777163777163777163777163777163
756F61756F61756F61756F61756F61756F61756F61756F61746E627770666D6960706D664E4B46\
3E3E3C76767684888B92959C9097A19098A5919AA9929EAE949FB194A1B495A1B7
A0A8BFA0A7C1A0A7C1A0A7C1A0A7C19FA6C09FA6C09FA6C09EA5BF9DA4BE9DA4BE9CA3BD9BA2BC\
9AA1BB9AA1BB99A0BA9FA6C2A0A7C4A1A8C5A4ABC8A7AECBA9B0CDABB2CFACB3D0
A5ACC9A4ABC8A2A9C6A0A7C49DA4C19AA1BE989FBC959EBB9099B88F9AB88E99B78C97B58B96B4\
8A95B38994B28893B18893B18792B08691AF8590AE848FAD828DAB818CAA818CAA
7C87A57C87A57B86A47B86A47A85A37984A27984A27883A17782A07782A076819F76819F75809E\
747F9D747F9D737E9C
9B96829A958198937F96917D948F7B928D79908B778F8A768B86728A85718A857188836F87826E\
86816D85806C827F6C807D6C7F7D6E7E7C6D7E7C6D7D7B6C7C7A6B7C7A6B7B796A
7B796A7C7A6B7C7A6B7D7B6C7E7C6D7E7C6D7F7D6E7F7E6C847F6C85806C85806C86816D87826E\
87826E88836F88836F8E89758F8A76908B77918C78928D79938E7A948F7B95907C
98937F9994809A95819B96829C97839D98849E99859F9A86A19C88A29D89A39E8AA39E8AA29D89\
A09B879E99859C9783A29D89A09B879D98849A958195907C918C788F8A768D8874
86816D847F6B7F7A667B766278735F77725E78735F78735F716C58726D59736E5A726D596F6A56\
6A6551645F4B615C48635E4A625D495F5A465B5642544F3B4C473345402C413C28
56513D58533F5B56425F5A46625D49645F4B65604C65604C68634F6964506A65516B66526D6854\
6F6A56706B57716C58736E5A736E5A736E5A736E5A736E5A736E5A736E5A736E5A
7A75617A75617A75617A75617A75617A75617A75617A756175705C75705C75705C75705C75705C\
75705C75705C75705C79746079746078735F77725E77725E76715D75705C75705C
75705C75705C75705C75705C75705C75705C75705C75705C75705C75705C746F5B736E5A736E5A\
726D59716C58716C59767060767062767062767062767062767062767062767062
736D5F736D5F736D5F736D5F736D5F736D5F736D5F736D5F6F695B7B75697672667573674E4B42\
40413B7B7C77898D8C8C90938B92988D969D909AA4939FAB97A3B199A7B49BA8B8
9199AC929AAD939BAE949CAF969EB198A0B399A1B499A1B49DA5B89DA5B89EA6B99FA7BAA0A8BB\
A1A9BCA1A9BCA2AABF939BB2949BB5969DB799A0BA9BA2BC9EA5BFA0A7C1A1A8C2
A6ADC7A5ACC6A4ABC5A2A9C3A0A7C19EA5BF9DA4BE9AA4BF9CA5C29AA5C19AA5C199A4C098A3BF\
97A2BE96A1BD96A1BD909BB7909BB78F9AB68F9AB68E99B58D98B48C97B38C97B3
8290AB8290AB818FAA808EA9808EA97F8DA87E8CA77E8CA772809B72809B717F9A717F9A707E99\
6F7D986F7D986E7C97
97927E96917D95907C928D79908B778E89758C87738C877388836F88836F87826E86816D85806C\
847F6B847F6B827F6C7F7C6B7E7C6D7D7B6C7C7A6B7C7A6B7B796A7A78697A7869
7A78697A78697B796A7C7A6B7C7A6B7D7B6C7E7C6D7E7D6B837E6B837E6A847F6B85806C85806C\
86816D87826E87826E8B86728C87738C87738D88748E89758F8A768F8A76908B77
98937F9994809994809A95819B96829C97839C97839D98849E99859E99859F9A869E99859D9884\
9B968298937F97927E9C97839B968298937F95907C928D798E89758C87738A8571
7D78647D78647B766279746077725E746F5B726D59716C586A65516B66526C67536B6652696450\
66614D625D495F5A4668634F68634F68634F67624E65604C625D49605B475E5945
615C48625D4965604C67624E68634F69645068634F68634F67624E68634F68634F696450696450\
6A65516A65516A65516D68546D68546D68546D68546D68546D68546D68546D6854
6F6A566F6A566F6A566F6A566F6A566F6A566F6A566F6A56726D59726D59726D59726D59726D59\
726D59726D59726D5975705C75705C746F5B746F5B736E5A726D59726D59716C58
716C58716C58716C58716C58716C58716C58716C58716C58746F5B746F5B746F5B736E5A726D59\
716C58716C58716C59716B5B716B5D716B5D716B5D716B5D716B5D716B5D716B5D
716B5D716B5D716B5D716B5D716B5D716B5D716B5D716B5D676153736D5F6A6758676558424034\
36382D6B6C667176708084837F8789828C8E86919789969E8D9AA2909EA792A0AB
969FAE97A0AF98A1B09AA3B29DA6B59FA8B7A1AAB9A2ABBA8891A08992A18A93A28B94A38D96A5\
8E97A69099A89099AA9AA2B79AA2B799A1B698A0B5979FB4969EB3959DB2959DB2
939BB0939BB0949CB1949CB1949CB1959DB2959DB2939EB4929CB7919CB8919CB8919CB8919CB8\
919CB8929DB9929DB98B96B28B96B28B96B28B96B28B96B28B96B28B96B28B96B2
8A98B38A98B38997B28997B28896B18795B08795B08694AF8492AD8492AD8391AC8391AC8290AB\
818FAA818FAA808EA9
928D79918C788F8A768D88748B867289847087826E86816D837E6A837E6A827D69827D69817C68\
817C68807B677E7B687B78677A7869797768797768787667777566777566767465
7674657775667775667876677977687977687A78697A79677F7A67807B67807B67817C68827D69\
827D69837E6A837E6A85806C86816D86816D86816D87826E88836F88836F88836F
8F8A768F8A768F8A76908B77908B77918C78918C78928D79918C78918C78918C78908B778F8A76\
8C87738A857188836F89847088836F86816D847F6B817C687F7A667D78647C7763
76715D78735F7974607A756178735F746F5B6F6A566C675375705C726D596D68546A6551696450\
6B66526E6955716C586A65516B66526E6955716C58746F5B76715D77725E78735F
746F5B75705C76715D77725E77725E76715D746F5B736E5A746F5B736E5A736E5A726D59726D59\
716C58706B57706B57706B57706B57706B57706B57706B57706B57706B57706B57
6B66526B66526B66526B66526B66526B66526B66526B6652706B57706B57706B57706B57706B57\
706B57706B57706B57706B57706B576F6A566E69556E69556D68546C67536C6753
6C67536C67536C67536C67536C67536C67536C67536C67536D68546D68546C67536C67536B6652\
6A65516A65516964516B65556B65576B65576B65576B65576B65576B65576B6557
6C66586C66586C66586C66586C66586C66586C66586C6658655F4F655F4F504D3C4C4A3B323023\
292B1E51524A454A43595E5A57605D5963625A65675B696C5E6B71606F76617077
76808A76808C77818D78828E79838F7A84907B85917B8591949EAA949EAA959FAB959FAB959FAB\
96A0AC96A0AC96A0AC8D96A78C94A78B93A68991A4878FA2858DA0848C9F838B9E
7B83967C84977E869980889B838B9E868EA18890A38792A677819C76819D77829E78839F7A85A1\
7B86A27C87A37D88A47B86A27B86A27C87A37E89A57F8AA6808BA7818CA8828DA9
8492AD8492AD8391AC8290AB8290AB818FAA808EA9808EA98492AD8492AD8492AD8391AC8290AB\
818FAA818FAA818FAA
8D88758C87738B867389847086816E847F6B837E6B827D697F7A677E79657E79667E79657D7865\
7D78647D78657D7865787564767563767563757462747361747361737260737260
7372607372607473617473617574627675637675637776627C77637C77637D78647D78647E7965\
7F7A667F7A66807B67807B67807B67817C68817C68817C68827D69827D69827D69
827D6A827D6A827D6A837E6B837E6B837E6B837E6B847F6C817C69827D6A827D6A817C697F7A67\
7C776479746178736075705D746F5C736E5B716C596F6A576D68556C67546B6653
726D5A75705D7974617B7663797461746F5C6D6855686252534D3D494635413B2D3835243A3426\
3F3C2B4C4638514E3D6761536764536D6759716E5D7973657C7968827C6E827F6E
837D6F827F6E847E70827F6E837D6F7F7C6B7F796B7B7867837D6F817E6D817B6D7E7B6A7E786A\
7B78677C7668797665797363777461797461777461797461777461797461777461
797461777461797461777461797461777461797461777461706B586E6B58706B586E6B58706B58\
6E6B58706B586E6B586B66536966536B6653686552696451666350686350666350
67624F65624F67624F65624F67624F65624F67624F65624F635E4B615E4B625D4A5F5C49615C49\
5E5B485F5A475F5A47655F51655F51665E53655F51665E53655F51665E53655F51
696156686254696156686254696156686254696156686254716B5D655F51454233423E32302E21\
2C2C2047473D2D2E282F312C2D322E2D332F2C35322D36352D35372D37392D3739
293237293237293036283136282F35273035272E34262F34262D33242D32242B31222B3022292F\
1F282D1F262C1E272E272E38262F38272D39262F38282E3A273039282E3A273039
323844333C45373D493A434C404652434C55474D5948505D626A7D636B80656D84676F846A7289\
6C74896D758C6E768B727A91737B90747C93767E937981987B83987D859C7D859A
7A859B78859879849A7784977782987683967681977582956D788E6B788B6C778D6A778A6A758B\
69768969748A687588
8B84748B84728A837388816F878070857E6C847D6D847D6B817A6A817A68817A6A8079677F7868\
7E77657E77677D786572705B71705B71705B71705B71705B71705B71705B71705B
74735E74735E74735E74735E74735E74735E74735E74735E78735D79745E7A755F7B76607C7761\
7D78627E79637E79637E79637E79637F7A647F7A647F7A64807B65807B65807B67
878171868070857F6F847E6E827C6C817B6B807A6A7F79697F79697E78687D77677B7565797363\
7872627670607670627C7668797367756F63716B5F6D675B6B65596A64586A6458
6F695D716B5F716B5F6B6559635D51605A4E635D5168615758534D54514A514C484D4A43514C48\
56534C5F5A5663605965605C625F58615C58625F586964606C69626E69656C6962
645F5B6B686176716D79766F7A757179766F7F7A76827F7886817D7F7C757A757179766F7D7874\
7E7B747C777377746D7D796E79776A7773677674677A766A7A786B7A766A767467
747064737164747064737164747064737164747064737164706C606F6D60706C606F6D60706C60\
6F6D60706C606F6D606C685C6B695C6B675B69675A696559676558676357666455
6461526867556A6756636250615E4D6463516B68576D6C5A66635261604E5F5C4B5F5E4C646150\
6362505E5B4A585546635B50635B50645A51625A4F63595061594E62584F60584D
61574E60584D62584F61594E62584F61594E62584F61584F5E574D5750484C453D403931363229\
332F26322D27332E282C29242E2B26302D28302F2A32312D32312D31302C2F302B
2E302D2D322E30322F2E332F2F312E2B302C2A2C29262B27292B28282D292A2C29282D29282A27\
2429252325222025212E302D2C312D2C2E2D292E2A292B2A252A26262827232824
343635333834383A393A3F3B40424141464246484745494A51545B52555E535561555861565864\
585B64595B67595C6560626E61646D636571666972696B776B6E776D6F7B6D717A
7077816F787F7077816F787F7077816F787F7077816F787F69707A6972796B727C6B747B6D747E\
6D767D6F76806E777E
8B84748A8373898272888171867F6F857E6E847D6D837C6C7D76667D76667C75657B74647B7464\
7A736379726278736074725D73735B73735B73735B73735B73735B73735B73735B
6E6E566E6E566E6E566E6E566E6E566E6E566E6E566E6E5676715B77725C77725C77725C78735D\
78735D79745E79745E75705A76715B76715B77725C78735D79745E7A755F7A7561
756F5F756F61746E60746E60736D5F726C5E726C5E716B5D6D67596D67596E685A6E685A6F695B\
6F695B706A5C706A5C6D665C6E675D716A60746D63756E64756E64756E64746D63
4F483E5B544A6A6359726B61766F657E776D8C857B969289C6C1BECCC8C7D6D2D1DBD7D6D7D3D2\
CCC8C7BDB9B8B4B0AFA7A3A29E9A99918D8C8581807C7877726E6D686463615D5C
6E6A69716D6C706C6B6965645C5857514D4C4C48474C4847433F3E423E3D464241504C4B5D5958\
666261696564686461726F667775697C7A6E7F7D717D7B6F777569716F636D6B5F
737165737165737165737165737165737165737165737165716F63716F63716F63716F63716F63\
716F63716F63716F636F6D616F6D616E6C606D6B5F6C6A5E6B695D6B695D6A685C
7270637270616E6C5F6765566361546260516361546361526F6D606664555C5A4D5A5849605E51\
6866576D6B5E706C606B62596B62596B605A685F56685D57655C53655A54635A51
655A54645B5264595362595063585261584F61565060575059524C524D474D4542443F39413936\
3C37313E36333C3731352D2A332E28342C29302B253129262D28222E26232B2620
31302B2F30282E2F292D2E262C2D272D2E262D2E282E2F2733342E35362E373832393A323C3D37\
3E3F373F403A40413934352F34352D34352F35362E35363035362E36373136372F
2B2C262B2C242D2E282E2F2730312B31322A32332D33342F27272927262B28272C28272C29282D\
2A292E2A292E2B2A2F2E2D322F2E33302F3431303533323735343936353A36373B
3D41443D42453E43463F444741464942474A43484B44494C555A5D555A5D565B5E575C5F585D60\
595E61595E615A5F62
857E6E847D6D837C6C827B6B8079697F78687E77677D7666787161777060777060766F5F756E5E\
756E5E746D5D736E5B6D6B566C6B566C6B566C6B566C6B566C6B566C6B566C6B56
6B6A556B6A556B6A556B6A556B6A556B6A556B6A556B6A55716C58716C58716C58706B57706B57\
6F6A566F6A566F6A566A65516B66526C67536E6955706B57726D59736E5A746F5C
6B65556C66586C66586D67596D67596E685A6E685A6E685A6D67596E685A706A5C726C5E756F61\
7872647A74667B75677F786E837C728982788D867C8C857B867F757F786E7A7369
938C82AEA79DCFC8BEE1DAD0E4DDD3E2DBD1E6DFD5EAE6DDEDE8E4EEEAE7F2EEEBF7F3F0FAF6F3\
FCF8F5FCF8F5FCF8F5F8F4F1F5F1EEF1EDEAF2EEEBF5F1EEF8F4F1F7F3F0F5F1EE
E7E3E0E4E0DDDBD7D4CBC7C4B6B2AFA4A09D989491938F8CACA8A5A4A09D96928F86827F75716E\
625E5B504C4943403B2F2C233A382C49473B5452465C5A4E656357716F637A786C
727064727064727064727064727064727064727064727064737165737165737165737165737165\
737165737165737165737165737165727064727064716F63706E62706E62706E62
747266706E616D6B5F6E6C5F706E62716F62716F63716F626260546765586F6D6177756879776B\
7270636563575B574C766F67756E66756C67726B637168636E675F6E65606C655D
6F66616D665E6E65606B645C6B625D69625A69605B68615B6E69656A676265605D5D5A5557524F\
4F4C474B4643484540544F4C514E494E494649464146413E43403B423D3A413E39
39383435363031322D2D2E282C2D282C2D272E2F2A2F302A1F201B1E1F191C1D181A1B151A1B16\
1A1B151A1B161B1C1620211C20211B1F201B1F201A1E1F1A1E1F191E1F1A1D1E18
32332E31322C30312C2F302A2D2E292C2D272B2C272A2A282D2D2F2D2C312D2C312C2B302B2A2F\
2B2A2F2B2A2F2A292E29282D29282D29282D29282D29282D29282D29282D28292D
1E22251E23261F242721262923282B262B2E272C2F282D3023282B23282B24292C24292C252A2D\
262B2E262B2E262B2E
7C75657C75657A7363797262787161766F5F756E5E746D5D746D5D746D5D736C5C726B5B726B5B\
716A5A7069596F6959696653686752686752686752686752686752686752686752
6968536968536968536968536968536968536968536968536A65516A655169645068634F67624E\
66614D65604C65604C645F4B65604C67624E6964506C67536E6955706B57716C59
726C5C726C5E736D5F756F617771637872647A74667A74667771637872647A74667D7769807A6C\
827C6E847E70857F717C756B7E776D817A707E776D736C62625B51514A40463F35
5E574D8B847AC9C2B8F5EEE4FFFEF4FFFEF4FFFEF4FFFFF6FFFEFAFFFEFBFFFEFBFFFEFBFFFEFB\
FFFEFBFFFEFBFFFEFBFFFEFBFFFEFBFFFEFBFFFCF9FFFCF9FFFCF9FDF9F6FAF6F3
FFFBF8FFFDFAFFFEFBFFFEFBFFFEFBFFFEFBFFFEFBFFFEFBF2EEEBF4F0EDF9F5F2FDF9F6FFFBF8\
FEFAF7FAF6F3F6F3EEFFFFF6FAF8ECDFDDD1B8B6AA908E827A786C7775697D7B6F
716F63716F63716F63716F63716F63716F63716F63716F63727064727064727064727064727064\
727064727064727064737165737165737165727064727064727064727064727064
7370676B685F69665D706D64757269747168737067747168807D747A776E726F666E6B626F6C63\
7572697B786F7F7C73746F69746F6B746F6B736E6A736E6A726D69726D69726D69
726D69726D69726D69726D69726D69736E6A736E6A736E6A6D69686E6D6B7372707877757C7B79\
7E7D7B7E7D7B7E7D7B7877757675737372706F6E6C6D6C6A6D6C6A6E6D6B6E6D6B
7878767777757575737272706F6F6D6D6D6B6B6B696A6A687C7C7A79797776767472727070706E\
70706E70706E71716F70706E6E6E6C6B6B696767656363615F5F5D5C5C5A5A5A58
4444424242403F3F3D3B3B3937373534343231312F2F2F2F2B2B2D2A292E29282D27262B252429\
2423282322272221261D1C211C1B201B1A1F1A191E18171C17161B16151A141519
1A1E21191E211A1F221A1F221B20231B20231C21241C212421262921262921262921262922272A\
22272A22272A22272A
787264777163767062756F61736D5F726C5E716B5D706A5C716B5D716B5D706A5C6F695B6F695B\
6E685A6D67596D67576A6754696854696854696854696854696854696854696854
64634F64634F64634F64634F64634F64634F64634F64634F65604D65604D645F4C635E4B625D4A\
615C49605B485F5A4765604D66614E6863506A65526D6855706B58716C59726D5A
756F5F7670627771637973657C76687E786A7F796B807A6C7872647973657973657A74667B7567\
7C76687D77697D77697B746A7D766C7E776D7972686D665C5A53494841373C352B
4F483E736C62A29B91C3BCB2CEC7BDCCC5BBCBC4BACAC6BDC5C0BCD1CDCAE6E2DFF9F5F2FFFEFB\
FFFCF9F8F4F1F2EEEBFAF6F3F7F3F0F5F1EEF7F3F0FCF8F5FFFBF8FFFCF9FFFBF8
FCF8F5FAF6F3F8F4F1F8F4F1F8F4F1F7F3F0F6F2EFF5F1EEFAF6F3FEFAF7FFFEFBFFFEFBFFFEFB\
FFFEFBFFFEFBFFFFFAE2DFD6D7D5C9BDBBAF9694886F6D6159574B5654485C5A4E
716F63716F63716F63716F63716F63716F63716F63716F63706E62706E62706E62706E62706E62\
706E62706E62706E62706E62706E62706E62706E62706E62716F63716F63716E65
78756E6E6B646C69627370697370696A676066635C6B6861625F5867645D6F6C6574716A75726B\
726F686F6C656C69647975727975747A76757B77767D79787E7A797F7B7A7F7B7A
7571707672717773727975747B77767D79787F7B7A7D7C7A76767876777978797B78797B757678\
7172746B6C6E68696B797A7C797A7C797A7C7A7B7D7B7C7E7D7E807F8082808183
74747676767879797B7B7B7D7B7B7D79797B767678737375717173717173717173717173737375\
7474767676787777796F6F716E6E706B6B6D6767696363655F5F615C5C5E5A5A5C
5353555151534E4E504A4A4C4646484141433E3E403C3C3E36353A353439343338323136302F34\
2E2D322C2B302B2A2F252429242328232227201F241E1D221C1B201A191E18191D
1F23261E22251C20231A1E21181C1F161A1D15191C14181B23272A222629222629222629222629\
222629212528212528
787264787264777163756F61746E60726C5E716B5D716B5D6D67596D67596C66586C66586B6557\
6A64566A6456676455605F4D605F4B605F4B605F4B605F4B605F4B605F4B605F4B
5F5E4A5F5E4A5F5E4A5F5E4A5F5E4A5F5E4A5F5E4A5F5E4A65604D65604D65604D645F4C645F4C\
645F4C635E4B635E4B6A65526B66536C67546E6956706B58726D5A736E5B746E5E
6F695B706A5C726C5E736D5F756F617771637872647973657A74667A74667A74667A7466797365\
7973657973657973657E776D817A70847D73857E7480796F7871676E675D686157
5851475E574D635C525F584E564F454D463C4B443A4B473E544F4B5D5A556E6A67817E79908C89\
9B9893A09C99A29F9AA29E9BA6A39EB0ACA9C2BFBAD9D5D2EEEBE6FBF7F4FFFEF9
FFFEFBFFFFFAFFFEFBFFFFFAFFFEFBFFFFFAFFFEFBFFFFFAFFFEFBFFFFFAF6F2EFDBD8D3B9B5B2\
9A979284807D7A77723A372E4644385654486260546B695D7674688381758D8B7F
706E62706E62706E62706E62706E62706E62706E62706E626F6D616F6D616F6D616F6D616F6D61\
6F6D616F6D616F6D616D6B5F6D6B5F6E6C606E6C606F6D61706E62706E62706D64
74716C6E6A67736F6C7F7B787C7875706C69726E6B807C7975716E7A76737F7B787E7A7776726F\
6B6764635F5C5F5B5855535454545455555757575758585A5959595A5A5C5B5B5B
69696B6969696B6B6D6D6D6D6F6F71717171727274737375767A7D777C7F7B7E837C81847E8186\
7B80837A7D82777C7F696C716A6F726D70756F747772757A717679717479717578
68696E6B6A6F6F6E7473727775747A76757A75747A7473787A797F7A797E7A797F7A797E78777D\
7473787170766F6E73737278737277727177727176717076717075717076706F74
68676D67666B65646A6261665F5E645C5B605A595F59585D646368636267626166605F645E5D62\
5D5C615B5A5F5B5A5F57565B56555A5453585251564F4E534D4C514B4A4F4A494E
4142463E42453B3F42383C3F34383B3135382E32352D313423272A222629222629212528212528\
2024272024271F2326
706C60706C606F6B5F6D695D6C685C6A665A696559696559666256666256656155646054646054\
635F53625E52625F505C5B495C5B495C5B495C5B495C5B495C5B495C5B495C5B49
6362506362506362506362506362506362506362506362506B65556B65556B65556C66566C6656\
6D67576D67576D67576F6959706A5A706A5A716B5B726C5C736D5D746E5E746E5E
6F695B6F695B706A5C716B5D726C5E736D5F746E60756F617B75677B75677B75677B75677B7567\
7B75677B75677B75676C655B6E675D70695F726B61736C62736C62716A60716A60
726B616E675D6962586760566A635970695F766F6578746B736E6869665F5C5954504D464A4742\
4A47404E4B46524F484A474249463F4B48435350495E5B5668655E6C69646E6B64
615E59625F5867645F76736C8A87829C9992A6A39EA9A69F65625D66635C64615C5C5952514E49\
49463F46433E48453E615E556664586D6B5F716F63716F636D6B5F68665A656357
6F6D616F6D616F6D616F6D616F6D616F6D616F6D616F6D61716F63716F63716F63716F63716F63\
716F63716F63716F636D6B5F6D6B5F6E6C606F6D61706E62716F63716F63726F66
6F6B686B676674706F7E7A79736F6E5F5B5A635F5E78747376727164605F484443302C2B2A2625\
3C38375C58577371726E6E706C6D6F6C6D716B6C6E6A6B6F696A6C68696D68696B
36373B35363835363A35363835363A35363835363A33373A2F3438333B3E41464C4E56595F646A\
6B7376777C827A82857D82887D858882878D81898C81868C7A8285757A8071767A
8D8D958B8A9084838B7F7E847C7B837C7B817E7D857F7E8473727A76757B7B7A827F7E84807F87\
7D7C8278777F75747A6F6E766F6E746F6E76706F75706F77717076717078717076
73727A73727873727A7372787271797271777271797271776F6E736F6E736E6D726D6C716B6A6F\
6A696E69686D69686D6A696E69686D67666B6564696362676160655F5E635E5D62
6364686162665F60645C5D61595A5E57585C5455595354585051554F50544E4F534E4F534D4E52\
4C4D514B4C504B4C50
676357666256656155646054625E52615D51605C505F5B4F615D51615D51615D51605C505F5B4F\
5E5A4E5E5A4E5E5A4E6A68596A69576A69576A69576A69576A69576A69576A6957
6C6B596C6B596C6B596C6B596C6B596C6B596C6B596C6B59706A5A706A5A716B5B726C5C746E5E\
756F5F756F5F767060726C5C726C5C726C5C726C5C736D5D736D5D736D5D736D5D
756F61756F61767062767062777163787264787264787264736D5F746E60746E60756F61767062\
7771637872647872647D766C7C756B7A7369787167777066777066787167797268
7D766C787167746D63756E647972687A7369766F656F6B606F6B62726F6878756E7C79727C7972\
78756E726F686E6B6474716A716E676F6C65706D6675726B78756E78756E77746D
817E7778756E6E6B646A67606B68616A676066635C615E5773706976736C77746D7370696D6A63\
6B68616F6C657471686E6C606C6A5E6A685C6D6B5F727064767468767468747266
6F6D616F6D616F6D616F6D616F6D616F6D616F6D616F6D61737165737165737165737165737165\
7371657371657371656E6C606E6C606F6D61706E62716F63727064737165747168
7571706F6B6C716D6E6E6A6B514D4E2C28292925263D393A979394B1ADAED5D1D2F2EEEFFEFAFB\
FEFAFBFAF6F7F5F3F4FEFFFFFCFFFFFCFFFFFCFFFFFBFFFFF7FBFEF5F9FCF4F8FB
FCFFFFFCFFFFFCFFFFFBFFFFF8FCFFF6FAFDF4F8FBF2F7FAFAFFFFF2F9FFE8EFF5DAE1E7CCD3D9\
BFC6CCB5BCC2B0B7BDA5ACB2A7AEB4A9B0B6A8AFB5A2A9AF979EA48B9298868B91
50505845444C33323A22212916151D13121A16151D1918202E2D3538373F4948505C5B636A6971\
73727A77767E77767E7B7A827A798179788077767E76757D74737B73727A727179
6C6B736D6C746E6D756F6E7671707872717974737B747379727177727176727176717075706F74\
6F6E736F6E736F6E73727176727176706F746E6D726D6C716B6A6F6A696E69686D
6463686364686362676061655F5E635D5E625D5C615B5C60605F645F60645F5E635D5E625D5C61\
5B5C605B5A5F595A5E
68665A6462565F5D515B594D5A584C5D5B4F615F53646256605E525C5A4E59574B5B594D605E52\
6563576664586664576B695A6C6A5B6B695A6967586765566664556967586B695A
6C6A5B6C6A5B6B695A6B695A6A6859696758696758696758706A5C726C5E746E60746E60716B5D\
706A5C716B5D736D5F7A7466787264756F61756F61767062767062746E60736D5F
746E60746E60746E60746E60746E60746E60746E60746E60746E60746E60746E60746E60746E60\
746E60746E60746E60746D63746D63746D63746D63746D63746D63746D63746D63
746D63746D63746D63746D63746D63746D63746D63726E63706C636F6C636F6C636F6C636F6C63\
6F6C636F6C636F6C636F6C636F6C636F6C636F6C636F6C636F6C636F6C636F6C63
706D646F6C636F6C636E6B626C69606B685F6B685F6A675E706D64706D64706D646F6C636F6C63\
6E6B626E6B626E6B626F6D616F6D616F6D616F6D616F6D616F6D616F6D616F6D61
6F6D616F6D616F6D616F6D616F6D616F6D616F6D616F6D61716F63716F63716F63716F63716F63\
716F63716F63716F636F6D616F6D616F6D616F6D616F6D616F6D616F6D616F6C63
817D7C7975766E6A6B635F605C58595B57585D595A5F5B5CB5B1B2C6C2C3DDD9DAEFEBECF8F4F5\
FDF9FAFFFDFEFFFEFFFCFDFFFBFFFFFCFFFFFCFFFFFBFFFFFAFEFFF8FCFFF6FAFD
F8FCFFFAFEFFFAFEFFF8FCFFF5F9FCF6FAFDFBFFFFFBFFFFFBFFFFF4FBFFEAF1F7DFE6ECD5DCE2\
CDD4DAC7CED4C5CCD2BDC4CAC2C9CFC7CED4C7CED4BFC6CCB1B8BEA2A9AF999EA4
79798168676F53525A48474F49485049485043424A3B3A423E3D4545444C4D4C54504F57525159\
5A59616B6A7279788076757D76757D75747C74737B74737B73727A727179727179
727179727179717078706F77706F776F6E766E6D756E6D73706F75706F746F6E736E6D726E6D72\
6D6C716C6B706C6B706C6B706C6B706B6A6F6A696E6A696E69686D68676C68676C
66656A66656A666469646368656368636267636166626166636166626166626065616065615F64\
5F5E63605E635E5D62
57554957574B5C5A4E5C5C505F5D515B5B4F5B594D58584C5E5C505D5D5162605466665A6D6B5F\
6A6A5E666458615F536F6D60706E5F706E5F6F6D5E6E6C5D6F6D5E716F60737162
6765566967586C6A5B706E5F7573647977687C7A6B7E7C6D6E685A6C66586A64566D6759726C5E\
756F61756F61746E606F695B706A5C736D5F7771637A74667B7567797365777163
746E60746E60746E60746E60746E60746E60746E60746E60746E60746E60746E60746E60746E60\
746E60746E60746E60746D63746D63746D63746D63746D63746D63746D63746D63
746D63746D63746D63746D63746D63746D63746D63726E63706C636F6C636F6C636F6C636F6C63\
6F6C636F6C636F6C636F6C636F6C636F6C636F6C636F6C636F6C636F6C636F6C63
6F6C636F6C636E6B626D6A616D6A616C69606B685F6B685F6E6B626E6B626F6C636F6C636F6C63\
6F6C63706D64706D646F6D616F6D616F6D616F6D616F6D616F6D616F6D616F6D61
6F6D616F6D616F6D616F6D616F6D616F6D616F6D616F6D61716F63716F63716F63716F63716F63\
716F63716F63716F636F6D616F6D616F6D616F6D616F6D616F6D616F6D616F6C63
6C6865716D6C7D79788F8B8AA6A2A1BFBBBAD5D1D0E1DDDCFAF6F5FFFEFDFFFEFDFFFEFDFFFEFD\
FFFEFDFDF9F8F8F6F7FAFAFCFAFBFDFAFBFFFBFCFEFCFDFFFDFEFFFEFFFFFEFFFF
FEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFAFBFDF3F4F8ECF0F3F7FCFFF6FEFFF9FEFFF8FFFFFAFFFF\
F8FFFFFAFFFFF8FFFFFBFFFFF9FFFFFBFFFFF9FFFFF9FEFFF1F9FCECF1F7E7ECF0
E5E5EDE2E1E7DDDCE4D9D8DED7D6DED6D5DBD4D3DBD2D1D7C6C5CDC5C4CAB9B8C09F9EA47E7D85\
68676D64636B68676D76757D75747A75747C74737973727A737278727179727177
727179717076717078706F756F6E766F6E746E6D756E6D73706F746F6E736F6E736E6D726D6C71\
6D6C716C6B706C6B706C6B706B6A6F6B6A6F6A696E69686D69686D68676C68676C
67656A666469666469656368646267646267636166636166626065626065626065615F64605E63\
5F5D625F5D625F5D62
63635962645964645A65675C6A6A606D6F6472726874766B77776D73756A717167707267737369\
73756A7171676E6E626A685B6A685B6B695C6B695C6C6A5D6D6B5E6D6B5E6D6B5E
7D7B6E7B796C7876697472656F6D606A685B676558656356857F737D776B756F63726C60746E62\
736D616E685C686256726C60746E62777165787266767064716B5F6B6559686256
736D5F736D5F736D5F736D5F736D5F736D5F736D5F736D5F736D5F736D5F736D5F736D5F736D5F\
736D5F736D5F736D5F736C62736C62736C62736C62736C62736C62736C62736C62
736C62736C62736C62736C62736C62736C62736C62716D626F6B606E6C606E6C606E6C606E6C60\
6E6C606E6C606E6C606E6C606E6C606E6C606E6C606E6C606E6C606E6C606E6C60
6F6D616E6C606E6C606D6B5F6D6B5F6C6A5E6C6A5E6B695D6C6A5E6C6A5E6D6B5F6E6C60706E62\
716F637270647270646F6D616F6D616F6D616F6D616F6D616F6D616F6D616F6D61
6F6D616F6D616F6D616F6D616F6D616F6D616F6D616F6D61716F63716F63716F63716F63716F63\
716F63716F63716F63706E62706E62706E62706E62706E62706E62706E62706D64
67645F6763606965626C6865706C6976726F7A76737D7976C7C3C0D3CFCCE4E0DDF3EFECFBF7F4\
FFFBF8FFFEFBFFFEFBFFFEFFFFFFFFFEFEFFFBFBFBFAFAFCFBFBFBFDFDFFFFFFFF
FAFAFCF6F6F6F4F4F6F9F9F9FFFFFFFFFFFFFFFFFFFFFFFFF9FDFFFAFFFFFCFFFFFBFFFFFCFFFF\
FBFFFFFCFFFFFAFFFFFCFFFFFAFFFFF9FCFFF6FBFEF7FAFFF7FCFFFBFEFFFCFFFF
FCFDFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFF9F8FEF0EFF4E5E4EADFDEE3D7D6DC\
C1C0C5A1A0A688878C75747A757479747379747378737278727176727177717075
717076717075706F75706F746F6E746E6D726E6D736D6C716F6E736F6E736E6D726E6D726D6C71\
6C6B706C6B706B6A6F6B6A6F6B6A6F6A696E6A696E69686D68676C68676C67666B
666469686369676268676268666167656066656066645F65635E64635E64625D63625D63615C62\
605B61605B615F5A60
2C2E2325271C1C1E13191B1020221731332844463B51534847493E393B3026281D191B10181A0F\
1F211627291E2C2E235D5D51605E516462556C6A5D7472657A786B7D7B6E7C7A6D
6563566664576866596B695C6E6C5F706E617270637371646660546660546761556963576C665A\
706A5E736D61756F63716B5F736D61756F63736D616E685C6A6458686256686256
726C5E726C5E726C5E726C5E726C5E726C5E726C5E726C5E726C5E726C5E726C5E726C5E726C5E\
726C5E726C5E726C5E726B61726B61726B61726B61726B61726B61726B61726B61
726B61726B61726B61726B61726B61726B61726B61706C616E6A5F6D6B5F6D6B5F6D6B5F6D6B5F\
6D6B5F6D6B5F6D6B5F6D6B5F6D6B5F6D6B5F6D6B5F6D6B5F6D6B5F6D6B5F6D6B5F
6E6C606D6B5F6D6B5F6D6B5F6D6B5F6D6B5F6D6B5F6C6A5E6A685C6B695D6C6A5E6E6C60706E62\
7270647371657472666F6D616F6D616F6D616F6D616F6D616F6D616F6D616F6D61
6F6D616F6D616F6D616F6D616F6D616F6D616F6D616F6D61716F63716F63716F63716F63716F63\
716F63716F63716F63716F63716F63716F63716F63716F63716F63716F63716E65
817E77807D767E7B747A777076736C726F686E6B646B6861514E4756534C5D5A53625F58636059\
615E575E5B545C59544E4A47494544413D3C393534332F2E312D2C322E2D332F2E
464241433F3E4A4645676362969291C7C3C2E8E4E3F6F5F3FFFFFFFCFDFFF9FAFCF7F8FAF5F6F8\
F5F6F8F6F7F9F6F7F9FCFDFFFAFBFDF8F9FBF7F8FAF8F9FBFCFDFFFEFFFFFEFFFF
F7F7F9F7F7F9F7F7F9F6F6F8F6F6F8F7F7F9FAFAFCFCFCFEFDFDFFAFAFB1565658323234474749\
6767696C6C6E626264747476747476737375737375727274717173717173707072
7070727070726F6F716F6F716E6E706D6D6F6D6D6F6C6C6E6E6D726E6D726D6C716D6C716C6B70\
6B6A6F6B6A6F6A696E6A696E6A696E69686D69686D68676C67666B67666B67656A
676268676268666167666167656066645F65645F65635E64625D63615C62615C62605B615F5A60\
5F5A605E595F5E595F
46494041443B3A3D343A3D3444473E5659506A6D647679706A6D645B5E55464940373A3133362D\
373A313E41384244394545394745394B493D5452465F5D51656357656357626054
807E727F7D717D7B6F7A786C777569757367737165716F637972687F786E827B717E776D756E64\
6F685E716A60766F656B645A6E675D716A6070695F6E675D70695F7770667D776B
726C5E726C5E726C5E726C5E726C5E726C5E726C5E726C5E726C5E726C5E726C5E726C5E726C5E\
726C5E726C5E726C5E726B61726B61726B61726B61726B61726B61726B61726B61
726B61726B61726B61726B61726B61726B61726B61706C616E6A5E6D6B5E6D6B5E6D6B5E6D6B5E\
6D6B5E6D6B5E6D6B5E6D6B5E6D6B5E6D6B5E6D6B5E6D6B5E6D6B5E6D6B5E6D6B5E
6C6A5D6D6B5E6D6B5E6D6B5E6D6B5E6D6B5E6D6B5E6E6C5F6A685B6B695C6C6A5D6E6C5F706E61\
7270637371647472656F6D616F6D616F6D616F6D616F6D616F6D616F6D616F6D61
6F6D616F6D616F6D616F6D616F6D616F6D616F6D616F6D61716F63716F63716F63716F63716F63\
716F63716F63716F63716F63716F63716F63716F63716F63716F63716F63716F63
64615866635A69665D6D6A616F6C636F6C636F6C636E6B626B685F6A675E68655C66635A615E55\
5B584F5350474E4B42625D575D585455504C4D484447423E45403C46413D47423E
494440423D39423D3956514D7B7672A29D99BDB8B4C9C4C0D2CECDCECDCBCBCAC8CBCAC8D1D0CE\
DBDAD8E5E4E2ECEBE9FEFDFBFEFDFBFFFEFCFFFEFCFFFFFDFFFFFDFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDF1F1EFE0E0DED0D0CE8F8F8D4444422626243D3D3B\
61615F73737174747274747273737173737172727071716F71716F70706E70706E
70706E6F6F6D6F6F6D6E6E6C6D6D6B6D6D6B6C6C6A6C6C6C6E6E706D6C716D6C716C6B706B6A6F\
6B6A6F6A696E6A696E6A696E69686D69686D68676C67666B67666B66656A67656A
676268676067676067665F66655E65655E65645D64645D64615A61615A616059606059605F585F\
5E575E5E575E5D565D
BFC2B9C4C7BECBCEC5D3D6CDDBDED5E2E5DCE6E9E0E8EBE2E7EAE1E2E5DCDBDED5D6D9D0D2D5CC\
CDD0C7C7CAC1C2C3BB88887E8280747A786C75736772706469675B5B594D4F4D41
35332739372B4240344D4B3F59574B6563576D6B5F727064645D536C655B746D63777066736C62\
70695F6F685E70695F756E647972687B746A7770666F685E6D665C716A60777066
716B5F716B5D716B5D716B5D716B5D716B5D716B5D716B5D716B5D716B5D716B5D716B5D716B5D\
716B5D716B5D716B5D716A60716A60716A60716A60716A60716A60716A60716A60
716A60716A60716A60716A60716A60716A60716A606F6B606D695D6C6A5D6C6A5D6C6A5D6C6A5D\
6C6A5D6C6A5D6C6A5D6C6A5D6C6A5D6C6A5D6C6A5D6C6A5D6C6A5D6C6A5D6C6A5D
6B695C6C6A5D6C6A5D6D6B5E6D6B5E6E6C5F6E6C5F6F6D606C6A5D6C6A5D6D6B5E6E6C5F706E61\
716F627270637270636F6D616F6D616F6D616F6D616F6D616F6D616F6D616F6D61
6F6D616F6D616F6D616F6D616F6D616F6D616F6D616F6D61716F63716F63716F63716F63716F63\
716F63716F63716F63727064727064727064727064727064727064727064727064
807E72807E717F7D717D7B6E79776B757366727064706E6169675B6866596B695D716F6278766A\
7D7B6E7D7B6F7C786D716A626E675F6C635E686159685F5A6861596B625D6C655D
7F7671766F676F66616B645C6B625D67605860575257504A4F4A464B48434944414946414F4A47\
585550645F5C6A67629B96939C99949F9A979F9C979F9A979C999499949196938E
A9A8A4ACADA7B8B9B4C7C8C2CBCCC7B8B9B393948F757670393A354B4C4663645F74756F797A75\
76777173746F72736D73746F72736D72736E71726C70716C70716B6F706B6F706A
6F706B6E6F696E6F6A6D6E686C6D686C6D676B6C676B6B696D6D6F6C6B706C6B706B6A6F6A696E\
6A696E69686D69686D69686D68676C68676C67666B66656A66656A656469666469
666167665F66665F66655E65645D64645D64635C63635C636059605F585F5F585F5E575E5D565D\
5D565D5C555C5C555C
E9ECE5EFF2EBF8FBF4FEFFFAFEFFFAFEFFFAFDFFF9F9FCF5FEFFFAFEFFFAFEFFFAFEFFFAFEFFFA\
FBFEF7F2F5EEECEDE5FEFEF4F5F2E9E9E6DDE0DDD4D8D5CCCAC7BEB6B3AAA7A49B
A09D9497948B86837A6F6C6357544B413E35302D2427241B4A433B4C453D564F476861597B746C\
827B737A736B716A62655E566F68607871697871696F6860676058665F57686157
706A5E706A5C706A5C706A5C706A5C706A5C706A5C706A5C706A5C706A5C706A5C706A5C706A5C\
706A5C706A5C706A5C70695F70695F70695F70695F70695F70695F70695F70695F
70695F70695F70695F70695F70695F70695F70695F6E6A5F6C685C6B695C6B695C6B695C6B695C\
6B695C6B695C6B695C6B695C6B695C6B695C6B695C6B695C6B695C6B695C6B695C
6B695C6B695C6C6A5D6D6B5E6D6B5E6E6C5F6F6D606F6D606E6C5F6E6C5F6F6D606F6D606F6D60\
6F6D60706E61706E616F6D616F6D616F6D616F6D616F6D616F6D616F6D616F6D61
6F6D616F6D616F6D616F6D616F6D616F6D616F6D616F6D61716F63716F63716F63716F63716F63\
716F63716F63716F63737165737165737165737165737165737165737165737165
66645767655669675A6B695A6E6C5F716F607371647472638381747E7C6D79776A7876677A786B\
7A7869757366726E62827970827970847973847B72867B75867D74887D77877E75
716660726960786D677A71687C716B786F66746963706760756E68726D67736B68706B65716966\
706B65736B68716C66524A47504B45534B48514C46524A474F4A444F47444C4741
54534E58595161625C6A6B636B6C665F60584A4B453A3B3364655F72736B7D7E787A7B736D6E68\
68696171726C7E7F7772736D72736B71726C71726A70716B6F70686F706A6E6F67
6E6F696E6F676D6E686D6E666C6D676B6C646B6C666A6B666C6C6E6C6B706B6A6F6B6A6F6A696E\
69686D69686D68676C68676C68676C67666B67666B66656A656469656469656368
656066665F66655E65655E65645D64635C63635C63625B625E575E5E575E5E575E5D565D5C555C\
5B545B5B545B5B545B
FFFFFBFFFFFAFFFFFBFFFFFAFFFFFBFFFFFAFFFFFBFFFFFAFFFFFBFFFFFAFBFCF7FBFCF6FEFFFA\
FFFFFAFFFFFBFFFFFAFFFFF8FFFFF8FFFFF7FFFFF8FFFFF8FFFFF8FFFFF8F8F8F0
FBFBF3FBFBF3FCFCF4FCFCF4FDFDF5FEFEF6FEFEF6FFFEF7F4EFE9DEDAD1C8C1BBBCB8AFB7B0AA\
9C988F716A6449453C332C264541386059536C685F7069636C685F706963716D64
706A5E6E6B5C706A5E6E6B5C706A5E6E6B5C706A5E6E6B5C706A5E6E6B5C706A5E6E6B5C706A5E\
6E6B5C706A5E6E6B5C706A5C6E6B5C706A5C6E6A5E706A5E6E6A5E706A5E6E6A5E
706A5E6E6A5E706A5E6E6A5F70695F6E6A5F70695F6E6A5F6B695C6B695C6B695C6B695C6B695C\
6B695C6B695C6B695C6B695C6B695C6B695C6B695C6B695C6B695C6B695C6B695C
6A685B6B695C6B695D6C6A5D6E6C606F6D606F6D61706E61706E62706E61706E626F6D606F6D61\
6E6C5F6E6C606E6C606F6C636F6C636F6C636F6C636F6C636F6C636F6C636F6D61
6F6D616F6D616F6D616F6D616F6D616F6D616F6D616F6D61716F63716F63716E65716F63716E65\
716F63716E65716F63737067737165737067737165737067737165737067737165
79776A787669767467757366757366757366777568787669767467716F626D6B5E706E61767467\
7A786B7876697672667972687B72697C736C7C736A7B726B7A7168786F68766D64
7E756E7F766D7F766F7C736A7970697A71687E756E827972756E6876716B7E77717F7A74827B75\
7C77717A736D746F6987807A837E78837C767F7A74817A74807B75847D77847F79
79797178797176757071726A6F6E6972736B7C7B7683847C7675707071696F6E69707169777671\
78797174736E6E6F6773726D72736B72716C70716971706B6F70686F6E696E6F67
6F6E696E6F676E6D686C6D656D6C676B6C646B6A656A6B666D6B6C6C6C6E6C6A6D6A6A6C6B696C\
69696B69676A68686A69676A68686A686669666668676568656567656366656366
656064666064655F63645E62645E62635D61625C60625C605E585C5D575B5D575B5C565A5B5559\
5B55595A54585A5458
FFFEFCFFFFFBFFFFFDFFFFFBFFFEFCFDFCF8FAF9F7F9F8F4FFFFFDFAF9F5F6F5F3F8F7F3FFFEFC\
FFFFFBFFFFFDFDFCF8FEFFFAFFFFFBFFFFFBFFFFFBFFFFFBFEFFFAFBFCF7F9FAF5
F4F5F0FCFDF8FFFFFBFFFFFBFDFEF9F7F8F3F5F6F1F5F6F1FBF8F3E9E6DFD7D2CECFCCC5CAC5C1\
B3B0A98C878369665F4C4743524F485E595568655E706B67706D666E69656B6861
6D695E6C6A5D6D695E6D6B5E6E6A5F6D6B5E6F6B606E6C5F6B675C6A685B6B675C6B695C6C685D\
6C6A5D6D695E6C6A5B716E5B6D6C576B69546B6A566D6A576C6B576A6756666553
747162727061716E5F6E6C5F6D695D6A685B69655A67655968665969675A6A685B6B695C6C6A5D\
6D6B5E6E6C5F6E6C5F6B695C6B695C6B695C6A685B69675A69675A69675A686659
6B695D6B695D6C69606C6A5E6D6A616D6B5F6E6B626E6C6067645B6B695D706D64737165757269\
737165706D646D6A616C69646C68656C69646D6A656E6B666F6C676F6C656E6B62
716E65716E65716F63716F63716F62716F62716F62716F636F6C636F6C636F6C656F6C636F6C65\
6F6C636F6C656F6C63716E67726F66726F6873706774716A74716875726B757269
73706773706773706773706773706773706773706773706777746B77746B77746B77746B77746B\
77746B77746B77746B78746B78746B78736D78746B78736D78746B78736D78746B
78736D78746B78736D78746B78736D78746B78736D78736D78736D77746D78736D77746D78736D\
77746D78736D77746D7C77717B78717C77717B78717C77717B78717C77717B7871
79767177767178747175746F77737074736E75716E73726D75716E72716C74706D71706B726E6B\
706F6A716D6A6F6E69716D6A6F6E69716D6A6F6E69716D6A6F6E69716D6A6F6E69
706C696E6D68716D6A6F6E69716D6A706F6A726E6B706F6B6D69686B6A686C68676968666B6766\
686765696564676664696564676664686463656462676362646361656160656160
635F5E635F5E625E5D615D5C615D5C605C5B5F5B5A5F5B5A5B57565B57565A5655595554595554\
585453575352575352
FBF7F6FCF8F7FDF9F8FFFBFAFFFDFCFFFEFDFFFEFDFFFEFDFFFEFDFFFEFDFFFEFDFFFEFDFFFEFD\
FFFBFAF3EFEEE9E8E6FEFEFCFDFFFCFCFEFBFCFEFBFCFEFBFCFEFBFDFFFCFDFFFC
FEFFFDF6F8F5EEF0EDF3F5F2FEFFFDFEFFFDFEFFFDFFFFFBFAF9F4FCF9F4FFFDF8FFFFFAFFFFFA\
FFFCF7EFECE7E1DED9ADAAA59C9994807D786865605D5A555F5C576A6762737069
6F6C636F6D616F6D616F6D616F6D616F6D61706E62706E626B695D6B695D6B695D6B695D6B695D\
6B695D6C6A5E6C6A5B73725D6F6F556C6C546C6C546E6D58706F5A6E6D596C6B57
6867556968566B695A6C6A5B6D6B5E6D6B5E6D6B5F6C6A5E6E6C5F6E6C5F6E6C5F6F6D606F6D60\
706E61706E61706E6169675A69675A676558656356636154615F52605E515F5D50
5B584F5D5A515F5C53625F5666635A69665D6B685F6D6A61716E65726F66737067737067716E65\
6E6B626B685F69665F7A7673767271736F6C726E6B736F6C726F6A6D6A6569665F
716E65716E65716F63716F63716F62716F62716F62716F636F6C636F6C656F6C656F6C656F6C65\
6F6C656F6C656F6C656D6A636D6A636E6B646F6C656F6C65706D66716E67716E67
73706973706973706973706973706973706973706973706977746D77746D77746D77746D77746D\
77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D
77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D\
77746D77746D77746D7B78717B78717B78717B78717B78717B78717B78717B7871
79757278747178747177737076726F76726F75716E75716E76726F75716E75716E74706D736F6C\
736F6C726E6B726E6B6E6A676F6B68706C69716D6A726E6B736F6C74706D74706D
716D6A716D6A716D6A716D6A716D6A706C69706C69706C696D69666D69666C68656B67646B6764\
6A666369656269656269656268646168646167636066625F66625F65615E65615E
635F5C625E5B625E5B615D5A605C59605C595F5B585F5B585B57545B57545A5653595552595552\
585451575350575350
FFFDFAFFFBF8FEFAF7FDF9F6FFFBF8FFFEFBFFFEFBFFFEFBEFEBE8F7F3F0FDF9F6F9F5F2F3EFEC\
F9F5F2FFFEFBFFFFFBFFFFFBFEFFFBFDFFFAFCFEF9FDFFFAFEFFFBFEFFFBFEFFFB
FEFFFBFEFFFBFEFFFBFAFCF7F4F6F1F0F2EDEEF0EBEEEFEAFFFFFAFFFFF8FEFBF4DEDBD4B1AEA7\
85827B67645D59564F64615A615E575D5A535B58515E5B5464615A6C6962716E67
6E6B626E6C606D6B5F6D6B5F6D6B5F6D6B5F6D6B5F6D6B5F6B695D6B695D6B695D6B695D6B695D\
6B695D6A685C6A68596D6C5768685063634B63634B6766516A69546B6A566A6955
6564526765566A685B6D6B5E6E6C606C6A5E6A685C69675B6A685B6A685B69675A69675A686659\
6866596765586765586563566462556260535F5D505C5A4D59574A575548565447
58554C57544B57544B57544B56534A5552495552495552495F5C535F5C535F5C53605D54625F56\
64615866635A68655E6C68656965646763606B6764726E6B75726D716E696C6962
716E65716E65716F63716F63716F62716F62716F62716F63706D64706D66706D66706D66706D66\
706D66706D66706D666E6B646E6B646E6B646F6C65706D66716E67716E67716E67
74716A74716A74716A74716A74716A74716A74716A74716A77746D77746D77746D77746D77746D\
77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D
77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D\
77746D77746D77746D7A77707A77707A77707A77707A77707A77707A77707A7770
78747178747177737077737076726F75716E75716E74706D77737077737076726F76726F75716E\
74706D74706D736F6C726E6B726E6B726E6B726E6B726E6B726E6B726E6B726E6B
736F6C736F6C726E6B716D6A706C696E6A676E6A676D69666D69666D69666C68656B67646B6764\
6A666369656269656268646168646167636067636066625F65615E65615E64605D
625E5B625E5B615D5A615D5A605C595F5B585F5B585E5A575B57545B57545A5653595552595552\
585451575350575350
474340433F3C3C383535312E322E2B312D2A332F2C34302D54504D8A8683D1CDCAFEFAF7FFFEFB\
FFFEFBFFFCF9FFFFFBFFFFFBFEFFFBFEFFFBFEFFFBFEFFFBFDFFFAFAFCF7F9FBF6
F3F5F0FEFFFBFEFFFBD7D9D48D8F8A51534E3B3D383F403A26261E3A37304F4C455B58515E5B54\
615E5769665F726F6858554E605D566C696275726B75726B6D6A63625F5859564D
6A685C6A685C6A685C69675B69675B68665A68665A68665A6A685C6A685C6A685C69675B69675B\
68665A68665A68665969685464644C5F5F475F5F4763624D6867526A69556A6957
6A68596B695A6D6B5E6D6B5E6B695D6765596260545E5C505D5B4F5D5B4E5C5A4D5B594C5A584B\
59574A5856495755485E5C4F5D5B4E5C5A4D5A584B585649575548555346555347
58554C58554C57544B56534A55524954514854514853504758554C56534A535047514E45524F46\
56534A5A574E5D5A534E4A474E4A49534F4C5F5B586E6A6776736E77746F74716A
716E65716E65716F63716F63716F62716F62716F62716F63716E65716E67716E67716E67716E67\
716E67716E67716E6773706973706974716A74716A75726B76736C76736C77746D
75726B75726B75726B75726B75726B75726B75726B75726B77746D77746D77746D77746D77746D\
77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D
77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D\
77746D77746D77746D79766F79766F79766F79766F79766F79766F79766F79766F
77737077737076726F76726F75716E74706D74706D736F6C78747177737077737076726F75716E\
75716E74706D74706D79757278747176726F74706D716D6A6F6B686D69666C6865
74706D74706D726E6B706C696E6A676D69666B67646B67646D69666D69666C68656B67646B6764\
6A666369656269656267636067636066625F66625F65615E64605D64605D635F5C
615D5A615D5A605C59605C595F5B585E5A575E5A575D59565B57545B57545A5653595552595552\
585451575350575350
59555254504D4B4744433F3C3E3A373C38353C38353D39363834316B6764ABA7A4D5D1CEE0DCD9\
DEDAD7E1DDDAE5E4E0F8F9F4FBFCF7FFFFFBFFFFFBFFFFFBF8F9F4EFF0EBEAEBE6
BABBB6CFD0CBD6D7D2B3B4AF72736E40413C32332E3839333131293D3A314A473E56534A5D5A51\
625F5667645B6A675E7C797077746B706D6469665D66635A66635A68655C6A675E
6C6A5E6B695D6B695D6A685C69675B68665A67655967655968665A68665A676559666458656357\
64625664625663615468675363624D605F4A605F4A6564506968546A6957696856
666455676556686659676559656357615F535D5A515B594D5A584C59574B58564A575549565448\
55534754524654524657554957554957554958564A58564A59574B59574B59574B
514E4553504956534C59564F5D5A53615E5763605965625B6360595F5C5558554E524F484F4C45\
504D4653504955524D5753505B5756625E5B6B6764726E6B76736E77746F76736C
716E65716E65716F63716F63716F62716F62716F62716F63716E65716E67716E67716E67716E67\
716E67716E67716E6774716A74716A75726B75726B76736C77746D77746D78756E
75726B75726B75726B75726B75726B75726B75726B75726B77746D77746D77746D77746D77746D\
77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D
77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D\
77746D77746D77746D79766F79766F79766F79766F79766F79766F79766F79766F
77737076726F76726F75716E74706D74706D736F6C736F6C77737076726F76726F75716E74706D\
74706D736F6C736F6C75716E75716E74706D74706D736F6C736F6C726E6B726E6B
736F6C736F6C716D6A706C696E6A676C68656A66636A66636D69666D69666C68656B67646B6764\
6A666369656269656267636066625F66625F65615E64605D64605D635F5C635F5C
615D5A605C59605C595F5B585E5A575E5A575D59565D59565B57545B57545A5653595552595552\
585451575350575350
5F5B585D5A5559555256534E54504D54514C55514E56534E4A46434A474244403D393631332F2C\
413E395F5B587875709998949B9C96A1A09CA2A39DA09F9B989993908F8B898A84
403F3B41423C4544404849434E4D4952534D5857535B5A5568655C68655C69665D6D6A61706D64\
706D646D6A6169665D605D545D5A5159564D58554C5D5A5166635A706D6476736A
6F6D616E6C606D6B5F6C6A5E6A685C69675B68665A68665A656357646256636155626054615F53\
5F5D515E5C505E5C4F5A59455857425655405857425B5A465D5C485B5A48585647
58564758564958564A59574B5A584C5B584F5B584F5C59505C59505C5A4E5B594D5B594D5A584C\
5A584C59574B59574B53514553514554524656544857554959574B5A584C5A574E
535049535049535049535049535049535049535049535049535049535049524F4855524B5A5750\
625F586A67606F6C6786827F8D8988918D8A8C88857F7B7874716C706D68706D66
716E65716E65716F63716F63716F62716F62716F62716F63726F66726F68726F68726F68726F68\
726F68726F68726F68706D66706D66716E67726F68726F6873706974716A74716A
76736C76736C76736C76736C76736C76736C76736C76736C77746D77746D77746D77746D77746D\
77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D
77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D\
77746D77746D77746D78756E78756E78756E78756E78756E78756E78756E78756E
76726F75716E75716E74706D736F6C736F6C726E6B726E6B75716E74706D74706D736F6C726E6B\
726E6B716D6A716D6A6C68656D6966706C69736F6C76726F7975727B77747C7875
716D6A706C69706C696E6A676D69666C68656B67646B67646D69666D69666C68656B67646B6764\
6A666369656269656266625F65615E65615E64605D635F5C635F5C625E5B625E5B
605C595F5B585F5B585E5A575D59565D59565C58555C58555B57545B57545A5653595552595552\
585451575350575350
65625D65625B66635E67645D6966616A67606B68636C696265625D66635C65625D615E575A5752\
524F484C494449463F3E3B363C3C343F3C373D3D353E3B363B3B333B3833393931
65625D595951524F4A53534B615E59686860686560625F585F5C53605E52626054646256656357\
656357656357656357716F637472667775697775697371656A685C615F535B594D
6A685C69675B68665A666458656357636155626054615F53615F53615F535F5D515E5C505C5A4E\
5B594D59574B59574A53524052513D53523E565541595846575644514F404C4A3B
4F4D404D4B3F4A483C48453C49463D4C4942504D46535047535047535047535047545148545148\
555249555249555249524F46524F46535047535047545148545148555249555249
55524B55524D55524D55524D55524D55524D55524D55524D5855505B5853625F5A6C6964787570\
86837E918E89989590A19D9AACA8A7B2AEABA39F9C86827F706D686B6863706D66
716E65716E65716F63716F63716F62716F62716F62716F63737067737069737069737069737069\
737069737069737069716E67716E67716E67726F6873706974716A74716A74716A
77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D\
77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D
77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D\
77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D
75716E75716E74706D74706D736F6C726E6B726E6B716D6A726E6B726E6B716D6A716D6A706C69\
6F6B686F6B686E6A67706C69716D6A726E6B74706D76726F777370797572797572
6E6A676E6A676E6A676D69666D69666D69666D69666D69666D69666D69666C68656B67646B6764\
6A666369656269656265615E65615E64605D64605D635F5C625E5B625E5B615D5A
5F5B585F5B585E5A575E5A575D59565C58555C58555B57545B57545B57545A5653595552595552\
585451575350575350
53504955524B57544D5A57505B58515C59525B58515B585165625B615E575E5B54625F5869665F\
6C696268655E625F586F6C656D6A6369665F67645D69665F6E6B6474716A78756E
5D5A5366635C706D66737069706D666C69626C69626D6A616A685C6E6C60716F636E6C60676559\
6361556664586A685C636155646256646256646256646256646256636155636155
615F53605E525F5D515D5B4F5B594D59574B58564A5755495F5D515E5C505D5B4F5B594D59574B\
58564A5654485654475E5D4B5E5D4961604C6564526766546361525B594A535144
504E424B493D4441383E3B323C39323D3A33413E3744413A43403943403744413845423946433A\
47443B48453C49463D535047535047524F46514E45504D444F4C434F4C434E4B44
4B4843504D4858545163605B6F6B687A7772827E7B86837E8A86838C89848F8B8894918C9B9794\
A29F9AA8A4A1ABA7A49A9695ABA7A6B5B1AEA5A19E85817E6D6A656C696476736C
716E65716E65716F63716F63716F62716F62716F62716F63737067737069737069737069737069\
73706973706973706975726B76736C76736C77746D78756E78756E79766F79766F
77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D\
77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D
77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D\
77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D77746D
75716E75716E74706D736F6C736F6C726E6B716D6A716D6A716D6A706C69706C696F6B686E6A67\
6E6A676D69666D69667C78757B777479757277737074706D716D6A6F6B686E6A67
6C68656C68656C68656D69666D69666D69666E6A676E6A676D69666D69666C68656B67646B6764\
6A666369656269656265615E65615E64605D635F5C635F5C625E5B615D5A615D5A
5F5B585F5B585E5A575D59565D59565C58555B57545B57545B57545B57545A5653595552595552\
585451575350575350
57544B57544B58554C59564D59564D5A574E5B584F5B584F5F5C53605D54605D54615E55625F56\
625F5663605763605768645B68645B68645B68645B68645B68645B68645B68645B
68645B69655C69655C6A665D6B675E6B675E6C685F6C685F69675B69675A69675A69675A69675A\
69675A69675A69675A676558676558676558656356636154605E515D5B4E5B594C
605E525E5C505C5A4E5A584C5A584C5A584C5A584C5B594D58564A575549555347535145525044\
5250445250445351445B594A5756445756445D5B4C6765566D6B5C6C6A5D69675B
5D5B4F5A574E54514A4C494246433E403D383D3A353B38313F3C35423F3845423B46433C44413A\
44413A48453E4B4841514E4745423B4D4A43524F4843403945423B535049514E47
524E4B5B57546561606C6865757170807C7985818085817E938F8E918D8A8D8988908C89A4A09F\
94908D989493B4B0AFACA8A7A5A1A0ACA8A5BEBAB774706D74716C73706B726F68
737067737067737165737165737164737164737164737165737067737069737069737069737069\
73706973706973706975726B75726B75726B75726B75726B75726B75726B75726B
73706979766F7C79727A777079766F7C7972807D76807D767C79727C79727B78717A777079766F\
79766F78756E78756E74716A74716A74716A74716A75726B76736C77746D77746D
74716A75726B77746D77746D77746D75726B726F68706D6675726B75726B75726B75726B75726B\
75726B75726B75726B737069737069737069737069737069737069737069737069
7A76737A767378747176726F74706D726E6B716D6A706C696F6B686F6B686E6A676F6B68706C69\
726E6B74706D75716E79757278747175716E736F6C706C696D69666B6764696562
6F6B686F6B686E6A676D69666D69666C68656B67646B6764696562696562686461676360676360\
66625F65615E65615E635F5C635F5C625E5B615D5A615D5A605C595F5B585F5B58
625E5B615D5A605C595E5A575C58555A56535955525854515E5A575D59565B575458545156524F\
534F4C514D4A504C49
57544B57544B58554C58554C59564D5A574E5A574E5B584F5F5C535F5C535F5C53605D54615E55\
625F56625F56625F56656158656158656158656158656158656158656158656158
68645B68645B68645B69655C6A665D6B675E6B675E6B675C69675A69675A69675A69675A69675A\
69675A69675A69675A666457676558676558676558656356636154605E515F5D50
49473B464438413F333B392D363428323024302E222F2D213B392D3C3A2E3D3B2F3E3C303F3D31\
403E32413F33413F323D3B2C383725373526424031535142605E516260545F5D51
69665D68655C66635C65625B64615C63605B63605B63605B53504B514E474D4A4545423B3D3A35\
3A37303C3934403D3649464138352E43403B55524B57544F615E576D6A6566635E
7773727975747B77767E7A798581808D8988908C8B8F8B8A938F8E938F8E928E8D9B9796A9A5A4\
A09C9B9D9998AFABAAADA9A8A5A1A0ACA8A5BEBAB774706D74716C73706B726F68
737067737067737165737165737164737164737164737165737067737069737069737069737069\
73706973706973706975726B75726B75726B75726B75726B75726B75726B75726B
7D7A737B787176736C737069737069726F686E6B6469665F79766F78756E78756E77746D76736C\
74716A74716A73706979766F79766F79766F79766F77746D75726B726F68716E67
73706973706975726B77746D7A77707E7B74817E7784817A78756E78756E78756E78756E78756E\
78756E78756E78756E76736C76736C76736C76736C76736C76736C76736C76736C
75716E75716E74706D74706D74706D74706D74706D74706D6F6B686F6B68706C69716D6A74706D\
7773707B77747D797676726F75716E74706D726E6B706C696E6A676C68656B6764
6F6B686E6A676E6A676D69666C68656C68656B67646B676469656268646168646167636066625F\
66625F65615E65615E635F5C625E5B625E5B615D5A605C59605C595F5B585F5B58
605C595F5B585F5B585D59565C58555B57545A56535A56535D59565C58555A565358545156524F\
534F4C514D4A514D4A
56544857554957554958564A59574B59574B5A584C5A584C5D5B4F5E5C505E5C505F5D51605E52\
605E52615F53615F53625E53645D53645D53645D53645D53645D53645D53645D53
6861576962586962586A63596B645A6B645A6C655B6A665B686659686657686657686657686657\
686657686657686657666455666455686657696758686657676556666455656356
58564A5553474F4D4149473B4341353E3C303C3A2E3A382C1D1B0F1F1D11222014242216242216\
232115201E121F1D103634252D2B1C2A281B3836295250436563576A685C67645B
6A67606A67606B68636C69646E6A676F6B68706C69716D6A706C69716E69716D6A6B686364605D\
5E5B565C58555D5A55524E4B3C393445413E5F5C57686461716E6976726F696562
7A76757571727470717B77788682838D898A8F8B8C8E8A8B959192979394969293A7A3A4A9A5A6\
ACA8A9A5A1A2ABA7A8AEAAA9A7A3A2ADA9A6BFBBB874706D75726D73706B716E67
737067737067737165737165737164737164737164737165737067737069737069737069737069\
73706973706973706975726B75726B75726B75726B75726B75726B75726B75726B
7A777075726B73706978756E807D76838079817E777E7B7475726B76736C78756E7A77707C7972\
7F7C75817E77827F786F6C65716E6773706975726B76736C76736C75726B75726B
76736C74716A716E676F6C656F6C65716E6773706975726B7A77707A77707A77707A77707A7770\
7A77707A77707A777078756E78756E78756E78756E78756E78756E78756E78756E
75716E74706D74706D74706D736F6C736F6C736F6C736F6C78747177737076726F76726F76726F\
7773707975727A7673736F6C726E6B726E6B716D6A706C696F6B686E6A676E6A67
6E6A676E6A676D69666D69666C68656B67646B67646A666368646168646167636067636066625F\
65615E65615E64605D625E5B625E5B615D5A615D5A605C595F5B585F5B585E5A57
5D59565D59565D59565C58555C58555C58555C58555B57545C58555B575459555257535055514E\
534F4C524E4B514D4A
55534756544856544857554958564A58564A59574B59574B5C5A4E5C5A4E5D5B4F5D5B4F5E5C50\
5F5D515F5D51615D52635C52635C52635C52635C52635C52635C52635C52635C52
6760566760566861576861576962586A63596A63596B6559686556676556676556676556676556\
6765566765566765566563546664556866576A68596B695A6B695A6A68596A6859
716F626F6D616D6B5F6B695D69675B69675B6A685C6A685C77756978766A7A786C7A786C777569\
706E626A685C6563574A483B3E3C2D3836294442355E5C5072706477746B737067
6A67606A67606A67626A676269656267636065616064605F595552615D5A6B6764706C696F6B68\
6B67646864616763606A6663514D4A5854516D6966686461615D5A5F5B58534F4E
5A56575551525B57586F6B6C837F808C88898E8A8B8F8B8C9894959A9697959192A8A4A5979394\
B1ADAEADA9AAABA7A8B0ACABA8A4A3AFABA8C0BCB975716E75726D73706B716E67
737067737067737165737165737164737164737164737165737067737069737069737069737069\
73706973706973706975726B75726B75726B75726B75726B75726B75726B75726B
7E7B7478756E76736C77746D74716A6D6A636A67606D6A6377746D77746D77746D77746D77746D\
77746D77746D77746D7A777079766F77746D76736C77746D78756E7A77707B7871
827F78817E77807D767E7B747D7A737C79727B78717B78717A77707A77707A77707A77707A7770\
7A77707A77707A777078756E78756E78756E78756E78756E78756E78756E78756E
79757278747177737075716E736F6C716D6A706C696F6B6884807D817D7A7D7976787471736F6C\
706C696E6A676E6A676F6B686F6B686F6B686F6B68706C69706C69706C69706C69
6D69666D69666C68656C68656B67646A66636A666369656267636067636066625F66625F65615E\
64605D64605D635F5C615D5A615D5A605C59605C595F5B585E5A575E5A575D5956
5A56535B57545B57545B57545C58555C58555C58555C58555A565359555258545156524F55514E\
534F4C524E4B514D4A
55534655534656544756544757554858564958564959574A5A584B5B594C5B594C5C5A4D5D5B4E\
5D5B4E5E5C4F5F5B4F655F53665E53665E53665E53665E53665E53665E53665E53
665E53675F54675F546860556961566961566A6257696357686556676654676654676654676654\
6766546766546766546564526665536867556B6A586C6B596C6B596C6B596C6A5B
6C6A5D6B695D6B695D6B695D6C6A5E6F6D61716F63727064716F63737165757367747266716F63\
6B695D646256605E52605E515452454B493D52504464615873706775726B716E67
73706B73706B736F6C726E6B706C6B6C68676864636662615D5956625E5B676360696562696562\
6B67646F6B68736F6C706C695A565364605D74706D605C594B47444A4643474342
4945464843475752567671758D888C938E929590949A95999A95999B969A8F8A8EA19CA0797478\
ABA6AAB3AEB2AFABACB2AEADAAA6A5B0ACA9C1BDBA75716E75726D73706B716E67
737067737067737165737165737164737164737164737165737067737069737069737069737069\
73706973706973706975726B75726B75726B75726B75726B75726B75726B75726B
76736C75726B7B7871827F787D7A7375726B7B787189867F807D767E7B747C797278756E74716A\
716E676E6B646D6A6387847D8380797E7B7479766F77746D79766F7C79727E7B74
706D6673706977746D7C79727E7B747D7A737B78717A777078756E78756E78756E78756E78756E\
78756E78756E78756E76736C76736C76736C76736C76736C76736C76736C76736C
76726F76726F76726F76726F75716E75716E75716E75716E817D7A7F7B787A767374706D6F6B68\
6C68656A66636965626D69666D69666E6A676E6A676F6B68706C69706C69706C69
6D69666C68656C68656B67646A66636A666369656269656267636066625F66625F65615E64605D\
64605D635F5C635F5C615D5A605C59605C595F5B585E5A575E5A575D59565D5956
5A56535A56535A56535A56535B57545B57545B57545C585558545157535056524F55514E54504D\
534F4C524E4B514D4A
54524554524555534655534656544757554857554858564959574A59574A5A584B5A584B5B594C\
5C5A4D5C5A4D5E5A4E645E52655D52655D52655D52655D52655D52655D52655D52
655D52655D52665E53665E53675F54686055686055686254676455666553666553666553666553\
6665536665536665536564526665536867556A69576B6A586B6A586B6A586A6859
6A685B69675B68665A67655966645867655969675B69675B6A685C6C6A5E6F6D61716F63716F63\
706E626D6B5F6B695D716F6269675A6260546462566B685F726F66737069706D66
716E6973706B75716E77737077737274706F716D6C6F6B6A7D79787A767375716E6E6A676A6663\
6D696676726F7D7976676360514D4A5F5B58726E6B5D595646423F4945424E4A49
4A46474A45495C575B7B767A8B868A8984888E898D9B969A9792969C979B8D888C9D989C5A5559\
A29DA1B5B0B4B2AEAFB4B0B1ACA8A7B1ADAAC2BEBB76726F75726D73706B716E67
737067737067737165737165737164737164737164737165737067737069737069737069737069\
73706973706973706975726B75726B75726B75726B75726B75726B75726B75726B
7F7C7577746D79766F807D767A77706B68616C69627B78716C69626D6A63716E6775726B79766F\
7D7A73807D76827F786B68616C69626F6C65726F6876736C7B78717F7C75817E77
79766F7A77707C79727C79727B787178756E75726B73706978756E78756E78756E78756E78756E\
78756E78756E78756E76736C76736C76736C76736C76736C76736C76736C76736C
716D6A726E6B74706D7773707A76737C78757F7B78807C7974706D736F6C716D6A6F6B686E6A67\
6E6A676F6B68706C696D69666D69666D69666E6A676E6A676E6A676F6B686F6B68
6C68656B67646B67646A666369656269656268646168646166625F65615E65615E64605D635F5C\
635F5C625E5B625E5B605C595F5B585F5B585E5A575D59565D59565C58555C5855
5B57545A56535A56535A56535A565359555259555259555256524F56524F55514E54504D534F4C\
534F4C524E4B524E4B
53514454524554524555534656544756544757554857554858564958564958564959574A5A584B\
5B594C5B594C5C584C615B4F625A4F625A4F625A4F625A4F625A4F625A4F625A4F
645C51645C51645C51655D52665E53675F54675F54666052666354656452656452656452656452\
6564526564526564526564526665536867556968566A6957696856686755676556
716F62706E626E6C606C6A5E6C6A5E6C6A5E6D6B5F6D6B5F65635766645867655968665A6A685C\
6B695D6B695D6C6A5E727064727064716F63706E626F6C63706D64726F6874716A
6B68636E6B66726E6B74706F757170726E6D6F6B6C6C68676662616E6A697773727B7776797574\
757170716D6C706C6B6F6B6A504C4B5854536F6B6A615D5C4C48474C48474F4B4A
4D494A4B464A5A5559716C70777276716C707E797D9691958F8A8E9C979B918C90A09B9F474246\
9C979BB6B1B5B4B0B1B5B1B2ADA9A8B2AEABC3BFBC76726F75726D726F6A706D66
737067737067737165737165737164737164737164737165737067737069737069737069737069\
73706973706973706975726B75726B75726B75726B75726B75726B75726B75726B
87847D6F6C6565625B706D6673706963605958554E5C5952322F2835322B39362F3F3C3545423B\
4B48414F4C45514E47726F6878756E807D7685827B84817A7E7B7474716A6E6B64
7C79727A777077746D75726B76736C7A77707F7C75827F787A77707A77707A77707A77707A7770\
7A77707A77707A777078756E78756E78756E78756E78756E78756E78756E78756E
7A76737A76737B77747B77747C78757C78757D79767D7976706C696F6B686E6A676E6A676F6B68\
706C69726E6B736F6C6E6A676E6A676E6A676D69666D69666D69666D69666D6966
6B67646B67646A66636A666369656268646168646167636065615E65615E64605D64605D635F5C\
625E5B625E5B615D5A5F5B585F5B585E5A575E5A575D59565C58555C58555B5754
5C58555C58555B57545A565359555257535057535056524F55514E54504D54504D54504D534F4C\
524E4B524E4B524E4B
5450445351445551455553465652465654475854485755485854485755485955495856495A564A\
5A584B5B574B5C584C5E584C5F574C5F574C5F574C5F574C5F574C5F574C5F574C
635B50635B50645C51645C51655D52665E53665E53666054666354656354666354656354666354\
656354666354656354666354666455686556686657696657676556676455656354
6C685C6A685C6A665B69675B6B675C6C6A5E6F6B606F6D61736F64706E626F6B606C6A5E6C685D\
6B695D6D695E6C6A5E64615869665D6D6A616C696068655C66635C6A67606F6C65
706D68726F6A75716E76726F757170706C6B6B676668646354504F6F6B6A959190B1ADACB6B2B1\
A8A4A3928E8D837F7E837F7E5955545753526F6B6A6561604F4B4A494544454142
514C504D484C5853576A6569696468645F637974789A96978985869C9899959192A5A1A2403C3D\
9A9697B6B2B3B3AFAEB6B2AFAEAAA7B3B0ABC3C0BB77746F75726D726F68706D64
73706773706773716573716573716473716473716473716571716971706B71706B71706B71706B\
71706B71706B71706B73726D73726D73726D73726D73726D73726D73726D73726D
504F4A3C3B3649484384837EC1C0BBDEDDD8EBEAE5F5F4EFFFFFFAFFFFFAFFFEF9F8F7F2F1F0EB\
EAE9E4E5E4DFE2E1DCB0AFAAB4B3AEB7B6B1B0AFAA9B9A957C7B765C5B56484742
21201B201F1A21201B2827223736314C4B4662615C6F6E697B7A757B7A757D7A757B7A757D7A75\
7B7A757D7A757B7A757B78737978737B78737978737B78737978737B7873797873
8A868386858184807F7E7D797B7776757470736F6E6F6E6A75717072716D726E6D6E6D696F6B6A\
6C6B676F6B6A6E6D696F6B686D6C686E6A676B6A666D69666A69656B6764696864
6B67646968646A666367666269656266656167636067636065615E65615E64605D635F5C635F5C\
625E5B615D5A615D5A5F5B585F5B585E5A575D59565D59565C58555B57545B5754
5E5A575D5A555C58555A575258545156534E55514E54514C54504D54514C534F4C53504B534F4C\
524F4A524E4B524F4A
544D43534F44554E445450455750465551465851475652475851475652475952485854495A5349\
59554A5C554B5C554B5C554B5C554B5D564C5E574D5E574D5F584E60594F60594F
60594F60594F615A50625B51625B51635C52645D53645D53625C50605C50635D51625E52645E52\
635F536660546460546862566662566963576864586A64586965596C665A6A665A
6C655B6A665B6C655B6A665B6C655B6A665B6C655B6A665B6E675D6C685D6E675D6C685D6E675D\
6C685D6E675D6C685F6C69626E6B646F6C656C696268655E6865606B68636E6B66
6A676273706B75726D726F6A76726F7A76736E6A675B575454504F716D6C969291ADA9A8B0ACAB\
A6A2A19B97969692917A76755854535C5857706C6B5D59584642414844434E4A4B
4341445250555351566F6D7269676A5452557D7B7C9796949E9D9B8584829A999587868253524D\
868580C4C3BE9D9C97B2AFA8B6B3AAB1AEA59B988F7D7A716C69606F6C6379776B
7371657371657371657371657371657371657371657171676F706A6E6F6A6E6F6A6F706B71726D\
73746F74757074757071726D797A7580817C81827D7879746C6D6861625D5C5C5A
474745575757777777A4A4A4D0D0D0EEEEEEF8F8F8F9F9F9FFFFFFFFFFFFFFFFFFFBFBFBF6F6F6\
EEEEEEE7E7E7E3E3E3CDCDCBC9C9C7C4C4C2C1C1BFB8B8B6A1A19F80807E676765
4242404444424949474F4F4D5555535B5B595F5F5D61615F5E5E5C61615F6665636A6A68706F6D\
7373717776747777757372707474727877757A7A787E7D7B7E7E7C7F7E7C7E7E7C
8B8A888282807674756B6B696866676B6B697371727878766F6D6E70706E7270716E6E6C6A6869\
6767656A68696B6B6974736F6D6E686968636869636C6B666D6E686B6A65666761
6D6C676B6C666B6A6568696365645F60615B5D5C575B5A5564605D6763606A66636C68656A6663\
65615E5F5B585B57545E5A575E5A575F5B585F5B585F5B58605C59605C59605C59
59565159564F58555057544D57544F56534C55524D55524B55524D54514A53504B524F48504D48\
4F4C454E4B464D4A43
544D43544D43544D43554E44564F455750465750465750465851475851475952485952485A5349\
5B544A5B544A5C554B5C554B5C554B5D564C5D564C5E574D5F584E5F584E60594F
60594F60594F615A50615A50625B51635C52635C52645D53625B51625B51635C52645D53645D53\
655E54665F55665F556861576861576962586A63596A63596B645A6C655B6C655B
6C655B6C655B6C655B6C655B6C655B6C655B6C655B6C655B6E675D6E675D6E675D6E675D6E675D\
6E675D6E675D6C685F6F6A646F6C676E6B6669666163605B5F5C57605D58625F5A
67645F6D6A656D6A656966616C696473706B6C69645E5B5655514E6B67668783829A96959E9A99\
9D99989C98979D999874706F514D4C54504F686463595554433F3E423E3D433F40
4846495654595654597371746F6D705957587877758988866968645A595567666162615C57574F\
919189BFBFB7A1A1979D9B8FA09E929C9A8E8B897D7674686B695D6E6C60767468
737165737165737165737165737165737165737165717167777873767875757774737572727471\
747673787A777B7D7A6E706D6B6D6A6365625B5D5A5759565B5D5A6668656F716E
A9ABAAB7B8BACCCDCFE1E2E4F1F2F4FAFBFDFEFFFFFEFFFFFBFCFEFDFEFFFEFFFFFEFFFFFEFFFF\
FEFFFFFBFCFEF9FAFCFEFFFFFEFFFFFDFFFEFEFFFFFEFFFFF4F6F5E2E4E3D3D5D4
E4E6E5E3E5E4DEE0DFD1D3D2BCBEBDA1A3A2888A89797B7A7272727272727171716E6E6E676767\
5D5D5D5353534D4D4D4848484E4E4E5858586565657171717B7B7B838383868686
7474747676767A7A7A7C7C7C7A7A7A7676767070706D6D6D6464646767676C6C6C717171767676\
7777777676767575736C6D686E6F696F706A6C6D67686963676862696A646C6D67
5C5D575E5F5962635D666761696A646B6C666C6D676C6D6764605D5F5B58585451534F4C54504D\
5A5653625E5B6864615F5B585F5B585F5B585F5B585F5B585E5A575E5A575E5B56
59565158554E58554E57544D56534C56534C55524B55524B55524B54514A535049524F48504D46\
4F4C454E4B444D4A43
524B41534C42534C42544D43554E44554E44564F45564F455750465851475851475952485A5349\
5A53495B544A5B544A5B544A5C554B5C554B5D564C5E574D5E574D5F584E5F584E
5F584E60594F60594F615A50625B51625B51635C52635C52625B51625B51635C52645D53645D53\
655E54665F55665F556861576861576962586A63596A63596B645A6C655B6C655B
6C655B6C655B6C655B6C655B6C655B6C655B6C655B6C655B6E675D6E675D6E675D6E675D6E675D\
6E675D6E675D6C685F6E69636E6B646E6B6469665F625F585D5A535C59525E5B54
615E57636059605D565A57505C5952605D565D5A5354514C48444154504D625E5B6B67646F6B68\
736F6C7A7673817D7A726E6B4F4B48534F4C6B676465615E55514E514D4A4B4746
5550545E595F5651556D686C6661654945465A56555D5958625E5B5E5A57514E4946433E57544D\
7E7B7488857C726F66848276838175807E7278766A706E626C6A5E6F6D61727064
72706472706472706472706472706472706472706470706663645E696B6670726D71736E6B6D68\
666863676964696B66737570686A655B5D58585A55696B6690928DBEC0BBDEE0DD
F1F3F2FCFDFFFEFFFFFEFFFFFEFFFFFAFBFDFBFCFEFEFFFFFAFBFDFCFDFFFEFFFFFEFFFFFEFFFF\
FEFFFFFEFFFFFEFFFFFEFFFFFCFEFDF8FAF9FBFDFCFEFFFFFEFFFFFEFFFFFAFCFB
F9FBFAFEFFFFFEFFFFFEFFFFFEFFFFFBFDFCF0F2F1E8EAE9DDDDDDDDDDDDDBDBDBD5D5D5C8C8C8\
B8B8B8A8A8A89E9E9E9E9E9E9696968888887474745D5D5D4848483636362D2D2D
3636364040404E4E4E5D5D5D6767676B6B6B6A6A6A6868688282827777776A6A6A656565686868\
6C6C6C6C6C6C6A6A686667626D6E6871726C6D6E6864655F60615B64655F6B6C66
72736D72736D70716B6C6D6768696362635D5E5F595B5C566C68656B67646A666366625F625E5B\
5D595658545156524F615D5A615D5A605C595F5B585E5A575C58555C58555B5853
58555058554E57544D57544D56534C55524B55524B54514A54514A535049524F48514E474F4C45\
4E4B444D4A434C4942
514A40514A40524B41524B41534C42544D43544D43554E44564F45575046575046585147595248\
5952485A53495A53495A53495B544A5B544A5C554B5D564C5D564C5E574D5E574D
5E574D5F584E5F584E60594F615A50615A50625B51625B51625B51625B51635C52645D53645D53\
655E54665F55665F556861576861576962586A63596A63596B645A6C655B6C655B
6C655B6C655B6C655B6C655B6C655B6C655B6C655B6C655B6E675D6E675D6E675D6E675D6E675D\
6E675D6E675D6C685D6B675E6C69626D6A636A676064615A605D565F5C55605D56
615E57615E57605D565C59525B58515B585158554E54514A5B58535F5B58625E5B635F5C635F5C\
66625F6D696674706D6C68654B4744504C496C68656E6A67676360625E5B575352
635E626863675954586C6869686465504C4B5D595858545176726F807D785E5B56423F3859564F\
615E554B483F413E357674687270646F6D616D6B5F6F6D61706E62706E626F6D61
716F63716F63716F63716F63716F63716F63716F636F6F656F706A7678737C7E7974767160625D\
4C4E493F413C3B3D38A7A9A4BDBFBADDDFDAF7F9F4FEFFFBFEFFFBFEFFFBF9FBF8
FAFCFBFEFFFFFEFFFFFEFFFFFBFCFEF8F9FBFAFBFDFDFEFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFF\
FEFFFFFDFEFFFCFDFFFEFFFFFCFEFDF8FAF9F9FBFAFEFFFFFEFFFFFEFFFFFEFFFF
F9FBFAF8FAF9F7F9F8F7F9F8F9FBFAFCFEFDFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FCFCFCF5F5F5F0F0F0F2F2F2F5F5F5F8F8F8FBFBFBFEFEFEFFFFFFFFFFFFFFFFFF
F9F9F9F2F2F2E6E6E6DADADACFCFCFC7C7C7C4C4C4C2C2C29090907070704545452626261D1D1D\
1F1F1F2222222323215C5D5860615B666761696A646B6C666E6F6972736D757670
5C5D575E5F5961625C64655F6667616768626768626768624C4845504C4956524F5B57545F5B58\
605C595F5B585E5A57625E5B625E5B605C595E5A575C58555B5754595552595651
57544F57544D56534C56534C55524B54514A54514A535049535049535049524F48504D464F4C45\
4D4A434C49424C4942
4F483E50493F50493F514A40524B41524B41534C42534C42564F45564F45575046575046585147\
5952485952485A53495A53495A53495B544A5B544A5C554B5D564C5D564C5E574D
5E574D5E574D5F584E5F584E60594F615A50615A50625B51625B51625B51635C52645D53645D53\
655E54665F55665F556861576861576962586A63596A63596B645A6C655B6C655B
6C655B6C655B6C655B6C655B6C655B6C655B6C655B6C655B6E675D6E675D6E675D6E675D6E675D\
6E675D6E675D6C685D6C685F6D6A616E6B626A675E625F565B584F58554C57544B
5E5B525F5C53625F5666635A66635A636057625F5664615A5D5A555F5B58605C59605C595F5B58\
615D5A64605D68646166625F4945424D494664605D65615E635F5C605C59514D4C
6A6667706B6F5F5A5E706C6D7470716965647E7A797874716B676486837E6966614F4C4567645D\
6461584B483F5452467472666F6D616C6A5E6D6B5F716F63737165716F636E6C60
716F63716F63716F63716F63716F63716F63716F636F6F6573746E73746F6E6F6A62635E53544F\
494A45474843494A45C9CAC5DBDCD7F4F5F0FFFFFBFFFFFBFFFFFBF8F9F4F2F2F0
FFFFFFFAFAFAF7F7F7FAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFCFCFC\
FAFAFAF9F9F9F9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFBFBFBF6F6F6F4F4F4F3F3F3F3F3F3F5F5F5F5F5F5F5F5F5F5F5F5F7F7F7\
F9F9F9FCFCFCFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDF9F9F9F7F7F7
FFFFFFFAFAFAE7E7E7D4D4D4C5C5C5BEBEBEBCBCBCBDBDBDB7B7B79696966969694949493D3D3D\
3D3D3D3F3F3F3F3F3D45464140413C3F403B494A455657525D5E5958595451524D
73746F72736E6F706B6B6C6766676260615C5B5C57585954706C696A6663615D5A5A5653585451\
5B5754605C5964605D615D5A615D5A5F5B585E5A575C58555A5653585451585550
57544F56534C56534C55524B54514A54514A535049535049524F48524F48514E474F4C454E4B44\
4C49424B48414B4841
4E473D4E473D4F483E4F483E50493F514A40514A40524B41554E44554E44564F45564F45575046\
5851475851475952485952485952485A53495A53495B544A5C554B5C554B5D564C
5D564C5D564C5E574D5E574D5F584E60594F60594F615A50625B51625B51635C52645D53645D53\
655E54665F55665F556861576861576962586A63596A63596B645A6C655B6C655B
6C655B6C655B6C655B6C655B6C655B6C655B6C655B6C655B6E675D6E675D6E675D6E675D6E675D\
6E675D6E675D6C685D6E6A616F6C636F6C6369665D5F5C535552494F4C434D4A41
504D444F4C435350475A574E5A574E58554C5D5A5167645B5956515A57525C58555F5C57625E5B\
65625D6763606966616C6865524F4A54504D625F5A5E5A575D5A555C58554F4B48
6561626E6A6B5A5456615D5C605A5A54504D6A6562615E595F5A567C79726F6A645F5C53757168\
716F63646055737165737165706E626F6D61706E62727064737165716F636F6D61
706E62706E62706E62706E62706E62706E62706E62706D646B6A656869636A696574756F8E8D89\
AFB0AAD2D1CDE5E6E0FFFEFAFCFDF7F9F8F4F2F3EDF0EFEBF3F4EEFDFCF8FFFFFB
FFFFFDFFFFFFFAF8F9FAFAFAFFFEFFFFFFFFFFFEFFFAFAFAFFFEFFFFFFFFFFFEFFFEFEFEFFFDFE\
FFFFFFFFFEFFFFFFFFF7F5F6F8F8F8FCFAFBFDFDFDFFFDFEFCFCFCFBF9FAF8F8F8
EFEDEEF4F4F4FEFCFDFFFFFFFFFEFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFCFCFC\
FEFEFEFFFFFFFFFFFFEDEDEDEFEFEFF3F3F3F7F7F7FBFBFBFDFDFDFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6EAEAEADADADAD0D0D0CECECE\
CECECECBCBCBC7C7C791918F82837E74757072736E7576716F706B5B5C57484944
2E2F2A32332E3A3B3643443F4C4D48545550595A555B5C57534F4C595552615D5A686461686461\
635F5C5C58555753505F5B585E5A575E5A575C58555B57545A5653595552595651
56534E55524B55524B54514A535049535049524F48524F48524F48514E47504D464F4C454D4A43\
4C49424B48414A4740
4D463C4D463C4D463C4E473D4F483E50493F50493F50493F544D43554E44554E44564F45575046\
5750465851475851475851475952485952485A53495B544A5B544A5C554B5C554B
5C554B5D564C5D564C5E574D5F584E5F584E60594F60594F625B51625B51635C52645D53645D53\
655E54665F55665F556861576861576962586A63596A63596B645A6C655B6C655B
6C655B6C655B6C655B6C655B6C655B6C655B6C655B6C655B6E675D6E675D6E675D6E675D6E675D\
6E675D6E675D6C685D6A665B6D6B5F706E626E6C60676559605E525C5A4E5A584C
59574B4F4D4149473B48463A4240343E3C3048463A59564D67645D65625B65625D66635C6A6762\
6E6B64706D68716E6765625D514E4755524D5E5B5456534E59564F615E59585550
5B55556A64645B52535C5656554C4D433E3B574F4D4A454169615E77726C736C666A665D766F67\
736F646E675D726E626C6A5E6E6C60706E62706E626F6D616E6C606E6C606F6D61
6F6D616F6D616F6D616F6D616F6D616F6D616F6D616F6C637E7B747A7A72817E7996968EBDBAB5\
E0E0D8FCF9F4FFFFF8F8F5F0FFFFF7FFFFFAFFFFF8FFFFFAFFFFF7F9F6F1F3F2ED
FFFEFDFFFFFDFFFCFBFDFCFAFFFBFAFCFBF9FCF8F7F8F7F5FFFEFDFFFFFDFFFDFCFEFDFBFFFDFC\
FFFFFDFFFEFDFFFFFDFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FCF8F9FDFBFCFFFEFFFFFEFFFFFEFFFFFEFFFCF8F9F6F4F5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFAFAFBFBFBFCFCFCFBFBFBF9F9F9F4F4F4EFEFEFECECECFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFDF8F8F6EBEBE9E4E4E2DEDEDCD1D1CFBDBDBBACACAA
A1A19F98989687878570706E5656543D3D3B2A2A281F1F1D34302D3D39364B4744585451615D5A\
64605D635F5C615D5A5C58555C58555C58555B57545B57545B57545B57545B5853
55524D55524B54514A54514A535049524F48524F48514E47514E47504D464F4C454E4B444C4942\
4B48414A474049463F
4C453B4C453B4D463C4D463C4E473D4F483E4F483E50493F544D43544D43554E44564F45564F45\
5750465851475851475851475851475952485A53495A53495B544A5C554B5C554B
5C554B5C554B5D564C5E574D5E574D5F584E60594F60594F625B51625B51635C52645D53645D53\
655E54665F55665F556861576861576962586A63596A63596B645A6C655B6C655B
6C655B6C655B6C655B6C655B6C655B6C655B6C655B6C655B6E675D6E675D6E675D6E675D6E675D\
6E675D6E675D6C685D6460556A685C727064757367747266727064727064737165
7A786C67655954524648463A39372B312F233E3C305351454B483F46433C403D363D3A333E3B34\
413E3743403944413A4C49423D3A3345423B4E4B4447443D504D46605D565D5852
544C4A6E6566685F60736B696F6765645C5979716E6F68626E67617069616D665E6C655B726B61\
756F63716B5F6B655965615669675B6E6C606E6C606B695D6A685C6C6A5E6F6D61
6F6D616F6D616F6D616F6D616F6D616F6D616F6D616F6D617370676B686164615A66635C68655E\
5E5B5447443D34312A47443D3B38312F2C2533302955524B939089D9D6CFFFFFF8
F7F3F0FEFAF7FFFEFDFFFEFBFDF9F8FBF7F4FFFCFBFFFEFBFFFEFDFFFEFBFFFDFCFEFAF7FDF9F8\
FEFAF7FFFCFBFFFDFCFFFEFFFFFEFFFFFEFFFFFCFDFDF9FAFEFAFBFFFEFFFFFEFF
FFFEFFFFFEFFFFFDFEFEFAFBFEFAFBFFFEFFFFFEFFFFFEFFFAF8F9FBFBFBFEFEFEFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFF5F5F5F7F7F7F9F9F9FBFBFBFDFDFDFDFDFDFDFDFDFCFCFC
FFFFFFFDFDFDFCFCFCFBFBFBFDFDFDFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFBFBFB\
F9F9F9FBFBFBFEFEFEF8F8F8FAFAF8FDFDFDFFFFFDFFFFFFFFFFFDFFFFFFFBFBF9
F9F9F9FAFAF8FCFCFCFDFDFBFEFEFEFEFEFCFDFDFDFCFCFAF8F4F1D6D2CFA29E9B706C69534F4C\
4D4946585451635F5C5A56535A56535A56535B57545B57545B57545C58555C5954
55524D55524B54514A535049535049524F48514E47514E47514E47504D464F4C454E4B444C4942\
4B48414A474049463F
4C453B4C453B4D463C4E473D4E473D4F483E50493F50493F524B41524B41534C42544D43544D43\
554E44564F45564F455851475851475952485A53495A53495B544A5C554B5C554B
5C554B5C554B5D564C5E574D5E574D5F584E60594F60594F625B51625B51635C52645D53645D53\
655E54665F55665F55645D53645D53655E54665F55665F55676056686157686157
6861576861576962586A63596A63596B645A6C655B6C655B6D665C6D665C6F685E70695F70695F\
6F685E6D665C6B675C6C685C6B695C6B695C6B695C6B695C6B695C6B695C6B695C
7573666361545654474D4B3E3836292624173533265553474441383E3B3236332A312E25312E25\
37342B3F3C334441383D3A31423F3648453C4C49404F4C435552495D5A51645F59
6B63616C62616D63626D63626E64636F65636F65637067626E65606E655E6F665D6F675C70685D\
71695C71695C716B5F6B675C6A685C6A685C6B695D6C6A5E6D6B5F6D6B5F6D6B5F
6B695D6B695D6C6A5E6D6B5F6D6B5F6E6C606F6D616F6D61757168726E656D696067635A5F5B52\
59554C545047514D443F3B323F3B323F3B324642395B574E817D74AEAAA1CCC7C1
C2BDB9CCC7C3DCD7D4ECE7E3F9F4F1FFFBF7FFFDFAFFFDF9FCF7F4FCF7F3FCF7F4FBF6F2FBF6F3\
FDF8F4FFFCF9FFFEFBFFFDFDFFFDFFFFFCFEFFFCFEFFFDFFFFFDFFFFF9FBFAF4F6
FFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFCF8F9FFFEFFFEFEFEFCFCFCFFFFFFFFFFFF\
FFFFFFFEFEFEFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFFFFFFFFF9F9FBF3F3F3FFFFFFFDFDFDEDEDEFFFFFFFF0ECEBC6C2BF8F8B886A66635E5A57\
5E5A575B575456524F59555259555258545157535057535056524F55514E55524D
59565159564F58554E56534C55524B535049524F48524F48504D464F4C454E4B444C49424A4740\
48453E47443D46433C
4C453B4C453B4D463C4D463C4E473D4F483E4F483E50493F524B41524B41534C42534C42544D43\
554E44554E44564F455851475851475952485952485A53495B544A5B544A5C554B
5C554B5C554B5D564C5D564C5E574D5F584E5F584E60594F625B51625B51635C52635C52645D53\
655E54655E54665F55645D53645D53655E54655E54665F55676056676056686157
6861576861576962586962586A63596B645A6B645A6C655B6C655B6D665C6E675D6F685E6F685E\
6E675D6D665C6A665B6C685C6B695C6B695C6B695C6B695C6B695C6B695C6B695C
6A685B59574A4D4B3E4846393533261E1C0F2220133735282624182320171F1C131E1B12221F16\
2C292036332A3D3A3146433A49463D4C49404E4B42504D4456534A5F5C5367635A
68605D695F5E695F5E6A605E6B615F6C635E6C635E6C635C6B625B6B62596C64596D65586D6558\
6E66596F675A6E685A69655968665A68665A69675B6A685C6B695D6B695D6B695D
6B695D6B695D6C6A5E6C6A5E6D6B5F6E6C606E6C606F6D61767269757168747067736F66726E65\
706C636F6B626F6B62726E65706C6368645B5B574E4D494045413844403747433A
4A453F55504C67625E7C77738F8A869E9995A6A19DAAA5A1D6D1CDEAE5E1FFFDF9FFFEFAFFFEFA\
FFFEFAFFFCF8FFFEFBFFFDFDFFFBFDFFFBFDFFFBFDFFFDFFFFFDFFFFFDFFFFFDFF
FFFDFFFFFBFDFCF6F8F8F2F4FAF4F6FFFAFCFFFDFFFFFEFFFFFEFFFFFFFFFEFEFEFFFFFFFFFFFF\
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
EFEFF1FFFFFFFFFFFFF2F2F4FFFFFFFFFFFFFFFFFFD3D3D384807F736F6C615D5A5A56535F5B58\
635F5C5F5B5859555259555259555258545157535057535056524F55514E55524D
58555057544D56534C54514A535049524F48504D46504D464F4C454E4B444D4A434C49424A4740\
48453E47443D46433C
4B443A4C453B4C453B4D463C4E473D4E473D4F483E4F483E514A40524B41524B41534C42544D43\
544D43554E44554E445750465851475851475952485A53495A53495B544A5B544A
5B544A5C554B5C554B5D564C5E574D5E574D5F584E5F584E615A50625B51625B51635C52645D53\
645D53655E54655E54635C52645D53645D53655E54665F55665F55676056676056
6760566861576861576962586A63596A63596B645A6B645A6B645A6C655B6D665C6E675D6E675D\
6D665C6C655B69655A6A665A696758696758696758696758696758696758696758
6B695A5D5B4C5553445755464D4B3C3836273230213A382B302E222E2C202C2A1E2D2B1F323024\
3B392D4442364A483C514F43514F43514F43504E42504E42565448615F536A665D
635957655A58655A58665B59675C5A675C58685D59685D57685E55685E54695F55695F536A6054\
6B62536B62536B635665615565635765635766645867655967655968665A68665A
6A685C6B695D6B695D6C6A5E6D6B5F6D6B5F6E6C606E6C606E6A5F70695F716A60736C62746D63\
766F657770667871676A6359716A607A73697D766C7B746A766F65736C62726B63
655E58645D57635C566059535B544E564F49514A444E4741544D475C554F625B55625B5568615B\
817A74ABA49ECCC4C1FFFCFDFFFCFFFFFCFFFFFCFFFFFBFEFFFBFEFFFCFFFFFCFF
F9F0F3FFFBFEFFFCFFFFFCFFFFFCFFFFFCFFFFFCFFFFFDFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
F5F4F9FFFEFFFFFEFFF7F6FBE1E0E5D8D7DCB5B4B97B7B7D56525155514E5753505B5754605C59\
605C595C585557535059555259555258545157535057535056524F55514E55524D
55524D54514A535049524F48504D464F4C454E4B444D4A434E4B444D4A434C49424B484149463F\
48453E47443D47443D
4A43394B443A4B443A4C453B4D463C4D463C4E473D4E473D50493F514A40514A40524B41534C42\
534C42544D43544D43564F455750465750465851475952485952485A53495A5349
5A53495B544A5B544A5C554B5D564C5D564C5E574D5E574D60594F615A50615A50625B51635C52\
635C52645D53645D53625B51635C52635C52645D53655E54655E54665F55665F55
665F556760566760566861576962586962586A63596A63596962586A63596B645A6C655B6C655B\
6B645A6A6359676357696657686657686657686657686657686657686657686657
6F6D5E6260515E5C4D6664556967585F5D4E585647595748585649555347525044504E42514F43\
54524658564A5B594D5755495654485351454F4D414E4C405452465F5D51686459
5D544F5F54525F545260555161565261565062575162584F63594F645A4E645A4E655C4D665D4E\
665D4E675E4F665E51635F53626054626054636155646256656357656357656357
69675B6A685C6A685C6B695D6C6A5E6C6A5E6D6B5F6E6A5F6F685E6F685E6E675D6E675D6D665C\
6D665C6C655B6C655B6D665C6F685E716A60746D63766F657A73697E776D817A70
8079717F78727C756F7A736D78716B77706A766F69766F69746D677E7771867F79847D7779726C\
726B65746D6779716E50474851484B4F4649473E413D3437372E31372E31393033
574E517F7679BCB3B6EFE6E9FFFAFDFFF9FCFFF8FBFFFDFFF8F6F7FFFFFFFFFFFFFFFFFFFDFDFD\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFF4F3F8FFFEFFF4F3F89493985251565150555353556A666568646165615E5F5B585A5653\
5854515A56535C585559555259555258545157535057535056524F55514E55524D
53504B524F48514E47504D464E4B444D4A434C49424B48414C49424C49424B48414A474049463F\
48453E47443D47443D
4A43394A43394B443A4B443A4C453B4D463C4D463C4E473D50493F50493F514A40514A40524B41\
534C42534C42544D43564F45564F455750465750465851475952485952485A5349
5A53495A53495B544A5B544A5C554B5D564C5D564C5E574D60594F60594F615A50615A50625B51\
635C52635C52645D53625B51625B51635C52635C52645D53655E54655E54665F55
665F55665F556760566760566861576962586962586A63596861576962586A63596B645A6B645A\
6A6359696258666256676455666553666553666553666553666553666553666553
6867555D5C4A5857455F5E4C6867556867556564526462536462556260535F5D505B594C59574A\
59574A59574A59574A565447555346514F424C4A3D4B493C504E415A584B635F54
594E4A5C4E4B5C4E4B5D4F4C5E504D5E514B5F524C5F524A62554C62564A63574B64584A64584A\
655949665A4A645B4C615D51605E52615F53615F53626054636155636155646256
69675B69675B6A685C6A685C6B695D6C6A5E6C6A5E6E6A5F777165776F64766E63746C61736B60\
71695E70685D70685D81796E7C7469756D6270685D6D655A6C64596B63586B6259
726962726962746B64776E677C736C827972887F788B827B837A73837A73847B748279727C736C\
706760605750554C47685E5F685D61655A5E5E5357554A4E4D4246493E42473C40
473C4063585C94898DBEB3B7CEC3C7D0C5C9DDD2D6EFE6E9E8E6E7FAFAFAFFFFFFFFFFFFFBFBFB\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FEFDFFF1F0F6F5F4FAC4C3C958575D2B2A304D4C5266656A605C5B605C595F5B585A565356524F\
5753505E5A5764605D59555259555258545157535057535056524F55514E55524D
524F4A524F48504D464F4C454E4B444C49424B48414A47404A47404A474049463F49463F48453E\
48453E47443D47443D
4942384942384A43394A43394B443A4C453B4C453B4D463C4F483E4F483E50493F50493F514A40\
524B41524B41534C42554E44554E44564F45564F45575046585147585147595248
5952485952485A53495A53495B544A5C554B5C554B5D564C5F584E5F584E60594F60594F615A50\
625B51625B51635C52615A50615A50625B51625B51635C52645D53645D53655E54
655E54655E54665F55665F55676056686157686157696258665F55676056686157696258696258\
686157676056646054666354656452656452656452656452656452656452656452
6665535E5D4B5857455958465E5D4B61604E5F5E4C5D5C4A59574A59574A59574A59574A585649\
575548575548565447525043525043504E414C4A3D4A483B4E4C3F5654475E5A4F
564B45584A47594B485A4D475A4D475B4E465C4F475C4F46605448615549615547625648635747\
63574764584862594A615D51605E52615F53615F53626054636155636155646256
68665A68665A69675B69675B6A685C6B695D6B695D6D695E706A5E726A5F726A5F736B60746C61\
756D62766E63766E63736B60746C61776F647D756A827A6F837B707F776C7B7368
7D746D7B726B776E67736A637067606E655E6D645D6C635C7B726B6F665F645B54665D56736A63\
837A738B827B8D847F786E6F776C70776C70796E727A6F73766B6F6E6367665B5F
6B6064594E52473C40392E32291E22261B1F42373B665D60D4D2D3F2F2F2FFFFFFFFFFFFFBFBFB\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FAF9FFFFFEFFDCDBE175747A343339504F55706F755D5C6154504F5955525E5A57615D5A5F5B58\
5C58555A56535A565359555259555258545157535057535056524F55514E55524D
53504B524F48514E47504D464E4B444D4A434C49424B484148453E48453E48453E48453E48453E\
48453E48453E48453E
4841374942384942384A43394B443A4B443A4C453B4C453B4E473D4F483E4F483E50493F514A40\
514A40524B41524B41544D43554E44554E44564F45575046575046585147585147
5851475952485952485A53495B544A5B544A5C554B5C554B5E574D5F584E5F584E60594F615A50\
615A50625B51625B5160594F615A50615A50625B51635C52635C52645D53645D53
645D53655E54655E54665F55676056676056686157686157655E54665F55676056686157686157\
676056665F55635F53646152636250636250636250636250636250636250636250
64635163625061604E5E5D4B5E5D4B5F5E4C5C5B4958574558564959574A5B594C5C5A4D5C5A4D\
5B594C59574A5856494F4D40504E41514F424F4D404D4B3E504E415654475C584D
544943574946574A44584B45594C46594C445A4D455A4D44605448605448615547625648625646\
63574764584862594A615D51615F53615F53626054636155636155646256646256
67655968665A68665A69675B6A685C6A685C6B695D6C685D6A64586B63586D655A6E665B70685D\
726A5F736B60746C61736B6071695E70685D726A5F746C6171695E68605561594E
6F665F716861746B64786F687C736C7F766F827972837A736E655E756C658077708A817A8B827B\
8178716F665F615853867C7D84797D867B7F92878B9E93979E939790858982777B
796E7252474B291E2210050907000008000133282C62595CC2C0C1E9E9E9FFFFFFFFFFFFFBFBFB\
FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FBFAFFFFFEFFC8C7CD4E4D533130366160666B6A704C4B50615D5C625E5B64605D65615E64605D\
5F5B58585451534F4C59555259555258545157535057535056524F55514E55524D
54514C535049524F48514E474F4C454E4B444D4A434C494247443D47443D47443D47443D47443D\
48453E48453E48453E
4841374841374942384A43394A43394B443A4C453B4C453B4E473D4E473D4F483E50493F50493F\
514A40524B41524B41544D43544D43554E44564F45564F45575046585147585147
5851475851475952485A53495A53495B544A5C554B5C554B5E574D5E574D5F584E60594F60594F\
615A50625B51625B5160594F60594F615A50625B51625B51635C52645D53645D53
645D53645D53655E54665F55665F55676056686157686157645D53655E54676056676056676056\
676056655E54625E52646152636250636250636250636250636250636250636250
5958465F5E4C62614F605F4D5E5D4B5E5D4B5A59475655435C5A4D5E5C4F5F5D505F5D505E5C4F\
5A584B5654475452454D4B3E504E41525043525043514F425250435755485C584D
544943564845574A44574A44584B43594C44594C435A4D44605448605448615547625648625646\
63574764584862594A625E52626054626054636155646256646256656357656357
67655967655968665A69675B69675B6A685C6B695D6C685D716B5F726A5F736B60736B60736B60\
736B60736B60746C617C7469746C616D655A6D655A746C617A72677C74697B7368
776E67786F687970697A716A797069786F68766D66746B647B726B7A716A766D667067606E655E\
756C65847B749087827A7071766B6F786D71887D819A8F939B9094887D8174696D
7A6F73554A4E31262A1F14181005090E03072B202452494CB7B5B6E3E3E3FFFFFFFFFFFFFCFCFC\
FFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
F6F5FBFFFEFFBEBDC359585E47464C57565C59585E605F64666261605C595955525854515B5754\
5F5B585F5B585D595659555259555258545157535057535056524F55514E55524D
55524D54514A535049524F48504D464F4C454E4B444D4A4346433C46433C46433C47443D47443D\
47443D48453E48453E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0085034 0.97619 0.348639 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00372024 0.0178571 0.00372024 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01786 translate
.95238 .71428 scale
768 string
256 192 8 [256 0 0 192 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
9899939A9B959D9E98A0A19BA2A39DA3A49EA4A59FA3A49EA6A7A1A7A8A2A8A9A3AAABA5ACADA7\
AEAFA9AFB0AAB0B1ABB0B1ABB1B2ACB2B3ADB4B5AFB6B7B1B8B9B3B9BAB4BABBB5
B5B6B0B6B7B1B7B8B2B8B9B3B9BAB4BBBCB6BBBCB6BDBCB7BBB8B3BDB8B4BEB9B5BFBAB6C1BCB8\
C2BDB9C3BEBAC4BFBBC3BEBAC4BFBBC5C0BCC7C2BEC9C4C0CBC6C2CCC7C3CCC9C2
C1C1B9C0C2B7C0C2B7C0C2B7BFC1B6BFC1B6BFC1B6BFC1B6C5C7BCC5C7BCC4C6BBC4C6BBC5C7BC\
C7C9BEC9CBC0CACCC1C4C6BBC4C6BBC5C7BCC7C9BEC8CABFCACCC1CBCDC2CBCDC2
C8CABFC8CABFC8CABFC7C9BEC7C9BEC6C8BDC5C7BCC5C7BCC5C8BDC6C9BEC7CABFC7CABFC7C9BE\
C5C7BCC6C3BAC5C2B9C4C0B7D8D4CBDDD6CE9E978F4A413A322922413831403732
38302D38302E38302E38302E38302E38302E38302E38302E3C34323C34323C34323C34323C3432\
3C34323C34323C34313C34313C352F3C352F3C352F3C352F3C352F3C352F3C352F
3C352F3C352F3C352F3C352F3C352F3C352F3C352F3C352F38312B38312B38312B38312B38312B\
38312B38312B38312B362F29362F29362F29362F29362F29362F29362F29362F29
362F29362F29362F29362F29362F29362F29362F29362F29342D27342D27332C26322B25322B25\
312A24302923302923322A28322A283129273028263028262F27252E26242E2624
3028263028263028263028263028263028263028262E29262C26282B27282B27282C28292C2829\
2C28292D292A2D292A242021242021231F20221E1F221E1F211D1E201C1D1E1C1D
1F1D221C1B201A191E18171C16151A16151A16151A16151A1514191413181211160F0E130D0C11\
0A090E08070C0607090E0F110C100F0E12110F13120F13120E12110C100F0C100F
0E12110D11100D11100C100F0A0E0D090D0C090D0C080C0B0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C\
0C0C0C0C0C0C0C0C0C0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E
0D0D0D0D0D0D0E0E0E0E0E0E0E0E0E0F0F0F0F0F0F0F0F0F0C0C0C1212121B1B1B232323262626\
2424242020201C1C1C
353630363731393A343B3C363C3D373D3E383D3E383C3D372C2D272D2E282E2F2930312B31322C\
33342E34352F35363044453F454640464741484943494A444B4C464C4D474D4E48
5758525859535A5B555D5E5860615B62635D64655F6665606D6A65706B67736E6A77726E7B7672\
7F7A76827D79837E7A8B86828B86828C87838E8985908B87918C88938E8A928F88
A9A9A1A9ABA0ACAEA3B0B2A7B5B7ACB9BBB0BCBEB3BDBFB4C2C4B9C3C5BAC3C5BAC5C7BCC7C9BE\
C9CBC0CCCEC3CDCFC4D3D5CAD3D5CAD4D6CBD5D7CCD6D8CDD8DACFDADCD1DADCD1
DFE1D6E0E2D7E1E3D8E2E4D9E3E5DAE3E5DAE3E5DAE3E5DAD5D8CDD6D9CED8DBD0D9DCD1DBDDD2\
DADCD1DCD9D0DBD8CFD2CEC5D3CFC6C4BDB5817A72352C25261D16382F28372E29
38302D38302E38302E38302E38302E38302E38302E38302E3C34323C34323C34323C34323C3432\
3C34323C34323C34313C34313C352F3C352F3C352F3C352F3C352F3C352F3C352F
3C352F3C352F3C352F3C352F3C352F3C352F3C352F3C352F38312B38312B38312B38312B38312B\
38312B38312B38312B362F29362F29362F29362F29362F29362F29362F29362F29
362F29362F29362F29362F29362F29362F29362F29362F29342D27342D27332C26332C26322B25\
312A24312A24302923322A28322A283129273129273028262F27252F27252E2624
3028263028263028263028263028263028263028262E29262C26282A2627292526282425272324\
262223262223252122252122252122242021242021231F20221E1F221E1F1F1D1E
211F241F1E231D1C211C1B201B1A1F1A191E1A191E1B1A1F1413181312171110150F0E130D0C11\
0A090E08070C07080A0D0E100C100F0D11100E12110E12110D11100C100F0B0F0E
1014130F13120F13120E12110D11100C100F0B0F0E0B0F0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E\
0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E
0B0B0B0B0B0B0B0B0B0C0C0C0C0C0C0D0D0D0D0D0D0E0E0E1414141818181D1D1D222222242424\
2121211E1E1E1B1B1B
21221C22231D24251F25262025262024251F23241E22231D1E1F191F201A20211B21221C22231D\
24251F2526202526202D2E282E2F292F302A30312B31322C33342E34352F34352F
3839333A3B353C3D3740413B44453F4748424A4B454C4B464E4B46514C48534E4A56514D5A5551\
5D5854605B57615C58625D59625D59635E5A645F5B66615D67625E68635F68655E
66665E67695E6B6D6270726775776C7A7C717E80758082778D8F848E908590928792948995978C\
97998E9A9C919B9D92A3A59AA3A59AA3A59AA4A69BA5A79CA7A99EAAACA1ABADA2
B0B2A7B1B3A8B3B5AAB6B8ADB7B9AEB7B9AEB7B9AEB7B9AEBBBEB3BDC0B5C0C3B8C3C6BBC6C8BD\
C7C9BECBC8BFCBC8BFD1CDC4C5C1B8B1AAA27C756D443B343C332C483F383D342F
372F2C372F2D372F2D372F2D372F2D372F2D372F2D372F2D3A32303A32303A32303A32303A3230\
3A32303A32303A322F3A322F3A332D3A332D3A332D3A332D3A332D3A332D3A332D
3A332D3A332D3A332D3A332D3A332D3A332D3A332D3A332D37302A37302A37302A37302A37302A\
37302A37302A37302A362F29362F29362F29362F29362F29362F29362F29362F29
362F29362F29362F29362F29362F29362F29362F29362F29352E28342D27342D27332C26322B25\
322B25312A24312A24332B29322A28322A283129273028263028262F27252F2725
3028263028263028263028263028263028263028262E29262C2628292526272324242021201C1D\
1D191A1B17181A16171F1B1C1F1B1C1E1A1B1D191A1D191A1C18191B1718191718
1B191E1A191E1A191E19181D19181D19181D18171C18171C131217121116100F140E0D120C0B10\
0A090E09080D07080A0C0D0F0B0F0E0C100F0D11100D11100C100F0B0F0E0A0E0D
1014131014131014130F13120E12110E12110D11100D1110101010101010101010101010101010\
1010101010101010100E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E
0C0C0C0D0D0D0D0D0D0E0E0E0F0F0F1010101010101111111C1C1C1D1D1D1E1E1E1F1F1F1F1F1F\
1E1E1E1C1C1C1A1A1A
22231D23241E24251F24251F23241E21221C1F201A1E1F19060701060701070802080903090A04\
0A0B050A0B050B0C06020300030400030400040500050600060701070802070802
0001000001000102000304000607010809030A0B050C0B060906010A05010A0501090400090400\
090400090400090400040000040000040000040000040000050000060100050200
010100010300010300020400040600050700050700060800000200000200010300030500050700\
060800060800060800060800050700040600040600060800090B000C0E030E1005
0B0D020C0E030E10051012071012070E10050C0E030A0C01080B000B0E030F120714170C191B10\
1C1E13211E15221F1619150C17130A251E16261F172017103027203C332C2C231E
362E2B362E2C362E2C362E2C362E2C362E2C362E2C362E2C39312F39312F39312F39312F39312F\
39312F39312F39312E39312E39322C39322C39322C39322C39322C39322C39322C
39322C39322C39322C39322C39322C39322C39322C39322C362F29362F29362F29362F29362F29\
362F29362F29362F29362F29362F29362F29362F29362F29362F29362F29362F29
362F29362F29362F29362F29362F29362F29362F29362F29362F29352E28352E28342D27332C26\
332C26322B25322B25342C2A332B29332B29322A28312927312927302826302826
3028263028263028263028263028263028263028262E29262C2628292526252122211D1E1C1819\
171314130F10110D0E130F10130F10120E0F120E0F110D0E100C0D100C0D0D0B0C
100E130F0E13100F14100F14100F14100F140F0E130E0D12111015100F140F0E130D0C110C0B10\
0A090E09080D07080A0A0B0D090D0C0A0E0D0B0F0E0B0F0E0A0E0D090D0C080C0B
0D11100D11100D11100D11100D11100C100F0C100F0C100F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F\
0F0F0F0F0F0F0F0F0F0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E
1010101111111212121313131414141616161616161717171D1D1D1C1C1C1B1B1B1A1A1A1A1A1A\
1B1B1B1C1C1C1D1D1D
191A151A1B161A1B161A1B1618191416171214151012130E161712161712171813171813181914\
181914191A15191A1513140F141510141510151611151611161712161712161712
13140F13140F13140F13140F14151014151014151015141018141117131017131015110E14100D\
130F0C120E0B120E0B0F0B080F0B080F0B08100C09100C09110D0A110D0A120F0A
17170F15160E15160E14150D12130B11120A11120A1011090F100810110912130B14150D14150D\
13140C12130B11120A0D0E060B0C04090A020809010A0B030D0E0612130B14150D
12130B13140C15160E14150D11120A0C0D05070800040500010400040700090C030F120916170F\
1A1B13201D16211E1718130D15100A29221C39322C3E35304C433E4E4540382F2A
362E2B362E2C362E2C362E2C362E2C362E2C362E2C362E2C372F2D372F2D372F2D372F2D372F2D\
372F2D372F2D372F2C372F2C37302A37302A37302A37302A37302A37302A37302A
37302A37302A37302A37302A37302A37302A37302A37302A362F29362F29362F29362F29362F29\
362F29362F29362F29362F29362F29362F29362F29362F29362F29362F29362F29
362F29362F29362F29362F29362F29362F29362F29362F29362F29362F29352E28352E28342D27\
332C26332C26322B25342C2A342C2A332B29332B29322A28312927312927302826
3028263028263028263028263028263028263028262E29262D27292A2627262223211D1E1B1718\
161213120E0F100C0D100C0D0F0B0C0F0B0C0E0A0B0D090A0D090A0C08090A0809
0B090E0B0A0F0D0C110D0C110D0C110B0A0F09080D07060B0F0E130E0D120D0C110C0B100B0A0F\
0A090E09080D07080A090A0C080C0B090D0C0A0E0D0A0E0D090D0C080C0B070B0A
090D0C090D0C090D0C090D0C090D0C0A0E0D0A0E0D0A0E0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D\
0D0D0D0D0D0D0D0D0D0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E
1010101111111212121313131515151717171818181919191A1A1A1919191818181818181A1A1A\
1C1C1C1F1F1F212121
21221D21221D22231E22231E21221D1F201B1C1D181B1C17070803070803070803070803070803\
070803070803070803090A05090A05090A05090A05090A05090A05090A05090A05
0D0E090D0E090C0D080B0C070B0C070A0B06090A05090A050807030B07040B07040C08050D0906\
0E0A070F0B080F0B080D09060D09060D09060D09060D09060D09060D09060B0A06
04050005060005060006070007080007080008090108090115160E1819111B1C141E1F171F2018\
1D1E161B1C14191A12191A1216170F13140C12130B13140C1819111D1E16202119
25261E27282028292127282022231B1B1C1414150D0F100812150C15180F1B1E1522251C292A22\
2E2F2734312A35322B49443E39342E3C352F3B342E2E25202E25202E25201B110F
352D2B352D2B352D2B352D2B352D2B352D2B352D2B352D2B362E2C362E2C362E2C362E2C362E2C\
362E2C362E2C362E2B362E2B362F29362F29362F29362F29362F29362F29362F29
362F29362F29362F29362F29362F29362F29362F29362F29352E28352E28352E28352E28352E28\
352E28352E28352E28362F29362F29362F29362F29362F29362F29362F29362F29
362F29362F29362F29362F29362F29362F29362F29362F2937302A37302A362F29362F29352E28\
342D27342D27332C26352D2B352D2B342C2A342C2A332B29322A28322A28312927
3028263028263028263028263028263028263028262E29262F292B2C2829292526242021201C1D\
1C1819181415161213181415171314171314161213151112151112141011121011
110F141211161312171413181211160F0E130B0A0F08070C0D0C110D0C110C0B100B0A0F0A090E\
0A090E09080D08090B07080A060A09070B0A080C0B080C0B070B0A060A09050908
060A09060A09060A09070B0A080C0B080C0B090D0C090D0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C\
0C0C0C0C0C0C0C0C0C0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E
0E0E0E0E0E0E1010101212121414141616161818181919191C1C1C1C1C1C1C1C1C1D1D1D1E1E1E\
212121242424252525
16161417171518181618181618181616161414141213131112121011110F11110F11110F11110F\
11110F11110F10100E12121012121012121012121012121011110F11110F11110F
1212101212101212101313111313111313111313111313110D0C0A0E0D0B0E0D0B0E0D0B0E0D0B\
0F0E0C0F0E0C0F0E0C0D0C0A0D0C0A0D0C0A0D0C0A0D0C0A0D0C0A0D0C0A0C0B07
0E0F090E0F090F100A11120C13140E14150F1617111617110E0F0912130D1819131E1F1921221C\
22231D20211B1F201A191A1416171112130D10110B11120C1617111C1D1720211B
22231D24251F26272126272122231D1B1C1613140E0F100A0104000407000A0D0610130C181913\
1C1D17221F1A24211C322D2927221E332B283A322F3329273B312F4A403E463C3A
342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A\
342C2A342C2A342C29342C29342D27342D27342D27342D27342D27342D27342D27
342D27342D27342D27342D27342D27342D27342D27342D27342D27342D27342D27342D27342D27\
342D27342D27342D27362F29362F29362F29362F29362F29362F29362F29362F29
362F29362F29362F29362F29362F29362F29362F29362F2938312B37302A37302A362F29352E28\
352E28342D27342D27362E2C352D2B352D2B342C2A332B29332B29322A28322A28
3028263028263028263028263028263028263028262E2926302A2C2E2A2B2C2829292526262223\
242021211D1E201C1D211D1E201C1D201C1D1F1B1C1E1A1B1E1A1B1D191A1B191A
18161B19181D1A191E1A191E17161B1211160C0B1008070C0C0B100B0A0F0B0A0F0B0A0F0A090E\
09080D09080D08090B060709050908060A09070B0A070B0A060A09050908040807
060A09070B0A070B0A080C0B090D0C0A0E0D0B0F0E0B0F0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E\
0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E
1313131414141616161818181B1B1B1D1D1D1F1F1F202020262626262626272727272727272727\
272727272727272727
1313131414121515151616141616161515131414141313110C0C0C0C0C0A0C0C0C0B0B090B0B0B\
0A0A080A0A0A0A0A080E0E0E0E0E0C0E0E0E0D0D0B0D0D0D0D0D0B0C0C0C0C0C0A
0D0D0D0E0E0C0F0F0F10100E1212121414121515151616141414141313111210110E0E0C0C0A0B\
0808060705060505030F0D0E0E0E0C0F0D0E0D0D0B0E0C0D0C0C0A0D0B0C0C0C0A
0D0E090D0E080D0E090D0E080E0F0A0E0F090E0F0A0E0F0911120D1617111F201B2728222D2E29\
30312B30312C2F302A1D1E191A1B1515161113140E1415101A1B1520211C24251F
191A151C1D171F201B21221C1F201B18191311120D0D0E080E100B12150E1719141E211A252621\
2A2B25302C29312E2937322F302B27403836463E3B3329282F2523382E2D332928
342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A\
342C2A342C2A342C29342C29342D27342D27342D27342D27342D27342D27342D27
342D27342D27342D27342D27342D27342D27342D27342D27342D27342D27342D27342D27342D27\
342D27342D27342D27362F29362F29362F29362F29362F29362F29362F29362F29
362F29362F29362F29362F29362F29362F29362F29362F2938312B38312B37302A362F29362F29\
352E28342D27342D27362E2C362E2C352D2B342C2A342C2A332B29322A28322A28
3028263028263028263028263028263028263028262E2926312B2D302C2D2E2A2B2D292A2B2728\
292526282425272324242021231F20231F20221E1F211D1E211D1E201C1D1E1C1D
1A181D1A191E1C1B201B1A1F17161B1110150A090E06050A0B0A0F0B0A0F0A090E0A090E0A090E\
09080D09080D08090B050608040807060A09060A09060A09060A09040807030706
080C0B090D0C090D0C0A0E0D0C100F0D11100D11100E1211101010101010101010101010101010\
1010101010101010100E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E
1C1C1C1D1D1D1F1F1F2222222424242727272929292A2A2A2F2F2F3030303030303030302E2E2E\
2B2B2B282828272727
0E0E100F0F0F0F0F111010101111131111111212141212120C0C0E0C0C0C0C0C0E0C0C0C0C0C0E\
0C0C0C0C0C0E0C0C0C0C0C0E0C0C0C0C0C0E0C0C0C0C0C0E0C0C0C0C0C0E0C0C0C
1010121010101010121010101010121010101010121010100E0E100D0F0E0E0E100D0F0E0E0E10\
0D0F0E0E0E100D0F0E0E0E100D0F0E0E0E100D0F0E0E0E100D0F0E0E0E100E0E0E
0E0E0C0E0F0A0E0E0C0E0F0A0E0E0C0E0F0A0E0E0C0E0F0A0D0D0B12130E1A1A182526212E2E2C\
30312C2B2B292526212424221F201B1A1A181A1B161C1C1A1F201B1F1F1D1E1F1A
1515131A1B1620201E23241F21211F191A1510100E090A050B0D0A10120D181A1721231E282826\
2A2B262E2A292D2926342E2E342F2C362D2E362E2C372D2E372D2C372D2E372D2C
342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A\
342C2A342C2A342C29342C29342D27342D27342D27342D27342D27342D27342D27
322B25322B25322B25322B25322B25322B25322B25322B25342D27342D27342D27342D27342D27\
342D27342D27342D2738312B38312B38312B38312B38312B38312B38312B38312B
362F29362F29362F29362F29362F29362F29362F29362F2938312B38312B37302A362F29362F29\
352E28342D27342D27362E2C362E2C352D2B342C2A342C2A332B29322A28322A28
322A283129273028262F27252E26242F27253028262E29262E282A2C28292C28292B27282A2627\
2A2627292526292526252122252122272324272324272324262223242021211F20
222025212025201F241E1D2219181D1312170D0C110A090E06050A0A090E100F14141318151419\
1211160D0C11090A0C060709040807050908050908050908060A09060A09060A09
040807050908060A09080C0B0A0E0D0C100F0D11100E1211131313131313121212121212121212\
1111111111111111110F0F0F0E0E0E0D0D0D0E0E0E1111111616161B1B1B1E1E1E
1D1D1D1E1E1E2121212525252A2A2A2E2E2E3131313232322828282A2A2A2C2C2C2E2E2E2F2F2F\
2E2E2E2C2C2C2B2B2B
0D0D0F0D0D0F0E0E100E0E100F0F111010121010121111130C0C0E0C0C0E0C0C0E0C0C0E0C0C0E\
0C0C0E0C0C0E0C0C0E0C0C0E0C0C0E0C0C0E0C0C0E0C0C0E0C0C0E0C0C0E0C0C0E
1010121010121010121010121010121010121010121010120D0E100D0E100D0E100D0E100D0E10\
0D0E100D0E100D0E100D0E100D0E100D0E100D0E100D0E100D0E100D0E100D0E10
0E0E0E0E0E0C0E0E0C0E0E0C0E0E0C0E0E0C0E0E0C0E0E0C11110F1616141F1F1D2A2A28343432\
3636343232302C2C2A2B2B292525231D1D1B1919171B1B191D1D1B1E1E1C1D1D1B
11110F1616141C1C1A20201E1E1E1C18181610100E0A0A080C0E0B111310191B18222421292927\
2B2B292F2B2A2E2A29312B2B312B2B332A2B332A2B342A2B342A2B342A2B342A2B
342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A\
342C2A342C2A342C29342C29342D27342D27342D27342D27342D27342D27342D27
322B25322B25322B25322B25322B25322B25322B25322B25342D27342D27342D27342D27342D27\
342D27342D27342D2738312B38312B38312B38312B38312B38312B38312B38312B
362F29362F29362F29362F29362F29362F29362F29362F2938312B38312B37302A362F29362F29\
352E28342D27342D27362E2C362E2C352D2B342C2A342C2A332B29322A28322A28
322A28312927302826302826302826302826312927302B28312B2D2F2B2C2F2B2C2E2A2B2D292A\
2D292A2C28292C2829252122262223262223252122242021231F20211D1E1E1C1D
1F1D221E1D221D1C211B1A1F17161B1110150C0B1009080D0F0E1312111618171C1C1B201D1C21\
1A191E16151A11121408090B060A09060A09060A09060A09070B0A070B0A070B0A
060A09070B0A080C0B0A0E0D0D11100F1312101413111514141414131313131313121212111111\
1111111212121212121111111111111111111212121616161B1B1B202020222222
2424242525252727272A2A2A2E2E2E3131313333333434343535353333333131312E2E2E2C2C2C\
2B2B2B2B2B2B2B2B2B
0A090E0B0A0F0B0A0F0C0B100D0C110D0C110E0D120E0D120C0B100C0B100C0B100C0B100C0B10\
0C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B10
0F0E130F0E130F0E130F0E130F0E130F0E130F0E130F0E130D0E120B0F120B0F120B0F120B0F12\
0B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120D0E10
0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E1010101515151F1F1F2B2B2B363636\
3939393535353030303030302727271B1B1B141414131313151515161616171717
0C0C0C1010101616161A1A1A1919191515150F0F0F0B0B0B0D0F0E1214131B1D1C2325242A2A2A\
2D2D2D302C2D2F2B2C2F292B2F292B31282B31282B32272B32272B32272B322829
342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A\
342C2A342C2A342C29342C29342D27342D27342D27342D27342D27342D27342D27
332C26332C26332C26332C26332C26332C26332C26332C26352E28352E28352E28352E28352E28\
352E28352E28352E2838312B38312B38312B38312B38312B38312B38312B38312B
362F29362F29362F29362F29362F29362F29362F29362F2938312B38312B37302A362F29362F29\
352E28342D27342D27362E2C362E2C352D2B342C2A342C2A332B29322A28322A28
312927312927312927312927312927322A28322A28302B28302A2C2E2A2B2E2A2B2D292A2C2829\
2C28292B27282B2728262223252122242021221E1F201C1D1E1A1B1D191A1A1819
1B191E19181D18171C16151A1312170E0D120A090E08070C0A090E0D0C1112111615141916151A\
141318100F140D0E10090A0C070B0A070B0A070B0A070B0A070B0A070B0A070B0A
070B0A080C0B0A0E0D0C100F0F1312111514131716141817141414141414121212111111111111\
1212121313131414141515151515151717171A1A1A1E1E1E2323232727272A2A2A
2D2D2D2E2E2E2F2F2F3030303232323333333434343535353A3A3A3737373232322E2E2E2C2C2C\
2C2C2C2D2D2D2E2E2E
08070C09080D09080D0A090E0B0A0F0B0A0F0C0B100C0B100C0B100C0B100C0B100C0B100C0B10\
0C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B100C0B10
0E0D120E0D120E0D120E0D120E0D120E0D120E0D120D0E120B0F120B0F120B0F120B0F120B0F12\
0B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F12
0D0E100E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0B0B0B0F0F0F1A1A1A272727323232\
3636363333332E2E2E3131312626261717170D0D0D0A0A0A0C0C0C0E0E0E0E0E0E
0808080B0B0B0F0F0F1313131414141212120F0F0F0D0D0D0E100F1315141B1D1C2426252B2B2B\
2D2D2D312D2E302C2D2F292B2F292B31282B31282B32272B32272B32272B32272B
342B2C342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A\
342C2A342C2A342C29342C29342D27342D27342D27342D27342D27342D27342D27
342D27342D27342D27342D27342D27342D27342D27342D27362F29362F29362F29362F29362F29\
362F29362F29362F2938312B38312B38312B38312B38312B38312B38312B38312B
362F29362F29362F29362F29362F29362F29362F29362F2938312B38312B37302A362F29362F29\
352E28342D27342D27362E2C362E2C352D2B342C2A342C2A332B29322A28322A28
302826302826312927322A28322A28322A283129272E29262B25272A2627292526282425282425\
272324262223262223252122231F20201C1D1D191A1B1718191516181415151314
1614191514191312171110150E0D120B0A0F09080D08070C04030806050A0A090E0D0C110E0D12\
0C0B100A090E07080A090A0C070B0A070B0A060A09060A09050908050908050908
060A09070B0A090D0C0B0F0E0E1211101413111514121615141414131313111111101010111111\
1414141717171919191A1A1A1C1C1C1E1E1E2222222727272B2B2B2F2F2F313131
3333333333333333333333333333333333333333333333333232323131313030302F2F2F2F2F2F\
2E2E2E2E2E2E2E2E2E
07060C08070D08070D09080E0A090F0A090F0B0A100B0A100C0B110C0B110C0B110C0B110C0B11\
0C0B110C0B110C0B110C0B110C0B110C0B110C0B110C0B110C0B110C0B110C0B11
0E0D130E0D130E0D130E0D130E0D130E0D130E0D130D0E130B0E130A0F130A0F130A0F130A0F13\
0A0F130A0F130A0F130A0F130A0F130A0F130A0F130A0F130A0F130A0F130B0F12
0D0E100E0E100E0E100E0E100E0E100E0E100E0E100E0E100A0A0C0F0F1119191B262628313133\
3535373232342D2D2F32323427272918181A0E0E100A0A0C0B0B0D0D0D0F0D0D0F
07070909090B0B0B0D0E0E100F0F110F0F110F0F110E0E100D0E101213151A1B1D2324262A2A2C\
2D2D2F302B2F2F2A2E312B2F312B2F332A2F332A2F34292F34292F34292F34292D
342B2C342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A\
342C2A342C2A342C29342C29342D27342D27342D27342D27342D27342D27342D27
342D27342D27342D27342D27342D27342D27342D27342D27362F29362F29362F29362F29362F29\
362F29362F29362F2938312B38312B38312B38312B38312B38312B38312B38312B
362F29362F29362F29362F29362F29362F29362F29362F2938312B38312B37302A362F29362F29\
352E28342D27342D27362E2C362E2C352D2B342C2A342C2A332B29322A28322A28
2F2725302826322A28322A283129272F27252D25232924212A2426282425282425272324262223\
262223252122252122221E1F201C1D1C1819181415151112141011141011121011
1311161110150F0E130D0C110B0A0F0A090E09080D08070C08070C0A090E0D0C110F0E13100F14\
0F0E130D0C110B0C0E0B0C0E090D0C080C0B070B0A060A09050908050908040807
060A09070B0A080C0B090D0C0A0E0D0C100F0D11100D11101111111010100F0F0F0F0F0F121212\
1717171C1C1C1F1F1F2121212323232626262A2A2A2E2E2E323232343434353535
3434343434343333333232323131313131313030303030302E2E2E3030303232323232322F2F2F\
2B2B2B262626232323
08070D08070D09080E09080E0A090F0B0A100B0A100C0B110C0B110C0B110C0B110C0B110C0B11\
0C0B110C0B110C0B110C0B110C0B110C0B110C0B110C0B110C0B110C0B110C0B11
0D0C120D0C120D0C120D0C120D0C120D0C120D0C120C0D120B0E130A0F130A0F130A0F130A0F13\
0A0F130A0F130A0F130A0F130A0F130A0F130A0F130A0F130A0F130A0F130B0F12
0D0E120E0E100E0E100E0E100E0E100E0E100E0E100E0E100E0E101313151C1C1E29292B333335\
3737393333352E2E303131332727291B1B1D121214101012111113111113111113
09090B09090B0A0A0C0B0B0D0C0C0E0D0D0F0E0E100F0F110B0C0E10111318191B21222428282A\
2A2A2C2E292D2D282C312B2F312B2F332A2F332A2F34292F34292F34292F34292D
342B2C342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A\
342C2A342C2A342C29342C29342D27342D27342D27342D27342D27342D27342D27
352E28352E28352E28352E28352E28352E28352E28352E2837302A37302A37302A37302A37302A\
37302A37302A37302A38312B38312B38312B38312B38312B38312B38312B38312B
362F29362F29362F29362F29362F29362F29362F29362F2938312B38312B37302A362F29362F29\
352E28342D27342D27362E2C362E2C352D2B342C2A342C2A332B29322A28322A28
2F27253028263129273129272F27252B2321261E1C211C19292325272324272324262223252122\
2521222420212420211E1A1B1B1718171314130F10110D0E110D0E120E0F110F10
110F140E0D120C0B100A090E09080D09080D0A090E0B0A0F0A090E0B0A0F0D0C110F0E130F0E13\
0F0E130F0E130D0E101112140E12110D11100C100F0B0F0E090D0C080C0B080C0B
090D0C090D0C090D0C090D0C090D0C080C0B080C0B080C0B0D0D0D0C0C0C0C0C0C0E0E0E131313\
1A1A1A2222222727272727272A2A2A2D2D2D313131343434353535363636363636
3333333333333232323131313030302F2F2F2F2F2F2E2E2E3333333333333333333131312C2C2C\
2727272121211E1E1E
09080E0A090F0A090F0B0A100C0B110C0B110D0C120D0C120C0B110C0B110C0B110C0B110C0B11\
0C0B110C0B110C0B110C0B110C0B110C0B110C0B110C0B110C0B110C0B110C0B11
0C0B110C0B110C0B110C0B110C0B110C0B110C0B110B0C110B0E130A0F130A0F130A0F130A0F13\
0A0F130A0F130A0F130A0F130A0F130A0F130A0F130A0F130A0F130A0F130B0F12
0D0E120E0E100E0E100E0E100E0E100E0E100E0E100E0E100E0E101212141B1B1D272729303032\
3333352E2E3029292B2626281F1F211616181111131010121111131010120F0F11
0D0D0F0C0C0E0A0A0C09090B0A0A0C0B0B0D0E0E100F0F1108090B0D0E101617191E1F21252527\
28282A2B262A2B262A2F292D2F292D31282D31282D32272D32272D32272D32272B
342B2C342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A\
342C2A342C2A342C29342C29342D27342D27342D27342D27342D27342D27342D27
362F29362F29362F29362F29362F29362F29362F29362F2938312B38312B38312B38312B38312B\
38312B38312B38312B38312B38312B38312B38312B38312B38312B38312B38312B
362F29362F29362F29362F29362F29362F29362F29362F2938312B38312B37302A362F29362F29\
352E28342D27342D27362E2C362E2C352D2B342C2A342C2A332B29322A28322A28
2F27253028263129273028262C2422261E1C1F1715191411201A1C1F1B1C1E1A1B1D191A1D191A\
1C18191B17181B1718191516161213120E0F0E0A0B0D090A0F0B0C120E0F121011
100E130D0C110B0A0F09080D09080D0A090E0C0B100E0D12111015111015121116131217141318\
1514191514191415171A1B1D171B1A161A191418171317161115141014130F1312
0F13120E12110D11100B0F0E0A0E0D080C0B070B0A060A090909090808080909090C0C0C131313\
1E1E1E2828282E2E2E2D2D2D2F2F2F323232353535373737373737353535343434
3434343434343333333232323232323131313131313030303434343131312D2D2D292929282828\
2B2B2B2E2E2E313131
0A090E0A0B0F0B0A0F0B0C100D0C110C0D110E0D120D0E120C0B100B0C100C0B100B0C100C0B10\
0B0C100C0B100B0C100C0B100B0C100C0B100B0C100C0B100B0C100C0B100B0C10
0C0B100B0C100C0B100B0C100C0B100B0C100C0B100B0C100B0E130A0F130A0F130A0F130A0F13\
0A0F130A0F130A0F130A0F130A0F130A0F130A0F130A0F130A0F130A0F130B0F12
0D0E100D0E100E0E100D0E100E0E100D0E100E0E100D0E1009090B0C0D0F1616182021232A2A2C\
2B2C2E27272921212319191B1414160D0D0F0A0A0C0B0B0D0B0B0D0A0A0C08080A
0F0F110D0D0F0B0B0D09090B09090B0B0B0D0D0D0F0F0F110608070C0E0D1416151C1E1D242424\
2626262A26272925262C26282C26282E25282E25282F24282F24282F24282F2428
342B2C342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A342C2A\
342C2A342C2A342C2A342C29342D27342C29342D27342C29342D27342C29342D27
362E2B362F29362E2B362F29362E2B362F29362E2B362F2938302D38312B38302D38312B38302D\
38312B38302D38312B38302D38312B38302D38312B38302D38312B38302D38312B
362E2B362F29362E2B362F29362E2B362F29362E2B362F2938302D38312B372F2C362F29362E2B\
352E28342C29342C29362E2C362E2C352C2D342C2A342B2C332B2932292A322A28
2F26273028263128292F27252A2122221A181B1213160D0E141011110F10130E12100E0F110C10\
0F0D0E100B0F0E0C0D161115110F100F0A0E0A08090C070B0C0A0B120D11131114
0F0F110D0D0F0B0A0F09090B09080D0B0B0D0D0C110F0F11222126222224222126232325242328\
2525272524292525272123222022211F21201D1F1E1B1D1C171B1A161A19151918
1418171317161115140E12130C1011090D0E070B0C060A0B0506080606060707090B0B0B141416\
2020202C2C2E3333332F2F3132323235353737373738383A373737353537333333
3634373834353733343733343733343432333432333433312F2E2C2A292724232121221D272622\
33342F41423D4B4C47
0B0C0E070B0C07080A070B0C0D0E100D11120D0E10090D0E0B0C0E090D0E0B0C0E090D0E0B0C0E\
090D0E0B0C0E090D0E0B0C0E090D0E0B0C0E090D0E0B0C0E090D0E0B0C0E090D0E
0B0C0E090D0E0B0C0E090D0E0B0C0E090D0E0B0C0E090D0E090D10090D10090D10090D10090D10\
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10
090D0E090D0C0B0D0C090D0C0B0D0C090D0C0B0D0C090D0C0B0D0C1014131B1D1C1D21201D1F1E\
181C1B181A191719180C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C
0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C090B080E100D1517141B1D1A21211F\
222220231F1E221E1D2822222822222B22232D24252F2526312728322829322829
2E26242E26242E26242F2725302826312927312927312927302826302826302826312927322A28\
332B29332B29332B29332B29332B28332B29332B28332B29332B28332B29332B28
38302E38302D38302E38302D38302E38302D38302E38302D38302E38302D38302E38302D38302E\
38302D38302E38302D362E2C362E2B362E2C362E2B362E2C362E2B362E2C362E2B
362E2C362E2B362E2C362E2B362E2C362E2B362E2C362E2B372F2D362E2B342C2A322A27312927\
322A27332B29332B29372D2E372D2E362B2F352B2C352A2E342A2B33282C33292A
382D31342A2B3025292D23242C2125271D1E2015191A1114130E120F0F11100E130E0E100E0C11\
0C0C0E0D0B100B0B0D0F0D120E0E100F0D120E0E100F0D120E0E100F0D120E0E10
1111131010101010120F0F0F0D0D0F0C0C0C0B0B0D0B0B0B19191B1C1C1C212123252525262628\
2424242121231F1F1F20202020201E1F1F1D1E1E1C1E1E1E1C1E1D1B1C1E1B1C1E
191A1C17181A1216170F13160B1013090E11090E110A0E110C0D110F10120C0D1107080A0E0F13\
2021232D2E322F3032393A3E3B3C3E3A3B3F3637393031352D2E30303135363437
362C34382D333A2F353C31373C31353A3134382F30372F2D2C27232B26222C29222F2F253B392D\
46463A5353475B5B4F
090D0C070B0A050908070B0A0B0F0E0D11100B0F0E090D0C090D0C090D0C090D0C090D0C090D0C\
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D10090D10090D10090D10090D10\
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D0E
090D0E090D0C090D0C090D0C090D0C090D0C090D0C090D0C070B0A0E1211151918181C1B161A19\
1216150F13120F13120C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C
0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0A090B080E100B1517121D1F1A23241F\
24252027232026221F2823202924212C24222D2523302625312726322827332928
302826302826302826312927322A28332B29332B29332B29322A28322A28332B29332B29342C2A\
352D2B352D2B362E2C362E2C362E2C362E2C362E2C362E2C362E2C362E2C362E2C
38302E38302E38302E38302E38302E38302E38302E38302E38302E38302E38302E38302E38302E\
38302E38302E38302E362E2C362E2C362E2C362E2C362E2C362E2C362E2C362E2C
362E2C362E2C362E2C362E2C362E2C362E2C362E2C362E2C39312F39312F38302E372F2D362E2C\
362E2C362E2C362E2C352A2E352A2E34292D33282C33282C32272B31262A31262A
34292D31262A2E23272D22262E23272B2024251A1E1F16191E1C211B1A1F19181D16151A131217\
100F140E0D120D0C110E0D120E0D120E0D120E0D120E0D120E0D120E0D120E0E10
1010121010101010100F0F0F0E0E0E0D0D0D0C0C0C0B0B0B1515151818181D1D1D212121232323\
2222221F1F1F1E1E1E21201E201F1D201F1D1F1E1C1D1D1D1D1D1D1B1C1E1B1C1E
1B1C1E191A1C14181B1115180F12170C11150C11150D111407080A0C0C0E0B0B0D08080A121214\
2727293737393A3A3C3D3D3F3E3E403D3D3F3B3B3D39393B38383A39393B3D383C
3C31393F30374031383E2F34372B2F312527291F1E251B19463F394E4A415E5A4F6C6A5E767467\
7A7869767767747565
090D0C070B0A050908070B0A0B0F0E0D11100B0F0E090D0C090D0C090D0C090D0C090D0C090D0C\
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D10090D10090D10090D10090D10\
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D0E
090D0E090D0C090D0C090D0C090D0C090D0C090D0C090D0C060A090C100F1216151317160F1312\
0A0E0D080C0B080C0B0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C
0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0A090B080E100B1719141F211C262722\
2829242B27242A26232A25222B26232E2624302826322827332928352B2A352B2A
332B29332B29342C2A342C2A352D2B362E2C362E2C372F2D352D2B362E2C362E2C372F2D38302E\
38302E39312F39312F39312F39312F39312F39312F39312F39312F39312F39312F
3A32303A32303A32303A32303A32303A32303A32303A323039312F39312F39312F39312F39312F\
39312F39312F39312F372F2D372F2D372F2D372F2D372F2D372F2D372F2D372F2D
362E2C362E2C362E2C362E2C362E2C362E2C362E2C362E2C38302E38302E39312F39312F38302E\
372F2D352D2B342C2A34292D33282C33282C32272B31262A31262A302529302529
31262A2F24282D22262E23273025292F24282A1F23251C1F2A282D27262B2322271E1D2219181D\
1514191110150F0E130E0D120E0D120E0D120E0D120E0D120E0D120E0D120E0E10
0F0F111010101010101111111010100E0E0E0D0D0D0C0C0C0E0E0E1111111616161B1B1B1D1D1D\
1E1E1E1D1D1D1C1C1C201F1D201F1D1E1E1E1E1E1E1D1D1D1C1C1C1C1C1C1B1B1B
1D1E201B1C1E18191B1317181115181014170F13161213150808080D0C0A0C0B090B0A08161513\
2C2B293C3B39403F3D403F3D3D3C3A3B3A383C3B393E3D3B3E3D3B3C3B393D3739
3F32393F30373D2E353C2D323C30343F3335433938463C3A4F484257534A67635873716579776A\
7674676C6D5D666757
090D0C070B0A050908070B0A0B0F0E0D11100B0F0E090D0C090D0C090D0C090D0C090D0C090D0C\
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D10090D10090D10090D10090D10\
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D0E
090D0E090D0C090D0C090D0C090D0C090D0C090D0C090D0C080C0B0D11101115141014130C100F\
070B0A0408070408070C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C
0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0A0A0C090F110C181A1521231E282924\
2B2C272F2B282E2A272F2A27302B28332B29342C2A372D2C382E2D392F2E3A302F
362E2C362E2C362E2C372F2D38302E39312F39312F39312F39312F39312F3A32303B33313B3331\
3C34323D35333D35333D35333D35333D35333D35333D35333D35333D35333D3533
3B33313B33313B33313B33313B33313B33313B33313B33313A32303A32303A32303A32303A3230\
3A32303A32303A323038302E38302E38302E38302E38302E38302E38302E38302E
362E2C362E2C362E2C362E2C362E2C362E2C362E2C362E2C342C2A352D2B362E2C372F2D362E2C\
342C2A322A28302826352A2E34292D34292D33282C32272B32272B31262A31262A
32272B3025292E23272F24283025292F24282A1F23251C1F28262B26252A2221261E1D2219181D\
151419121116100F140E0D120E0D120E0D120E0D120E0D120E0D120E0D120E0E10
0E0E100F0F0F1111111212121212121010100E0E0E0C0C0C0909090C0C0C101010151515181818\
1A1A1A1B1B1B1B1B1B1F1E1C1F1E1C1D1D1D1D1D1D1C1C1C1B1B1B1B1B1B1A1A1A
1A1B1D191A1C1617191415171213151112141112141313130E0A07130E0A130E0A110C081B1612\
2F2A263E3935403B37423D393E39353A35313B36323E39353F3A363C37333A3230
35292B36272C37282D3E2F324A3E405F53537268667E75707B746C78746B777368757367737164\
716F626E6F5F6E6F5F
090D0C070B0A050908070B0A0B0F0E0D11100B0F0E090D0C090D0C090D0C090D0C090D0C090D0C\
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D10090D10090D10090D10090D10\
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D0E
090D0E090D0C090D0C090D0C090D0C090D0C090D0C090D0C0C100F0F13121216151115140B0F0E\
070B0A050908060A090C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C
0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0A0A0C0910120D181A1521231E292A25\
2C2D282F2B282F2B28332E2B332E2B362E2C38302E3A302F3C32313D33323D3332
372F2D38302E38302E39312F3A32303A32303B33313B33313C34323C34323C34323D35333E3634\
3F37353F37353F3735403836403836403836403836403836403836403836403836
3D35333D35333D35333D35333D35333D35333D35333D35333A32303A32303A32303A32303A3230\
3A32303A32303A323038302E38302E38302E38302E38302E38302E38302E38302E
362E2C362E2C362E2C362E2C362E2C362E2C362E2C362E2C352D2B362E2C362E2C362E2C352D2B\
342C2A322A28312927352C2F342B2E342B2E332A2D32292C32292C31282B31282B
342B2E31282B2E25282D24272E25282B2225251C1F1E181A1C1A1F1A191E19181D17161B141318\
121116111015100F140E0D120E0D120E0D120E0D120E0D120E0D120E0D120E0E10
0C0C0E0E0E0E1212121414141414141212120F0F0F0D0D0D0909090B0B0B0E0E0E121212151515\
1818181A1A1A1A1A1A1E1E1E1D1D1D1D1D1D1C1C1C1B1B1B1B1B1B1A1A1A1A1A1A
18181816161614141412121210101010101011111112110D0E0701160D041A11081B1209261D14\
382F26443B32453C33483F36443B3240372E3E352C3F362D41382F41382F413831
3E30304334374C3D40594B4B6559597267657B716F807772867F777F7B72787469706E626C6A5D\
6C6A5D6C6D5F6E6F61
090D0C070B0A050908070B0A0B0F0E0D11100B0F0E090D0C090D0C090D0C090D0C090D0C090D0C\
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D10090D10090D10090D10090D10\
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D0E
090D0E090D0C090D0C090D0C090D0C090D0C090D0C090D0C0D11101014131216151014130B0F0E\
070B0A070B0A080C0B0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C
0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0A0C0E0B11130E191B1621231E282924\
2A2B262D29262D2926322D2A322D2A352D2B372F2D392F2E3B31303C32313C3231
372F2D38302E38302E39312F3A32303A32303B33313B33313D35333D35333D35333E36343F3735\
403836403836403836403836403836403836403836403836403836403836403836
3E36343E36343E36343E36343E36343E36343E36343E36343B33313B33313B33313B33313B3331\
3B33313B33313B333139312F39312F39312F39312F39312F39312F39312F39312F
362E2C362E2C362E2C362E2C362E2C362E2C362E2C362E2C39312F372F2D352D2B332B29332B29\
332B29342C2A352D2B332A2D332A2D32292C31282B31282B30272A2F26292F2629
332A2D2F26292C23262B22252B2225292023231A1D1C1618121015111015111015100F14100F14\
0F0E130F0E130F0E130E0D120E0D120E0D120E0D120E0D120E0D120E0D120E0E10
0A0A0C0E0E0E1212121616161717171414141010100E0E0E0D0D0D0E0E0E101010121212151515\
1818181A1A1A1B1B1B1D1D1D1C1C1C1C1C1C1B1B1B1A1A1A1A1A1A191919191919
15151515141213121011100E100F0D130F0C130F0C15100C0F05001C100425190D2A1E1235291D\
463A2E4D41354C40344B3F334B3F33493D3145392D43372B473B2F504438584B42
6658556F61607B6D6C847675817674776C68685F5A5E554E635C54635F56666257676559666457\
6260535C5D4F595A4C
090D0C070B0A050908070B0A0B0F0E0D11100B0F0E090D0C090D0C090D0C090D0C090D0C090D0C\
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D10090D10090D10090D10090D10\
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D0E
090D0E090D0C090D0C090D0C090D0C090D0C090D0C090D0C0B0F0E0E12111014130E1211090D0C\
070B0A070B0A0A0E0D0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C
0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0A0D0F0C11130E191B1620221D262722\
2829242A26232925222D28252D2825302826322A28342A29362C2B372D2C372D2C
372F2D372F2D38302E38302E39312F3A32303A32303B33313C34323D35333D35333E36343F3735\
3F3735403836403836403836403836403836403836403836403836403836403836
4038364038364038364038364038364038364038364038363C34323C34323C34323C34323C3432\
3C34323C34323C34323A32303A32303A32303A32303A32303A32303A32303A3230
362E2C362E2C362E2C362E2C362E2C362E2C362E2C362E2C352D2B322A282C242228201E271F1D\
2A22202E26243129272C26282C26282B25272A24262A2426292325282224282224
2A2426282224251F21262022282224262022221C1E1C1819121015100F14100F14100F140F0E13\
0F0E130E0D120E0D120E0D120E0D120E0D120E0D120E0D120E0D120E0D120E0E10
09090B0D0D0D1313131717171818181616161111110E0E0E131313131313131313141414161616\
1818181B1B1B1C1C1C1B1C1E1B1C1E1B1B1B1B1B1B1A1A1A1919191A1917191816
18171518141117131015110E15110E16110D17120E1B120B23150A3121123B2B1C3F2F20453526\
4E3E2F4E3E2F4737284434254838294A3A2B4535264131224A3A2B5F4F406F6154
83746D847673847673817370776C686B605A5D544D554C43665F5569655A706C61747266757366\
706E6168695B636456
090D0C070B0A050908070B0A0B0F0E0D11100B0F0E090D0C090D0C090D0C090D0C090D0C090D0C\
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D10090D10090D10090D10090D10\
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D0E
090D0E090D0C090D0C090D0C090D0C090D0C090D0C090D0C080C0B0B0F0E0D11100B0F0E070B0A\
050908070B0A090D0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C
0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0A0D0F0C12140F191B1620221D252621\
26272228242126221F2823202823202B23212D25232F2524312726322827322827
362E2C362E2C372F2D372F2D38302E39312F39312F3A32303C34323C34323D35333E36343E3634\
3F3735403836403836403836403836403836403836403836403836403836403836
4038364038364038364038364038364038364038364038363C34323C34323C34323C34323C3432\
3C34323C34323C34323A32303A32303A32303A32303A32303A32303A32303A3230
362E2C362E2C362E2C362E2C362E2C362E2C362E2C362E2C2D252328201E2119171B13111A1210\
1E1614251D1B29211F272123272123272123262022251F21241E20241E20241E20
241E20221C1E211B1D241E20272123272123241E201F1B1C161419141318131217121116111015\
100F140F0E130E0D120E0D120E0D120E0D120E0D120E0D120E0D120E0D120E0E10
09090B0D0D0D1313131818181919191616161212120F0F0F171717171717161616161616171717\
1919191B1B1B1D1D1D1B1C1E1B1C1E1B1B1B1A1A1A1A1A1A1919191918161B1714
1C18151C17131A15111B140E1A130D1B140E1D140F1F150B3A2A1B4736244F3E2C4E3D2B4E3D2B\
4E3D2B4534223A2917372614402F1D453422402F1D3B2A184736246453417D6D5E
7C6E6571645C62554D5548404F453C5349405B52496259506C655B6A665B6A665B69675B676558\
656356616254606153
080C0B040807060A090D11100C100F040807030706090D0C090D0C090D0C090D0C090D0C090D0C\
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D10090D10090D10090D10090D10\
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D0E
090D0E090D0C090D0C090D0C090D0C090D0C090D0C090D0C0B0F0E121615101413050908000302\
0307060509080206050C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C
0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0C1113101416111719141A1C171D1E19\
1C1D181D19161C1815241F1C25201D28201E29211F2C22212D23222E24232F2524
2F2725302826312927332B29352D2B372F2D38302E39312F3A32303A32303B33313B33313C3432\
3D35333D35333E3634403836403836403836403836403836403836403836403836
3E36343E36343E36343E36343E36343E36343E36343E36343E36343E36343D35333C34323C3432\
3B33313A32303A32303A32303A32303A32303A32303A32303A32303A32303A3230
38302E38302E372F2D362E2C362E2C352D2B342C2A342C2A2F2725241C1A160E0C100806160E0C\
2119172C24223129272822242824252A26272B27282A2627272324231F20211D1E
201C1D211D1E221E1F211D1E1E1A1B1C18191D191A1F1B1C1513181312171211161110150F0E13\
0E0D120D0C110C0B100E0D120E0D120E0D120E0D120E0D120E0D120E0D120E0E10
0F0F110909090C0C0C1818181C1C1C1616161111111212121515151616161919191B1B1B1C1C1C\
1C1C1C1B1B1B1B1B1B1B1C1E1A1B1D191A1C18191B171717161616161513171310
1914101E17111F18121E150E1C130C1E150C271D143125194D3C2C4D3B274C3A264A3824483622\
46342045331F44321E45331F42301C402E1A412F1B463420513F2B5C4A3662513F
6A5C4F675A5165584F62554C5C5248594F45554D42544C415B5549696559706C616563575D5B4F\
615F535F5F5359594D
0B0F0E060A09070B0A1115141418170F13120D1110111514090D0C090D0C090D0C090D0C090D0C\
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D10090D10090D10090D10090D10\
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D0E
090D0E090D0C090D0C090D0C090D0C090D0C090D0C090D0C1115141A1E1D1B1F1E1115140B0F0E\
0C100F0A0E0D050908060606060606060606060606060606060606060606060606
0909090909090909090909090909090909090909090909070B0D0A0E100B131510181A151C1D18\
1E1F1A211D1A211D1A211C19221D1A251D1B271F1D2A201F2C22212D23222E2423
302826302826322A28332B29352D2B372F2D38302E38302E3B33313B33313C34323C34323D3533\
3E36343E36343F3735403836403836403836403836403836403836403836403836
3E36343E36343E36343E36343E36343E36343E36343E36343E36343E36343D35333D35333C3432\
3B33313B33313A32303A32303A32303A32303A32303A32303A32303A32303A3230
38302E38302E372F2D372F2D362E2C352D2B352D2B342C2A352D2B30282629211F251D1B271F1D\
2B23212F2725302B282824252725262B27282A28292C2829282627272324232122
211D1E1F1D1E211D1E1E1C1D1D191A1A18191C18191A18191413181312171211161110150F0E13\
0E0D120D0C110C0B100E0D120E0D120E0D120E0D120E0D120E0D120E0D120E0E10
0F0F110909090C0C0C1818181C1C1C1616161111111212121919191A1A1A1C1C1C1E1E1E1F1F1F\
1F1F1F1E1E1E1D1D1D191A1C18191B17181A16171915151515141216120F16110D
17100A160D06170E071F150C2A2017382B2241332A44362946352347351F46341E44321C42301A\
412F193F2D173F2D1744321C412F193C2A143927113A28123D2B1542301A453420
3D30203F332544382A4C403252493A594F435E564961594E655F53686458666257615F53676559\
716F636B6B5F5F5F53
0B0F0E0307060206050D11101418171014130A0E0D0A0E0D090D0C090D0C090D0C090D0C090D0C\
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D10090D10090D10090D10090D10\
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D0E
090D0E090D0C090D0C090D0C090D0C090D0C090D0C090D0C070B0A1115141519180E1211080C0B\
090D0C070B0A010504121212121212121212121212121212121212121212121212
121212121212121212121212121212121212121212121210070906090B060D0F0A12140F161712\
1819141C18151D1916201B18211C19251D1B271F1D2B21202D23222F2524302625
322A28322A28332B29342C2A362E2C372F2D38302E39312F3D35333D35333D35333E36343F3735\
403836403836403836423A38423A38423A38423A38423A38423A38423A38423A38
4038364038364038364038364038364038364038364038363F37353E36343E36343D35333C3432\
3C34323B33313B33313B33313B33313B33313B33313B33313B33313B33313B3331
39312F38302E38302E372F2D362E2C362E2C352D2B352D2B3A3230352D2B2E2624251D1B201816\
21191728201E2D28252B292A2B2B2B2C2A2B2A2A2A292728252525232122212121
201E1F1E1E1E1E1C1D1B1B1B1A1819181818171516151515151419141318131217121116100F14\
0F0E130E0D120D0C110E0D120E0D120E0D120E0D120E0D120E0D120E0D120E0E10
0F0F110909090C0C0C1818181C1C1C1616161111111212121919191A1A1A1C1C1C1D1D1D1E1E1E\
1E1E1E1D1D1D1C1C1C18191B15191C16171915161814141414131115110E15100C
1E17111C130C1F150C2E211843352A51433657473A55453648372347372046361F45351E43331C\
42321B41311A40301945351E43331C4030193D2D163A2A133A2A133A2A13392A15
332615342818392D1D3E3222433A29483F304C45354E4639575143605D4E6460545D5B4E5A584C\
605E5265655B67675D
0F13120509080307060E12111519180F1312060A09030706090D0C090D0C090D0C090D0C090D0C\
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D10090D10090D10090D10090D10\
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D0E
090D0E090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C1216151418170C100F080C0B\
0C100F0D1110090D0C0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B
0707070707070707070707070707070707070707070707050F110E10120D12140F151712181914\
1A1B161E1A171E1A17241F1C25201D29211F2C2422302625332928352B2A362C2B
352D2B362E2C362E2C372F2D38302E39312F3A32303A32303F37353F3735403836403836413937\
423A38423A38433B39433B39433B39433B39433B39433B39433B39433B39433B39
4139374139374139374139374139374139374139374139374038363F37353F37353E36343D3533\
3D35333C34323C34323C34323C34323C34323C34323C34323C34323C34323C3432
3A323039312F39312F38302E372F2D372F2D362E2C362E2C3F3735372F2D29211F19110F110907\
150D0B221A182C27242A28292929292727272626262323232121211E1E1E1D1D1D
2020201D1D1D1A1A1A191919191919181818151515121212151419151419141318121116111015\
0F0E130E0D120E0D120E0D120E0D120E0D120E0D120E0D120E0D120E0D120E0E10
0F0F110909090C0C0C1818181C1C1C1616161111111212121717171818181919191B1B1B1B1B1B\
1A1A1A19191917181A171B1E161A1D17181C16171915151515141017120F18110B
231A13291F1635281F4234294E3E315240324F3D2F4B3A2A46352144351E44352043341D42331E\
41321B40311C40311A3D2E193E2F183F301B40311A40311C40311A3F301B3F301B
4134214035213F34223E33213C34213B32213932223932223E382A5653446965595E5C4F48463A\
44423659594F727268
1317160C100F0C100F171B1A1C201F1519180D11100B0F0E090D0C090D0C090D0C090D0C090D0C\
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D10090D10090D10090D10090D10\
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D0E
090D0E090D0C090D0C090D0C090D0C090D0C090D0C090D0C1C201F2125241D2120101413090D0C\
0D11101014130E1211111111111111111111111111111111111111111111111111
0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0B11131012140F151712191B161E1F1A\
23241F2A26232C28252E29262F2A27322A28352D2B382E2D3B31303C32313D3332
3A32303B33313B33313C34323C34323D35333D35333D3533413937423A38423A38433B39443C3A\
443C3A453D3B453D3B453D3B453D3B453D3B453D3B453D3B453D3B453D3B453D3B
433B39433B39433B39433B39433B39433B39433B39433B394038364038363F37353F37353E3634\
3D35333D35333C34323C34323C34323C34323C34323C34323C34323C34323C3432
3A32303A323039312F39312F38302E372F2D372F2D362E2C38302E332B292A22202119171B1311\
1B1311211917241F1C191919181A19191B1A1A1C1B1C1E1D1E201F202221212322
1E201F191B1A1517161517161719181719181315140F111016151A16151A151419131217121116\
100F140F0E130F0E130E0D120E0D120E0D120E0D120E0D120E0D120E0D120E0E10
0F0F110909090C0C0C1818181C1C1C1616161111111212121A1A1A1B1B1B1C1C1C1D1D1D1D1D1D\
1B1B1B1A1A1A18191B181C1F161B1E161A1D17181A16161616151118131019120C
1D140D30261D483A2F5343364E3C2E4431223F2C1D3F2C1B3E2F1C3C301A3B2E1B3B2F193A2D1A\
3A2E18392C19392D17322512342812372A173A2E183C2F1C3D311B3C2F1C3B2F19
3B301C3B301A3C311D3C311D3B33203C34213B34223C3525342E20423F30534F435553464E4C40\
4C494059594F6A6A60
181C1B151918191D1C2125241E22211115140A0E0D0C100F090D0C090D0C090D0C090D0C090D0C\
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D10090D10090D10090D10090D10\
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D0E
090D0E090D0C090D0C090D0C090D0C090D0C090D0C090D0C1519181A1E1D151918070B0A000201\
0003020003020001000D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D
0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0B0507040709040C0E0912140F1B1C17\
23241F2E2A27322E2B3833303934313C34323D35333F3534413736423837423837
413937413937413937413937413937413937413937413937443C3A443C3A443C3A453D3B463E3C\
473F3D473F3D473F3D463E3C463E3C463E3C463E3C463E3C463E3C463E3C463E3C
443C3A443C3A443C3A443C3A443C3A443C3A443C3A443C3A4139374139374038364038363F3735\
3E36343E36343D35333D35333D35333D35333D35333D35333D35333D35333D3533
3B33313B33313A32303A323039312F38302E38302E372F2D1F1715201816231B1928201E2A2220\
251D1B1B1311100B080A0A0A0A0C0B0C0E0D1113121719181D1F1E232524262827
1B1D1C151716101211121413171918191B1A1416150F111017161B16151A151419141318121116\
111015100F140F0E130E0D120E0D120E0D120E0D120E0D120E0D120E0D120E0E10
0F0F110909090C0C0C1818181C1C1C1616161111111212121E1E1E1F1F1F202020202020202020\
1E1E1E1C1C1C1A1B1D161A1D14191D14181B15161814141416120F16110D17100A
1D120C372A215342385B493B513E2F44312045301F4734233E311E3D321E3C311D3C311D3C311D\
3C311D3C311D3C311D3A2F1B3A2F1B3C311D3C311D3C311D3B301C392E1A382D19
392E18392E18392E18382D17362E19362E1B352E1C352E1C342E1E272415292519413F325A574E\
5E5B5250504644443A
3B3F3E3B3F3E3E42413A3E3D262A290E1211030706060A09090D0C090D0C090D0C090D0C090D0C\
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C
090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D0C090D10090D10090D10090D10090D10\
090D10090D10090D10090D10090D10090D10090D10090D10090D10090D10090D0E
090D0E090D0C090D0C090D0C090D0C090D0C090D0C090D0C0E12111A1E1D1F23221A1E1D161A19\
171B1A1519180F13120F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F
0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0B151714161813181A151C1E1923241F\
2A2B2634302D383431403B38403B38423A38423A38433938433938433938433938
463E3C463E3C463E3C463E3C463E3C453D3B453D3B453D3B453D3B463E3C463E3C473F3D48403E\
48403E49413F49413F48403E48403E48403E48403E48403E48403E48403E48403E
463E3C463E3C463E3C463E3C463E3C463E3C463E3C463E3C423A384139374139374038363F3735\
3F37353E36343E36343E36343E36343E36343E36343E36343E36343E36343E3634
3C34323B33313B33313A323039312F39312F38302E38302E1D1513170F0D160E0C1F17152B2321\
2D2523221A18140F0C1010100E100F0E100F0F11101113121517161A1C1B1C1E1D
1719181113120C0E0D0F1110181A191B1D1C16181710121118171C17161B16151A151419131217\
121116111015100F140E0D120E0D120E0D120E0D120E0D120E0D120E0D120E0E10
0F0F110909090C0C0C1818181C1C1C1616161111111212121B1B1B1B1B1B1C1C1C1C1C1C1B1B1B\
1919191717171516181115180F14180F13161011130F0F0F110D0A110C08120B03
1A10072B1F133E2E21443224402D1E3D2817402919422F1E372A17342C19342C19352D1A352D1A\
352D1A352D1A352D1A3B33203A321F39311E38301D372F1C362E1B362E1B362E19
3A30173A3017382E15362B15322A153129142E27142E27153E3828302D1E3531254F4D40615E55\
58554C3E3E362D2D25
72747171767270726F5F64603E403D161A19090B0A090D0C0B0D0C090D0C0B0D0C090D0E0B0C0E\
090D0E0B0C0E090D0E0B0D0C090D0C0B0D0C090D0C0B0D0C090D0C0B0D0C090D0C
0B0D0C090D0C0B0D0C090D0C0B0D0C090D0C0B0D0C090D0C0B0C0E090D0E0B0C10090D0E0B0C10\
090D0E0B0C10090D0E0B0C10090D0E0B0C10090D0E0B0C10090D0E0B0C100B0C0E
0B0C0E0B0D0C0B0D0C0B0D0C0B0D0C0B0D0C0B0D0C0B0D0A242623373936494B4850524F545653\
595B585658554E504D545452545452555452545452555452545452555452545452
4A49474949474A49474949474A49474949474A4947494A453F413C3D40393B3E373A3D363C3D37\
3F403A45423D47443F433E3A433E3A443C39433B38433937433937423836423836
4A423F4A423F49413F49413E48403E48403D48403E48403D463E3C473F3C473F3D48403D49413F\
49413E4A42404A423F48403E48403D48403E48403D48403E48403D48403E48403D
463E3C463E3B463E3C463E3B463E3C463E3B463E3C463E3C423A38423A38413937403836403836\
3F37353E36343E36343E36343E36343E36343E36343E36343E36343E36343E3634
3D33323D33323C32313B31303B313039312F38302E38302E362E2C241C1A140C0A15100D29211F\
36312E383330312D2A21211F1D1F1C1719161113100D0F0C0B0D0C0B0D0C0B0D0C
1517160E100F090B0A0E0F1118191B1C1D1F18191B11121417181A16171916151A141517131217\
1112141110150F10120E0D120D0E100E0D120D0E100E0D120D0E100E0D120D0E10
0E0F11060A09090D0E15191A191D1E151618101113111214121315121315131416141416121214\
1010120E0D120C0D0F0C10110C10110D0E100B0D0C0B0B090C08050C07030E0700
0B02000F0500140800180A001B0B001D0D002110002313031F16051E17051F18061F1806201907\
2019072019072019072A231129221028210F28210F2922102B24122D26142E2714
2C240F2D250E2F2712332B16362E1B38311F3B34243C3525504A3E5B544A6E6A5F79766D6A655F\
49463F3835303A3732
8D8E897678739495908688832D2E29090B081919170406050E0E0E0C0D0F0D0D0F0B0C100B0A0F\
0A0B0F0A090E090A0E0C0C0E0B0D0C0C0C0C0B0D0C0C0C0C0B0D0C0C0C0C0B0D0C
1111110F11101010100E100F0D0D0D0B0D0C0C0C0C0A0C0B0B0B0B0A0C0B0B0B0D0A0C0B0C0C0E\
0B0D0C0C0C0E0B0D0C0D0D0F0C0E0D0C0C0E0B0D0C0C0C0E0D0F0E101012111113
0806090C0A0D0C0A0D09070A0907080E0C0D1413111514101E1D194F4E4A6867626766616A6A62\
65655D63635B70706864635E64635E65625D62615C625F5A5F5E59615E595E5D58
66635E64635E64615C605F5A615E595D5C575D5A555B5B53595A52575A4F56594E54574C53554A\
525449535047524F465A564D4440375A534B5851494D443D4037302F261F4E453E
463F39463F39463E3B463F39463E3B463F39463E3B463F3948403D48413B473F3C463F39463E3B\
453E38443C39443D37463E3B463F39463E3B463F39463E3B463F39463E3B463F39
463E3B463F39453D3A443D37443C39433C36423A37423A37423A38423A38413937403836403836\
3F37353E36343E36343E36343E36343D35333C34323C34323B33313A32303B3130
3E32323E32323D31313C30303C30303A302F392F2E392F2E2E2624251D1B1B16131C181527221F\
2D29262B272424231F1A1B1616171211120D11120D13140F141412131311101010
0F0F0F13131518181A1B1A1F1A191E16151A100F140B0C10151618121615131416101413101113\
0D11100E0F110B0F0E0D0E100B0F0E0D0E100B0F0E0D0E100B0F0E0D0E100B0F10
020B0A050F0E0B1516111B1C121C1D11191B0C1417091114080D13090E140B0E150D0D150D0D15\
0B0B130A0A1408090E0D0D0B0B0C070809040607010706010807020D0A030E0B04
0A0700100C03141007151106150E04130C02140D031610041A14061A14061A14061A14061A1406\
1A14061A14061A1406201A0C201A0C201A0C201A0C201A0C201A0C201A0C201A0C
231B0E352D202C24171F170A2C2419383226423B31554E4669625A67605A70686575706D665E5C\
423D3A332D2D373131
A9AAA4959690ACADA79899933C3D381415101E1E1C0E0E0C17171916161816151A151419141319\
141319131218131217141416141414141414141414141414141414141414141414
1414141414141414141313131313131212121212121212121010101010100F0F0F0D0D0D0C0C0C\
0A0A0A0909090909090A0A0A0909090808080808080909090A0A0A0C0C0C0D0D0D
140F13140F13110C100F0A0E120E0F191514201C1B221E1B403D388D8A85BFBCB5C4C1BAC3C0B7\
BCB9B0B6B3AABFBCB3C0BDB6C0BDB6BFBCB5BEBBB4BDBAB3BDBAB3BCB9B2BCB9B2
B4B1AAB3B0A9B2AFA8B1AEA7AFACA5ADAAA3ACA9A2A9A99FA4A69BA3A799A2A698A0A4969FA194\
9EA0939F9D919F9D91ADA99E99958AA7A096979086857C736F665D433A31443B32
463F39463F39463F39463F39463F39463F39463F39463F3948413B48413B47403A463F39463F39\
453E38443D37443D37463F39463F39463F39463F39463F39463F39463F39463F39
463F39463F39453E38443D37443D37433C36423B35423B35423A38423A38413937403836403836\
3F37353E36343E36343E36343E36343D35333C34323C34323B33313A32303B3130
3E32324032323F31313E30303C30303B2F2F392F2E392F2E3A32302A2522191411100C09110D0A\
130F0C0F0E0A0A090514150F11120C0E0F090F100A13140F151611141412121210
11111313131516151A18171C17161C141319100F150D0E121516181216151115141014130E1211\
0D11100C100F0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0A100E
010D0D0311110917170E1C1C111C1E0F1A1C0B141908111600050B01050E040710050811070711\
07071107071307060C0403000805000C09020F0C03110E07120F06110E07100D04
120F081A170E25221B2F2C233330292F2C2327241D201D14141004141004141004141004141004\
141004141004141004120E02120E02120E02120E02120E02120E02120E02120E02
0B04001710060F0800140D033C352D5A534B645D57716A646F67646C6461736B697A7172685F60\
463D3E362D303B3235
B2B3ADA3A49EB4B5AF9C9D9743443F1819141E1E1C14141218181A18181A17161B17161B16151B\
15141A15141A141318141416141414141414141414141414141414141414141414
1A1A1A1B1B1B1B1B1B1B1B1B1C1C1C1C1C1C1D1D1D1D1D1D1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B\
1B1B1B1C1C1C1C1C1C1E1E1E1C1C1C191919151515131313111111111111111111
181317120D110D080C0E090D130F101A1615201C1B24201D3D3A359A9792D5D2CBD1CEC7CAC7BE\
C9C6BDC7C4BBCDCAC1CAC7C0CAC7C0C9C6BFC9C6BFC8C5BEC8C5BEC7C4BDC7C4BD
C3C0B9C2BFB8C1BEB7C0BDB6BEBBB4BDBAB3BCB9B2BABAB0B6B8ADB4B8AAB3B7A9B2B6A8B2B4A7\
B0B2A5B2B0A4B2B0A4B6B2A7AAA69BB9B2A8A8A197A29990978E85564D44362D24
47403A47403A47403A47403A47403A47403A47403A47403A48413B48413B47403A463F39463F39\
453E38443D37443D37463F39463F39463F39463F39463F39463F39463F39463F39
463F39463F39453E38443D37443D37433C36423B35423B35423A38423A38413937403836403836\
3F37353E36343E36343E36343E36343D35333C34323C34323B33313A32303B3130
3E32324032323F31313E30303C30303B2F2F392F2E392F2E3A32302A25221914110F0B08110D0A\
16120F161511161511191A141617111516101819131C1D181F201B1E1E1C1C1C1A
1414161414161413181312171211171110161110160F10141516181216151115141014130E1211\
0D11100C100F0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0A100E
040E0F0713130D1919111D1D131D1E0F191A0B131608101300030700040A01040B04040C05050D\
06060E0806110A080D0502000703000A06000F0B001511081D190E231F16272318
302C23302C213430273D392E444037433F343A362D302C21161004161002161002161002161002\
161002161002161002161002161002161002161002161002161002161002161002
120C00140E02070000160F05504941766F677A736D7C756F756D6A726A67776F6D7C7472696061\
463D3E362D2E3B3233
ABACA6A4A59FAFB0AA9899934E4F4A22231E23232120201E1B1B1D1B1B1D1B1A1F1A191E19181E\
18171D18171D18171C171719171717171717171717171717171717171717171717
1D1D1D1E1E1E1F1F1F2020202121212222222323232323232323232424242727272B2B2B2F2F2F\
3333333636363737373B3B3B3737373131312B2B2B2424242020201C1C1C1B1B1B
1A1519130E12110C101611151B17181C1817201C1B26221F686560B7B4AFDAD7D0C3C0B9BBB8AF\
C5C2B9C9C6BDCECBC2C4C1BAC4C1BAC4C1BAC3C0B9C3C0B9C3C0B9C3C0B9C3C0B9
C7C4BDC7C4BDC6C3BCC5C2BBC4C1BAC3C0B9C2BFB8C0C0B6C2C4B9C0C4B6C0C4B6BFC3B5BFC1B4\
BEC0B3C0BEB2C0BEB2B9B5AAB5B1A6C7C0B6BBB4AAC8BFB6CEC5BC867D7450473E
48413B48413B48413B48413B48413B48413B48413B48413B48413B48413B47403A463F39463F39\
453E38443D37443D37463F39463F39463F39463F39463F39463F39463F39463F39
463F39463F39453E38443D37443D37433C36423B35423B35423A38423A38413937403836403836\
3F37353E36343E36343E36343E36343D35333C34323C34323B33313A32303B3130
3E32324032323F31313E30303C30303B2F2F392F2E392F2E3A32302E2926231E1B1C18151E1A17\
221E1B23221E23221E1E1F191C1D171B1C161D1E1820211C21221D1F1F1D1B1B19
1515171414161110150E0D120E0D130F0E14100F151112161516181216151115141014130E1211\
0D11100C100F0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0A100E
0711120A16160F1B1B131D1E131D1E10181A0A1214080D10060B0F06090E08090E07080D08090E\
0A090F0B0A100E090D1009030F07000D05001109001C14092E261B40382D4B4338
534B40453D32372F24342C213A322740382D3E362B3830251D17091D17091D17091D17091D1709\
1D17091D17091D17091D17091D17091D17091D17091D17091D17091D17091D1709
201A0E201A0E120B01221B115D564E837C74847D77837C7679716E746C6978706E7B7371675E5F\
443B3C342B2C393031
ABACA6AAABA5AFB0AA9B9C9663645F3839342D2D2B2D2D2B232325232325222126222126212026\
201F25201F251F1E231F1F211F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F1F
1B1B1B1C1C1C1D1D1D1E1E1E1F1F1F2020202121212121212020202121212424242727272B2B2B\
2E2E2E3131313232323636363434342F2F2F2A2A2A262626222222212121202020
201B1F1B161A1D181C27222628242524201F2A262536322F9D9A95D1CEC9DAD7D0C0BDB6C0BDB4\
CDCAC1CBC8BFCAC7BECCC9C2CCC9C2CCC9C2CCC9C2CDCAC3CDCAC3CDCAC3CDCAC3
CDCAC3CDCAC3CDCAC3CCC9C2CCC9C2CBC8C1CBC8C1C8C8BECACCC1C8CCBEC8CCBEC7CBBDC8CABD\
C7C9BCCAC8BCCAC8BCCDC9BEC7C3B8D3CCC2C1BAB0CFC6BDD8CFC68B82794C433A
48413B48413B48413B48413B48413B48413B48413B48413B48413B48413B47403A463F39463F39\
453E38443D37443D37463F39463F39463F39463F39463F39463F39463F39463F39
463F39463F39453E38443D37443D37433C36423B35423B35423A38423A38413937403836403836\
3F37353E36343E36343E36343E36343D35333C34323C34323B33313A32303B3130
3E32324032323F31313E30303C30303B2F2F392F2E392F2E3F373537322F302B282A262326221F\
221E1B1B1A1618171320211B1E1F191C1D171D1E181E1F1A1C1D18171715121210
1515171212140F0E130C0B100B0A100C0B110F0E141011151516181216151115141014130E1211\
0D11100C100F0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0A100E
0B13150D1718121C1D161E20141C1E1116190B1013080C0D0C10130D0E120A0B0F09080D08070C\
09070C0A080D0E0808130900180C001E1204281C0E362A1C44382A514537584C3E
54483A45392B362A1C312517382C1E3E32243C3022352C1D2B24142B24142B24142B24142B2414\
2B24142B24142B2414231C0C231C0C231C0C231C0C231C0C231C0C231C0C231C0C
1C1608241E101C160A2A24185E574D817A70857E768A837B79726C746D67766E6B79716E635B59\
413937312829372E2F
AAABA5ABACA6A9AAA49A9B957778734C4D4833333131312F252527252527242328242328232228\
222127222127212025242426242424242424242424242424242424242424242424
2121212121212121212222222222222323232323232323232020202020201F1F1F1E1E1E1C1C1C\
1B1B1B1B1B1B1A1A1A1D1D1D1C1C1C1B1B1B1B1B1B1B1B1B1D1D1D1F1F1F202020
201B1F1C171B221D212C272B2A262727232239353455514EAAA7A2C8C5C0C9C6BFBDBAB3C8C5BC\
CBC8BFBEBBB2BAB7AEC1BEB7C2BFB8C2BFB8C3C0B9C3C0B9C4C1BAC4C1BAC5C2BB
C4C1BAC4C1BAC4C1BAC4C1BAC4C1BAC4C1BAC4C1BAC2C2B8BCBEB3BBBFB1BBBFB1BBBFB1BCBEB1\
BCBEB1BFBDB1BFBDB1C6C2B7BCB8ADC8C1B7B5AEA4BCB3AABEB5AC7269603B3229
49423C49423C49423C49423C49423C49423C49423C49423C48413B48413B47403A463F39463F39\
453E38443D37443D37463F39463F39463F39463F39463F39463F39463F39463F39
463F39463F39453E38443D37443D37433C36423B35423B35423A38423A38413937403836403836\
3F37353E36343E36343E36343E36343D35333C34323C34323B33313A32303B3130
3E32324032323F31313E30303C30303B2F2F392F2E392F2E38302E36312E35302D332F2C312D2A\
2D2926282723252420292A2427282225262025262026272222231E1B1B19151513
1313151111130D0C110B0A0F0A090F0B0A100D0C120E0F131516181216151115141014130E1211\
0D11100C100F0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0A100E
0E171611191B151D1F191E21171C1F1216170B0F1008090B0C0D0F0B0B0B080808060405070304\
0905060B0708100805160A002616063929194B3B2B5444345545355040304B3B2B
3D2D1D3B2B1B3B2B1B4030204636264636263F2F1F352817372E1D362F1F362F1F362F1F362F1F\
362F1F362F1F362F1F2F28182F28182F28182F28182F28182F28182F28182F2818
272113322C1E2923172F291D5650446F685E716A60766F677A736D736C66756D6A776F6C625A58\
403836322A2839312F
A5A6A0A9AAA4A4A59F9E9F9991928D6A6B6646464441413F323234323234313035313035302F35\
2F2E342F2E342E2D32333335333333333333333333333333333333333333333333
3737373737373737373636363636363535353535353535353131313030302D2D2D2A2A2A272727\
2323232121212020201F1F1F1F1F1F1E1E1E1E1E1E202020222222242424262626
2B262A2722262D282C353034322E2F3531305C58578B8784C2BFBACECBC6C9C6BFC9C6BFD7D4CB\
CFCCC3C2BFB6CAC7BEC5C2BBC6C3BCC6C3BCC7C4BDC8C5BEC9C6BFCAC7C0CAC7C0
CDCAC3CDCAC3CDCAC3CDCAC3CDCAC3CECBC4CECBC4CCCCC2C4C6BBC3C7B9C3C7B9C4C8BAC5C7BA\
C5C7BAC8C6BAC8C6BAC6C2B7BDB9AED0C9BFC5BEB4C7BEB5BDB4AB766D644D443B
4A433D4A433D4A433D4A433D4A433D4A433D4A433D4A433D48413B48413B47403A463F39463F39\
453E38443D37443D37463F39463F39463F39463F39463F39463F39463F39463F39
463F39463F39453E38443D37443D37433C36423B35423B35423A38423A38413937403836403836\
3F37353E36343E36343E36343E36343D35333C34323C34323B33313A32303B3130
3E32324032323F31313E30303C30303B2F2F392F2E392F2E2F27252E29262F2A272E2A272E2A27\
2F2B28302F2B32312D26272125262024251F2627212728232425201D1D1B171715
1010120F0F110D0C110C0B100B0A100B0A100B0A100B0C101516181216151115141014130E1211\
0D11100C100F0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E
121818151B1B181E1E1B1F20181C1D1416150C0E0D0808080A0A0A0908060905040804030B0603\
0F0A07140F0C1B120B3020113C2A164B392557453159473353412D483622402E1A
3725113B2915412F1B45331F47352145331F402E1A3B2A183C311F3A31203A31203A31203A3120\
3A31203A31203A312039301F39301F39301F39301F39301F39301F39301F38311F
3731213E3828302A1C332D1F5852446D675B6861576962587B746C756E6677706A78716B645C59\
433B38362E2B3E3633
A7A8A2AEAFA9A9AAA4ACADA7B0B1AC8F908B67676560605E4C4C4E4C4C4E4C4B504B4A4F4A494F\
49484E49484E49484D4F4F514F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F4F
4F4F4F4F4F4F4E4E4E4D4D4D4C4C4C4B4B4B4A4A4A494949464646464646444444424242404040\
3F3F3F3D3D3D3C3C3C3A3A3A3838383535353232323030302F2F2F2F2F2F2F2F2F
443F43403B3F443F434A4549454142514D4C878382C4C0BDCCC9C4CAC7C2BCB9B2BCB9B2C6C3BA\
BAB7AEB7B4ABD0CDC4C1BEB7C2BFB8C2BFB8C3C0B9C5C2BBC6C3BCC7C4BDC7C4BD
C5C2BBC5C2BBC6C3BCC6C3BCC6C3BCC7C4BDC7C4BDC5C5BBC0C2B7BFC3B5C0C4B6C0C4B6C1C3B6\
C2C4B7C5C3B7C5C3B7BFBBB0B6B2A7CEC7BDC7C0B6C0B7AEAAA198635A51423930
4A433D4A433D4A433D4A433D4A433D4A433D4A433D4A433D48413B48413B47403A463F39463F39\
453E38443D37443D37463F39463F39463F39463F39463F39463F39463F39463F39
463F39463F39453E38443D37443D37433C36423B35423B35423A38423A38413937403836403836\
3F37353E36343E36343E36343E36343D35333C34323C34323B33313A32303B3130
3E32324032323F31313E30303C30303B2F2F392F2E392F2E352D2B2F2A272823201E1A17171310\
15110E16151119181412130D12130D13140E161711191A1517181310100E0A0A08
0E0E100D0D0F0D0C110C0B100C0B110B0A100A090F090A0E1516181216151115141014130E1211\
0D11100C100F0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E
141819191A1C1C1D1F1D1F1E1B1B1B1414140E0D0B0908060D09080C08050C0703100805140D07\
1B140E231A15291F15503F2D523D28513C274F3A254C372248331E45301B432E19
46311C45301B432E193E291439240F39240F3E2914412F1B3C2F1E39301F39301F39301F39301F\
39301F39301F39301F332A19332A19332A19332A19332A19332A19332A19332A19
312A1A342E1E282212342E20655F51827C6E7E786C7D766C7D766C77706879726C7A736D665E5B\
473F3C3B3330423A37
A5A6A0A5A6A0A8A9A3ABACA6AAABA6A0A19C8D8D8B7F7F7D5B5B5D5757595150554D4C514B4A50\
4C4B514E4D53504F54545456555555555555555555565656565656565656565656
4F4F4F5050505050505151515252525353535454545454544E4E4E4C4C4C4A4A4A484848464646\
4646464646464646464343434242423F3F3F3B3B3B393939383838383838383838
474246464145454044474246565253777372A19D9CBFBBB8C1BEB9C1BEB9C1BEB7C1BEB7C1BEB5\
C1BEB5C1BEB5C1BEB5C7C4BDC7C4BDC6C3BCC6C3BCC6C3BCC5C2BBC5C2BBC5C2BB
CBC8C1CBC8C1CAC7C0CAC7C0C9C6BFC9C6BFC8C5BEC6C6BCC3C5BAC4C8BAC3C7B9BFC3B5BFC1B4\
C3C5B8C6C4B8C4C2B6C3BFB4B2AEA3D9D2C8B5AEA4BDB4ABBDB4AB5249404A4138
5049434F48424F48424E47414D46404D46404C453F4C453F4E47414D46404D46404C453F4B443E\
4B443E4A433D4A433D48413B48413B48413B48413B48413B48413B48413B48413B
463F39453E38453E38443D37433C36433C36423B35423B35443C3A443C3A433B39423A38423A38\
4139374038364038363D35333A323039312F3C34324139374139373B3331352B2A
4438384133333B2D2D3A2C2C3A2E2E3C30303B31303A302F352D2B2A25221E1916181411191512\
1B17141817131514100E0F090F100A10110B11120C11120D10110C0E0E0C0D0D0B
0C0C0E0C0C0E0B0A0F0A090E0B0A100C0B110E0D130E0F131516181216151014130E12110D1110\
0E12110E12110F1312060A09050908040807040807070B0A0B0F0E0F1312121615
1516181D1D1F252525262626201E1F1514120E0A070A0702100B070F08020E07001108011A1108\
281F16372D2442362A5947335A442D564029513B244C361F47311A432D16412B14
422C15422C15412B14402A13402A133F29123E28113B2913392C19382D1B382D1B382D1B382D1B\
382D1B382D1B382D1B362B19362B19362B19362B19362B19362B19362B19342C19
2B241236311E302B18393323615B4B777163746E60756F637E776D7D766C7A736B726B63645D57\
524B45413A3437302A
ABACA6A8A9A3A7A8A2A9AAA4ABACA7A8A9A49F9F9D9797959393958F8F9189888D8281867C7B81\
78777D77767C76757A6E6E706D6D6D6B6B6B696969676767646464636363626262
6C6C6C6B6B6B6969696767676565656363636161616060606A6A6A686868666666646464626262\
6262626262626262625C5C5C5B5B5B585858565656555555545454555555555555
474246504B4F645F637F7A7E9C9899B6B2B1C8C4C3D0CCC9C5C2BDC5C2BDC5C2BBC5C2BBC5C2B9\
C5C2B9C5C2B9C5C2B9C1BEB7C1BEB7C1BEB7C2BFB8C2BFB8C2BFB8C2BFB8C2BFB8
C5C2BBC5C2BBC6C3BCC7C4BDC8C5BEC8C5BEC9C6BFC8C8BEBEC0B5BEC2B4BDC1B3BCC0B2BFC1B4\
C3C5B8C9C7BBC9C7BBC8C4B9B4B0A5D7D0C6BCB5ABC2B9B0B7AEA55249404F463D
514A44514A445049435049434F48424E47414E47414D46404F48424F48424E47414D46404D4640\
4C453F4B443E4B443E49423C49423C49423C49423C49423C49423C49423C49423C
47403A47403A463F39453E38453E38443D37433C36433C36443C3A433B39433B39423A38413937\
413937403836403836423A383F37353E3634403836433B394139373B3331362C2B
4034343F31313B2D2D3B2D2D3C30303D31313A302F372D2C3C3432312C29282320221E1B24201D\
26221F23221E21201C1F201A1F201A1F201A1E1F191B1C17181914151513131311
1111131010120E0D120C0B100B0A100C0B110D0C120D0E121516181115140F13120D11100C100F\
0B0F0E0C100F0C100F0B0F0E0A0E0D080C0B080C0B090D0C0C100F101413151716
1E1E20201E1F201E1F1E1A1918141316110E18130F1C150F0801000E0500170E05241A1031271B\
3E3226483C304E41314E3C28503A234E38214C361F49331C463019452F18442E17
422C15422C15412B14402A13402A133F29123E28113B29133B2C19382D1B382D1B382D1B382D1B\
382D1B382D1B382D1B362B19362B19362B19362B19362B19362B19362B19342C19
2F281636311E2E291637321F645E4E7E78687B75677B7567746E62766F6579726879726A766F67\
70696369625C645D57
ADAEA8AAABA5A6A7A1A6A7A1ABACA7AFB0ABB0B0AEB0B0AE969698949496908F948A898E85848A\
807F857C7B817A797E7777797676767474747272727070706E6E6E6C6C6C6C6C6C
6666666565656464646363636262626060605F5F5F5F5F5F6565656363636161615E5E5E5D5D5D\
5C5C5C5D5D5D5D5D5D5A5A5A585858575757565656565656575757585858595959
736E727B767A8D888CA7A2A6BEBABBC7C3C2BFBBBAB5B1AEB9B6B1B9B6B1B9B6AFB9B6AFB9B6AD\
B9B6ADB9B6ADB9B6ADC3C0B9C4C1BAC5C2BBC6C3BCC7C4BDC8C5BEC9C6BFCAC7C0
C7C4BDC7C4BDC7C4BDC7C4BDC7C4BDC7C4BDC7C4BDC5C5BBC3C5BAC0C4B6BFC3B5BFC3B5C1C3B6\
C2C4B7C7C5B9C9C7BBCAC6BBB1ADA2CDC6BCBFB8AEC1B8AFA59C934A413850473E
544D47534C46534C46524B45514A44514A44504943504943514A44514A445049434F48424F4842\
4E47414D46404D46404B443E4B443E4B443E4B443E4B443E4B443E4B443E4B443E
49423C49423C48413B47403A47403A463F39453E38453E38433B39433B39423A38423A38413937\
4038364038363F3735433B394038363E36343E36343F37353E363439312F352B2A
3D31313D2F2F3C2E2E3E30303D31313B2F2F342A292F25243A3230322D2A2C27242824212A2623\
2B27242928242827232A2B252A2B2528292325262021221D1C1D18181816151513
1515171212140F0E130C0B100B0A100B0A100D0C120D0E121415171115140E12110B0F0E090D0C\
090D0C090D0C090D0C0F13120E12110C100F0B0F0E0C100F0F1312121615171918
232122252122221E1F1D1717171111170F0D1A120F1F16111108001C12082B21153E3224493D2D\
4F423250433250412E43311D45301B45301B45301B45301B45301B45301B45301B
412C17412C17402B163F2A153F2A153E29143D28133B29133B2C19392C19392C19392C19392C19\
392C19392C19392C19372A17372A17372A17372A17372A17372A17372A17362B17
352E1B38331F2A2511332E1A635E4B7F7A677C76667B75677C76687B7569797268756E646F685E\
69625A635C54605951
93948E91928C8F908A8F908A93948F999A959D9D9BA0A09EADADAFAEAEB0AFAEB3B0AFB4B0AFB5\
AFAEB4ADACB2ACABB0B3B3B5B3B3B3B4B4B4B5B5B5B7B7B7B8B8B8B9B9B9B9B9B9
B9B9B9BABABABDBDBDC1C1C1C5C5C5C9C9C9CCCCCCCECECEC9C9C9C8C8C8C5C5C5C3C3C3C1C1C1\
C1C1C1C1C1C1C1C1C1C4C4C4C4C4C4C3C3C3C3C3C3C4C4C4C6C6C6C8C8C8C9C9C9
C6C1C5C4BFC3C4BFC3C7C2C6CBC7C8C9C5C4C2BEBDBBB7B4CAC7C2CAC7C2CAC7C0CAC7C0CAC7BE\
CAC7BECAC7BECAC7BEC6C3BCC7C4BDC8C5BECAC7C0CCC9C2CECBC4CFCCC5D0CDC6
CBC8C1CAC7C0C9C6BFC7C4BDC5C2BBC3C0B9C2BFB8BFBFB5C5C7BCBFC3B5BEC2B4C0C4B6BFC1B4\
B9BBAEBBB9ADBFBDB1CFCBC0B7B3A8C7C0B6C4BDB3C2B9B0978E854B4239584F46
564F49554E48554E48544D47534C46534C46524B45524B45524B45524B45514A44514A44504943\
4F48424F48424E47414C453F4C453F4C453F4C453F4C453F4C453F4C453F4C453F
4A433D4A433D49423C49423C48413B47403A47403A463F39423A38423A38413937413937403836\
3F37353F37353E36343C34323B33313A32303A32303A323039312F372F2D372D2C
3E32323F31313F31314032323D3131372B2B2B21202319182B232128232025201D24201D24201D\
25211E23221E22211D24251F23241E22231D1F201A1C1D1817181313131111110F
1212140F0F110B0A0F09080D08070D0B0A100E0D130F10141415171014130D11100A0E0D080C0B\
070B0A070B0A070B0A0D11100C100F0B0F0E0B0F0E0E1211121615171B1A1C1E1D
231F20262022272121241B1C1D1513190F0D170E09190E082E241A382C2044382A4E4131514433\
50412E493A2744331F412F1B412F19432E1B42301A442F1C42301A442F1C43311B
412C193F2D17402B183D2B153F2A173C2A143D28153B29153B2C17392C19392C19392C19392C19\
392C19392C19392C19372A17372A17372A17372A17372A17372A17372A17362B17
39321F39342027220E2F2A165F5A477D78657A74647872627E786A7872646F695D635C52564F45\
4B443A443D35403931
73746E757670777872797A747A7B767B7C777D7D7B7E7E7C7575777777797A797E7E7D82807F85\
81808682818782818688888A8989898A8A8A8B8B8B8D8D8D8F8F8F909090919191
9090909393939797979D9D9DA4A4A4AAAAAAAEAEAEB1B1B1B3B3B3B1B1B1AFAFAFACACACABABAB\
AAAAAAABABABABABABAFAFAFAFAFAFAFAFAFAFAFAFB0B0B0B3B3B3B5B5B5B6B6B6
C0BBBFC1BCC0BFBABEBAB5B9B5B1B2B6B2B1BEBAB9C6C2BFBFBCB7BFBCB7BFBCB5BFBCB5BFBCB3\
BFBCB3BFBCB3BFBCB3BFBCB5C0BDB6C1BEB7C3C0B9C5C2BBC7C4BDC8C5BEC9C6BF
C7C4BDC7C4BDC7C4BDC8C5BEC8C5BEC8C5BEC9C6BFC7C7BDC8CABFC2C6B8C5C9BBD0D4C6D2D4C7\
C9CBBECAC8BCD0CEC2C9C5BABAB6ABBEB7ADBFB8AEBAB1A88C837A544B4261584F
57504A564F49564F49554E48544D47544D47534C46534C46524B45524B45514A44514A44504943\
4F48424F48424E47414C453F4C453F4C453F4C453F4C453F4C453F4C453F4C453F
4A433D4A433D49423C49423C48413B47403A47403A463F39423A384139374139374038363F3735\
3F37353E36343E36343A32303A32303B33313A32303A32303A32303B33313E3433
4034344133334032324032323A2E2E3125252319181A100F1E16141E1916201B181F1B181E1A17\
1C18151A19151A191517181217181218191317181216171213140F11110F0F0F0D
0D0D0F0B0B0D07060B05040906050B0A090F0F0E141213171314160F13120C100F0A0E0D080C0B\
080C0B080C0B080C0B0A0E0D090D0C0A0E0D0C100F101413161A191C201F222423
231F20251C1F231A1B1F15161C1211201513271C162F221A493D314C3E314F423151422F4E3F2A\
48382141311A3D2D1646342045342045322143321E43301F41301C412E1D402F1B
3F2C1B3E2D193E2B1A3C2B173D2A193B2A163B28173A29153B2C173B2C173B2C173B2C173B2C17\
3B2C173B2C173B2C17392A15392A15392A15392A15392A15392A15392A15372B15
352F1936311B28230D302B15605B477E79657D78657D7767746E606F695B6761555D574B544D43\
4D463C494238474036
0001000506000A0B050C0D07090A050708030606040707050C0C0E0C0C0E0D0C110D0C110D0C12\
0E0D130E0D130E0D12141416141414131313121212111111101010101010101010
0909090A0A0A0D0D0D1010101313131616161818181919192121212020201D1D1D1B1B1B1A1A1A\
1919191919191A1A1A1A1A1A1919191919191919191A1A1A1C1C1C1E1E1E202020
191418201B1F272226262125201C1D201C1B282423312D2A25221D25221D25221B25221B252219\
25221925221925221937342D37342D38352E39362F3A37303B38313C39323D3A33
3F3C35413E3744413A48453E4D4A43514E4754514A54544A56584D535749606456787C6E828477\
797B6E7B796D8482769C988D9C988D979086979086948B826F665D4F463D584F46
564F49564F49554E48554E48544D47534C46534C46524B45514A44514A445049434F48424F4842\
4E47414D46404D46404B443E4B443E4B443E4B443E4B443E4B443E4B443E4B443E
49423C49423C48413B47403A47403A463F39453E38453E384139374038364038363F37353E3634\
3E36343D35333D35333D35333F37353F37353D35333A32303A32303D3533423837
3E32323F31313D2F2F3D2F2F372B2B2F2323221817190F0E1A12101D1815211C19211D1A1E1A17\
1A161317161217161211120C12130D13140E14150F151611141510131311121210
1111130D0D0F08070C05040905040A0A090F100F151314181112140E12110C100F0B0F0E0A0E0D\
0B0F0E0B0F0E0C100F0E12110E12110E12111014131418171A1E1D202423272727
272123241B1E1E1415190F0E1D12102D221E44373153463D4E40354D40304C3C2C493A25483821\
45351C45331B44321A49382648392647362644352243322240311E402F1F3E2F1C
3E2D1D3D2E1B3D2C1C3B2C193C2B1B3A2B183A2919392A173B2C173B2C173B2C173B2C173B2C17\
3B2C173B2C173B2C17392A15392A15392A15392A15392A15392A15392A15372B15
2C2610342F192B2610322D175B564276715D77725F7B7663756F5F716B5D6B6559645E525D564C\
575046544D43524B41
0506000A0B050E0F090E0F090A0B06090A050B0B090F0F0D1111130F0F110C0B1009080D07060C\
08070D0A090F0B0A0F0D0D0F0D0D0D0C0C0C0C0C0C0B0B0B0B0B0B0A0A0A0A0A0A
1212121212121212121212121313131313131313131313131A1A1A181818161616131313121212\
111111121212121212121212111111101010101010101010111111131313141414
1510141813171B161A1C171B1A161718141317131217131019161119161119160F19160F19160D\
19160D19160D19160D19160F1A17101A17101A17101A17101B18111B18111B1811
1D1A131E1B14211E1724211A28251E2B28212D2A232D2D23323429313527464A3C696D5F77796C\
6D6F626E6C6078766A615D52736F64696258665F55696057554C434B42394D443B
554E48544D47544D47534C46524B45524B45514A44514A444F48424F48424E47414D46404D4640\
4C453F4B443E4B443E49423C49423C49423C49423C49423C49423C49423C49423C
47403A47403A463F39453E38453E38443D37433C36433C364038364038363F37353F37353E3634\
3D35333D35333C34323E36344038363F373539312F322A282F2725332B29392F2E
372B2B372929372929372929352929312525271D1C20161519110F1E191625201D24201D1F1B18\
19151215141015141010110B11120C12130D13140E14151013140F12121011110F
1D1D1F171719100F140A090E08070D0A090F0F0E141213171011130D11100C100F0C100F0D1110\
0E12111014131115141A1E1D191D1C181C1B181C1B1A1E1D1E2221222625282828
2721232B20242D21232E222235272640332D50413A5B4D424A3A2D48382847362446352147351F\
48361E4A391F4A3A214637244437264535264134234232233F32214030213D301F
3D2D1E3B2E1D3C2C1D392C1B3B2B1C382B1A39291A3929193B2C173C2C153C2C153C2C153C2C15\
3C2C153C2C153C2C153A2A133A2A133A2A133A2A133A2A133A2A133A2A13372B13
2A240C3632192E29132D281248432F57523E544F3C5A55425E58485C5646585244544E404E483C\
494337453E34433C32
0B0C070E100B12130E0F110C0C0C0A0C0E0B131313191B1A18181A141517100F140C0D110D0C12\
0F101514131916171B0C0C0E0C0E0D0F0F1110121114141615171618181A181A19
0E0E100D0F0E0E0E100E100F0F0F110E100F1010120F111018181A161817141416111312101012\
0F1110101012101211141416121413121214101211111113111312131315141416
1614170E0C0F07050809070A100E0F14121312110F0E0D09100F0B100F0B100F0A100F0A101008\
10100810100810100816151016151016151015140F15140F15140F14130E14130E
13120D13120D12110C11100B100F0A0F0E090F0E090E0D080D0F040D0F0225271C4B4D405A5A50\
4D4D4149463D545045454138635F54564F47524B415A514A524940554C45544B44
554C45544B46544B46534A455249445249445148435148434F46414E45404E45404D443F4C433E\
4C433E4B423D4B423D48413B48413B48413B48413B48413B48413B48413B48413B
463F39453E38453E38443D37433C36433C36423B35423B354038354038353F37343E36333E3633\
3D35323C34313C34313C34313D35323A322F312926271F1C221A17251D1A29211F
2F25242E24232E242530262533292A3129272C2324271F1D150F0F1D181524201F22211D1D1918\
14130F12110F12110D0F100B10110C11120D11120D10110C0F0F0D0D0D0B0C0C0C
2828282121231717190F0E130A090E0B0A0F0E0D121110150F10140D11120E0F110D1112101113\
11151615161815191A28292B2428272325241F2322202221202423252726272725
251D1B3328264338344D423E51443E4D4037493B3047392C443727463626453623453621473720\
48381F493920493A234033203F32223F32223F32223F32223F32223F32223F3222
3B2E1E3B2E1E3A2D1D392C1C392C1C382B1B372A1A372A193B2C173B2C153B2C173B2C153B2C17\
3B2C153B2C173B2C15392A15392A13392A15392A13392A15392A13392A15372B15
2E260F3C3620312B15261F0C332C19352E1C2C2714312B1B2A24162C26182F291D302C20322E23\
332F24332F26322E25
0D0E100B0F100D0E100B0F100D0E100B0F100D0E100B0F100D0E120B0F120D0E120B0F120D0E12\
0B0F120D0E120B0F120F10140D11120F10140D11120F10140D11120F10140D1112
0D0E120A0E0F0C0D110D11121213170E12130B0C100408091415190F13140E0F130C1011101115\
0E12130D0E12080C0D0F10140D11120F10140D11120F10140D11120F10140F1012
0F10120F11100F11100F11100F11100F11100F11100F110E0F110E0F110E0F110E0F110E0F110E\
0F110E0F110E0F110E0E12110C100F0B0F0E0D11101014131014130D1110090D0C
0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0D0F0C110E090C08002E292357534A58534D\
524E45544F49514A42544D47544D45534C46524B43524B45514A42504943514841
52474153484254494354494353484252474150453F4F443E51464051464050453F50453F50453F\
4F443E4F443E4F443E4B423B4A413A4A413A494039483F38483F38473E37473E37
453C35453C35443B34433A33433A334239324138314138314138334138334037324037323F3631\
3E35303E35303D342F39302B413833433A35342B261F1611170E092017122D2522
2F29292E2A292F2B2C2E2A292D292A2827252624252423211B191A1B1A181A1819181816171516\
14141212121211110F16161414141210100E0D0D0B0C0C0A0D0D0D0F0F0F101010
1B1B1B1717171111110C0C0E0A0A0C0A0A0C0C0C0E0E0D1211101811111914131B16161E1A1921\
1C1D22201F2520212524232825262828282A28292B2A2A2A272928262626262521
2A22173B2F214D4133564A3C4F4333433727403523453A28473C2A443724403320403320443822\
463A24463A24443822463B294035233A2F1D382D1B3B301E3F3422403523403523
3A2F1D392E1C392E1C382D1B372C1A372C1A362B19362B19392C19382C16382B18372B15362916\
362A14352815352913332613332711332613332711332613332711332613332613
403521362B192F2412332717352C1B342B1C2D25182A2215332D21312A202D29202B281F2D2A23\
302D2631312934342C
0B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F12\
0B0F120B0F120B0F120D11140D11140D11140D11140D11140D11140D11140D1114
0B0F120A0E110A0E110D11141014170F13160A0E1105090C13171A1014170C10130C10130E1215\
0E12150B0F12080C0F0D11140D11140D11140D11140D11140D11140D11140D1112
0D11120D11100D11100D11100D11100D11100D11100D11100D11100D11100D11100D11100D1110\
0D11100D11100D11100D13130B11110A10100C12120F15150F15150C1212080E0E
0A10100A10100A10100A10100A10100A10100A10100D0F0E120F0A0E070130292358514B5A534D\
544D47564F49514A44544D47544D47534C46524B45524B45514A44504943514843
52474155484256494356494355484253464051443E50433D4E413B4D403A4D403A4D403A4C3F39\
4B3E384B3E38493E384E433D4C433C4C433C4B423B4A413A4A413A494039494039
453C35453C35443B34443B34433A334239324239324138314037304037304037303F362F3E352E\
3D342D3D342D3D342D3A312A403730413831362D26261D161E150E231A132A231D
2928262828282929292828282727272424242222222020201D1D1D1A1A1A151515111111101010\
1111111313131515151616161414141111110E0E0E0D0D0D0E0E0E101010111111
1010100E0E0E0C0C0C0A0A0A0A0A0A0D0D0D111111131315120F1814111C1916211E1B24221F28\
26232C28252C29272C312F342F2D302C2A2D2A28292A28292A29272C2B292F2C25
615A4A534834433824413622483D29504531524733524733483D29433824403521433824483D29\
473C283E331F352A16382D1B352A18332816352A18392E1C3B301E392E1C362B19
3D32203C311F3C311F3B301E3A2F1D3A2F1D392E1C392E1C3B301C3A2F1B3A2F1B392E1A382D19\
382D19372C18372C18352A16352A16352A16352A16352A16352A16352A16352A18
372A19372A1A392C1C3A2D1D372B1D34281A32281C342C212B231829221827231A28241B28251E\
2B28212B2B232C2C24
0B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F12\
0B0F120B0F120B0F120D11140D11140D11140D11140D11140D11140D11140D1114
0B0F120A0E110A0E110D11141115181014170B0F12060A0D161A1D1115180D11140C10130D1114\
0E12150C1013090D100D11140D11140D11140D11140D11140D11140D11140D1112
0D11120D11100D11100D11100D11100D11100D11100D11100D11100D11100D11100D11100D1110\
0D11100D11100D11100D13130B11110A10100C12120F15150F15150C1212080E0E
0A10100A10100A10100A10100A10100A10100A10100D0F0E120F0A0E07012F282257504A59524C\
544D4757504A524B45544D47544D47534C46524B45524B45514A44504943514843
51464054474155484255484254474153464051443E50433D51443E51443E50433D4F423C4E413B\
4E413B4D403A4B403A4B403A4A413A4A413A494039483F38473E37473E37473E37
453C35453C35453C35443B34433A334239324239324239323F362F3F362F3E352E3E352E3D342D\
3C332C3C332C3B322B3B322B3D342D3E352E382F28302720292019271E1727201A
201F1D1F1F1F2020201F1F1F1E1E1E1B1B1B1919191717171E1E1E1919191111110B0B0B090909\
0D0D0D1313131717171111110F0F0F0D0D0D0C0C0C0B0B0B0C0C0C0D0D0D0D0D0D
0606060707070808080B0B0B0F0F0F1414141818181C1A1D19141B1D1721231D272A252C2F2A31\
322D33332E34332E32393536363231312D2C2F2B28302C2935312E3B3734413D34
5148394B402E4338264439274B402E4D4230453A283A2F1D3E33213B301E3D32204A3F2D584D3B\
584D3B483D2B372C1A342917332816322715352A18392E1C392E1C352A18312614
3C311F3C311F3B301E3A2F1D3A2F1D392E1C382D1B382D1B3A2F1D3A2F1D392E1C382D1B382D1B\
372C1A362B19362B19352A18352A18352A18352A18352A18352A18352A18352A18
2C201034281A392D1F34281A2D21132B1F1130261A372D212E241830281D352D223A33293F382E\
433C32433F34444035
0B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F12\
0B0F120B0F120B0F120D11140D11140D11140D11140D11140D11140D11140D1114
0A0E110A0E110A0E110E12151216191115180D1114080C0F191D2014181B0E12150B0F120C1013\
0D11140C10130A0E110D11140D11140D11140D11140D11140D11140D11140D1112
0D11120D11100D11100D11100D11100D11100D11100D11100D11100D11100D11100D11100D1110\
0D11100D11100D11100D13130B11110A10100C12120F15150F15150C1212080E0E
0A10100A10100A10100A10100A10100A10100A10100D0F0E14110C0F08022F2822564F4958514B\
534C4657504A534C46544D47544D47534C46524B45524B45514A44504943514843
51464053464054474154474154474152453F50433D4F423C52453F52453F51443E4F423C4E413B\
4D403A4C3F39493E38453C35453C35443B34443B34433A33423932423932413831
443B34443B34443B34433A334239324138314138314138313E352E3D342D3D342D3C332C3B322B\
3B322B3A312A3A312A3B322B3B322B3A312A3A312A382F28332A232B221B251E18
1817151717171818181717171616161313131111110F0F0F1919191515150F0F0F0B0B0B0A0A0A\
0C0C0C1111111414140B0B0B0B0B0B0A0A0A0A0A0A0909090A0A0A0A0A0A0A0A0A
0707070909090D0D0D1313131919191E1E1E2222222523242720272C222A322830382E363C3338\
3D34393C33363B32333B32333A323039312E3A322F3E3731443D374A433D4E473D
393021483D2B5146344D4230433826392E1C2E2311251A083126143025133A2F1D5449376F6452\
776C5A675C4A544937463B294136243B301E392E1C392E1C3A2F1D382D1B352A18
392E1C392E1C382D1B372C1A372C1A362B19352A18352A18372C1A372C1A362B19352A18352A18\
342917332816332816332816332816332816332816332816332816332816332717
332719362D1E372B1D2F23152C201235291B3E342843392D463C304B4135544A3E5E5448675D51\
6D63576F675A70685B
0B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F12\
0B0F120B0F120B0F120D11140D11140D11140D11140D11140D11140D11140D1114
0A0E11090D100B0F120F131613171A13171A0F13160A0E111C2023161A1D0F13160B0F120C1013\
0D11140C10130B0F120D11140D11140D11140D11140D11140D11140D11140D1112
0D11120D11100D11100D11100D11100D11100D11100D11100D11100D11100D11100D11100D1110\
0D11100D11100D11100E12110C100F0B0F0E0D11101014131014130D1110090D0C
0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0D0F0C15120D0F08022E2721554E4857504A\
534C4658514B554E48544D47544D47534C46524B45524B45514A44504943514843
5045415146425146425247435146424F44404D423E4C413D4C413D4C413D4A3F3B493E3A473C38\
453A36443935433834453C37433C36433C36423B35413A34413A34403933403933
413A34413A344039333F38323F38323E37313D36303D36303B342E3B342E3A332D3A332D39322C\
38312B38312B37302A38312B37302A37302A3A332D3B342E37302A2E2721241F1B
1C1B191B1B1B1B1B1B1B1B1B1919191717171414141313131111111111111010100F0F0F0F0F0F\
0E0E0E0E0E0E0E0E0E0F0F0F0F0F0F101010111111111111111111101010101010
1010101414141A1A1A2121212727272B2B2B2C2C2C2E2C2D3A31343D323640353942373B43393A\
4238394137363F3533413735423934443B34463D36483F36494037494037494136
52493A514837483F2E3F3625443B2A4D4433483F2E3A3120352C1B352C1B4138275F56457E7564\
8B82717F76656F66555C5441514936413926362E1B322A17342C19352D1A362E1B
39311E39311E38301D372F1C372F1C362E1B352D1A352D1A372E1D372E1D362D1C352C1B352C1B\
342B1A332A19332A19332A19332A19332A19332A19332A19332A19332A19332A19
3A302439312432281C2D23173B3125544A3E64584A635749635749695C4C706353776A5A7D7060\
817464827564827564
0B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F12\
0B0F120B0F120B0F120D11140D11140D11140D11140D11140D11140D11140D1114
0A0E11090D100B0F120F131614181B14181B1014170C10131F2326181C1F0F13160B0F120B0F12\
0D11140D11140C10130D11140D11140D11140D11140D11140D11140D11140D1112
0D11120D11100D11100D11100D11100D11100D11100D11100D11100D11100D11100D11100D1110\
0D11100D11100D11100E12110C100F0B0F0E0D11101014131014130D1110090D0C
0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0B0F0E0E0E0C17120E1009032E2721544D47554E48\
524B4558514B564F49544D47544D47534C46524B45524B45514A44504943504943
4E45405045415146425146425045414E433F4D423E4B403C5146425045414F44404D423E4A3F3B\
483D39473C38453C37453E38453E38443D37433C36433C36423B35413A34413A34
3D36303D36303C352F3C352F3B342E3A332D3A332D39322C3A332D39322C39322C38312B37302A\
37302A362F29362F29342D27342D27362F2938312B3A332D37302A302923292420
2726242727272727272626262525252323232020201F1F1F0E0E0E0F0F0F111111121212121212\
1010100F0F0F0E0E0E1818181919191B1B1B1D1D1D1E1E1E1D1D1D1C1C1C1B1B1B
1919191F1F1F2727273030303636363838383838383A3637493F40493D3D4B3D3D483C3C493B3A\
473C3A493B38473C3850433D4F453C51443C4E443A4D4037463C3043372B3D3327
4037283A3120352C1B473E2D736A599188777D7463564D3C5148374F4635554C3B685F4E7F7665\
8A8170837A69786F5E68604D59513E433B28332B182D25122E2613312916342C19
3C34213C34213C34213B33203A321F39311E39311E39311E3A31203A31203A312039301F382F1E\
372E1D372E1D372E1D382F1E382F1E382F1E382F1E382F1E382F1E382F1E373020
30281D342C2130281D30281B493F336C62567D7163776B5D796C5C796C5C7C6C5C7C6C5C7C6C5C\
7A6B58786956776855
0B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F12\
0B0F120B0F120B0F120D11140D11140D11140D11140D11140D11140D11140D1114
0A0E11090D100B0F1210141714181B15191C1216190D11142125281A1E211014170B0F120B0F12\
0C10130D11140C10130D11140D11140D11140D11140D11140D11140D11140D1112
0D11120D11100D11100D11100D11100D11100D11100D11100D11100D11100D11100D11100D1110\
0D11100D11100D111010120F0E100D0D0F0C0F110E1214111214110F110E0B0D0A
0D0F0C0D0F0C0D0F0C0D0F0C0D0F0C0D0F0C0D0F0C0E0F0A18130F1009032E2721534C46554E48\
524B4558514B57504A544D47544D47534C46524B45524B45514A44504943504943
4E44424E44424F45434F45434F45434D43414B413F4A403E4C42404B413F493F3D473D3B443A38\
4238364036343F35333F37343C37333C37333B36323A35313A3531393430393430
38332F37322E37322E36312D35302C35302C342F2B342F2B36312D36312D36312D35302C342F2B\
332E2A332E2A332E2A2D2824302B27332E2A342F2B332E2A312C282F2A262E2A27
2D2C2A2D2D2D2D2D2D2D2D2D2B2B2B2929292626262525251313131212121010100F0F0F0F0F0F\
1111111313131414141B1B1B1D1D1D1F1F1F2222222323232222222121211F1F1F
1C1C1C2323232E2E2E3939394141414444444343434541405145455042414E3F3C4A3C394B3C37\
4D403A51423B53463E55473E52463A5042374C4032493B2E463A2C453828433727
3D3425484131554E3E6962528C8575A29B8B8C8575645D4D6D6656676050635C4C686151726B5B\
797262787161756E5C67604D59523F453E2B362F1C2F28152F2815312A17322B18
37301D37301D362F1C352E1B352E1B342D1A332C19332C19352E1C352E1E342D1D332C1C332C1C\
322B1B312A1A312A1A332C1C332C1C332C1C332C1C332C1C332C1C332C1C332C1C
332B20433C324B443A4A44385B5348796F6385796B7D7163897C6C877A6A857565827360806F5D\
7E6D597D6C587D6C58
0B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F12\
0B0F120B0F120B0F120D11140D11140D11140D11140D11140D11140D11140D1114
090D10090D100B0F1210141715191C161A1D1216190E121523272A1B1F221115180B0F120A0E11\
0C10130D11140D11140D11140D11140D11140D11140D11140D11140D11140D1112
0D11120D11100D11100D11100D11100D11100D11100D11100D11100D11100D11100D11100D1110\
0D11100D11100D111010120F0E100B0E0E0C0F110C13131112140F10100E0B0D08
0E0E0C0D0F0A0E0E0C0D0F0A0E0E0C0D0F0A0E0E0C0F0E0A18130F110A042D2620524B45544D47\
524B4559524C57504A544D47544D47534C46524B45524B45514A44504943504943
4D43414E44424F45444F45434E44434D43414B4140493F3D382E2D372D2B352B2A332927302625\
2E24222C22212A221F332E2B332E2A322D2A312C28312C29302B272F2A272F2A26
35302D35302C35302D342F2B332E2B322D29322D2A322D2936312E35302C35302D342F2B332E2B\
332E2A322D2A322D292A25222F2A26332E2B332E2A2F2A272D28242F2A27322E2B
2C2B292B2B2B2C2C2C2B2B2B2A2A2A2727272525252323231919191414140F0F0F0B0B0B0B0B0B\
1010101616161B1B1B1717171919191C1C1C1F1F1F2020202020201E1E1E1C1C1C
1A1A1A2222222F2F2F3D3D3D4646464A4A4A4A4A4A4C484752474551423D4D3E394A3B344C3D36\
51433A5749405C4E434F41364C3E31483A2D453828453828493C2B4F4231514634
82796A9891819A93837F78686C6555736C5C7A73637770607B7464726B5B686151645D4D676050\
6C6555716A5A726B5B655E4C5A53404A43303E372438311E362F1C352E1B342D1A
2E27142E27142D26132D26132C25122B24112B24112A23112C25152C25152B24142B24142A2313\
2922122922122821112A23132A23132A23132A23132A23132A23132A2313292315
494238665F55787167736C62766D64857D728B81758178699387799185758E81708C7F6E8D7E6B\
8F806D92816F948371
0B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F12\
0B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F12
0D1114070B0E0E12151E22250206093C404324282B282C2F3135381B1F22090D10070B0E080C0F\
05090C080C0F101417090D10090D10090D10090D10090D10090D10090D10090D0E
080C0D090D0C090D0C0B0F0E0C100F0D11100E12110E12110B0F0E0A0E0D090D0C090D0C0A0E0D\
0C100F0D11101113100F100B0E0F090F0E0A13140E1C1B171E1F191615110A0B05
18171316171117161215161015141014150F14130F14130E1B1610231C162D262039322C443D37\
4C453F514A44534C46524B455B544E58514B342D27645D5748413B47403A4C4441
4C44424C44424B42434A42404A414249413F483F4048403E3E3536372F2D2D2425231B191E1516\
1E1614211819241C1A231D1D221E1B221E1D221E1B221E1D221E1B221E1D221E1B
24201F24201D24201F24201D24201F24201D24201F24201D2622212723202824232A26232C2827\
2D29262F2B2A2F2B282824232824212925242A26232A26252B27242C28272C2827
2826272828282A2A2A2B2B2B2A2A2A2727272323232121210C0C0C0D0D0D0E0E0E101010141414\
1919191D1D1D1F1F1F1B1B1B1A1A1A1A1A1A1A1A1A191919191919191919191919
1818182424243535354141414646464747474848484B4746554A464E3F38493A334C3D364E3F38\
4C3E3552443B5C4E435E50454E40333D30203B2E1D493C2B5C4F3E685B4A6C614F
928B7B938D7F898375756F616C6658736D5F7F796B847E70797365837D6F746E60676153716B5D\
716B5D6D675978726277725F645F4B524D394A4531433E2A3A352138331F3D3824
3A35213A352139342039342038331F37321E37321E36311E322C1C312B1D302A1C2F291B2D2719\
2C26182B25172A2416302A1C2E281A2B2517282214262012241E10241E10241E10
433C326D6960837F76878378948D838C867A7A7267766E6181776B8E8478968A7C9185778C8072\
8D81738C7F6F867969
0B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F12\
0B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F12
080C0F060A0D10141724282B2A2E317F83867B7F828185886F73763E424513171A0C10130F1316\
0B0F120D1114181C1F0C10130C10130C10130C10130C10130C10130C10130C1011
0E12130E12110F13121014131115141115141216151216151014130F13120E12110E12110F1312\
1014131216151517140C0D0812110C13120D1817122D2C2749484354534E504F4A
4C4B464C4B464B4A454A49444A49444948434847424A474245403A4A433D4E4741514A44544D47\
554E48544D47544D47443D3749423C47403A38312B534C46524B4558514B5A524F
4A4240484242494041474141483F40453F3F473E3F443E3E453C3D3B3535302728211B1B1A1112\
140E0E150C0D140E0E130F0E11100E130F0E11100E130F0E11100E130F0E11100E
110D0C0F0E0C110D0C0F0E0C110D0C0F0E0C110D0C0F0E0C120E0D11100E14100F141311171312\
1716141A1615191816211D1C201F1D221E1D21201E24201F22211F252120232220
2020202121212323232323232222222020201D1D1D1B1B1B0D0D0D0D0D0D0E0E0E111111141414\
1818181C1C1C1E1E1E1010101111111212121515151717171A1A1A1B1B1B1C1C1C
1414141919192424243636364747475050504F4F4F4E4A49352A262E211935261F4E413964554E\
61544B52443B45392D3123183B2F215346367065538B7E6D9388768C7F6E7E7663
6962526B68596A64565D5A4B5E584A6966577973657C796A7A74667E7B6C7771636D6A5B787264\
787566797365817E6D7D78656A68535D584455533E534E3A4A48334C4733504E39
534E3A504E39524D394F4D38504B374E4C374F4A364D4A374E48384B48394C4638494637494335\
464334474133444132443E30403D2E3F392B3A37283A3426373425383224363226
4541366E6A6189857C8F8B82918D84848075706C6169655A8D867C928B818F887E847D73817A70\
867F75888177847E72
0B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F12\
0B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F12
11151810141713171A1D212445494CADB1B4B1B5B8B4B8BB989C9F4B4F520C1013090D1013171A\
0B0F1205090C0E12150A0E110A0E110A0E110A0E110A0E110A0E110A0E110A0E0F
0C10110C100F0C100F0D11100E12110E12110F13120F13120C100F0B0F0E0B0F0E0A0E0D0B0F0E\
0D11100F1312121411100F0A17140D0F0C050B080129261F5B5851716E676A6760
6A676069665F69665F68655E67645D67645D66635C66635C645F59665F59665F59645D57615A54\
5D565059524C57504A67605A665F595D5650564F49362F29443D37453E383E3633
464040454142453F41444041443E40423E3F433D3F413D3E3F393B3632332B25271D191A140E10\
0E0A0B0E080A0D090A110F10101010110F10101010110F10101010110F10101010
0B090A0A0A0A0B090A0A0A0A0B090A0A0A0A0B090A0A0A0A0C0A0B0C0C0C0E0C0D0E0E0E100E0F\
1111111311121212121715161616161715161717171917181919191A1819191919
1717171818181919191A1A1A1919191717171515151414140F0F0F0F0F0F0F0F0F111111141414\
1717171B1B1B1D1D1D1313131414141515151717171A1A1A1C1C1C1D1D1D1E1E1E
1C1C1C1515151414141F1F1F2F2F2F3535352E2E2E262221372E29392E28463933534940574A42\
453B313629202D23173E32264C43346A5E50877E6D9C9080978F7C867B69726B59
726C5E747265736F636866596662566D6B5E7571657472657F7B6F7D7B6E7A766A7876697A766A\
7A786B7D796D817F70706D5A605F4A55533E52513C52503B4D4C374F4D3854533E
56543F54533E55533E53523D53513C52513C52503B51503C555243535144534F43514F42504C40\
4E4C3F4E4A3E4C4A3D474337444235423E323E3C2F3D392D3B392C3B372B3B372B
423E336861578A867D959188908C8383807975726B6C69628786818988838485807D7E797D7F7C\
83858280827F787A75
0B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F12\
0B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F12
15191C15191C14181B13171A595D60BFC3C6C0C4C7BBBFC2ACB0B353575A0E121512161924282B\
191D200A0E110D1114101417101417101417101417101417101417101417101415
0F13140F13120F13120F13120F13121014131014131014130D11100D11100C100F0C100F0C100F\
0E12111014131315121C1B1624211A221F182F2C256C6962B8B5AED6D3CCC9C6BF
C9C6BFC8C5BEC8C5BEC7C4BDC6C3BCC6C3BCC5C2BBC6C1BBCAC3BDCAC3BDC9C2BCC9C2BCC7C0BA\
C6BFB9C4BDB7C4BDB7BCB5AFBFB8B2B1AAA4A39C96453E38514A444C453F3E3935
443E3E423E3F423E3F413D3E403C3D403C3D3F3B3C3F3B3C2C28292723241F1B1C171314130F10\
110D0E130F10121011151515151515151515151515151515151515151515151515
0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F101010101010111111121212131313\
141414141414151515101010111111111111121212131313131313141414141414
121212121212131313131313131313121212111111111111111111101010111111111111131313\
1616161919191B1B1B2424242323232222222121212020201F1F1F1E1E1E1D1D1D
1D1D1D1616160F0F0F1010101616161717170F0F0F0807050F0704271E19433A354940393B322B\
3A31285C534A857D729F978C9A9285938B7E9089798E8777898270817A68797363
83807187857884827579776A757366777568767467706E6183817477756879776A7E7C6F757366\
72706377756874726364634F5655404C4B364C4B364C4B364847324A4934504F3A
4D4C374C4B364C4B364B4A354A49344A49344948334948344C4A3B4C4A3D4A483B49473A484639\
464437454336444235424033403E313D3B2E3A382B383629373528373528383428
3F382E585147827B739692898E8B848887828788837E7F7A7E807D838786858B8B828A8C838D8F\
848F937A85896B767A
0B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F12\
0B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F12
090D100C101313171A161A1D7C8083D2D6D9CCD0D3C6CACDC7CBCE6F7376262A2D2024272E3235\
262A2D1D2124202427181C1F181C1F181C1F181C1F181C1F181C1F181C1F181C1D
1A1E1F1A1E1D191D1C191D1C191D1C191D1C191D1C181C1B161A19161A19151918151918151918\
171B1A191D1C1C1E1B17140D19150C19150C332F2679756CBFBBB2CDC9C0B5B1A8
C4C0B7C4C0B7C3BFB6C3BFB6C2BEB5C1BDB4C1BDB4C0BCB3C0B9B3C0B9B3C0B9B3C1BAB4C2BBB5\
C3BCB6C4BDB7C5BEB8BFB8B2D0C9C3CAC3BDB0A9A3413A3447403A48413B413C38
3E383A3D383C3C373B3B363A3B363A3A35393934383934381F1A1E1C171B171216130E12120D11\
130E121611151614170F0F110E0F110E0F110E0F110E0F110E0F110E0F110E0F11
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0C0D0F0D0E10\
0D0E100D0E100E0F110E0F110E0F110F10120F1012101113111214111214121315
111111101010101010101010101010111111111111121212131313121212121212121212131313\
1515151717171818182626262525252424242323232121211F1F1F1E1E1E1D1D1D
1111111212121313131212121111111111111313131615130904011D1512302825302923221B15\
2B241C5B544C8F887E968F858D877B807A6E7872647771637D7767837D6D858273
7573667A786C7B796D7674687775697C7A6E7A786C737165767468605E526D6B5F7C7A6E6C6A5E\
6A685C7573676D6B5E6A69555C5B4653523D53523D53523D4E4D384E4D3853523D
51503B51503B51503B504F3A4F4E394E4D384E4D384E4D394E4C3F4E4C404D4B3F4B493D4A483C\
48463A4745394745394745394543374240343F3D313D3B2F3C3A2E3C3A2E3D392E
4640344C463A7871679490878A87808B8C87949693858B8B7A82847D888C79868C6F80886C7E88\
6C808B637984576D78
0B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F12\
0B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F12
080C0F090D10181C1F202427999DA0D2D6D9C0C4C7C1C5C8CFD3D6888C8F4044472226291E2225\
1C20231D212423272A191D20191D20191D20191D20191D20191D20191D20191D1E
1E22231E22211E22211D21201C201F1C201F1B1F1E1B1F1E191D1C191D1C181C1B181C1B181C1B\
1A1E1D1C201F1F211E333029332F263E3A31635F569E9A91C8C4BBC8C4BBB3AFA6
C4C0B7C3BFB6C3BFB6C2BEB5C1BDB4C1BDB4C0BCB3C0BCB3C2BBB5C1BAB4BFB8B2BEB7B1BDB6B0\
BEB7B1BFB8B2C0B9B3A7A09ABEB7B1B3ACA67F78722B241E251E182C251F2C2723
322E2F322D31322D31312C30302B2F2F2A2E2F2A2E2F2A2E1F1A1E1C171B181317130E12110C10\
100B0F110C10100E110E0E100D0E100D0E100D0E100D0E100D0E100D0E100D0E10
0D0E100D0E100D0E100D0E100D0E100D0E100D0E100D0E100C0D0F0C0D0F0C0D0F0C0D0F0C0D0F\
0C0D0F0C0D0F0C0D0F0E0F110E0F110F10120F1012101113111214111214121315
1111111010100F0F0F0F0F0F0F0F0F111111131313141414151515141414131313121212121212\
1414141515151616161616161717171717171818181919191A1A1A1A1A1A1B1B1B
0F0F0F1313131515151212120D0D0D0A0A0A0C0C0C110F101D191814100D0E0A070E0B060C0904\
0C090218150E28251C2A271E3432264644385B594C6E6C5F7D7B6C8785768B897C
7C7A6E817F73807E727C7A6E7F7D7185837782807478766A5F5D514240345B594D78766A666458\
69675B7C7A6E716F626B6A565E5D48565540575641565540504F3A504F3A54533E
56554056554055543F54533E54533E53523D52513C52513D504E41504E424F4D414D4B3F4C4A3E\
4A483C49473B49473B4745394543374240343F3D313D3B2F3C3A2E3C3A2E3D392E
534D41484035716A6095918887847D8889848F9392727C7E63707663747C596D78465C693A5463\
3D5869405D6F3E5D6F
0B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F12\
0B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F120B0F12
1216190D11142125282E3235B2B6B9CCD0D3B3B7BAC0C4C7C9CDD0A7ABAE75797C4B4F5234383B\
2E32352C30332A2E312B2F322B2F322B2F322B2F322B2F322B2F322B2F322B2F30
2B2F302B2F2E2A2E2D2A2E2D292D2C282C2B272B2A272B2A252928242827242827232726242827\
262A29282C2B2B2D2A14110A1E1A11413D3479756CA8A49BBDB9B0C3BFB6C6C2B9
BFBBB2BFBBB2BEBAB1BEBAB1BDB9B0BCB8AFBCB8AFBBB7AEC3BCB6C1BAB4BDB6B0B9B2ACB7B0AA\
B7B0AAB8B1ABB9B2ACC3BCB6CFC8C2AFA8A258514B362F29231C162B241E2A2521
252122232124222023211F22211F22201E211F1D201F1D201C1A1D1A181B1614171210130F0D10\
0E0C0F0E0C0F0E0C0F121214111214111214111214111214111214111214111214
1011131011131011131011131011131011131011131011130F10120F10120F10120F10120F1012\
0E0F110E0F110E0F110D0E100D0E100D0E100E0F110F1012101113101113101113
1010100F0F0F0D0D0D0C0C0C0D0D0D101010131313151515171717161616141414131313121212\
1313131414141515150E0E0E0F0F0F0F0F0F101010101010111111111111111111
1010100F0F0F0F0F0F1010101111111010100C0C0C090909100E0F0504020100000B0A0612110D\
12110C11100B13130B0D0D051B1B1132322849493D5B5B4F67685A6E6F61717264
74746877776D77776D75756B7D7D7387877D85857B7C7C725353492F2F2552524878786E636359\
68685E81817772736563655057594350523C53553F5456404F513B4E503A52543E
51533D51533D51533D50523C4F513B4E503A4E503A4E503B4C4D3F4B4B414A4A4049493F47473D\
46463C45453B44443A4343394141373E3E343B3B3139392F37372D37372D39372B
554D423C34296962589692898685808587848389895661653B4C54495D684D6472415C6D355468\
34576D3A5E763E627A
0D0E100B0F100D0E100B0F100D0E100B0F100D0E100B0F100D0E100B0F100D0E100B0F100D0E10\
0B0F100D0E100B0F100D0E100B0F100D0E100B0F100D0E100B0F100D0E100B0F10
17181A0D1112292A2C3C4041CDCED0DADEDFC6C7C9DDE1E2D0D4D7D2D6D9BEC2C595999C74787B\
65696C575B5E494D504C50534C50534C50534C50534C50534C50534C50534C5051
4549484448474347464246454145444044433F43423F43423D41403D41403C403F3C403F3C403F\
3E424140444343454275726B7E7A719E9A91C4C0B7CBC7BEB8B4ABB3AFA6C1BDB4
CAC6BDCAC6BDC9C5BCC9C5BCC8C4BBC7C3BAC7C3BAC6C2B9C8C1B9C5BEB6C2BBB3BEB7AFBDB6AE\
BDB6AEBFB8B0C0B9B1BBB4ACBCB5AD8C857D211A1229221A120B031C150D1A150F
1C17131B17141A16131A1613191514181413181413151314171516161415141213121013110F12\
1010121210131111130D0E100D0E100D0E100D0E100D0E100D0E100D0E100D0E10
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0A0B0D0A0B0D0A0B0D090A0C090A0C\
08090B08090B08090B0B0C0E0C0D0F0C0D0F0D0E100E0F110E0F110F10120F1012
0E0E0E0D0D0D0B0B0B0A0A0A0C0C0C0E0E0E121212141414181818161616141414131313121212\
1212121313131414141314161213151011130D0E100C0C0C090909080607070604
0908060703020905021713102A2522332E2A2F2A2627221E47423F44403D423D3937342F231E1A\
0E0B04100B051C19121C180F19160D1511060F0D010E0A00110F021915091E1C0F
413F3347443B4D4A4156534A6A675E7F7C7386837A817E7559564D312E2556534A7F7C73656259\
69665D838077727064646553595B46535540585A455A5C475658435658435B5D48
53554052543F52543F51533E50523D50523D4F513C4F503E504E42504D444F4C434D4A414C4940\
4A473E49463D49463D4A473E48453C46433A423F36403D343F3C333F3C33403C31
4D453A2F251B61584F99928A8B88838787857E83864651572234403F596A5C7C936186A35582A3\
5080A64D81A94B80AA
0A0A0A090B0A0A0A0A090B0A0A0A0A090B0A0A0A0A090B0A090909080A09090909090B0A0A0A0A\
090B0A0B0B0B0A0C0B0A0A0A0E100F1414141416151212120E100F0E0E0E0D0F0E
0B0B0B181A19242424525453A4A4A4CDCFCEC2C2C2B3B5B4BDC1C2C0C6C6B9BFBF9CA2A2767C7C\
595F5F525858565C5C535959454B4B535959606666505656494F4F555B5B575D5D
4E54524E54524D53514C52504A504E494F4D484E4C484E4C4A504E474D4B444A48434947474D4B\
5056545A605E62676383837B9E9B92B5B2A9BBB8AFB6B3AAB6B3AABEBBB2C5C2B9
CBC8BFCAC7BEC8C5BCC7C4BBC7C4BBC7C4BBC8C5BCCAC6BBC9C2B8C0BAAEC3BDB1C1BBAFB7B1A5\
C3BDB1C7C1B5B0AA9EC9C3B7BBB5A9888276413B2F171105191307231D11221C10
251F13241E12221C101F190D1A160B17130A15100A13100B322E2B060501171614191919101012\
14151707060B0D0E120F10140D11140D11140D11140D11140D11140D11140D1114
0A0E11090D10080C0F070B0E070B0E080C0F090D100C0D0F0C0D0F0D0D0D0D0D0D0D0D0D0D0D0D\
0D0D0D0D0D0D0D0D0D0404040A0A0A0F0F0F0D0D0D0808080707070C0C0C121212
0B0B0B0D0D0D0F0F0F1010101111111111111111111010101A1A1A1919191717171313130F0F0F\
1111111717171B1C1E0D10150C11170C0F140B0F120C0D0F0D0B0C0E0A090E0906
120A07160D0820150F2F221A3C2E253F31263B2A203322185042394A3D3541322B3528202C1D16\
24170E21130A1E11081F11081E110820120920130A22140B22160A24160B21170D
332C222C281D343025322E237470657470657F7B707C786D4C483D4844395B574C6B675C686459\
716D6279756A6D695E6765586260535C5A4D5A584B5B594C5A584B585649555346
5452455553465755485856495654475250434D4B3E4A483B4B473C4C483F4E4A414E4A414D4940\
4C483F4A463D48443B4D494049453C433F36403C333F3B32403C333F3B32403931
564D444E443B453B328B827B9D96907E7A7986878C5C646F0C1E3249678351789F4478A84280B9\
3A81C13885CB2A7AC3
11111111110F11111111110F11111111110F11111111110F0F0F0F0F0F0D0F0F0F10100E101010\
10100E10101010100E0707070A0A080D0D0D0D0D0B0B0B0B0B0B090F0F0F121210
1010102828262626261919171A1A1A11110F040404080A091317181A20201F2525181E1E0A1010\
020808070D0D0F1515282E2E1A2020272D2D343A3A252B2B202626282E2E262C2C
2A3030292F2D282E2E252B292329292127251F25251E2422191F1F161C1A131919111715131919\
181E1C1E242423282414130E1F1C1325221B221F161D1A131E1B1224211A2A271E
302D26302D24312E27322F2634312A38352C3B38313D3A31514B3F5B5547807A6C9A9486999385\
A19B8DAEA89AA8A294928C7E9B9587948E80827C6E827C6E908A7C918B7D847E6E
89827288816F857E6C837C6A7F796B7C766A78746977736A3F3C37100F0A1D1C1A1C1C1A101113\
13141606070B0D0E120D11140D11140D11140D11140D11140D11140D11140D1114
0A0E11090D10080C0F080C0F090D100B0F120D11140E1213171719171717171717171717171717\
1717171717171717170F0F0F121212151515151515131313111111111111121212
1515151515151616161616161515151414141313131212121919191919191717171313130F0F0F\
1111111717171C1D1F0C1117080F15080D13070A0F090A0E0D0B0C120E0D170F0C
1F1611271A1233251C4333264E3C30503D2F4933253F2C1E4C3A2E49372D4432283F2D233B291F\
39271D39271D39271D36241A36241A37251B38261C39271D3A281E3A281E382A1F
352C232E271D3730263831277F786E80796F888177827B71443D33453E345D564C6E675D696258\
726B6180796F777368716D6269675B615F535A584C565448514F434B493D464438
454337434135413F333F3D313E3C303E3C303E3C303F3D31463F3747403849423A4B443C4D463E\
4D463E4D463E4D463E5049414D463E49423A463F37453E36443D35433C34433C32
493F364C42393F352C7D746DA2999488848389888E6D75820A1C34405E80517DAA4C84BD468CD1\
3F91DD3D96EA3290E7
1111131111111111131111111111131111111111131111110F0F110F0F0F0F0F110F0F0F0F0F11\
0F0F0F0E0E100E0E0E1D1D1F1D1D1D1C1C1E1717171313151212121616181A1A1A
1313153232323333351D1D1D1212140A0A0A0D0D0F212224040809070D0D0B11110C12120B1111\
0D1313111717151B1B1B21210F15151D2323292F2F1D23231A20201F2525181E1E
2329292228282025281E24241B2023191F1F171C1F161C1C171C1F161C1C13181B121818111619\
11171713181B1418171F1E1A19160F110E090E0B04100D0814110A1916111D1A13
23201B23201923201B24211A26231E29261F2C29242E2B221913072E281A6E685AA19B8D9E988A\
958F81A19B8DA7A193999385A19B8DA09A8C9A9486A09A8CA7A1939A9486827C6C
968F7F958E7C938C7A9089778C86788983778581768480774E4B461C1B162423211E1E1C0F1012\
13141606070B0F10140D11140D11140D11140D11140D11140D11140D11140D1114
090D10090D10090D100A0E110C10130F13161216191418191E1E201E1E1E1E1E1E1E1E1E1E1E1E\
1E1E1E1E1E1E1E1E1E1C1C1C1C1C1C1D1D1D2020202121211E1E1E171717121212
1E1E1E1D1D1D1D1D1D1B1B1B1A1A1A181818171717161616181818181818171717131313101010\
1111111818181D1E2015181D0F141A0A0D1405090C07080A0E0C0D1713121F1714
2F2621382B2343352C50403358463A574436503A2C45322448362A45342A443329423127413026\
4231274332284433293A291F3A291F3B2A203B2A203C2B213D2C223D2C223B2D22
39302730291F3831273C352B857E74857E748881777D766C4B443A4C453B635C52726B61696258\
70695F7D766C747065736F646B695D6260545C5A4E5755495351454D4B3F48463A
4A483C4644383F3D3138362A3634283735293B392D3E3C30362F253730263A33293D362C40392F\
433C32463F35474036463F35463F35453E34443D33423B31423B31413A30413A30
40362D51473D3E342B696059A39A95918D8A8281867B838E1121383754745A85B05B94CB5297DA\
4C9BE8449DEF439FF4
141318141416141318141416141318141416141318141416141318141416141318131315131217\
1212141211161212140F0E13111113131217121214100F1411111315141919191B
1B1A1F28282A1A191E0B0B0D1514191515170B0A0F0E0F111418191016160D13130C12120C1212\
0A1010080E0E050B0B090F0F0208081016161B21210F15150E1414141A1A090F0F
0F14170E13160D12150C11140B10130A0F12090E11080D100E13160F14170F14170E13160D1215\
0C11140A0F120A0E0F1C1B19120F0A0B0704120F0A1C1815211E19231F1C25221D
1A161319161117131015120D130F0C13100B14100D14110A150F03251F11696355A9A395A7A193\
938D7F979183A09A8C9D97899C9688928C7E868072888274938D7F938D7F8A8474
8D86768C85738A837187806E837D6F807A6E7C786D7B776E53504B1F1E192423211C1C1A0D0E10\
12131508090D1213170D11140D11140D11140D11140D11140D11140D11140D1114
080C0F090D100A0E110C10130F131613171A161A1D191D1E1D1D1F1D1D1D1D1D1D1D1D1D1D1D1D\
1D1D1D1D1D1D1D1D1D2525252222222222222626262A2A2A2626261A1A1A101010
1E1E1E1D1D1D1C1C1C1B1B1B1B1B1B1B1B1B1C1C1C1C1C1C171717171717161616121212101010\
1212121919191E1F211D2124161B1F0F12170B0C100D0D0D151412201C192A221F
3E353042382F493C33504033524034503D2F4A372845322447372A45342A4332284130263E2D23\
3C2B213B2A203B2A2037261C37261C37261C37261C37261C38271D38271D36281D
3B3229322B213932283D362C878076857E74847D73756E646861575F584E6D665C766F656D665C\
6F685E716A605F5B504D493E474539413F333E3C303D3B2F3C3A2E38362A353327
3432262F2D2128261A2220141E1C101E1C10201E12222014251E14261F152922182C251B30291F\
332C22352E24373026342D233730263C352B3D362C3C352B3C352B3C352B3E372D
3E362B584E4440362D564D449B928B96918E78777C8088932435492F4C6A618CB76BA2D8599DDE\
53A1EB449BEB47A2F5
1E1D231E1D221E1D231E1D221E1D231E1D221E1D231E1D22222127212025212026201F241F1E24\
1E1D221D1C221D1C210E0D131413181C1B2121202523222826252A2B2A302F2E33
2C2B313433382221271514192221271F1E230A090F03040815191A1115140E1211101413141817\
161A191317161014131519181216152125242226250F13120E12111519180A0E0F
0A0E110A0D120B0E130B0E130C0F140C0F140D10150D1015080B100A0D120C0F140D10150E1116\
0C0F140B0E130B0C100A08090300000300000F0B08171312120E0B0E0A09110D0A
191514171310151110120E0B100C0B100C09100C0B100D081E170D1F190B565042969082A09A8C\
958F819892849B9587958F819C96889D9789958F818F897B918B7D948E80948E7E
958E7E948D7B928B798F88768B8577888276848075837F764F4C471B1A15201F1D1818160A0B0D\
111214090A0E15161A0D11140D11140D11140D11140D11140D11140D11140D1114
080C0F090D100A0E110C101310141714181B181C1F1B1F201C1C1E1C1C1C1C1C1C1C1C1C1C1C1C\
1C1C1C1C1C1C1C1C1C2626262323232222222626262929292525251919190E0E0E
1717171616161616161616161818181B1B1B1E1E1E202020161616161616151515121212101010\
1313131A1A1A1F21201A1E1F161A1B1415171416151A1A1A252422332F2C3E3731
4A413A4B41384B3E35493B2E48382B4634264534244533254535284234294032273E30253B2D22\
382A1F36281D34261B3A2C213A2C213A2C21392B20392B20392B20392B20382C20
382F26312A203A33293E372D878076857E74867F757A73697D766C6A63596D665C756E646F685E\
70695F6861574C483D49453A4240343B392D363428333125302E222B291D272519
222014211F131F1D111E1C101D1B0F1D1B0F1D1B0F1D1B0F201A0E231D112721152B25192E281C\
2E281C2E281C2D271B2C261A342E223C362A403A2E3E382C3C362A3E382C403A2E
3A322750483D40362C443B328C837C9B969378787A868D973C4B5E2843606690BA7AAFE366A7E7\
62AFF74DA0F052ABFD
25242C25242A25242C25242A25242C25242A25242C25242A29283028272D27262E26252B25242C\
23222822212922212727262E2A292F2C2B332A292F27262E26252B2928302C2B31
3A394157565C5C5B635453595B5A625A595F56555D6261674C4D4F484C4B474B4A494D4C4C504F\
4D51504C504F4A4E4D4347464549484F53523F43421A1E1D121615191D1C101415
13171A13161B14171C14171C15181D15181D16191E16191E0E111610131812151A14171C15181D\
15181D15181D17181C1E1C1D1915141D1918262221211D1C130F0E151110231F1E
2E2A292D29282D29282C28272D29282F2B2A312D2C322F2A2821171D17093C3628686254716B5D\
706A5C716B5D686254605A4C777163928C7E9E988A9B9587908A7C868072817B6B
918A7A9089778D86748B8472878173847E72807C717E7A714A47421716111D1C1A1717150A0B0D\
1112140A0B0F15161A0D11140D11140D11140D11140D11140D11140D11140D1114
080C0F090D100A0E110C10130F131613171A171B1E191D1E1E1E201E1E1E1E1E1E1E1E1E1E1E1E\
1E1E1E1E1E1E1E1E1E2222222121212121212323232323231E1E1E171717111111
1111111010101010101111111414141818181D1D1D212121151515161616151515121212101010\
1313131A1A1A212121141615151716181A191F1F1D29282636322F413C3848433D
4940374B41374C4034493B3046362944342546362749392A3D2F223E3025403227413328413328\
4032273E30253D2F243A2C213A2C213A2C21392B20382A1F382A1F37291E362A1E
332A212F281E3B342A3B342A7D766C7A736980796F797268746D63625B51655E546C655B665F55\
665F555E574D423E3349453A413F33373529302E222A281C2422161D1B0F18160A
1D1B0F1D1B0F1E1C101F1D11211F132220142321152422162721152C261A342E223B35293D372B\
3C362A383226352F23383226423C304C463A4F493D4A4438443E32443E32464034
342C213B33283D3329382F26776E67A09B978583848B929A5060701B3550648BB282B6E870B0ED\
74BFFF57A9F560B5FF
38364138373F38364138373F38364138373F38364138373F38364137363E36343F34333B32303B\
313038302E392F2E362E2C372D2C342A283326252D26242F2D2C3439374243424A
73717C8F8E96918F9A83828A82808B7C7B8379778286858B8384868385828284817F817E7B7D7A\
787A777779767779767A7C797E807D80827F5A5C591D1F1C090B080F110E060807
1112161112170F10150E0F140C0D120B0C11090A0F090A0F0A0B100A0B100A0B100A0B100B0C11\
0C0D120C0D120E0D120F0D100D090A120E0F1713140C08090400011D191A433F40
454142454142444041433F40444041454142474344484441564F454B4537585244666052625C4E\
676153676153554F41494335595345736D5F8C86789B95879D97899B95879A9484
99928297907E958E7C928B798E887A8C867A8783788682794A4742181712201F1D1A1A180C0D0F\
12131508090D1213170D11140D11140D11140D11140D11140D11140D11140D1114
090D10090D10090D100B0F120E121511151814181B161A1B1D1D1F1D1D1D1D1D1D1D1D1D1D1D1D\
1D1D1D1D1D1D1D1D1D1D1D1D2020202222222020201C1C1C181818161616171717
1313131111110F0F0F0E0E0E1010101515151A1A1A1D1D1D141414151515141414121212101010\
1414141B1B1B2222221B1B191E1E1C2424222B2A2631302C36332E39342E3A362D
352C233D3329473B2F493D3147392C443727453828473A2A3A2C1F3B2F233E322641352942362A\
42362A4034283F3327372B1F372B1F362A1E35291D34281C33271B32261A30261A
352C23332C223A33292E271D625B51564F455D564C5B544A5C554B544D435E574D615A504F483E\
4B443A4A43393834292E2A1F29271B25231724221626241828261A262418242216
2B291D2624181F1D1119170B15130715130716140818160A2B2519342E20413B2D4C4638514B3D\
4E483A484234433D2F4C4638565042605A4C5F594B544E40494335443E30453F31
3830252C24193D352A342C2161584F9E99938C8B89878C926572820F29425B81A57EB1E06EACE5\
75BFFF51A1EA59ACF8
55535E55545C55535E55545C55535E55545C55535E55545C52505B515058504E594E4D554C4A55\
4A495149475248474F4B49544C4B534E4C5756555D68667184838BA3A1ACB8B7BF
D0CED9DCDBE3CFCDD8C7C6CED8D6E1DDDCE4D1CFDAD2D1D7CDCDCDD0D2CDD3D3D1D0D2CDCCCCCA\
C8CAC5CBCBC9CED0CBC7C7C5CACCC7C6C6C48F918C43434125272229292720221F
302F342D2E322B2A3026272B2322281F20241D1C221A1B1F1E1D231C1D211B1A2018191D19181E\
18191D1A191F1B1A1F1C1A1B1B1718221E1F2723241F1B1C252122575354918D8E
D0CCCDCECACBCBC7C8C8C4C5C5C1C2C3BFC0C3BFC0C3BFBCBFB8AEBBB5A7C4BEB0C4BEB0BAB4A6\
C5BFB1CBC5B7B7B1A3C3BDAFB0AA9C9E988A979183979183979183979183989282
948D7D928B799089778E87758A8476878175837F74817D744D4A451B1A152322201D1D1B0F1012\
12131506070B0F10140D11140D11140D11140D11140D11140D11140D11140D1114
090D10090D10090D100A0E110C10130F131612161914181919191B191919191919191919191919\
1919191919191919191B1B1B2020202323231F1F1F1717171414141717171C1C1C
1717171414141111110E0E0E0F0F0F1212121717171A1A1A141414151515141414121212101010\
1414141C1C1C222220292A252D2C2731302B33322D33302B2D2A2327231A251E14
1F170C2C24193D3327483C30483C2E44382A433626423628392D213B2F233D31253F33273F3327\
3D31253A2E22382C203D31253C30243C30243A2E22392D21382C20372B1F352B1F
3C332A3831273A3329221B11463F3530291F352E24342D234A43394C453B5E574D5B544A3A3329\
2F281E362F252F2B2044403543413548463A545246636155706E6278766A7A786C
706E626563575452464240343634283230243230243432252A2416352F21464032554F415C5648\
595345524C3E4C4638585244635D4F6B6557676153575143474133403A2C3F392B
433B30282015423A2F342C2151483F99928A8A89857A7F82717F8A0A233954789A77A8D365A2D8\
6EB4F2418ED44898E1
727179727177717078706F75706F776F6E746E6D756E6D7365646C65646A66656D67666C67666E\
68676D69687069686E706F777372787B7A8288878D9998A0ABAAB0BBBAC2C5C4CA
D3D2DAD3D2D8D3D2DAD3D2D8D3D2DAD3D2D8D3D2DAD3D2D7C9C9C7C9CAC4CAC9C5C9CAC4CAC9C5\
C9CAC4CAC9C5C9CAC4C8C7C3CCCDC7C1C0BC93948E5857532D2E282524202C2D28
2F2D302C2C2E29272C242426201E231B1B1D18161B1616182422271E1E201A181D16161818161B\
18181A19171C1816192B27281A16151B1716272322201C1B201C1B5A5655A6A2A1
C1BDBCC5C1C0CECAC9C8C4C3BFBBBACFCBCACDC9C8AAA7A2BBB4AAA9A395BDB7A9DAD4C6D0CABC\
C0BAACBFB9ABBDB7A9CAC4B6B8B2A4A19B8D958F81958F81989284979183948E7E
999282968F7D928B79918A788F897B8C867A8480757E7A714B48431615101E1D1B1B1B19111214\
18191B0C0D111213170F13160F13160E12150D11140D11140C10130B0F120B0F12
070B0E080C0F0A0E110C10130E1215101417121619131718141416141414141414141414141414\
1414141414141414141A1A1A1919191818181717171717171818181919191A1A1A
1414141515151717171919191A1A1A1A1A1A1A1A1A1919191919191111110909090A0A0A111111\
1919191C1C1C1C1C1A23221D2D2A2336332C37342B332F262E2A1F312A20332D21
292116352D22433B2E4F4539554C3D534A3B4A3E303B32233A30243A30243A30243A30243A3024\
3A30243A30243A3024372D21372D21372D21382E22382E22382E22392F23392F23
362D24261F15332C223E372D2D261C2922183831273E372D524B415952485C554B554E44484137\
3F382E40392F423E3357534859574B5E5C5063615569675B6C6A5E6F6D61706E62
6D6B5F6B695D615F534F4D41413F333C3A2E3B392D3B392C3933253D3727443E2E4B4535504A3A\
534D3D544E3E544E3E635D4D625C4C605A4A5B5545565040504A3A4A4434474131
342E20373123322A1D3D3528372F24948D858E8D8880848575828B2940523556756592BB6AA4D6\
5398D33B86C74B9ADD
D7D6DBD7D6DBD7D6DBD7D6DBD7D6DBD8D7DCD8D7DCD8D7DCD8D7DCD8D7DCD9D8DDD9D8DDDAD9DE\
DBDADFDBDADFDCDBE0DCDBE0DAD9DED7D6DBD5D4D9D5D4D9D6D5DAD9D8DDDAD9DE
D2D1D6D2D1D6D2D1D6D2D1D6D2D1D6D2D1D6D2D1D6D2D2D4D7D6D2D7D6D1D7D6D1D7D6D1D7D6D1\
D7D6D1D7D6D1D7D6D1CECDC8DAD9D4DAD9D4BBBAB586858055544F3B3A3534332E
403F3D403E3F403E3F403E3F403E3F403E3F403E3F403E3F3C3A3B3A38393634353230312F2D2E\
2F2D2E2F2D2E302F2D18141324201D28242126221F403C397D7976BEBAB7E3DFDC
CCC8C5C8C4C1CDC9C6C9C5C2C4C0BDCECAC7C0BCB994918C352E243B3527736D5FB3AD9FC5BFB1\
C3BDAFC5BFB1C0BAACC3BDAFB4AEA0A19B8D9892849892849A9486989284948E7E
9A9383968F7D938C7A918A78908A7C8C867A8480757F7B724B48431615101D1C1A1A1A18111214\
18191B0B0C101213170F13160F13160E12150D11140D11140C10130B0F120B0F12
090D100A0E110B0F120C10130D11140F1316101417101415121214121212121212121212121212\
1212121212121212121616161515151515151414141515151717171919191A1A1A
1414141515151717171919191A1A1A1A1A1A1919191919191818181212120D0D0D0E0E0E151515\
1C1C1C1F1F1F1F1E1C27241D403E32605C516F6B606B675C615D515C564A5B5549
443C314C4439595144655D506A6353655C4D52493A413829261C10261C10261C10261C10261C10\
261C10261C10261C10281E12281E12281E12281E12281E12291F13291F13282013
322B21241D132E271D3831272922182922183C352B433C326D665C756E647D766C7C756B766F65\
746D637972687D796E77736878766A7D7B6F817F7385837788867A89877B8A887C
8280747F7D717270645E5C50514F434E4C404D4B3F4B493C4A44364B45354D47374E48384D4737\
4A4434464030443E2E524C3C524C3C514B3B504A3A4D4737494333464030443E2E
3832243B3527342C1F3D3528372F248A83799090888488877A848D3B5061203F5B5884A9578FC0\
4788C03980BE418CCD
C5C5C7C5C5C7C6C6C8C8C8CAC9C9CBCACACCCBCBCDCCCCCEC9C9CBCACACCCACACCCBCBCDCCCCCE\
CCCCCECDCDCFCDCDCFDBDBDDD9D9DBD7D7D9D5D5D7D2D2D4CFCFD1CDCDCFCCCCCE
CECED0CECED0CECED0CECED0CECED0CECED0CECED0CECECEC4C3BEC6C3BCC6C3BCC6C3BCC6C3BC\
C6C3BCC6C3BCC6C3BCBEBBB4CAC7C0D1CEC7C4C1BAA3A0997D7A73625F5855524B
3C39343D3A353E3B36403D38423F3A43403B44413C45423D3F3C373F3C373D3A3539363134312C\
322F2A33302B35322D383530413E3944413C4845406865609E9B96C6C3BED2CFCA
C6C3BEBCB9B4BFBCB7C0BDB8BFBCB7C7C4BFB3B0AB838079221C102E281A6B6557ADA799C1BBAD\
C2BCAEC3BDAFBAB4A6B8B2A4AEA89AA19B8D9B95879C96889D9789999385958F7F
9A938397907E938C7A928B79908A7C8D877B8581767F7B724A47421615101D1C1A1A1A18101113\
17181A0B0C101213170F13160F13160E12150D11140D11140C10130B0F120B0F12
0C10130C10130C10130C10130C10130C10130D11140D11120F0F110F0F0F0F0F0F0F0F0F0F0F0F\
0F0F0F0F0F0F0F0F0F1010101010101010101111111313131616161919191A1A1A
1414141515151717171818181919191919191818181717171515151212121111111414141A1A1A\
1F1F1F21212122211D3632294D493D686256726C606C665A645E50635D4F666052
5F594B615B4D696355756F617A74666E6659554D4041392C30281B30281B30281B30281B30281B\
30281B30281B30281B31291C31291C31291C31291C31291C31291C31291C31291C
373026292218312A203730262A2319332C224C453B554E446E675D766F657D766C7F786E7C756B\
7B746A80796F8480757C786D7C7A6E7C7A6E7B796D79776B767468737165727064
8684788482767573675E5C50514F43525044514F434C4A3D544E3E544F3C534E3B514C394C4734\
45402D3F3A273B3623443F2C45402D46412E47422F47422F47422F45402D443E2E
3D3A2B423C2E3730203E3727372F227872669390878A8F8B808B8F5B6E7C09273F4D789A487CAB\
3D7CB13B81BC3680BD
9292909393919494929797959999979B9B999D9D9B9E9E9C9999979999979A9A989A9A989B9B99\
9C9C9A9C9C9A9D9D9B9595939898969C9C9AA0A09EA3A3A1A5A5A3A6A6A4A7A7A5
A1A19FA1A19FA1A19FA1A19FA1A19FA1A19FA1A19FA2A19DA7A49FA7A49DA7A49DA7A49DA7A49D\
A7A49DA7A49DA7A49DA7A49DABA8A1AEABA4ACA9A2A4A19A9A97909390898F8C83
97948B97948B96938A949188939087918E85908D848F8C8394918895928996938A949188918E85\
908D84918E8593908799968D88857C8D8A81A9A69DB3B0A7A5A299A4A198B4B1A8
AEABA2A5A299ABA89FAFACA3ADAAA1B7B4ABAEABA28A887C7F796D797365948E80B3AD9FB1AB9D\
AFA99BB3AD9FACA698ADA799A7A193A19B8D9F998BA09A8C9F998B9B9587969080
9B948497907E948D7B938C7A918B7D8E887C858176807C7349464115140F1C1B19191917101113\
17181A0A0B0F1112160F13160F13160E12150D11140D11140C10130B0F120B0F12
0E12150D11140D11140C10130B0F120A0E11090D10090D0E0D0D0F0D0D0D0D0D0D0D0D0D0D0D0D\
0D0D0D0D0D0D0D0D0D0A0A0A0A0A0A0B0B0B0D0D0D1111111414141818181A1A1A
1414141515151717171818181818181717171616161515151010101010101313131717171C1C1C\
20202022222224231F7C786D7C76667670626C6656655F51676153716B5D7A7466
797365726C5E736D5F7D7769807A6C706A5C575143463E314B43364B43364B43364B43364B4336\
4B43364B43364B4336494134494134484033484033473F32473F32463E31463E31
433C32362F253B342A3D362C342D23453E34655E546F685E827B718780768A8379898278847D73\
817A70827B71827E73827E73828074828074817F737F7D717D7B6F7A786C78766A
7A786C807E727573675B594D4C4A3E4F4D414F4D41484639514B3B524D3A524D3A514C394D4835\
484330433E2B3F3A27433E2B45402D47422F484330494431494431484330484330
43402F4643343933233E3727383023605A4E94918891938E858F91778B96012035477090477AA5\
3E7CAD478AC1347CB6
91928C92938D94958F979892999A949C9D979E9F999FA09AA0A19BA0A19BA1A29CA1A29CA2A39D\
A3A49EA3A49EA4A59F9B9C969C9D979D9E989E9F999FA09A9E9F999C9D979B9C96
9C9D979C9D979C9D979C9D979C9D979C9D979C9D979D9C97A3A099A4A097A4A097A4A097A4A097\
A4A097A4A097A4A097A9A59CA7A39AA6A299A8A49BACA89FB0ACA3B1ADA4B1ADA2
A4A094A3A091A19E8F9E9B8C9B9889989586969384959283949182939081939081969384999687\
9B98899A9788989586A6A495A19F90ADAB9CC1BFB0BCBAABA3A1929B998AA5A394
A3A1929C9A8BA5A394A6A4959C9A8BA5A394ADAB9C9D9B8CA8A2949791839D9789A49E90989284\
9B9587A7A193A29C8EA59F91A39D8FA19B8DA19B8DA19B8D9F998B9B9587989282
9C958598917F958E7C938C7A928C7E8E887C868277817D7448454014130E1B1A181818160F1012\
161719090A0E1011150F13160F13160E12150D11140D11140C10130B0F120B0F12
0E12150E12150D11140B0F120A0E11090D10080C0F070B0C0B0B0D0B0B0B0B0B0B0B0B0B0B0B0B\
0B0B0B0B0B0B0B0B0B0707070808080909090B0B0B0F0F0F1313131717171A1A1A
1515151515151717171717171717171616161414141313130C0C0C0F0F0F1414141818181C1C1C\
202020242424282723908A7E87806E7B7464756E5C766F5F7A73637A7464797363
847E6E777161746E607D77697B78696966575552434E483A504A3C504A3C504A3C504A3C504A3C\
504A3C504A3C504A3C4E483A4E483A4D47394C46384B45374A4436494335494335
4942383F382E423B31413A30393228534C42787167817A708780768A83798C857B8C857B898278\
878076878076868277827E73828074838175858377858377848276838175828074
6C6A5E7F7D717F7D716664585351455654485654484E4C3F504B38514C38524D39514C384E4935\
4A453145402C433E2A47422E48432F4944304A45314A453149443047422E46412E
4643324B48393C36263F39293A3323453F31928E8393948F80888A81939D0D293E3A61804E7FA7\
427FAE4C8DC3347BB3
93958A94968B96988D999B909B9D929EA095A0A297A1A3989FA1969FA196A0A297A0A297A1A398\
A2A499A2A499A3A59AACAEA3ACAEA3AAACA1A9ABA0A7A99EA6A89DA5A79CA4A69B
B1B3A8B1B3A8B1B3A8B1B3A8B1B3A8B1B3A8B1B3A8B2B2A8ACA9A0ADA9A0ADA9A0ADA9A0ADA9A0\
ADA9A0ADA9A0ADA9A0AEAAA1AEAAA1AEAAA1B0ACA3B1ADA4AEAAA1A8A49BA4A095
AFAC9BAFAC99AFAC99AEAB98AEAB98AEAB98AEAB98AEAB989A978493907D8F8C79969380A19E8B\
A6A3909F9C899693807F7E6AA09F8BAAA99794937F8E8D7BA2A18DA8A795999884
ABAA98A3A28EABAA98A9A8949897859D9C88ABAA98A6A593A6A0929A9486A19B8DA7A1939B9587\
A09A8CAAA496A19B8DA19B8DA19B8DA19B8DA19B8DA09A8C9E988A9B9587999383
9C9585999280958E7C948D7B928C7E8F897D878378827E7548454013120D1A19171717150E0F11\
151618090A0E0F10140F13160F13160E12150D11140D11140C10130B0F120B0F12
0D11140C10130B0F120A0E11090D10080C0F070B0E070B0C0B0B0D0B0B0B0B0B0B0B0B0B0B0B0B\
0B0B0B0B0B0B0B0B0B0808080808080909090B0B0B0F0F0F131313171717191919
1515151616161616161717171616161515151313131212120E0E0E1212121717171A1A1A1D1D1D\
2222222A2A2A31302B615B4D696250766F5D857E6C8E87758B84727F7969746E5E
6D6757635D4D655F51716B5D6B68595653444744354744354C46384C46384C46384C46384C4638\
4C46384C46384C46384E483A4E483A4D47394C46384A4436494335484234474133
463F353F382E423B313E372D3831275750467E776D857E7480796F827B71857E748881778A8379\
8B847A8C857B8A867B8D897E89877B8482767D7B6F7472666A685C6260545E5C50
4E4C407472668583776D6B5F5553475553475755494F4D4055503D55503C55503C534E3A4E4935\
48432F423D293F3A2646412D47422E47422E48432F47422E46412D443F2B433E2A
4542314D4A393F3929413B2B3C35252C26188E8A7F92938D7A82847B8C942340521D44614F81A6\
407BA74688BC347AAE
9A9C8F9B9D909D9F929EA093A0A295A2A497A4A699A4A699A1A396A1A396A2A497A3A598A3A598\
A4A699A5A79AA5A79AA2A497A1A396A0A2959FA194A1A396A5A79AA8AA9DABADA0
A2A497A2A497A2A497A2A497A2A497A2A497A2A497A3A397ACA9A0ADA9A0ADA9A0ADA9A0ADA9A0\
ADA9A0ADA9A0ADA9A0ADA9A0AEAAA1AFABA2AEAAA1ABA79EA7A39AA29E959F9B8F
A8A592A8A691A9A792AAA893ACAA95ADAB96AEAC97AFAD989D9B868F8D7884826D8D8B769E9C87\
A4A28D95937E83816C91907BB0AF9AB6B5A19E9D889A9985B2B19CB8B7A3A5A48F
B0AF9BA2A18CA8A793ACAB969F9E8AA1A08BAAA995A09F8BADA797A59F91AEA89AB1AB9DA59F91\
A9A395AFA99BA19B8DA09A8CA19B8DA29C8EA09A8C9E988A9C96889B95879B9585
9D96869A9381968F7D958E7C938D7F908A7E888479827E7547443F13120D1A19171717150D0E10\
14151708090D0F10140F13160F13160E12150D11140D11140C10130B0F120B0F12
0A0E110A0E110A0E11090D10090D10090D10080C0F080C0D0B0B0D0B0B0B0B0B0B0B0B0B0B0B0B\
0B0B0B0B0B0B0B0B0B0A0A0A0A0A0A0B0B0B0C0C0C0F0F0F131313161616181818
1515151616161616161616161515151414141212121010101515151818181C1C1C1E1E1E202020\
2727273333333D3C37534D3F645C49776F5C837B68847D6A867F6C8B8472918A78
524C3C514B3B5D5A4B706D5E6A67584E4B3C403E2F4644354C493A4C493A4C493A4C493A4C493A\
4C493A4C493A4C493A4F4C3D4F4C3D4D4A3B4C493A4A4738484536474435474435
433C323E372D423B313C352B362F2558514780796F857E74928B8190897F8E877D8C857B8A8379\
867F75817A707B776C7B776C777569706E626765595C5A4E504E42474539424034
2A281C626054858377716F635250444E4C40514F434B493C56513E56513B55503A534E384F4A34\
49442E433E283F3A24443F2945402A47422C48432D48432D48432D47422C46412D
423F2E4D4A39413B2B433E2B3E37251913038A867A8E8F87818A8974858D435E6F0126414F7FA3\
3C75A04180B33A7DB1
949587959686969789979888999A8C9A9B8B9B9C8E9C9D8DA3A496A3A494A3A496A4A595A5A698\
A6A797A6A799A6A797ABAC9EA9AA9AA5A698A3A494A4A597A7A898ACAD9FAFB0A0
AFB0A2AFB0A0AFB0A2AFB0A0AFB0A2AFB0A0AFB0A2AFB0A2ABA99CACA89CACA89DACA89CACA89D\
ACA89CACA89DACA89CAFABA0AEAA9EABA79CA7A397A7A398ABA79BB3AFA4BAB7A8
ABA895ABA994ABA994ABA994ACAA95ACAA95ACAA95ACAA95AFAD989B99848C8A7594927DA9A792\
AEAC9799978282806B96947F94947C9F9D88AEAE96B0AE99A3A38B9E9C87A1A189
ACAA959898809E9C87A9A991A6A48FA8A890AAA893999782A9A393A09A8CA6A092A6A092999385\
A19B8DABA5979E988AA19B8DA29C8EA29C8E9F998B9C96889A94869A94869C9688
9C9686999383958F7F948E7E918E7F8E8A7E87847B827F7847443F12110D1919171616160D0E10\
14151708090D0E0F130F12170E13170D12160C11140C11150B10130A0F120A0F12
080D10080D10080D10080D10080D10080D10080D10090D10090D100B0C0E0B0C100B0C0E0B0C10\
0B0C0E0B0C100B0C0E0B0C100B0C0E0B0C100C0D0F0F101412131515161A161719
14161515171615171615171614161313131111110F0F0F0D1A1A181F1E1A22211D22211D24231F\
2C2B263A393548443B494232524A37524A37453C2B3A3120463F2D6D64558E8679
4F473A564E436E685C8781757E786C5E584C4D493D5551454E4B3C4E4B3C4E4B3C4E4B3C4E4B3C\
4E4B3C4E4B3C4E4A3E4D493D4C483C4B473B494539474337454135444034433F33
433D31403A2E453F333E372D3831275C554B837C72867F758780787E7A71736F6668645B5B574E\
4D4940403C3334342A161910151D10191F151C22161F251B22251A23261B24261B
16180B5B5B4F8B897C797768575644514E3B54513E504E39504B37514C36524D37524D37504B35\
4C473148432D46412B45402A46412B49442E4B46304D48324E49334E49334B4934
3F3E2A4B4A36413B2B463F2F40382B0F07008982788E8B849095917785885E7682001529527FA0\
3D729C407CAE4584BA
A2A0919C9B899694859695839B998AA1A08EA5A394A6A593A2A091A2A18FA3A192A4A391A5A394\
A6A593A7A596A8A795A9A798A9A896A9A798A9A896A9A798A9A896A9A798A9A896
A7A596A7A694A7A596A7A694A7A596A7A694A7A596A7A694ACA998ACA996ACA998ACA996ACA998\
ACA996ACA998ACA996AAA796AAA794AAA796AAA794AAA796AAA794AAA796AAA794
A7A6929F9E8AA1A08CACAB97ACAB97A2A18DA4A38FB0AF9BA7A6929A998591907C979682A5A490\
A9A8949D9C888F8C79A2A089A4A289A9A48EAAA88FAFAA94AEAC93B0AB95AEAC93
AAA58FA7A58CA9A48EA6A48BA7A28CA5A38AA6A18BA6A18DA8A292A7A193A7A193A6A092A59F91\
A59F91A49E90A49E90A29C8EA19B8DA19B8DA09A8C9F998B9F998B9E988A9C998A
969485999A8A9899899192848E8E828F8F858888807D7C774D4C481919170C0C0A1E1E1E161618\
09080D0D0C120E0F140F141A0D141A0C13190C14170B12180A12150A1215091114
091113081012081012070F11060F0E060F0E050E0D050D0F030A10030A10030A12030A10030A12\
030A10030A12030A10040B13030A1002091102090F040B13080F150C131B0F171A
070D0D0F1513151A16141915181D1720221D1E1F1915161013130B2320172D291E282419272115\
302A1C413B2F4E463949402F4D42304F43334C403244382C493F356D60588F847E
3C312B584D49776C688176727267615D524C53484250473E565246514F404F4D404E4C3F4F4D40\
4E4C3F49473A4543373E3C304745394F4C434F4C4348453C423F36423F36464237
423C30453D3040382B372F243A3428524B41716D6288847B7A756F504D4655544F474641373833\
3E3F3A292A251E251E0F231A0822151D342A142A1E11251C1A2B21121F151E2A1E
1F271A3F43348587727C7C64555436585534534F2C595434565239534E3A514C38514C38514C38\
4D483446412D403B27443F2B46412D48432F4944304A45314A453149443046442F
42412C42412D443E2E49413642352F2B1E184F423C9C938C8C8C847A837E74868805212D274F69\
5484AC5085BB4179B4
817E6D7D7A697B78677C7968807D6C83806F83806F817E6D868372878473878473888574898675\
8A87768B88778B88778C89788C89788C89788C89788C89788C89788C89788C8978
8F8C7B8F8C7B8F8C7B8F8C7B8F8C7B8F8C7B8F8C7B8F8C7B93907D93917C93917C93917C93917C\
93917C93917C93917C95937E95937E95937E95937E95937E95937E95937E95927F
9796829897859F9E8CAAA997AEAD9BA8A795A3A290A3A290A6A5939E9D8B9998869F9E8CAAA997\
AEAD9BA6A5939C9B87A7A28CA9A58CABA78EADA990AFAB92AFAB92AFAB92AFAB92
AAA68DAAA68DAAA68DA9A58CA8A48BA7A38AA7A38AA7A28CA8A390A8A292A8A294A7A191A6A092\
A59F8FA59F91A59F8FA29C8EA29C8CA29C8EA19B8BA09A8C9F99899F998B9D9A8B
9795869A9B8B999A8C9293858F8F838F8F8587877F7A79744645411716140C0B091E1C1D181619\
0D0B0E1210151213180E13190C13190C14170B13160A1215091114091114091113
09111309121109121108111007100F060F0C060F0E060E100A11170A11190A11190A11190A1119\
0A11190A11190A1119091018091018080F17080F170910180B121A0E151D10171D
111A19161F1A1B211D1D241D262B242F322B292A221D1D133432262523161E180A2620123A3323\
4942304F46355047363E33213F342243372744382A44382C52453C796C66A0938D
3C2E2B5648457567648678758476737A6C69746663716660605C505856474E4C3F474538444235\
413F323E3C2F3A382C413F333C3930353229322F26322F2635322937342D39352A
3C36284740304C4437463E31423C30544E42757168918D8446433E1D1C172C2B27282924242623\
343633282A29202A290E2924082922001D17001B16021B18031916091C18081712
1D271F3C42368386737C7C64565537585534534D29595532565038534E3A514C38524D39514C38\
4E493547422E403B2745402C46412D48432F4A45314A45314A4531494430474530
42422A43422D443E304940374234312D1E1B4E3F3C988D878D897E7C8278788782223B4021445A\
527EA35281B74074B0
706D5E6F6C5D6F6C5D7370617875667A77687774657471627875667875667976677976677A7768\
7A77687B78697B78697C796A7C796A7C796A7C796A7C796A7C796A7C796A7C796A
7D7A6B7D7A6B7D7A6B7D7A6B7D7A6B7D7A6B7D7A6B7D7A69817E6B817E6B817E6B817E6B817E6B\
817E6B817E6B817E6B7F7C697F7C697F7C697F7C697F7C697F7C697F7C697F7C69
75746081806C8E8D79979682A1A08CAAA995ACAB97A7A692A6A591A4A38FA5A490A9A894AFAE9A\
B2B19DB0AF9BACAB97ACA791ADA892AEA993AFAA94AFAA94AFAA94ADA892ACA791
ACA791ABA690ABA690AAA58FA9A48EA9A48EA8A38DA8A38DAAA592A9A491A9A393A8A390A7A191\
A7A28FA6A090A6A18EA49E8EA39E8BA39D8DA29D8AA19B8BA19C89A09A8AA09A8A
9996859D9C8A9C9A8B959386939184918F8386847877746B44413A1916110F0B081E1A19161211\
0C0809100B0F0F0D100E0F130B10130A0F120A0F12090E11080E0E080E0E070D0D
070D0D070D0B060C0A050B09050B09040A06030907030909070C10070C12070C12070C12070C12\
070C12070C12070C12060B11060B11070C12080D13090E140B10160C11170C1114
1A201E202720262B252A2F293538313D40393839312C2C22201E121412051B1507342E20433C2C\
3A33232C2312271E0D362B19342917352919392D1F3F332553473B7D7067A4978F
5B4E48695C567A6D678578728477717C6F697366606C6259716E5F6564525654454A4839434132\
3F3D2E3C3A2B39372A3533262A281C201E12201E1229271B323024333027312D22
302A1C413A2A4F48384C4437423C304A443867635A86827946433E1A1914272622252523202221\
2E302F2122241C2627031B1D173438001115001C2010272F16293038464F182329
1E2629393D3C80817B7E7C7059564559543E534C3259533956503A534E3A524D39524D39524D39\
4F4A3648432F423D2945402C47422E48432F4A45314B46324B46324A4531474530
43432B44432E434031483F364335322E201D4A3C398D827C8D897E7D83777A898249616515354A\
497497507EB23E70AB
605C505D594D5A564A5C584C605C50646054635F53625E52635F53635F53646054646054646054\
646054646054646054656155656155656155656155656155656155656155656155
6864586864586864586864586864586864586864586865566A67566A67566A67566A67566A6756\
6A67566A67566A6756686554686554686554686554686554686554686554686552
64634F7A79648B8A768E8D7894937FA3A28DAEAD99AEAD98A8A793ABAA95AFAE9AB1B09BB1B09C\
B1B09BB2B19DB3B29DB0AB97B1AC96B1AC98B1AC96B0AB97AFAA94ACA793ABA690
ADA894ADA892ACA793ACA791ABA692AAA58FAAA591A9A490ABA692ABA692AAA592AAA591A9A491\
A8A38FA8A390A7A28EA5A08DA5A08CA49F8CA49F8BA39E8BA29D89A29D8AA19C89
9E9986A19B8BA09A8A9A9486999385958F81868074736C624A433B231C161B1310251D1A19110F\
100806140B0C0F09091212121113121012111012110F11100E100F0E100D0D0F0C
0C0E0B0B0D0A0B0D080A0C07090B06090B06080A05080A070B0C0E0B0C100B0C100B0C100B0C10\
0B0C100B0C100B0C1004050907080C0B0C100F1014121317131418141519141517
24292531362F383D3736393231342D32332B3030262A2A1E3836294E4A3E7D7769A39D8F9D9686\
746D5D5D54435F5744453A283D321E372C1A362A1A3A2E1E4B3F316E62568F8377
7D70677C6F667B6E66796C6476696170635D685B5560564D4744353E3D2B3332202A2917252314\
201F0D1A18091614051F1D0E1C1A0B1D1B0C2523143230233D3B2E413F32434031
5A5444655E4E706959726B5B69635568625679756A908C835F5C552D2C27363533323230282A29\
3032312122241F262C1E323D93ADBAA9C3D2DBF2FFEFFFFFDEEFFFDCE9FA6D7687
1F25333639427D7C817F7B7A5D58525A534951493C59524055503C534E3A524D39534E3A534E3A\
504B37494430443F2B46412D47422E4944304B46324C47334B46324B463248462F
43432B46462E4340314740364338343022214537347E756E908E8284877C7C8982667E800A293B\
3B6283507CAB4473A9
6664585D5B4F514F434A483C49473B4C4A3E4E4C404F4D41535145535145525044525044525044\
525044525044525044514F43514F43514F43514F43514F43514F43514F43514F43
58564A58564A58564A58564A58564A58564A58564A58564A59574A595748595748595748595748\
5957485957485957485B594A5B594A5B594A5B594A5B594A5B594A5B594A5B5A48
51503B6E6E568C8B7697977F9998839D9D85A3A28DA6A68EACAB96B0B098B4B39EB4B49CAFAE99\
ADAD95AEAD98B1B09BB3AE9AB3AE9AB3AE9BB3AE9AB2AD9AAFAA96ADA895ACA793
AFAA97AEA995AEA996ADA894ACA794ACA793ABA693ABA692ADA894ACA791ACA793ABA690AAA591\
AAA58FA9A490A9A48EA7A28EA6A18BA6A18DA5A08AA49F8BA49F89A39E8AA39E8A
A19A87A49D8BA29B899E97879D9686979080837B6E6D65583E362B1F160D1B120B241B14191009\
150C051B120D160F0916130E14130E13120D13120D12110C11100B11100B100F0A
12110C12110C11100B11100B100F0A0F0E090F0E090E0D08131210131210131210131210131210\
1312101312101312100A09070E0D0B1615131D1C1A232220252422252422252422
31322C45483F52554E48494138393135352B3C3C324341353D392D504C40787264969082908979\
716A5A615A48645D4A665E4B58503B49412C423A273F3724443C2959503F706756
7168596A615263594D61574D645A50685E55695F56675F5436332232311D31301C302F1B302F1D\
2C2B172423111E1D0B1918061C1B09201F0D2524122F2E1C42412F5958466B6857
7D78657A73617C7563837C6C807A6C7973677C786D89857C57544D23221D2D2C2A30302E2A2C2B\
32333527282C2B323A0D1E30ABC1D8CDE3FBDEF2FFE3F3FFE0EEFFDCE6FF565C76
22243B343247797785817B85625C605B5253504644595047554F3F534E3A524D39534E3A544F3B\
524D394B463246412D47422E48432F4A45314C47334C47334C47334B4632494730
44442C484830444132463F354439373126243F34306F665F9492868C8F847D8A81768B8C102D3D\
2B4E6C5076A34F79AB
6A67605D5A534A47403D3A3337342D37342D38352E39362F37342D36332C36332C35322B35322B\
34312A34312A333029333029333029333029333029333029333029333029333029
2F2C252F2C252F2C252F2C252F2C252F2C252F2C252F2C232F2D212F2D212F2D212F2D212F2D21\
2F2D212F2D212F2D2128261A28261A28261A28261A28261A28261A28261A282617
2B2A1540402866664E8D8D75A0A088A0A088A0A088A4A48CAEAE96B1B199B3B39BB2B29AAFAF97\
ADAD95ACAC94ADAC97B4AF9CB4AF9CB5AF9FB5B09DB3AD9DB1AC99AFA999AEA996
B0AA9AB0AB98AFA999AFAA97AEA898ADA895ADA797ACA794AEA993AEA993ADA892ADA892ACA791\
ABA690ABA690AAA58FA8A38DA8A38DA7A28CA7A28CA6A18BA5A08AA5A08AA59F89
A49C89A69E8BA69A8AA19887A2968699907F837769675E4F291D111006001407001B1107150800\
150B0120130B1A1007140D03120E05110D04100C03100C030F0B020E0A010E0A01
120E05120E05120E05110D04100B050F0A040F0A040F0A040A05010A05010A05010A05010A0501\
0A05010A05010A0501100B0716110D201B172924202F2A26302B272F2A262C2922
2D2D2547473D5B5B515B5B5158584E6664587B796D8A887BA39F939692868B8577898375908979\
908979857E6C7A73617C74616C644F5C543F544C374D453049412C5048335C543F
564E3B5249384E45364E443852483E584E445B51485C54495552415554405958445E5D4962614D\
5F5E4A58574351503C302F1B2C2B172524101E1D0824230E3D3C2764634E817F6A
85806C77705D746D5A7F7866807A6A7872647975698581785E5B542524202E2D2B3232322B2C2E\
2F30342425292C333D39485BB5C9E2C9DAF6AABBD79AA8C5A7B2D0A7ADCD3E4361
22233F312F47767386837D8B665F675C53584F444859504B544E3E534E3A524D39544F3B55503C\
534E3A4D483447422E48432F4944304B46324C47334D48344D48344C4733494730
44442A474931444331433F34453B393228273A2F2D615A52918F83929688818D837A8D8B2A4550\
1E3C564E7096587AA8
7675706C6B665E5D5855544F52514C53524D53524D53524D4E4D484E4D484D4C474C4B464B4A45\
4A49444A4944494843484742484742484742484742484742484742484742484742
3F3E393F3E393F3E393F3E393F3E393F3E393F3E393F3E393F3F373F3F353F3F353F3F353F3F35\
3F3F353F3F353F3F3534342A34342A34342A34342A34342A34342A34342A343527
53523E3E3E264848307979619F9F87A2A28AA2A28AACAC94AEAE96AEAE96AFAF97B0B098B2B29A\
B2B29AB0B098AEAD98B3AD9DB4AE9EB5AFA1B5AF9FB5AFA1B4AE9EB2AC9EB1AB9B
B1AB9DB1AB9BB1AB9DB0AA9AAFA99BAEA898AEA89AAEA996AFAA94AFAB92AFAB92AEAA91ADA990\
ACA88FACA88FACA88FA9A58CA9A58CA9A58CA8A48BA7A38AA6A289A6A289A7A18B
A89D8BA99E8CA89B8AA49987A598879C917F8174646357473D2F22281C0E2D1F12322618291B10\
2A1E1235271C2D21152C24172B25172A24162A2416292315282214282216272115
231C12231C12221B11211A10211A122019111F18101F18101A130B1A13091A13091A13091A1309\
1A13091A13091A1309241D132B241A352E243D362C413A3040392F3B342A383127
302C213F3D314B493D4E4C4058564A6F6B5F8480748D8A7B958F81948E808680727670627B7565\
88827280796968614F706956635C4959533D58523C554F374E48304D472F524C34
4D4731524C365952405E57475F574A5E564B5D544B5B544A6562536362506564526968566D6C58\
6C6B5768675363624E4F4E3944432E35341F2B2B132E2E163F3F2757573F696750
7B76606F69536F68557D76647E7868787264827E729A968D7370693534303A39373C3C3C303135\
2E2F342122272C303B2B384976889EA2B2CB97A5BF8994B0828BA85C617F191D3A
24243E2E2C42737083847E8C69626A5B55574D444558514B544E3E534E3A524D39544F3B56513D\
544F3B4E493549443048432F4944304B46324D48344E49354E49354D48344A4831
42452A484A32444331433F34453D3A332B29362C2A564F478684779498898893857A8B8553676E\
18314549668659779D
C7C6C4C1C1BFBDBCBABCBCBAC0BFBDC3C3C1C5C4C2C4C4C2CCCBC9CBCBC9CBCAC8C9C9C7C9C8C6\
C7C7C5C7C6C4C5C5C3C5C4C2C4C4C2C5C4C2C4C4C2C5C4C2C4C4C2C5C4C2C4C4C2
C7C6C4C6C6C4C7C6C4C6C6C4C7C6C4C6C6C4C7C6C4C6C7C2C7C6C2C6C7C1C7C6C1C6C7C1C7C6C1\
C6C7C1C7C6C1C6C7C1CAC9C4C9CAC4CAC9C4C9CAC4CAC9C4C9CAC4CAC9C4CACAC0
C1C0AE7B7A655655407675609C9B86A09F8AA09F8AAEAD98ADAC97ABAA95ABAA95AFAE99B6B5A0\
B8B7A2B5B49FB1B09CB2AC9EB3ADA1B5AFA3B6B0A4B6B0A4B5AFA3B4AEA2B3ADA1
B2ACA0B2ACA0B1AB9FB1AB9FB0AA9EAFA99DAFA99DAEA898B0AB97B0AC93AFAB92AFAB92AEAA91\
ADA990ADA990ACA88FAAA68DAAA68DA9A58CA9A58CA8A48BA7A38AA7A38AA7A18B
A99E8CAB9E8DA89B8BA69988A699889D907F8073636255457164545E5141605343615444514434\
50433357493C4D41315A514059523F59503F58513F584F3E564F3F574E3F554D40
453B2F443C31443A3142393043393041382F41363040372E4C42384B43364C42384B43364C4238\
4B43364C42384B4336453B314B4336554B415B53465E544A58504353493F4D4538
433D2F403A2C3630222D2719312B1D3C392A413B2D3C3628110B00433D2F666052635D4F625C4C\
6E6858696252534C3C5952404F48354B4431524C36565038514B314D472D4F492F
504A32605A44756E5B857E6E898176877E75847B74817A72827E727D7B6C7977687978667C7B69\
7D7C6A7B7A66787763605F4A55543F49493144442C46462C48482E45452B424027
403C233A341C403A244F48354D48354A44365F5B4F827E756F6C6531302C3735363C3C3E333439\
32323A27272F353944222E3A1727341D2A3B05122306112521293E23283E32344B
2624392E2B3C736F7D8380876A64665C57544D4542595248544E3E534E3A524D39544F3B56513D\
55503C4F4A364A45314944304A45314C47334D48344E49354E49354D48344A4831
42452A484C33424331413F33433E3B322D2A332B284E4A417A7B6D9498878E96877B887E708284\
192C3A495E79597090
B4B4B6B3B4B6B5B5B7B4B5B7B6B6B8B6B7B9B7B7B9B7B8BABCBCBEBCBDBFBDBDBFBDBEC0BFBFC1\
BEBFC1C0C0C2BFC0C2BEBEC0BDBEC0BEBEC0BDBEC0BEBEC0BDBEC0BEBEC0BDBEC0
BEBEC0BDBEC0BEBEC0BDBEC0BEBEC0BDBEC0BEBEC0BDBFBEBEBEBEBDBFBCBEBEBCBDBFBCBEBEBC\
BDBFBCBEBEBCBDBFBCC0C0BEBFC1BEC0C0BEBFC1BEC0C0BEBFC1BEC0C0BEC0C1BB
CDCEBE7F7E6A3B3A2673725E8C8B77A4A38F91907CA6A591A7A692A7A692A7A692A7A692A7A692\
A7A692A7A692A7A694ACA69AACA59BABA49AAAA399AAA399A9A298A8A197A8A197
AAA399A9A298A7A096A69F95A69F95A7A096A9A298AAA498A8A38FA8A38DA7A28CA6A18BA6A18B\
A5A08AA49F89A49F899E99839E99839E99839E99839E99839E99839E99839F9983
AA9E8EA69989A092859D9080998C7C908373837666796C5C7669596F6252635645584B3A514433\
50433252453554473670655169614C665B49635B48665B49645B4A6458485F5647
695D512C221830231B32281F3326203C312B332620392F265C50444E45364B3F33534A3B5E5246\
5A5142574B3F554C3D594D415B524361554962594A62564A5B5243564A3E504738
52493A4A43334039293C3525423B2B494333494232423B2B3F38284A4333696353453F2F534D3F\
888274655F51514B3D5A5444554F3F534E3B55503C555138524E33504C2F524E31
514D3266624996917D756F5F938D8187807878706D7E76737672677D7B6E79776A7B796C807E71\
706E5F6D6C5A8786726968534645304141294F4F3749492F45452B48482C434226
454126413B214E4830433D2747422F4C46364D493D89857C83807B27262445434646454A24242C\
37374131313B2C3039222D311C2C2C1A272D1A252B1D262F222933272D392C303B
2A2A34302F3555535681807C817C7659554A4D473B5E5848524D3A534E3A544F3B544F3B534E3A\
524D39504B374E4935443F2B46412D48432F4B46324C47334D48344D48344B4932
474A2D464A2F4647354341353E3A373E3A37423D3946433A7B7C6E878B7A8F98858F9B8D727E7C\
38464F2D3C515A6A84
B2B3B8B3B4B9B3B4B9B4B5BAB5B6BBB5B6BBB6B7BCB6B7BCB5B6BBB5B6BBB6B7BCB6B7BCB7B8BD\
B8B9BEB8B9BEB9BABFB8B9BEB8B9BEB8B9BEB8B9BEB8B9BEB8B9BEB8B9BEB8B9BE
B8B9BEB8B9BEB8B9BEB8B9BEB8B9BEB8B9BEB8B9BEB8B9BDBCBDBFBCBDBFBCBDBFBCBDBFBCBDBF\
BCBDBFBCBDBFBCBDBFB9BABCB9BABCB9BABCB9BABCB9BABCB9BABCB9BABCBABAB8
B7B7AB605E4F1715064846375755466B695A5C5A4B6F6D5E656354656354656354656354656354\
6563546563546563566D665E6D665E6C655F6C655D6B645E6A635B6A635D69625A
6B645E6A635B68615B67605867605A6861596A635D6B645A69635369645068634F68634F67624E\
66614D66614D65604C66614D66614D66614D66614D66614D66614D66614D67604E
5D514360544864564B63574B67594C726658887A6D978B7DA194849B8F7F9588788D8270897C6B\
887D6B8B7E6D8B806C877C668277617C715D7A6F5B7A6F5D796E5C766A5A736759
5C50441F120920130B22150F1F120C2719161C0E0B271A14594D4144382A34281A362A1C3D3123\
3E32243D31233F3325473B2D493D2F4B3F314C40324B3F31473B2D433729403426
4D4131493E2C443927413926463E2B4C43324C4332474030635C4C676050777161514B3B5D5749\
928C7E7C76686E685C6761555D594D554F414D4A374B4630454428454126434224
3D391E56543B95907D7A77689C958D98938F999091A19B9B9A979297948B8A877E8D8A81959387\
7C7A6D66645771705E6B6A5847463241402B4F4F3749493145452B49492F444327
464225413C1F4E482E433D2547422E4C46364C483C86827984817C2D2C2A43414445444A272731\
35354131313D2D30372B363228352C25302A222D29222B2A262C2C282D302B2F32
2A2B2D2E2E2C53524D838175837F735C59484D48345B5642534E3A534E3A544F3B544F3B544F3B\
524D39504B374F4A364944304B46324D48344E49354F4A364F4A364E49354B4932
45482B45492E4546344242383F3E3A3F3E3C46423F494941737665898E7A939B868F9887717B73\
3842441D2635343C51
ADB0B7ADB0B7AEB1B8AEB1B8AFB2B9B0B3BAB0B3BAB1B4BBAEB1B8AEB1B8AEB1B8AFB2B9B0B3BA\
B1B4BBB1B4BBB1B4BBB2B5BCB2B5BCB2B5BCB2B5BCB2B5BCB2B5BCB2B5BCB2B5BC
B2B5BCB2B5BCB2B5BCB2B5BCB2B5BCB2B5BCB2B5BCB2B5BCB6B9BEB6BABDB6BABDB6BABDB6BABD\
B6BABDB6BABDB6BABDB3B7BAB3B7BAB3B7BAB3B7BAB3B7BAB3B7BAB3B7BAB5B7B6
CCCBC668655C1E1B124B483F49463D57544B49463D58554C5D5A515D5A515D5A515D5A515D5A51\
5D5A515D5A515D5A51635C56635C56625A57615A546159566059535F57545F5852
6159566059535E56535D56505D55525E5751605855615A525F594B5F59495E58485D57475D5747\
5C56465B55455B55455E58485E58485E58485E58485E58485E58485E58485F574A
685E546B6158685B52554B414B3E35554B417A6E62988E8295897B9289789185758C83728D8171\
8A81708D82708B836E8A826B857E647F77607C745F7C74617B7360776E5D746B5C
5F554B1E140B1C110B1E130F180D091D1210150A08241915766C62584F403C3324352C1D393021\
3B32233D3425403728473E2F483F304A41324C43344D44354F4637504738524636
433625443724473A274D422E534834584D3B5C513F5C5342746D5B78715F7F79695E5848645E50\
88827474706465615667625C5D5A53504C41444233413F2A3F3F273E3D213A3A1E
413F26616149ABA8978C8A7E97928E8B87868A838A8A858B7C787974706D605C595956515B5851\
4C4940514E457573666E6C5F49483643422E4F4E3949483345452D4A4A3245432A
474326423D204E492C443E2449442E4C4734484536807C7185827D3837353F3D424342482D2D37\
33333F302F3D2C2F362D372E2A37262A35272A32272A31292B30292C312B2F312C
2B2C262B2C244E4E4281806E868370615F484C4B2F565539534E38544F3B55503C55503C544F3B\
524D39514C384F4A364A45314B46324C47334E49354E49354E49354C47334A4831
46492A464B2D474A3746483D4445404747454E4D4952534B686B5A888B769297808C917D7F8579\
616564494D564F535F
ACAEBAACAEBAADAFBBAEB0BCAEB0BCAFB1BDB0B2BEB0B2BEB0B2BEB0B2BEB1B3BFB2B4C0B2B4C0\
B3B5C1B4B6C2B4B6C2B6B8C4B6B8C4B6B8C4B6B8C4B6B8C4B6B8C4B6B8C4B6B8C4
B6B8C4B6B8C4B6B8C4B6B8C4B6B8C4B6B8C4B6B8C4B6B9C2B4B7BEB4B7BEB4B7BEB4B7BEB4B7BE\
B4B7BEB4B7BEB4B7BEB5B8BFB5B8BFB5B8BFB5B8BFB5B8BFB5B8BFB5B8BFB7B8BC
C6C5C35C59541E1B1654514C47443F504D4844413C4D4A4545423D45423D45423D45423D45423D\
45423D45423D45423D453D3A453D3A443C3A433B38433B39423A37413937413936
433B39423A374038363F37343F3735403835423A38433C36413A30413B2F403A2E3F392D3F392D\
3E382C3D372B3D372B3A34283A34283A34283A34283A34283A34283A34283A3329
3E352E453C37483F3A443B34463D365C534C857C73A69E938B83768B84748B84748B84748A8373\
88816F867F6D857E6B7E7860797359746E56736D57746D5A746D5B726B5B6F675A
655C532219122017122218161C12112117161E1415342A28675F544942322D2616261F0F2A2313\
2B24142C25152F2818302919302919322B1B352E1E3B3424423B2B4841314D4433
43362347382151422D60513C685C466C5F4C7366537A6F5D7067567B7462817B6B706A5A6F695B\
787264625E524A463D302C292D292624211A1C1A0E1D1C0A201F0A1B1B01121200
33331951503B9B998A69665D4E4A49312C3227212B18121C1F1A20272226241F23201C1D1A1615\
110D0A34312C78756C7270644C4A3D444233504F3D4948344645304B4A3547452C
484427433E204E492B453F254B46304C47344441327874698885804746443A383D41404834343E\
302F3D302F3F2B2E35262E23262F1C27301F292F212B31252D332931342B32352C
2C2D2529291F49473A7C7B6988867166644B4E4D31535236544F3955503C55503C56513D55503C\
534E3A514C38504B3746412D47422E4A45314C47334E49354F4A364F4A364C4A33
4D50314F543650534050524750514C5454545B5B5961625A6A6D5C8A8E778D917881856E8A8C7E\
8D8E8885858786858B
B4B8C4B4B8C4B5B9C5B5B9C5B6BAC6B7BBC7B7BBC7B8BCC8B8BCC8B8BCC8B9BDC9B9BDC9BABECA\
BBBFCBBBBFCBBCC0CCBEC2CEBEC2CEBEC2CEBEC2CEBEC2CEBEC2CEBEC2CEBEC2CE
BEC2CEBEC2CEBEC2CEBEC2CEBEC2CEBEC2CEBEC2CEBEC2CEBBBFCABBBFC8BBBFC8BBBFC8BBBFC8\
BBBFC8BBBFC8BBBFC8BBBFC8BBBFC8BBBFC8BBBFC8BBBFC8BBBFC8BBBFC8BCBFC6
BFBDC0565253322E2F7F7B7C736F707F7B7C7975767C7879757172757172757172757172757172\
757172757172757170766D6E766E6C756C6D746C6A746B6C736B6972696A726A68
746B6C736B69716869706866706768716967736A6B746C6A726B65726B63716A62706961706961\
6F68606E675F6E675F68615968615968615968615968615968615968615968615B
5D5553615957665E5C6C6462746C69837B78948D87A19A92878076878175878175868072847E70\
807A6A7C76667A756279745E757158716C56716C56746F5C767060756F61736D61
60595119120C18100E1E15161910131F161922191E42393A4E473D3E382A342E203A3426433D2F\
453F314640324A44364842344741334640324741334B4537504A3C5650425B5442
5E4F3A5B4B3262523B73634C7D6E577B6F597F725F877C6A7168578079677F79697E78687B7869\
7673646D695D57534A3834353C373B39353434312A39372A3D3C283131191E1E06
3C3B264D4C3A8F8D814F4C4725202416101A241D2D181121231D29211C231C171E231E24262125\
1612132824235F5C5776736C4F4C43464438514F424947384645334C4B37494730
4A4728433E1E4F4A2C4742254D49304D4834403D2E706C618A87825655533533383F3E463B3B47\
2D2C3A2F2E3E2C2C34262C22252C1A242B1B262A1C272A212A2D262D2E282F302A
32312C26261E403D347573668887756A695451513953513855503C55503C56513D56513D56513D\
544F3B524D39514C384B46324D4834514C3855503C5954405B56425D58445B5942
5A5F3F5B62435D624E5D60555C5E5B6062616769666D70677073608E92798D90757E81668C8B79\
9694888E8986898385
BFC2D1BFC2D1C0C3D2C0C3D2C1C4D3C2C5D4C2C5D4C3C6D5C0C3D2C0C3D2C1C4D3C1C4D3C2C5D4\
C3C6D5C3C6D5C4C7D6C5C8D7C5C8D7C5C8D7C5C8D7C5C8D7C5C8D7C5C8D7C5C8D7
C5C8D7C5C8D7C5C8D7C5C8D7C5C8D7C5C8D7C5C8D7C5C8D7C6CAD6C6CAD5C6CAD5C6CAD5C6CAD5\
C6CAD5C6CAD5C6CAD5C0C4CFC0C4CFC0C4CFC0C4CFC0C4CFC0C4CFC0C4CFC1C4CD
C9C6CD625D63575258BDB8BEB4AFB5C6C1C7C9C4CAC9C4CAD1CCD2D1CCD2D1CCD2D1CCD2D1CCD2\
D1CCD2D1CCD2D1CCD0D7CED1D6CDCED6CDCED5CCCDD4CBCCD4CBCCD3CACBD3CACB
D4CBCCD3CACBD2C9CAD1C8C9D1C8C9D2C9CAD3CACBD4CBCCD3CBC8D2CAC7D2CAC7D1C9C6D0C8C5\
D0C8C5CFC7C4CFC7C4CDC5C2CDC5C2CDC5C2CDC5C2CDC5C2CDC5C2CDC5C2CDC5C3
D1CBCDCAC6C7C1BDBEBAB6B5B2AEADA39F9C918E89838079807D74807E727E7C707C7A6D79776A\
747263716F606E6D5975755D7171596E6C556D6C57716E5D727061726E626F6D61
5E595314110C140E0E1D191A1913171E191F29222A504C4D4D49404E4C3D5E5B4C7270617F7C6D\
807E6F8582738C8A7B8B8879888677858273817F70807D6E807E6F83807187806E
82735C736149705E46806E5688786181725B7D715B827763756A58817867736C5C7E78687F7C6D\
7875668985797C79727F7A80858087837E827C78757F7C738381726F6E5A54533E
52513D565445949188555150332E354B4553837B90827A91958E9E5F5967251F2B1F1923322D34\
2B262C302B2F565251797572524F4848453C514F434A483B4745364D4C3A4A4831
4C492A44401D4F4A2A4843264F4B324D48343C392A6864598D8A85656462302E333D3C4443434F\
2928382F2E402B2B352F322B2B2F21272A1F24271E242621282A272D2D2B30302E
37353624232137342F6D6A618684786D6B5C54533F53523E55503C56513D57523E57523E56513D\
55503C534E3A524D395E5945605B47645F4B68634F6C67536E6955706B576E6C55
686D4D6970516A6F5B686B60676966696B6A6F716E75786F6568558589708C8F7289896D989681\
9A948689827C847A79
BFC2D3C0C3D4C0C3D4C1C4D5C2C5D6C2C5D6C3C6D7C3C6D7C2C5D6C2C5D6C3C6D7C4C7D8C4C7D8\
C5C8D9C6C9DAC6C9DAC5C8D9C5C8D9C5C8D9C5C8D9C5C8D9C5C8D9C5C8D9C5C8D9
C5C8D9C5C8D9C5C8D9C5C8D9C5C8D9C5C8D9C5C8D9C5C8D7C5C9D5C5C9D5C5C9D5C5C9D5C5C9D5\
C5C9D5C5C9D5C5C9D5BFC3CFBFC3CFBFC3CFBFC3CFBFC3CFBFC3CFBFC3CFC0C2CE
BCB9C2514C53514C53C1BCC3B3AEB5C6C1C8CFCAD1CCC7CEC5C0C7C5C0C7C5C0C7C5C0C7C5C0C7\
C5C0C7C5C0C7C5C0C6CDC4C9CDC4C7CCC3C6CBC2C5CBC2C5CAC1C4C9C0C3C9C0C3
CBC2C5CAC1C4C8BFC2C7BEC1C7BEC1C8BFC2CAC1C4CBC2C3C9C0C1C9C1BFC8C0BEC7BFBDC7BFBD\
C6BEBCC5BDBBC5BDBBC5BDBBC5BDBBC5BDBBC5BDBBC5BDBBC5BDBBC5BDBBC3BDBD
C6C1C5C1BFC4BEBCC1BDBBBEB9B7B8ADACAA9B9A988D8C8892918C9191898F8F858C8C80898A7C\
868777858676848573787A6474765E706F5A6C6E596F6E5C6D6E5E6C6A5E67675D
64615C1716121713141F1D201C171E1F1C232E28325A585B3E3B344B4C3E6A685B8182748A887B\
8586788B897C9495879391848F90828F8D808A8B7D8A887B87887A8886798B8673
93846D7C684F705C437F6D558B7B6483745D7B6F597D725E766B59857C6B736C5C8B85758D8A7B\
7D796D9795888C89828E8990928F9A8B888F807F7D83837B898A7C757664565843
47493444453586867E4A484928252E4D495A8D889F857F99A79FB4696274251E2E1A14222B2531\
252027312C325F5B5C7C787754504D49463F524F464A483C4745384E4C3D4C4A35
4D4A2B44401D4F4A2A494427504C334D4834393627625E538E8B86706E6F2C29303B3944484755\
2726362E2D3F2A2A3630302E2C2D252829232627222B2B2B3434363F3D42464449
3D3A41232126302C2D65615E83807B706D6458564A56544556513E57523E58533F58533F57523E\
55503C534E3A524D39726D59746F5B76715D78735F7A75617A756179746077755E
737858737A5B7277636F7267696E6A6A6E6D6F74707679706265527B7F6683866788886C98937D\
928B7B867B758C817F
B5BCCFB6BDCFB6BDD0B7BED0B8BFD2B8BFD1B9C0D3B9C0D2BEC5D8BEC5D7BFC6D9BFC6D8C0C7DA\
C1C8DAC1C8DBC2C9DBC0C7D9C0C7D9C0C7D9C0C7D9C0C7D9C0C7D9C0C7D9C0C7D9
C0C7D9C0C7D9C0C7D9C0C7D9C0C7D9C0C7D9C0C7D9C0C7D7BCC2D0BCC2CEBCC2D0BCC2CEBCC2CE\
BCC2CEBCC2CEBEC2CEBCC0CCBCC0CCBCC0CCBCC0CBBCC0CBBCC0CBBCC0CBBFBFC9
C3C0C7524D53524D54C0BBC1A9A4ABB8B3B9C2BDC4BCB7BDC0BBC2C0BBC1C0BBC2C0BBC1C0BBC2\
C0BBC1C0BBC2C0BBC1C3BDBFC3BDBDC4BBBCC1BBBBC3BABBC0BABAC1B8B9BFB9B9
C3BABBC0BABAC0B7B8BDB7B7BFB6B7BEB8B8C2B9BAC1BBBBC1B9B7BFBAB7C0B8B6BDB8B5BFB7B5\
BCB7B4BDB5B3BBB6B3BBB3B1B9B4B1BBB3B1B9B4B1BBB3B1B9B4B1BBB3B1B9B3B3
B5B3B6B5B4B9B6B4B7B5B5B7B2B0B1A9A9A7A09F9D9899948B8A85898A8287877D838578828375\
81837582837383847487897482846F7B7C6A7677657576667273656E6E626A6A60
61615914130F11100E1B191A14121518161B27252A57555642423A57584A77786A8C8D7F8A8B7D\
7F80728283758F908285867886877987887A898A7C8A8B7D8B8C7E8C8D7F8F8C7D
8D85706F634B62533C76684E8B7B6288785F80725882735C7D725C938B78868074A5A59DA4A6A3\
828888929C9E7C89917C8C9C8091A37787946C797F747E7D808A7F747B6B575C48
52554251524299998F5C5B592C2930403E4C6C697E4F4B62403B4F352E402C25353A34423D3743\
201B222621275B57587E7A7955524D4A47405250444A483C4745384E4C3D4C4A35
4D4A2B44411E4E4B2C484427514D344B49343734235F5B508F8C857874732A282B3A393F4C4A55\
2725322F2D3B2A2833292728272622252422292826343233444245585359635E64
423D432520242C2827615D5A827D77716E655B574C58544856504057523F58534058534057523F\
56513E544F3C534E3B7D78657D78657E79667E79667D78657B766379746176745F
797C5F787C61777A677274676D6E686C6E6970716B75776C7475637E806A7A7A6077755C7F7A66\
756E5E71675E857A74
B7C6DDB7C6DBB7C6DDB8C7DCB9C8DFBAC9DEBAC9E0BAC9DEBDCCE3BDCCE1BDCCE3BDCCE1BDCCE3\
BDCCE1BDCCE3BDCCE1BFCEE1BFCEE1BFCEE1BFCEE1BFCEE1BFCEE1BFCEE1BFCEE1
C1D0E3C1D0E3C1D0E3C1D0E3C1D0E3C1D0E3C1D0E3C3D0E1BBC7D5BEC8D4BEC7D6BBC5D1B7BFCC\
B5BDCAB8C0CBBCC2CEBAC1CBBCC0CBBCC0CBBDC0C9BDC0C9BDC0C9BDC0C7BFC0C5
BFBDC04B4746656162ADA9A8B7B3B4BBB7B6B9B5B6BFBBBABDB9BABDB9B8BDB9BABDB9B8BDB9BA\
BDB9B8BDB9BABDB9B8BDB9B6BDBAB5BEB9B5BDBAB5BEB9B5BDBAB5BEB9B5BDBAB5
BEB9B5BDBAB5BDB8B4BBB8B3BCB7B3BAB7B2BAB5B1B9B6B1BAB5B1B9B6B1BAB5B1B9B6B1BAB5B1\
B9B6B1BAB5B1B9B6B1BAB5B1B9B6B1BAB5B1B9B6B1BAB5B1B9B6B1BAB5B1B9B5B2
BBB7B6B8B6B7B5B1B0B3B2B0BCB8B7BCBBB7ACA9A493938B939089909086908D848A8A7E89877A\
848577838174828073858376817F727D7B6E7B796C7B796C79776B757367716F63
6461582320170E0B0417140D1310092E2B264D4A45423F384F4C435A584C6D6B5F7E7C7088867A\
8A887C8785798381758B897D8B897D8A887C89877B89877B88867A878579858579
86887B626554625F4C79735B7F74588475568979588271537E705698917EA9A8A37F888D8DA0B1\
6F89A46D8EB15F89AF5389AD568FAD5589A16D98A865888C5B7671697B6F485342
4B503C4C4F3A87887A6A6A6034343235363B3E404C3A3C493A3644302A382F293536303A2F2A31\
241F23332F30504C49827F7A5D5A514442364D4B3C5553444D4C3A4847334E4E36
4847284949274A492A4C4B2D4D4B324D4D354E4D394E4C3D7F7D716A675E3D3A352928263B393A\
3A383B27252A252026322C2E342E2E352F2F36303039343146413E59545167625F
38332F26211B2B271E524E437A74667B7869666050544E3E575141575141575141575141575141\
575141575141575141655F4F787262847E6E807A6A7A74647B75657D77677B7565
7A77647A77647A77687A766A7A766B79776B7A766B7A766A7A77687A77667976637A75627A7464\
797365797166797166
B9CBE3B9CBE3BACCE4BBCDE5BBCDE5BCCEE6BDCFE7BDCFE7BFD1E9BFD1E9BFD1E9BFD1E9BFD1E9\
BFD1E9BFD1E9BFD1E7C1D3E9C1D3E7C1D3E7C1D3E7C1D3E7C1D3E7C1D3E7C1D3E7
C3D5E9C3D5E9C3D5E9C3D5E9C3D5E9C3D5E9C3D5E9C4D5E7BAC7D7BDC9D7BDC9D7B9C5D3B6C0CC\
B5BFCBB8C0CBBBC3CEBAC1CBBAC1CBBDC0C9BDC0C9BDC0C7BDC0C7BFC0C5C0BFC4
BFBEBC4B474465615EAEAAA7B7B3B0BBB7B4BAB6B3BFBBB8BDB9B6BDB9B6BDB9B6BDB9B6BDB9B6\
BDB9B6BDB9B6BDBAB5BDBAB5BDBAB3BDBAB3BDBAB3BDBAB3BDBAB3BDBAB3BDBAB3
BDBAB3BDBAB3BCB9B2BCB9B2BBB8B1BAB7B0BAB7B0B9B6AFB9B6AFB9B6AFB9B6AFB9B6AFB9B6AF\
B9B6AFB9B6AFB9B6AFB9B6AFB9B6AFB9B6AFB9B6AFB9B6AFB9B6AFB9B6AFB9B6B1
BBB7B4BAB6B5B5B1AEB4B0ADBAB6B3BBB8B3AAA7A294918A8C89808A877E88867A858377828073\
7F7D707D7B6E7B796C78766A7371656F6D616D6B5F6E6C606C6A5E68665A646256
5250441A180C0A080019170B1E1C103735294D4B3F3E3C305F5D5168665A7674688381758B897D\
8D8B7F8A887C8785798B897D8B897D8A887C8A887C89877B88867A88867A84867B
838B805E66595E615076745D7F76578475548A7A568373518A7C6185806D74797542525F617C99\
567BA55B89BD4A83BA408AB93D8BB2337A9A47849950808A6185857F9990617262
49503E4D503D8485756D6D6134352F383A393C41453B3E473A3742312B352F29333530372F2A30\
252122332F2E4D4A45817E775E5C504644374D4C3A5453414D4C384948334E4E36
494A2B4A4B2B4A4B2C4C4D2E4E4E3450503852513C54534198968785837758554C3E3B34474340\
413D3A302C2B302C2D21181B251C1D2920212A22202B23203129263C352F453E36
463F353630243933255B55477B75657C776466614E534E3B585244585244585244585244585244\
585244585244585244686254797365847E70807A6C7B75677C76687D77697B7567
7C76687C76687C76687C76687C76687C76687C76687C76687C76687C76687B75677B75677A7466\
797365797365787264
BED0E8BED0E8BFD1E9C0D2EAC0D2EAC1D3EBC2D4ECC2D4ECC4D6EEC4D6EEC4D6EEC4D6EEC4D6EE\
C4D6EEC4D6EEC4D6ECC6D8EEC6D8ECC6D8ECC6D8ECC6D8ECC6D8ECC6D8ECC6D8EC
C8DAEEC8DAEEC8DAEEC8DAEEC8DAEEC8DAEEC8DAEEC9DAECBBC8D8BDC9D7BDC9D7BAC6D4B7C1CD\
B5BFCBB9C1CCBCC4CFBBC2CCBBC2CCBEC1CABEC1CABEC1C8BEC1C8C0C1C6C1C0C5
C0BFBD4B474466625FAEAAA7B8B4B1BCB8B5BAB6B3C0BCB9BEBAB7BEBAB7BEBAB7BEBAB7BEBAB7\
BEBAB7BEBAB7BEBBB6BEBBB6BEBBB4BEBBB4BEBBB4BEBBB4BEBBB4BEBBB4BEBBB4
BEBBB4BDBAB3BDBAB3BCB9B2BBB8B1BBB8B1BAB7B0BAB7B0BAB7B0BAB7B0BAB7B0BAB7B0BAB7B0\
BAB7B0BAB7B0BAB7B0B9B6AFB9B6AFB9B6AFB9B6AFB9B6AFB9B6AFB9B6AFB9B6B1
BAB6B3BAB6B5B5B1AEB2AEABB7B3B0B8B5B0A8A5A094918A939087928F86908E828D8B7F8A887B\
888679868477848275858377817F737D7B6F7B796D7C7A6E7A786C767468727064
68665A4240343B392D4A483C5250446361556B695D5B594D7573677A786C82807489877B8E8C80\
8F8D818E8C808C8A7E8C8A7E8B897D8B897D8A887C89877B89877B88867A85877C
838B805E66595F625177755E7F7659847755897B58817454877D648380717079783B4E5C52718E\
4069954072A72D6AA12770A3307FAA2C75983F7C984A7B8A5D8386708B86415347
4A52434C503F7F817373736933342F3C3E3D3A3D423D3D453A3740322C36302A34342F352F2A2E\
272324322E2D4845407F7C75605E5249473A4D4C3A5352404E4D394A49344E4E36
4E4F304D4E2E4C4D2E4B4C2D4B4B314C4C344D4C374F4E3C72706169675B4542392E2B24322E2B\
2C2825231F1E2B2726332A2B372F2D3C34323D35333C34313C34313E3731413A32
665F555852465751436C6658807A6A7B7565645F4C514C39585244585244585244585244585244\
5852445852445852446B65577B7567847E70807A6C7B75677D77697F796B7C7668
7D77697D77697D77697D77697D77697D77697D77697D77697D77697C76687C76687B75677A7466\
7A7466797365797365
C0D2EAC0D2EAC1D3EBC1D3EBC2D4ECC3D5EDC3D5EDC4D6EEC6D8F0C6D8F0C6D8F0C6D8F0C6D8F0\
C6D8F0C6D8F0C6D8EEC8DAF0C8DAEEC8DAEEC8DAEEC8DAEEC8DAEEC8DAEEC8DAEE
CADCF0CADCF0CADCF0CADCF0CADCF0CADCF0CADCF0CBDCEEBCC9D9BECAD8BECAD8BAC6D4B8C2CE\
B6C0CCB9C1CCBDC5D0BCC3CDBCC3CDBFC2CBBFC2CBBFC2C9BFC2C9C1C2C7C2C1C6
C0BFBD4C4845676360AFABA8B9B5B2BDB9B6BBB7B4C0BCB9BFBBB8BFBBB8BFBBB8BFBBB8BFBBB8\
BFBBB8BFBBB8BFBCB7BFBCB7BFBCB5BFBCB5BFBCB5BFBCB5BFBCB5BFBCB5BFBCB5
BFBCB5BEBBB4BEBBB4BDBAB3BCB9B2BCB9B2BBB8B1BBB8B1BBB8B1BBB8B1BBB8B1BBB8B1BBB8B1\
BBB8B1BBB8B1BBB8B1B9B6AFB9B6AFB9B6AFB9B6AFB9B6AFB9B6AFB9B6AFB9B6B1
B9B5B2BAB6B5B6B2AFB1ADAAB4B0ADB5B2ADA8A5A097948D8C89808B887F89877B878579848275\
828073807E717F7D708381757E7C707A786C79776B79776B7775697371656F6D61
8A887C817F738482768B897D8C8A7E8E8C808D8B7F85837789877B8A887C8B897D8D8B7F8E8C80\
8E8C808E8C808E8C808D8B7F8C8A7E8C8A7E8B897D8A887C8A887C89877B87877B
858B7F6066586162507A755F7E775A827757897C5A80755778725C8486798590925168786285A5\
527EAB6195CE5F9DD874BFF683D1FF79C0EA76B5D66C9FB47199A17B9798455852
4953484E5244787A6D7A7A7234332F42424238393E3F3E463A373E342F36312C33322D332E2A2B\
282423312D2A413E397D7A736361554D4B3E4D4C3A51503E4F4E3A4C4B364F4F37
5151355051324D4E2F4B4B2F49492F4848304847324847358987788F8D81807D7475726B7E7B76\
7D79767A76738A86838D85838F8784918987928A879088858F88828E877F8E877D
857F737C766A7872647F796B857F6F7B756565604D524D3A5D57495D57495D57495D57495D5749\
5D57495D57495D5749716B5D7D7769847E70807A6C7C7668807A6C807A6C7C7668
7E786A7E786A7E786A7E786A7E786A7E786A7E786A7E786A7E786A7D77697D77697C76687B7567\
7B75677A74667A7466
BFD1E9BFD1E9C0D2EAC0D2EAC1D3EBC2D4ECC2D4ECC3D5EDC5D7EFC5D7EFC5D7EFC5D7EFC5D7EF\
C5D7EFC5D7EFC5D7EDC7D9EFC7D9EDC7D9EDC7D9EDC7D9EDC7D9EDC7D9EDC7D9ED
C9DBEFC9DBEFC9DBEFC9DBEFC9DBEFC9DBEFC9DBEFCADBEDBDCADABFCBD9BFCBD9BBC7D5B8C2CE\
B7C1CDBAC2CDBEC6D1BCC3CDBCC3CDBFC2CBBFC2CBBFC2C9BFC2C9C1C2C7C2C1C6
C1C0BE4D4946676360B0ACA9BAB6B3BDB9B6BCB8B5C1BDBABFBBB8BFBBB8BFBBB8BFBBB8BFBBB8\
BFBBB8BFBBB8BFBCB7BFBCB7BFBCB5BFBCB5BFBCB5BFBCB5BFBCB5BFBCB5BFBCB5
BFBCB5BFBCB5BEBBB4BEBBB4BDBAB3BCB9B2BCB9B2BBB8B1BBB8B1BBB8B1BBB8B1BBB8B1BBB8B1\
BBB8B1BBB8B1BBB8B1B9B6AFB9B6AFB9B6AFB9B6AFB9B6AFB9B6AFB9B6AFB9B6B1
B7B3B0B9B5B4B7B3B0B2AEABB3AFACB5B2ADABA8A39C999296938A959289949286929084908E81\
8E8C7F8D8B7E8C8A7D88867A848276807E727E7C707E7C707C7A6E78766A747266
807E72959387A19F939F9D9199978B918F838E8C80969488939185929084908E828E8C808D8B7F\
8C8A7E8D8B7F8D8B7F8D8B7F8D8B7F8C8A7E8C8A7E8B897D8A887C8A887C87877B
888B806367596463517A755F7F785C82795A887D5F7E775B74715E797F7576858A4C677C6F95B9\
6F9FCF84BCF581C3FF8AD6FF92E1FF82CAFA77B7DD6298B26892A2819EA45B6F6D
4A554D4D534972736B82817C34333149474A363439413E453C373D363135322D31302C2D2D292A\
2A2625302C2939362F7A776E6664585250434D4C3A4F4E3C4F4E3A4F4E394F4F37
4F4F3350503452523654543856563C57573F5756415857456C6A5B7E7C707D7A717B787186837E\
827F7A7F7C778F8C87847C79827B758078757F78727F78728079718079717F786E
878175857F73847E70847E70847E6E7E78686E69565F5A476D67596D67596D67596D67596D6759\
6D67596D67596D6759767062807A6C847E707F796B7E786A827C6E817B6D7C7668
7E786A7E786A7E786A7E786A7E786A7E786A7E786A7E786A7E786A7E786A7D77697D77697C7668\
7B75677B75677A7466
BED0E8BED0E8BFD1E9BFD1E9C0D2EAC1D3EBC1D3EBC2D4ECC4D6EEC4D6EEC4D6EEC4D6EEC4D6EE\
C4D6EEC4D6EEC4D6ECC6D8EEC6D8ECC6D8ECC6D8ECC6D8ECC6D8ECC6D8ECC6D8EC
C8DAEEC8DAEEC8DAEEC8DAEEC8DAEEC8DAEEC8DAEEC9DAECBDCADAC0CCDABFCBD9BCC8D6B9C3CF\
B8C2CEBBC3CEBEC6D1BDC4CEBDC4CEC0C3CCC0C3CCC0C3CAC0C3CAC2C3C8C3C2C7
C2C1BF4E4A47686461B1ADAABAB6B3BEBAB7BDB9B6C2BEBBC0BCB9C0BCB9C0BCB9C0BCB9C0BCB9\
C0BCB9C0BCB9C0BDB8C0BDB8C0BDB6C0BDB6C0BDB6C0BDB6C0BDB6C0BDB6C0BDB6
C0BDB6C0BDB6BFBCB5BFBCB5BEBBB4BDBAB3BDBAB3BCB9B2BCB9B2BCB9B2BCB9B2BCB9B2BCB9B2\
BCB9B2BCB9B2BCB9B2B9B6AFB9B6AFB9B6AFB9B6AFB9B6AFB9B6AFB9B6AFB9B6B1
B5B1AEB9B5B4B8B4B1B3AFACB4B0ADB7B4AFB1AEA9A5A29B959289959289939185929084908E81\
8F8D808E8C7F8D8B7E8B897D878579838175817F73817F73807E727C7A6E777569
69675B8F8D819A988C918F839290848A887C87857999978B9694889492869290848F8D818D8B7F\
8C8A7E8C8A7E8C8A7E8E8C808E8C808D8B7F8D8B7F8C8A7E8B897D8B897D88887C
8A8C8166665A6463517B76627F785E83795E867F637D79607E7F6F7781796C80874A697E729DC0\
5B8FBF3F7CB51357960753911665A0246B9F4584AF497E9D4E798C67858F485D5E
4B57534E534C6B6C668A8984353130504C4D342F35443F453C373B383435332F302F2B2A2C2827\
2C28252F2C27322F2878766A6866595654454D4B3C4D4C3A504F3B51503C505038
4B4B315252365C5C4068684E70705875745F7675617776647E7C6D918F82918F838D8A8194918A\
8A8782817E798E8B849089838C857D878078867F77888179898278878076847E72
716B5F7A74687F796B7E786A7F7969827C6C7C7764736D5D817B6D817B6D817B6D817B6D817B6D\
817B6D817B6D817B6D7B7567837D6F847E707F796B7F796B847E70837D6F7C7668
7F796B7F796B7F796B7F796B7F796B7F796B7F796B7F796B7F796B7F796B7E786A7E786A7D7769\
7C76687C76687B7567
BFD1E9BFD1E9C0D2EAC1D3EBC1D3EBC2D4ECC3D5EDC3D5EDC5D7EFC5D7EFC5D7EFC5D7EFC5D7EF\
C5D7EFC5D7EFC5D7EDC7D9EFC7D9EDC7D9EDC7D9EDC7D9EDC7D9EDC7D9EDC7D9ED
C9DBEFC9DBEFC9DBEFC9DBEFC9DBEFC9DBEFC9DBEFCADBEDBECBDBC0CCDAC0CCDABCC8D6BAC4D0\
B8C2CEBCC4CFBFC7D2BEC5CFBEC5CFC1C4CDC1C4CDC1C4CBC1C4CBC3C4C9C4C3C8
C2C1BF4E4A47696562B1ADAABBB7B4BFBBB8BDB9B6C2BEBBC1BDBAC1BDBAC1BDBAC1BDBAC1BDBA\
C1BDBAC1BDBAC1BEB9C1BEB9C1BEB7C1BEB7C1BEB7C1BEB7C1BEB7C1BEB7C1BEB7
C1BEB7C0BDB6C0BDB6BFBCB5BEBBB4BEBBB4BDBAB3BDBAB3BDBAB3BDBAB3BDBAB3BDBAB3BDBAB3\
BDBAB3BDBAB3BDBAB3B9B6AFB9B6AFB9B6AFB9B6AFB9B6AFB9B6AFB9B6AFB9B6B1
B3AFACB9B5B4B9B5B2B4B0ADB6B2AFBAB7B2B7B4AFAEABA48C89808B887F8A887C89877B888679\
87857886847785837689877B848276807E727E7C707F7D717D7B6F79776B757367
7472669A988C98968A8B897D98968A9593878C8A7E9E9C90969488959387939185918F83908E82\
8F8D818E8C808E8C808F8D818E8C808E8C808D8B7F8C8A7E8C8A7E8B897D8B897D
8B8B7F6866596663527C7763807861827B61857F657B79627D81727F8C857990984C6F83638FB2\
4076A5256299004481115B9A0A549110538A4481AE5A8CAF59819A6888954E6368
4A58584D534F676862918E89363030554F51322C2E453F413C3837393534332F2E2D29262C2825\
2E2B262E2B242D2A217674686A685B5957484D4B3C4C4B3951503C52513D504F3A
5050385A5A406A6A5079796184846C888772878672858472817F708F8D8088867A827F7689867D\
817E7779766F85827B7E776D7C756B7A73697B746A7C756B7872666F695D676153
696355787264817B6D7E786A7F7969868070888272837D6D888274888274888274888274888274\
8882748882748882747F796B857F71847E707F796B807A6C868072847E707D7769
807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C7F796B7F796B7E786A7D7769\
7D77697C76687C7668
C1D3EBC1D3EBC2D4ECC3D5EDC3D5EDC4D6EEC5D7EFC5D7EFC7D9F1C7D9F1C7D9F1C7D9F1C7D9F1\
C7D9F1C7D9F1C7D9EFC9DBF1C9DBEFC9DBEFC9DBEFC9DBEFC9DBEFC9DBEFC9DBEF
CBDDF1CBDDF1CBDDF1CBDDF1CBDDF1CBDDF1CBDDF1CCDDEFBECBDBC1CDDBC0CCDABDC9D7BAC4D0\
B8C2CEBCC4CFBFC7D2BEC5CFBEC5CFC1C4CDC1C4CDC1C4CBC1C4CBC3C4C9C4C3C8
C3C2C04F4B48696562B1ADAABBB7B4BFBBB8BEBAB7C3BFBCC1BDBAC1BDBAC1BDBAC1BDBAC1BDBA\
C1BDBAC1BDBAC1BEB9C1BEB9C1BEB7C1BEB7C1BEB7C1BEB7C1BEB7C1BEB7C1BEB7
C1BEB7C1BEB7C0BDB6BFBCB5BFBCB5BEBBB4BDBAB3BDBAB3BDBAB3BDBAB3BDBAB3BDBAB3BDBAB3\
BDBAB3BDBAB3BDBAB3B9B6AFB9B6AFB9B6AFB9B6AFB9B6AFB9B6AFB9B6AFB9B6B1
B2AEABB9B5B4B9B5B2B5B1AEB7B3B0BDBAB5BBB8B3B3B0A9C0BDB4C0BDB4BFBDB1BEBCB0BDBBAE\
BCBAADBBB9ACBBB9ACB7B5A9B3B1A5AFADA1ADAB9FADAB9FACAA9EA7A599A3A195
8F8D81AEACA09D9B8F8C8A7EA3A195A3A195918F839D9B8F959387959387959387949286939185\
929084908E82908E828F8D818F8D818E8C808D8B7F8D8B7F8C8A7E8B897D8B897D
8E8C806A665A6862527C77637F7961817B638480677A79656F75677D8C877992993A5D71477495\
4A7FAB80BCF0A1E2FFB6FAFF75BAF53978AD497FAD507EA04E738D6986945D7277
4B59594E545064656095928D38302E5A525032292A483F403D38353A373234312C2D2A252C2924\
2E2B242E2B222A281C7573666C6A5D5B594A4D4B3C4B4A3851503E53523E51503C
58584063634B73735B82816C8A89748988748483717F7E6C7D7B6C8785767D7B6E777569848276\
848178827F76918E858983778882748A84768D87798D8779847E70746E60676153
706A5C827C6E8B8577857F71827C6C8983738D8777888272857F71857F71857F71857F71857F71\
857F71857F71857F71827C6E868072847E707E786A807A6C868072857F717D7769
807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C7F796B7E786A7E786A\
7D77697C76687C7668
C1D3EBC1D3EBC2D4ECC2D4ECC3D5EDC4D6EEC4D6EEC5D7EFC7D9F1C7D9F1C7D9F1C7D9F1C7D9F1\
C7D9F1C7D9F1C7D9EFC9DBF1C9DBEFC9DBEFC9DBEFC9DBEFC9DBEFC9DBEFC9DBEF
C7D9EDC7D9EDC8DAEEC9DBEFC9DBEFCADCF0CBDDF1CCDDEFBBC8D8C4D0DEC5D1DFBCC8D6B8C2CE\
BBC5D1BDC5D0B9C1CCBEC5CFBEC5CFC1C4CDC1C4CDC1C4CBC1C4CBC3C4C9C4C3C8
C5C4C2393532807C79ACA8A5BAB6B3B8B4B1C2BEBBC7C3C0C3BFBCC3BFBCC3BFBCC3BFBCC3BFBC\
C3BFBCC3BFBCC3C0BBC1BEB9C1BEB7C1BEB7C1BEB7C1BEB7C1BEB7C1BEB7C1BEB7
C1BEB7C1BEB7C1BEB7C1BEB7C1BEB7C1BEB7C1BEB7C1BEB7C1BEB7C1BEB7C0BDB6BFBCB5BFBCB5\
BEBBB4BDBAB3BDBAB3BDBAB3BDBAB3BCB9B2BBB8B1BBB8B1BAB7B0B9B6AFB9B6B1
B8B4B1B7B3B2B7B3B0B7B3B0B8B4B1BAB7B2BCB9B4BEBBB4C8C5BCC8C5BCC7C5B9C6C4B8C6C4B7\
C5C3B6C4C2B5C4C2B5BDBBAFC9C7BBBFBDB19E9C908E8C8099978BA2A0949F9D91
A19F93A09E929F9D919E9C909C9A8E9B998D9A988C99978B979589969488959387949286929084\
918F83908E828F8D81918F83908E828F8D818E8C808C8A7E8B897D8A887C89877B
8783786E6A5E645E50746F5C837D67817B657C77617B7C6A777D7169787372898F4F7081517A98\
3F709874AAD994D0FF8CC9FF7FBBF14D82B444759E527B9B5B7E946A86924F6268
4C5858555C556667616D6A635D55524238363B312F443A3837322C38352E3330292A271E2D2A21\
3634283634282E2C1F7775687775685D5B4C4A48395352405453414C4B3953523E
4D4C37605F4A7978638A89758E8D798A8975858472838270848273848273848275838174828073\
817F73817F73817F73847E70898373888272847E6E847E6E857F6F7D7767706A5A
666050797363888272888272857F71868072857F71807A6C868072868072868072868072868072\
868072868072868072847E70847E70837D6F827C6E827C6E817B6D807A6C807A6C
807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C7F796B7E786A7E786A\
7D77697C76687C7668
C0D2EAC0D2EAC0D2EAC1D3EBC2D4ECC3D5EDC3D5EDC3D5EDC6D8F0C6D8F0C6D8F0C6D8F0C6D8F0\
C6D8F0C6D8F0C6D8EEC8DAF0C8DAEEC8DAEEC8DAEEC8DAEEC8DAEEC8DAEEC8DAEE
C7D9EDC8DAEEC8DAEEC9DBEFCADCF0CADCF0CBDDF1CCDDEFBCC9D9C5D1DFC5D1DFBCC8D6B9C3CF\
BBC5D1BDC5D0B9C1CCBEC5CFBEC5CFC1C4CDC1C4CDC1C4CBC1C4CBC3C4C9C4C3C8
C5C4C2393532817D7AADA9A6BAB6B3B9B5B2C3BFBCC6C2BFC3BFBCC3BFBCC3BFBCC3BFBCC3BFBC\
C3BFBCC3BFBCC3C0BBC1BEB9C1BEB7C1BEB7C1BEB7C1BEB7C1BEB7C1BEB7C1BEB7
C1BEB7C1BEB7C1BEB7C1BEB7C1BEB7C1BEB7C1BEB7C1BEB7C1BEB7C1BEB7C0BDB6C0BDB6BFBCB5\
BEBBB4BEBBB4BDBAB3BDBAB3BDBAB3BCB9B2BCB9B2BBB8B1BAB7B0BAB7B0B9B6B1
B8B4B1B8B4B3B7B3B0B7B3B0B8B4B1BAB7B2BCB9B4BDBAB3BEBBB2BDBAB1BDBBAFBCBAAEBBB9AC\
BBB9ACBAB8ABBAB8ABB7B5A9BDBBAFACAA9E89877B7A786C8A887C9B998D9E9C90
A19F93A09E929F9D919E9C909C9A8E9B998D9A988C99978B979589969488959387949286929084\
918F83908E828F8D81918F83908E828F8D818E8C808C8A7E8B897D8A887C89877B
8884796E6A5F655F51746E5E837C69807B657C77637B7C6A81877975827B798E91526F7D567A92\
3C67895182AA5386B34D80AF5B8BBB48759E567EA16589A3698698758D975B6D6F
444F4B5257506B6B63837F76867F777C736C7C716B847B748E8A7F8684787F7D717C7A6E7B796D\
7A786B7775687573666B695C6C6A5D555344464435504F3D4E4D3B4544324D4C3A
53523E63624E7978648A89758F8E7A8F8E7A8D8C7A8D8C7A868475868475868477858376848275\
83817483817483817285806D898470898470847F6B847F6B86816E7E7966716B5B
645E4E777161878171888272868072878173878173827C6E868072868072868072868072868072\
868072868072868072847E70847E70837D6F827C6E827C6E817B6D807A6C807A6C
807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C7F796B7E786A7E786A\
7D77697C76687C7668
C0D2EAC0D2EAC0D2EAC1D3EBC2D4ECC3D5EDC3D5EDC3D5EDC6D8F0C6D8F0C6D8F0C6D8F0C6D8F0\
C6D8F0C6D8F0C6D8EEC8DAF0C8DAEEC8DAEEC8DAEEC8DAEEC8DAEEC8DAEEC8DAEE
C8DAEEC8DAEEC9DBEFC9DBEFCADCF0CBDDF1CBDDF1CDDEF0BCC9D9C5D1DFC6D2E0BDC9D7B9C3CF\
BCC6D2BDC5D0B9C1CCBFC6D0BFC6D0C2C5CEC2C5CEC2C5CCC2C5CCC4C5CAC5C4C9
C5C4C2393532817D7AAEAAA7BCB8B5BAB6B3C3BFBCC6C2BFC4C0BDC4C0BDC4C0BDC4C0BDC4C0BD\
C4C0BDC4C0BDC4C1BCC2BFBAC2BFB8C2BFB8C2BFB8C2BFB8C2BFB8C2BFB8C2BFB8
C2BFB8C2BFB8C2BFB8C2BFB8C2BFB8C2BFB8C2BFB8C2BFB8C2BFB8C1BEB7C1BEB7C0BDB6BFBCB5\
BFBCB5BEBBB4BEBBB4BEBBB4BDBAB3BDBAB3BCB9B2BBB8B1BBB8B1BAB7B0BAB7B2
B9B5B2B8B4B3B7B3B0B7B3B0B8B4B1B9B6B1BBB8B3BCB9B2B7B4ABB6B3AAB6B4A8B5B3A7B4B2A5\
B4B2A5B3B1A4B3B1A4B4B2A6BAB8ACAEACA0939185878579949286A19F93A2A094
A2A094A19F93A09E929F9D919D9B8F9C9A8E9B998D9A988C98968A979589969488959387939185\
929084918F83908E82918F83908E828F8D818E8C808C8A7E8B897D8A887C89877B
8A867D706C63666054756F61847D6B807B677C77637D7C687F837475817778888750676F617E90\
5478905D84A3456D903D6388567A9E52739465839D6A85986179836C7F83586764
49534B55584D6A6A5E858175928C7E928A7D92887E958B81979387868477807E7189877A89877A\
7E7C6D7B796A8381727775667A78696A6859615F506B695A6563545A5849646351
68675572715F81806E8B8A788F8E7C8F8E7C8F8E7C8F8E7C8A8879898778898778888677878576\
87857686847586857386816D8B86708A856F86816B86816B87826E7F7A66726D5A
625D4A75705D857F6F878171868072898375898377857F73857F71857F71857F71857F71857F71\
857F71857F71857F71847E70847E70837D6F827C6E827C6E817B6D807A6C807A6C
807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C7F796B7E786A7E786A\
7D77697C76687C7668
C2D4ECC2D4ECC3D5EDC4D6EEC4D6EEC5D7EFC6D8F0C6D8F0C8DAF2C8DAF2C8DAF2C8DAF2C8DAF2\
C8DAF2C8DAF2C8DAF0CADCF2CADCF0CADCF0CADCF0CADCF0CADCF0CADCF0CADCF0
C9DBEFC9DBEFCADCF0CADCF0CBDDF1CCDEF2CCDEF2CEDFF1BDCADAC6D2E0C7D3E1BDC9D7BAC4D0\
BDC7D3BEC6D1BAC2CDC0C7D1C0C7D1C3C6CFC3C6CFC3C6CDC3C6CDC5C6CBC6C5CA
C5C4C2393532837F7CB0ACA9BEBAB7BBB7B4C3BFBCC6C2BFC5C1BEC5C1BEC5C1BEC5C1BEC5C1BE\
C5C1BEC5C1BEC5C2BDC3C0BBC3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9
C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C2BFB8C2BFB8C1BEB7C0BDB6\
C0BDB6BFBCB5BFBCB5BFBCB5BEBBB4BEBBB4BDBAB3BCB9B2BCB9B2BBB8B1BBB8B3
BAB6B3B9B5B4B8B4B1B7B3B0B7B3B0B9B6B1BAB7B2BBB8B1B8B5ACB8B5ACB7B5A9B7B5A9B6B4A7\
B5B3A6B5B3A6B4B2A5ABA99DB7B5A9BAB8ACAFADA1A7A599A9A79BA7A599A09E92
A2A094A2A094A19F939F9D919E9C909C9A8E9B998D9B998D98968A98968A979589959387949286\
929084918F83918F83918F83908E828F8D818E8C808C8A7E8B897D8A887C89867D
8B8680716C66676056767062847D6B807B677C77637D7C68797C6B767E7177847D4B5D5F657B86\
6A85967A99AE5F7D975F79946E839E5E7388697C8B6779835B6D6F6C78765E685F
545A4E57594B60614F726F5E837E6B8B84728D81738980718986757372607270618887758E8C7D\
7F7D6E807E6F918F808D8B7C9290818886778583748F8D7E838172787667848273
8482738786748B8A788D8C7A8D8C7A8C8B798A89778988768C8A7B8C8A7B8C8A7B8B897A8A8879\
89877889877889887487826C8C886D8C886F87836A87836A89846E807B65736E5A
605B48746F5C847E6E8781718781738A84768A8478868074847E70847E70847E70847E70847E70\
847E70847E70847E70847E70847E70837D6F827C6E827C6E817B6D807A6C807A6C
807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C7F796B7E786A7E786A\
7D77697C76687C7668
C5D7EFC5D7EFC6D8F0C6D8F0C7D9F1C8DAF2C8DAF2C9DBF3CBDDF5CBDDF5CBDDF5CBDDF5CBDDF5\
CBDDF5CBDDF5CBDDF3CDDFF5CDDFF3CDDFF3CDDFF3CDDFF3CDDFF3CDDFF3CDDFF3
C9DBEFCADCF0CADCF0CBDDF1CCDEF2CCDEF2CDDFF3CEDFF1BECBDBC7D3E1C7D3E1BECAD8BBC5D1\
BDC7D3BFC7D2BBC3CEC0C7D1C0C7D1C3C6CFC3C6CFC3C6CDC3C6CDC5C6CBC6C5CA
C4C3C13A363384807DB2AEABC0BCB9BDB9B6C3BFBCC5C1BEC5C1BEC5C1BEC5C1BEC5C1BEC5C1BE\
C5C1BEC5C1BEC5C2BDC3C0BBC3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9
C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C3C0B9C2BFB8C2BFB8C1BEB7\
C0BDB6C0BDB6BFBCB5BFBCB5BFBCB5BEBBB4BEBBB4BDBAB3BCB9B2BCB9B2BBB8B3
BBB7B4BAB6B5B9B5B2B7B3B0B7B3B0B8B5B0B9B6B1BAB7B0B9B6ADB9B6ADB8B6AAB8B6AAB7B5A8\
B6B4A7B6B4A7B5B3A6A5A397AEACA0B4B2A6B1AFA3ADAB9FAAA89CA5A3979F9D91
A3A195A3A195A2A094A09E929F9D919D9B8F9C9A8E9C9A8E99978B99978B98968A969488959387\
939185929084929084918F83908E828F8D818E8C808C8A7E8B897D8A887C89867D
8D8884736E6A69625A777165847E6E807B677C77637D7B667D7C688486788C9489606B67728081\
70818880949F677A8875819179838F636B7670797E76807F6E77727F877C737A6A
5F624F5D5F495E5D4868664F7D7862918B759B907C98907D8B887577766278776592917D9A9987\
8C8B798D8C7A9F9E8C908F7D9594828F8D7E918F809A98898987787E7C6D8F8D7E
918F808F8D7E8E8C7D8D8B7C8D8B7C8D8B7C8B897A8A88798E8D7B8E8D7B8D8C7A8D8C7A8C8B79\
8B8A788B8A788A897489856C8E8A6D8D896E89856A89856A8A866D827D6775705C
605B48746F5C847E6E8781718781738A84768A8478868074847E70847E70847E70847E70847E70\
847E70847E70847E70847E70847E70837D6F827C6E827C6E817B6D807A6C807A6C
807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C7F796B7E786A7E786A\
7D77697C76687C7668
C4D6EEC5D7EFC5D7EFC6D8F0C7D9F1C7D9F1C8DAF2C8DAF2CADCF4CADCF4CADCF4CADCF4CADCF4\
CADCF4CADCF4CADCF2CCDEF4CCDEF2CCDEF2CCDEF2CCDEF2CCDEF2CCDEF2CCDEF2
CADCF0CBDDF1CBDDF1CCDEF2CDDFF3CDDFF3CEE0F4CFE0F2BFCCDCC8D4E2C8D4E2BFCBD9BBC5D1\
BEC8D4C0C8D3BCC4CFC1C8D2C1C8D2C4C7D0C4C7D0C4C7CEC4C7CEC6C7CCC7C6CB
C4C3C13A363385817EB4B0ADC2BEBBBEBAB7C4C0BDC5C1BEC6C2BFC6C2BFC6C2BFC6C2BFC6C2BF\
C6C2BFC6C2BFC6C3BEC4C1BCC4C1BAC4C1BAC4C1BAC4C1BAC4C1BAC4C1BAC4C1BA
C4C1BAC4C1BAC4C1BAC4C1BAC4C1BAC4C1BAC4C1BAC4C1BAC4C1BAC4C1BAC3C0B9C3C0B9C2BFB8\
C1BEB7C1BEB7C0BDB6C0BDB6C0BDB6BFBCB5BFBCB5BEBBB4BDBAB3BDBAB3BCB9B4
BCB8B5BBB7B6B9B5B2B8B4B1B7B3B0B7B4AFB8B5B0B9B6AFB7B4ABB7B4ABB6B4A8B5B3A7B5B3A6\
B4B2A5B3B1A4B3B1A4B3B1A5B1AFA3ADAB9FA8A69AA7A599A8A69AABA99DACAA9E
A4A296A3A195A2A094A19F939F9D919E9C909D9B8F9C9A8E9A988C99978B98968A979589959387\
949286939185929084918F83908E828F8D818E8C808C8A7E8B897D8A887C89867D
8F8A8675706C6A635D787167857F71807B687C77617F7A647B7964898876A3A597868C82959B97\
828C8B8B969A7780857E818683828770707083847F87888076786B818473737661
74765E74745A6F6E52706C517D775D908A70999278978F788F8D7882816D82816D92917D969581\
8D8C788A897792917F8E8D7B92917F8D8B7C9391829A98898583747B796A918F80
8D8B7E8A887B8886778987788E8C7D9290819391829290818E8D7B8E8D7B8D8C7A8D8C7A8C8B79\
8B8A788B8A768A89748A866B8F8B6E8F8B6E8A86698A866B8C886D837F6676715B
625D4975705D857F6F878171868072898375898377857F73837D6F837D6F837D6F837D6F837D6F\
837D6F837D6F837D6F847E70847E70837D6F827C6E827C6E817B6D807A6C807A6C
807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C7F796B7E786A7E786A\
7D77697C76687C7668
C1D3EBC1D3EBC1D3EBC2D4ECC3D5EDC4D6EEC4D6EEC4D6EEC7D9F1C7D9F1C7D9F1C7D9F1C7D9F1\
C7D9F1C7D9F1C7D9EFC9DBF1C9DBEFC9DBEFC9DBEFC9DBEFC9DBEFC9DBEFC9DBEF
CBDDF1CBDDF1CCDEF2CCDEF2CDDFF3CEE0F4CEE0F4D0E1F3BFCCDCC8D4E2C9D5E3BFCBD9BCC6D2\
BFC9D5C0C8D3BCC4CFC2C9D3C2C9D3C5C8D1C5C8D1C5C8CFC5C8CFC7C8CDC8C7CC
C3C2C03A363386827FB6B2AFC3BFBCBFBBB8C4C0BDC5C1BEC7C3C0C7C3C0C7C3C0C7C3C0C7C3C0\
C7C3C0C7C3C0C7C4BFC5C2BDC5C2BBC5C2BBC5C2BBC5C2BBC5C2BBC5C2BBC5C2BB
C5C2BBC5C2BBC5C2BBC5C2BBC5C2BBC5C2BBC5C2BBC5C2BBC5C2BBC4C1BAC4C1BAC3C0B9C2BFB8\
C2BFB8C1BEB7C1BEB7C1BEB7C0BDB6C0BDB6BFBCB5BEBBB4BEBBB4BDBAB3BDBAB5
BDB9B6BCB8B7BAB6B3B8B4B1B7B3B0B7B4AFB8B5B0B8B5AEB8B5ACB7B4ABB7B5A9B6B4A8B5B3A6\
B5B3A6B4B2A5B4B2A5BAB8ACB4B2A6AFADA1ADAB9FADAB9FADAB9FAFADA1B1AFA3
A5A397A4A296A3A195A2A094A09E929F9D919E9C909D9B8F9B998D9A988C99978B98968A969488\
959387949286939185918F83908E828F8D818E8C808C8A7E8B897D8A887C89867D
908C8975716E696460777368857F71817C697D77617F7B627D78627E7C679A99878C8D7FA0A297\
8789848D928E838582837E7B8D847F7C756D8A8379817E6F67665277775F75755B
86866A8B8A6C8685677E7A5D817C5F8C876A8F886C8781679D9B849A99849998839B9A859D9C87\
9B9A8596958191907C92917F9493818F8D7E9694859B998A8381727B796A959384
8B897C8785788482758785788E8C7F939184939182918F808E8D7B8D8C7A8D8C788C8B778B8A76\
8B8A768A89758A8A728C886B908D6E908D6E8B876A8B876C8D896E85816878735D
645F4B77725F878171888272868072878175878175827C70827C6E827C6E827C6E827C6E827C6E\
827C6E827C6E827C6E847E70847E70837D6F827C6E827C6E817B6D807A6C807A6C
807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C7F796B7E786A7E786A\
7D77697C76687C7668
BDCFE7BDCFE7BED0E8BED0E8BFD1E9C0D2EAC0D2EAC1D3EBC3D5EDC3D5EDC3D5EDC3D5EDC3D5ED\
C3D5EDC3D5EDC3D5EBC6D6EDC6D7EBC6D7EBC6D7EBC6D7EBC6D7EBC6D7EBC6D7EB
CCDDF1CCDDF1CDDEF2CEDFF3CEDFF3CFE0F4D0E1F5D1E0F3BFCCDDC8D4E4C9D5E5C0CCDABCC5D4\
BFC9D5C1C9D6BDC5D0C2C8D4C2C9D3C5C7D3C5C8D1C5C8D1C5C8CFC7C7CFC8C7CC
C3C1C23A3635878382B7B3B2C4C0BFBFBBB8C4C0BDC4C0BDC7C3C0C7C3C0C7C3C0C7C4BFC7C4BF\
C7C4BFC7C4BFC7C4BFC5C2BBC5C2BBC5C2BBC5C2BBC5C2BBC5C2BBC5C2BBC5C2BB
C5C2BBC5C2BBC5C2BBC5C2BBC5C2BBC5C2BBC5C2BBC5C2BBC5C2BBC5C2BBC4C1BAC3C0B9C3C0B9\
C2BFB8C1BEB7C1BEB7C1BEB7C1BEB7C0BDB6BFBCB5BFBCB5BEBBB4BDBAB3BDBAB5
BEBAB7BCB8B5BAB6B3B8B5B0B7B3B0B7B4AFB7B4ADB8B5AEBCB9B0BBB8AFBBB8AFBAB8ACB9B7AB\
B9B7ABB8B6AAB8B6AAADAB9FABA99DAFACA3B6B4A8B6B3AAAEACA0A6A39AA2A094
A5A299A4A296A3A097A2A094A09D949F9D919E9B929D9B8F9B998D9A988C99978B98968A969488\
959387949286939185918F83908E828F8D818E8C808C8A7E8B897D8A887C89867D
908D8677726E6A655F777368857F71817C697C7562807A6489846E76715B807E69726F5C868475\
696A5C74746A72706478706583796D746A5E7D76666F6A575C57417D7B628E8D71
848367908F719490738D896C8F8A6D989376989376908A708E8C7593927D93917C8D8C77908E79\
95947F908D7A83826E93907D92917F8E8B7A9493819996857F7E6C787564949381
918E7F8A88798784758785768D8A7B8F8D7E8D8A798887758E8B7A8C8B778D8A778B8A768B8875\
8A89758A87748A88738C886D918D70918D728C886D8C886F8E897385806A78735F
66614D797461888272888274857F71868074857F73807A6E827C6E807D6E827C6E807D6E827C6E\
807D6E827C6E807D6E847E70827F70837D6F807D6E827C6E7F7C6D807A6C807A6C
807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C7F796B7E786A7E786A\
7D77697C76687C7668
BDCFE7BDCFE7BED0E8BFD1E9BFD1E9C0D2EAC1D3EBC1D3EBC1D3EBC0D2EABFD1E9BFD1E9C0D2EA\
C1D3EBC3D5EDC5D5ECC3D2E9C3D2E7C3D2E7C3D2E7C3D2E7C3D2E7C3D2E7C3D2E7
C7D6EBC8D7ECCAD9EECCDBF0CEDDF2D0DFF4D2E1F6D5E1F7BDC8DCC6D1E3C9D4E6C2CEDEC1CADB\
C4CDDCC5CCDCC1C9D6C4CAD8C5CBD7C9CBD8C9CBD7C8CAD6C7CAD3C7C7D1C6C5CB
C1BFC2302C2D9C9899BEBABBBAB6B7C7C3C2C5C1BEC4C0BDC5C2BDC5C2BDC5C2BDC5C2BBC5C2BB\
C5C2BBC5C2BBC5C2BBC7C4BDC7C4BDC7C4BDC7C4BDC7C4BDC7C4BDC7C4BDC7C4BD
C7C4BDC7C4BDC7C4BDC7C4BDC7C4BDC7C4BDC7C4BDC7C4BDC5C2BBC5C2BBC4C1BAC3C0B9C3C0B9\
C2BFB8C1BEB7C1BEB7C3C0B9C3C0B9C2BFB8C1BEB7C1BEB7C0BDB6BFBCB5BFBCB5
BFBCB7BFBCB7BEBBB6BDBAB3BDBAB5BCB9B2BBB8B1BBB8B1B9B6AFB9B6AFB8B5AEB7B4ABB7B4AB\
B6B3AAB5B2A9B5B2A9B3B0A7B2AFA6B0ADA6AEABA2ACA9A2AAA79EA8A59EA7A49B
A7A49DA6A39AA4A19AA29F96A09D969E9B929C99929B988F9B998D9A988C99978B98968A969488\
959387949286939185918F83908E828F8D818E8C808C8A7E8B897D8A887C89877B
89857A7972686F695D756F617F796B7F79697D78657D78647E79657E79637D78647C77637A7863\
79776278766178766179746177705E77705E77725F726D596F6A567A755F8A856F
8A856F8B86708C87718D88728F8A74908B75918C76928D77928D798C8A7598937F8F8D78A29D89\
9C9A856A655167655087826E93907D95907D94917E99948185826F7C77648C8976
8A857283806D87826F8D8A77908B788986738C8774918E7B928D7A908E79918C788E8C77908B77\
8D8B768E89758E89758F8A778C87748A85728B86738C87748B8575878171827C6C
635D4D7771618781738A8476878173888274868072817B6D827F70817F70827F70817F70827F70\
817F70827F70817F70827F70817F70817E6F7F7D6E807D6E7E7C6D7E7B6C7E7B6C
807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C7E786A7E786A7D77697C76687C7668\
7B75677A74667A7466
BDCFE7BED0E8BED0E8BFD1E9C0D2EAC0D2EAC1D3EBC1D3EBC1D3EBC0D2EABFD1E9BFD1E9C0D2EA\
C2D4ECC4D6EEC6D6EDC3D2E9C5D1E7C5D1E7C5D1E7C5D1E7C5D1E7C5D1E7C5D1E7
C3CFE5C4D0E6C5D1E7C7D3E9CAD6ECCCD8EECDD9EFCEDAF0BDC8DCC7D2E6CAD5E7C3CEE0C1CADB\
C4CDDEC5CCDCC1C8D8C5CBD9C5CBD9C9CBD8C9CBD8C9CBD7C7C9D5C7C7D1C7C6CE
C2C0C5302B2F9D989CBFBABEBAB6B7C7C3C2C5C1C0C4C0BDC5C2BDC5C2BDC5C2BBC5C2BBC5C2B9\
C5C2B9C5C2B9C5C2B9C7C4BDC7C4BDC7C4BDC7C4BDC7C4BDC7C4BDC7C4BDC7C4BD
C7C4BDC7C4BDC7C4BDC7C4BDC7C4BDC7C4BDC7C4BDC7C4BDC5C2BBC5C2BBC4C1BAC4C1BAC3C0B9\
C2BFB8C2BFB8C1BEB7C3C0B9C3C0B9C2BFB8C1BEB7C1BEB7C0BDB6BFBCB5BFBCB5
BFBCB5BFBCB5BEBBB4BDBAB3BDBAB3BCB9B2BBB8B1BBB8B1B9B6AFB9B6AFB8B5AEB7B4ADB7B4AD\
B6B3ACB5B2ABB5B2ABB3B0A9B2AFA8B0ADA6AEABA4ACA9A2AAA7A0A8A59EA7A49D
A7A49DA6A39CA4A19AA29F98A09D969E9B949C99929B988F9B988F9A988C99978B98968A969488\
959387949286939185918F83908E828F8D818E8C808C8A7E8B897D8A887C89877A
8B85797973656F695B756F617F79697F79697D78657D78657E79657E79657D78627C77617C785F\
7B775E7A765B7A765D79745E76715D76715D77725E726D596F6A567A75618A8571
8A85718B86728C87738D88748F8A76908B77918C78928D79928D798B8672938E7A89847095907C\
8984704A4531413C28847F6B928D79938E7A948F7B96917D827D6975705C86816D
75705C75705C7D78648C8773928D798F8A768F8A76948F7B928D79928D79918C78908B77908B77\
8F8A768E89758E89768F89798C86788A84768B85778C86788B8577878173827C6E
625C4E7670628781738983758781738882748680727F7C6D827F70817F70817F70817F70817F70\
817F70817F70817F70817F70817F70807E6F7F7D6E7F7D6E7E7C6D7D7B6C7D7B6C
807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C7E786A7E786A7D77697C76687C7668\
7B75677A74667A7466
BED0E8BED0E8BFD1E9BFD1E9C0D2EAC1D3EBC1D3EBC2D4ECC2D4ECC1D3EBC0D2EAC0D2EAC1D3EB\
C2D4ECC4D6EEC6D6EDC4D3EAC6D2E8C6D2E8C6D2E8C6D2E8C6D2E8C6D2E8C6D2E8
C1CDE3C2CEE4C4D0E6C6D2E8C8D4EACAD6ECCCD8EECDD9EFBEC9DDC7D2E6CAD5E7C3CEE0C1CADB\
C5CEDFC6CDDDC2C9D9C5CBD9C6CCDACACCD9CACCD9C9CBD7C7C9D5C8C8D2C7C6CE
C2C0C5302B2F9D989CBFBABEBBB7B8C8C4C3C6C2C1C5C1BEC6C3BEC6C3BEC6C3BCC6C3BCC6C3BA\
C6C3BAC6C3BAC6C3BAC8C5BEC8C5BEC8C5BEC8C5BEC8C5BEC8C5BEC8C5BEC8C5BE
C8C5BEC8C5BEC8C5BEC8C5BEC8C5BEC8C5BEC8C5BEC8C5BEC6C3BCC5C2BBC5C2BBC4C1BAC3C0B9\
C3C0B9C2BFB8C2BFB8C3C0B9C3C0B9C2BFB8C1BEB7C1BEB7C0BDB6BFBCB5BFBCB5
BFBCB5BFBCB5BEBBB4BDBAB3BDBAB3BCB9B2BBB8B1BBB8B1B9B6AFB9B6AFB8B5AEB7B4ADB7B4AD\
B6B3ACB5B2ABB5B2ABB3B0A9B2AFA8B0ADA6AEABA4ACA9A2AAA7A0A8A59EA7A49D
A7A49DA6A39CA4A19AA29F98A09D969E9B949C99929B988F9B988F9A988C99978B98968A969488\
959387949286939185918F83908E828F8D818E8C808C8A7E8B897D8A887C89877A
8B85797973656F695B756F617F79697F79697D78657D78657E79657E79657D78627C77617C785F\
7B775E7A765B7A765D79745E76715D76715D77725E726D596F6A567A75618A8571
8A85718B86728C87738D88748F8A76908B77918C78928D799B9682938E7A9994808F8A769A9581\
86816D3B3622292410847F6B938E7A95907C96917D98937F837E6A746F5B847F6B
726D59736E5A7F7A66908B7797927E928D79908B77938E7A928D79928D79918C78908B77908B77\
8F8A768E89758E89768F89798C86788A84768B85778C86788B8577878173827C6E
605A4C756F618680728882748781738882748680727F7C6D827F70817F70817F70817F70817F70\
817F70817F70817F70817F70817F70807E6F7F7D6E7F7D6E7E7C6D7D7B6C7D7B6C
807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C7E786A7E786A7D77697C76687C7668\
7B75677A74667A7466
BFD1E9BFD1E9C0D2EAC0D2EAC1D3EBC2D4ECC2D4ECC3D5EDC2D4ECC2D4ECC1D3EBC1D3EBC1D3EB\
C3D5EDC5D7EFC7D7EEC5D4EBC7D3E9C7D3E9C7D3E9C7D3E9C7D3E9C7D3E9C7D3E9
C8D4EAC9D5EBCAD6ECCCD8EECFDBF1D1DDF3D2DEF4D3DFF5BFCADEC8D3E7CBD6E8C4CFE1C2CBDC\
C5CEDFC7CEDEC2C9D9C6CCDAC7CDDBCACCD9CBCDDACACCD8C8CAD6C8C8D2C8C7CF
C3C1C6312C309E999DC0BBBFBCB8B9C9C5C4C7C3C2C6C2BFC7C4BFC7C4BFC7C4BDC7C4BDC7C4BB\
C7C4BBC7C4BBC7C4BBC9C6BFC9C6BFC9C6BFC9C6BFC9C6BFC9C6BFC9C6BFC9C6BF
C9C6BFC9C6BFC9C6BFC9C6BFC9C6BFC9C6BFC9C6BFC9C6BFC7C4BDC6C3BCC6C3BCC5C2BBC4C1BA\
C4C1BAC3C0B9C3C0B9C3C0B9C3C0B9C2BFB8C1BEB7C1BEB7C0BDB6BFBCB5BFBCB5
BFBCB5BFBCB5BEBBB4BDBAB3BDBAB3BCB9B2BBB8B1BBB8B1B9B6AFB9B6AFB8B5AEB7B4ADB7B4AD\
B6B3ACB5B2ABB5B2ABB3B0A9B2AFA8B0ADA6AEABA4ACA9A2AAA7A0A8A59EA7A49D
A7A49DA6A39CA4A19AA29F98A09D969E9B949C99929B988F9B988F9A988C99978B98968A969488\
959387949286939185918F83908E828F8D818E8C808C8A7E8B897D8A887C89877A
8B85797973656F695B756F617F79697F79697D78657D78657E79657E79657D78627C77617C785F\
7B775E7A765B7A765D79745E76715D76715D77725E726D596F6A567A75618A8571
8A85718B86728C87738D88748F8A76908B77918C78928D799D988495907C9E998596917DA39E8A\
8D88743E392528230F85806C95907C98937F9C97839F9A868A85717C77638C8773
89847087826E8C877397927E9A9581938E7A908B77948F7B928D79928D79918C78908B77908B77\
8F8A768E89758E89768F89798C86788A84768B85778C86788B8577878173827C6E
5E584A736D5F847E708781738680728882748680727F7C6D827F70817F70817F70817F70817F70\
817F70817F70817F70817F70817F70807E6F7F7D6E7F7D6E7E7C6D7D7B6C7D7B6C
807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C7E786A7E786A7D77697C76687C7668\
7B75677A74667A7466
BFD1E9C0D2EAC0D2EAC1D3EBC2D4ECC2D4ECC3D5EDC3D5EDC3D5EDC2D4ECC2D4ECC1D3EBC2D4EC\
C4D6EEC6D8F0C8D8EFC5D4EBC7D3E9C7D3E9C7D3E9C7D3E9C7D3E9C7D3E9C7D3E9
CBD7EDCCD8EECEDAF0D0DCF2D2DEF4D4E0F6D6E2F8D7E3F9BFCADEC9D4E8CCD7E9C5D0E2C3CCDD\
C6CFE0C8CFDFC3CADAC7CDDBC7CDDBCBCDDACBCDDACBCDD9C9CBD7C9C9D3C9C8D0
C4C2C7322D319F9A9EC1BCC0BCB8B9C9C5C4C7C3C2C7C3C0C7C4BFC7C4BFC7C4BDC7C4BDC7C4BB\
C7C4BBC7C4BBC7C4BBC9C6BFC9C6BFC9C6BFC9C6BFC9C6BFC9C6BFC9C6BFC9C6BF
C9C6BFC9C6BFC9C6BFC9C6BFC9C6BFC9C6BFC9C6BFC9C6BFC7C4BDC7C4BDC6C3BCC6C3BCC5C2BB\
C4C1BAC4C1BAC3C0B9C3C0B9C3C0B9C2BFB8C1BEB7C1BEB7C0BDB6BFBCB5BFBCB5
BFBCB5BFBCB5BEBBB4BDBAB3BDBAB3BCB9B2BBB8B1BBB8B1B9B6AFB9B6AFB8B5AEB7B4ADB7B4AD\
B6B3ACB5B2ABB5B2ABB3B0A9B2AFA8B0ADA6AEABA4ACA9A2AAA7A0A8A59EA7A49D
A7A49DA6A39CA4A19AA29F98A09D969E9B949C99929B988F9B988F9A988C99978B98968A969488\
959387949286939185918F83908E828F8D818E8C808C8A7E8B897D8A887C89877A
8B85797973656F695B756F617F79697F79697D78657D78657E79657E79657D78627C77617C785F\
7B775E7A765B7A765D79745E76715D76715D77725E726D596F6A567A75618A8571
8A85718B86728C87738D88748F8A76908B77918C78928D79948F7B8E897597927E8F8A769C9783\
88836F3E39252C2713827D69928D7996917D9A9581A09B878D8874817C68938E7A
9B9682948F7B928D7996917D96917D908B77918C7898937F928D79928D79918C78908B77908B77\
8F8A768E89758E89768F89798C86788A84768B85778C86788B8577878173827C6E
5D5749716B5D837D6F868072868072888274878173807D6E827F70817F70817F70817F70817F70\
817F70817F70817F70817F70817F70807E6F7F7D6E7F7D6E7E7C6D7D7B6C7D7B6C
807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C7E786A7E786A7D77697C76687C7668\
7B75677A74667A7466
C0D2EAC1D3EBC1D3EBC2D4ECC3D5EDC3D5EDC4D6EEC4D6EEC4D6EEC3D5EDC2D4ECC2D4ECC3D5ED\
C5D7EFC6D8F0C9D9F0C6D5ECC8D4EAC8D4EAC8D4EAC8D4EAC8D4EAC8D4EAC8D4EA
C9D5EBC9D5EBCBD7EDCDD9EFCFDBF1D2DEF4D3DFF5D4E0F6C0CBDFCAD5E9CDD8EAC6D1E3C4CDDE\
C7D0E1C8CFDFC4CBDBC7CDDBC8CEDCCCCEDBCCCEDBCBCDD9CACCD8CACAD4CAC9D1
C5C3C8332E32A09B9FC2BDC1BDB9BACAC6C5C8C4C3C7C3C0C8C5C0C8C5C0C8C5BEC8C5BEC8C5BC\
C8C5BCC8C5BCC8C5BCCAC7C0CAC7C0CAC7C0CAC7C0CAC7C0CAC7C0CAC7C0CAC7C0
CAC7C0CAC7C0CAC7C0CAC7C0CAC7C0CAC7C0CAC7C0CAC7C0C8C5BEC8C5BEC7C4BDC7C4BDC6C3BC\
C5C2BBC5C2BBC4C1BAC3C0B9C3C0B9C2BFB8C1BEB7C1BEB7C0BDB6BFBCB5BFBCB5
BFBCB5BFBCB5BEBBB4BDBAB3BDBAB3BCB9B2BBB8B1BBB8B1B9B6AFB9B6AFB8B5AEB7B4ADB7B4AD\
B6B3ACB5B2ABB5B2ABB3B0A9B2AFA8B0ADA6AEABA4ACA9A2AAA7A0A8A59EA7A49D
A7A49DA6A39CA4A19AA29F98A09D969E9B949C99929B988F9B988F9A988C99978B98968A969488\
959387949286939185918F83908E828F8D818E8C808C8A7E8B897D8A887C89877A
8B85797973656F695B756F617F79697F79697D78657D78657E79657E79657D78627C77617C785F\
7B775E7A765B7A765D79745E76715D76715D77725E726D596F6A567A75618A8571
8A85718B86728C87738D88748F8A76908B77918C78928D7996917D918C789994808E897598937F\
8B86724D483447422E827D69908B77918C78938E7A99948088836F7F7A66928D79
97927E8F8A768B86728F8A76908B778E8975928D799C9783928D79928D79918C78908B77908B77\
8F8A768E89758E89768F89798C86788A84768B85778C86788B8577878173827C6E
5B55476F695B827C6E857F71857F71878173878173807D6E827F70817F70817F70817F70817F70\
817F70817F70817F70817F70817F70807E6F7F7D6E7F7D6E7E7C6D7D7B6C7D7B6C
807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C7E786A7E786A7D77697C76687C7668\
7B75677A74667A7466
C1D3EBC1D3EBC2D4ECC2D4ECC3D5EDC4D6EEC4D6EEC5D7EFC4D6EEC4D6EEC3D5EDC3D5EDC3D5ED\
C5D7EFC7D9F1C9D9F0C7D6EDC9D5EBC9D5EBC9D5EBC9D5EBC9D5EBC9D5EBC9D5EB
C7D3E9C8D4EACAD6ECCCD8EECEDAF0D0DCF2D2DEF4D3DFF5C1CCE0CAD5E9CDD8EAC6D1E3C4CDDE\
C8D1E2C9D0E0C5CCDCC8CEDCC9CFDDCDCFDCCDCFDCCCCEDACACCD8CACAD4CAC9D1
C5C3C8332E32A09B9FC2BDC1BEBABBCBC7C6C9C5C4C8C4C1C9C6C1C9C6C1C9C6BFC9C6BFC9C6BD\
C9C6BDC9C6BDC9C6BDCBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1
CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1C9C6BFC8C5BEC8C5BEC7C4BDC6C3BC\
C6C3BCC5C2BBC5C2BBC3C0B9C3C0B9C2BFB8C1BEB7C1BEB7C0BDB6BFBCB5BFBCB5
BFBCB5BFBCB5BEBBB4BDBAB3BDBAB3BCB9B2BBB8B1BBB8B1B9B6AFB9B6AFB8B5AEB7B4ADB7B4AD\
B6B3ACB5B2ABB5B2ABB3B0A9B2AFA8B0ADA6AEABA4ACA9A2AAA7A0A8A59EA7A49D
A7A49DA6A39CA4A19AA29F98A09D969E9B949C99929B988F9B988F9A988C99978B98968A969488\
959387949286939185918F83908E828F8D818E8C808C8A7E8B897D8A887C89877A
8B85797973656F695B756F617F79697F79697D78657D78657E79657E79657D78627C77617C785F\
7B775E7A765B7A765D79745E76715D76715D77725E726D596F6A567A75618A8571
8A85718B86728C87738D88748F8A76908B77918C78928D7995907C948F7B9E9985918C789D9884\
9B9682706B5778735F8C877397927E938E7A918C78948F7B847F6B7C7763918C78
908B778984708984708F8A76918C788D8874908B7798937F928D79928D79918C78908B77908B77\
8F8A768E89758E89768F89798C86788A84768B85778C86788B8577878173827C6E
5953456E685A817B6D857F71857F71878173878173807D6E827F70817F70817F70817F70817F70\
817F70817F70817F70817F70817F70807E6F7F7D6E7F7D6E7E7C6D7D7B6C7D7B6C
807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C7E786A7E786A7D77697C76687C7668\
7B75677A74667A7466
C1D3EBC1D3EBC2D4ECC3D5EDC3D5EDC4D6EEC5D7EFC5D7EFC5D7EFC4D6EEC3D5EDC3D5EDC4D6EE\
C5D7EFC7D9F1CADAF1C7D6EDC9D5EBC9D5EBC9D5EBC9D5EBC9D5EBC9D5EBC9D5EB
CAD6ECCAD6ECCCD8EECEDAF0D0DCF2D3DFF5D4E0F6D5E1F7C1CCE0CBD6EACED9EBC7D2E4C5CEDF\
C8D1E2C9D0E0C5CCDCC8CEDCC9CFDDCDCFDCCDCFDCCCCEDACBCDD9CBCBD5CBCAD2
C6C4C9342F33A09B9FC2BDC1BEBABBCBC7C6C9C5C4C8C4C1C9C6C1C9C6C1C9C6BFC9C6BFC9C6BD\
C9C6BDC9C6BDC9C6BDCBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1
CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1C9C6BFC9C6BFC8C5BEC7C4BDC7C4BD\
C6C3BCC5C2BBC5C2BBC3C0B9C3C0B9C2BFB8C1BEB7C1BEB7C0BDB6BFBCB5BFBCB5
BFBCB5BFBCB5BEBBB4BDBAB3BDBAB3BCB9B2BBB8B1BBB8B1B9B6AFB9B6AFB8B5AEB7B4ADB7B4AD\
B6B3ACB5B2ABB5B2ABB3B0A9B2AFA8B0ADA6AEABA4ACA9A2AAA7A0A8A59EA7A49D
A7A49DA6A39CA4A19AA29F98A09D969E9B949C99929B988F9B988F9A988C99978B98968A969488\
959387949286939185918F83908E828F8D818E8C808C8A7E8B897D8A887C89877A
8B85797973656F695B756F617F79697F79697D78657D78657E79657E79657D78627C77617C785F\
7B775E7A765B7A765D79745E76715D76715D77725E726D596F6A567A75618A8571
8A85718B86728C87738D88748F8A76908B77918C78928D7988836F89847097927E8D88749C9783\
A49F8B8984709C9783999480A29D899A958195907C96917D847F6B7D7864928D79
918C788C87738E897596917D96917D8E89758C8773908B77928D79928D79918C78908B77908B77\
8F8A768E89758E89768F89798C86788A84768B85778C86788B8577878173827C6E
5953456D6759807A6C847E70847E70878173878173807D6E827F70817F70817F70817F70817F70\
817F70817F70817F70817F70817F70807E6F7F7D6E7F7D6E7E7C6D7D7B6C7D7B6C
807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C7E786A7E786A7D77697C76687C7668\
7B75677A74667A7466
C1D3EBC1D3EBC1D3EBC1D3EBC1D3EBC1D3EBC1D3EBC1D3EBC5D7EFC5D7EFC5D7EFC5D7EFC5D7EF\
C5D7EFC5D7EFC6D6EDC7D6EDC9D5EBC9D5EBC9D5EBC9D5EBC9D5EBC9D5EBC9D5EB
CBD7EDCBD7EDCBD7EDCBD7EDCBD7EDCBD7EDCBD7EDCBD7EDBBC6DAC3CEE2C7D2E4C4CFE1C7D0E1\
CCD5E6CBD2E2C4CBDBC4CAD8C5CBD9CACCD9CBCDDACBCDD9CACCD8CACAD4CAC9D1
BEBCC1302B2FA19CA0C3BEC2BCB8B9C8C4C3C7C3C2C9C5C2C7C4BFC7C4BFC8C5BEC9C6BFC9C6BD\
CAC7BECBC8BFCBC8BFCBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1
CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1C9C6BFC9C6BFC8C5BEC7C4BDC7C4BD\
C6C3BCC5C2BBC5C2BBC5C2BBC5C2BBC4C1BAC3C0B9C3C0B9C2BFB8C1BEB7C1BEB7
BFBCB5BFBCB5BEBBB4BDBAB3BDBAB3BCB9B2BBB8B1BBB8B1B9B6AFB9B6AFB8B5AEB7B4ADB7B4AD\
B6B3ACB5B2ABB5B2ABB1AEA7B0ADA6AEABA4ACA9A2AAA7A0A8A59EA6A39CA5A29B
A5A29BA4A19AA3A099A29F98A09D969F9C959E9B949D9A9199968D98968A979589969488949286\
939185929084918F83918F83908E828F8D818E8C808C8A7E8B897D8A887C89877A
8C867A7A74666D6759726C5E7B75657C76667A75627B76637C77637C77637B76607A755F7A765D\
79755C78745978745B79745E736E5A716C58736E5A726D59706B5778735F86816D
88836F8984708A85718B86728D88748E89758F8A76908B77918C78928D79948F7B95907C96917D\
96917D95907C948F7B97927E918C789A95818F8A7697927E948F7B76715D908B77
8F8A768C87738A85718C8773908B77928D79908B778E8975908B77908B778F8A768E89758E8975\
8D88748C87738C87748C86768C86788B85778A84768A8476898375888274888274
5D57496B65577E786A888274878173847E70837D6F838071807D6E7F7D6E7F7D6E7F7D6E7F7D6E\
7F7D6E7F7D6E7F7D6E7F7D6E7F7D6E7E7C6D7D7B6C7D7B6C7C7A6B7B796A7B796A
7E786A7E786A7E786A7E786A7E786A7E786A7E786A7E786A7C76687C76687B75677A74667A7466\
797365787264787264
C2D4ECC2D4ECC2D4ECC2D4ECC2D4ECC2D4ECC2D4ECC2D4ECC7D9F1C7D9F1C7D9F1C7D9F1C7D9F1\
C7D9F1C7D9F1C8D8EFC8D7EECAD6ECCAD6ECCAD6ECCAD6ECCAD6ECCAD6ECCAD6EC
CCD8EECCD8EECCD8EECCD8EECCD8EECCD8EECCD8EECCD8EEBBC6DAC3CEE2C6D1E3C2CDDFC5CEDF\
CBD4E5CAD1E1C3CADAC4CAD8C5CBD9CACCD9CBCDDACBCDD9CACCD8CACAD4CAC9D1
BEBCC1302B2FA19CA0C3BEC2BCB8B9C8C4C3C7C3C2C9C5C2C7C4BFC7C4BFC8C5BEC9C6BFC9C6BD\
CAC7BECBC8BFCBC8BFCBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1
CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1C9C6BFC9C6BFC8C5BEC7C4BDC7C4BD\
C6C3BCC5C2BBC5C2BBC5C2BBC5C2BBC4C1BAC3C0B9C3C0B9C2BFB8C1BEB7C1BEB7
BFBCB5BFBCB5BEBBB4BDBAB3BDBAB3BCB9B2BBB8B1BBB8B1B9B6AFB9B6AFB8B5AEB7B4ADB7B4AD\
B6B3ACB5B2ABB5B2ABB1AEA7B0ADA6AEABA4ACA9A2AAA7A0A8A59EA6A39CA5A29B
A5A29BA4A19AA3A099A29F98A09D969F9C959E9B949D9A9199968D98968A979589969488949286\
939185929084918F83918F83908E828F8D818E8C808C8A7E8B897D8A887C89877A
8C867A7A74666D6759726C5E7B75657C76667A75627B76637C77637B76627B76607A755F79755C\
79755C78745978745B79745E736E5A716C58736E5A726D59706B5778735F86816D
88836F8984708A85718B86728D88748E89758F8A76908B77908B77918C78938E7A95907C96917D\
96917D95907C948F7B97927E908B779994808E897597927E938E7A76715D8F8A76
8E89758C87738A85718C8773908B77928D79908B778D8874908B778F8A768F8A768E89758D8874\
8D88748C87738C87748C86768B85778B85778A8476898375898375888274888274
5D57496B65577E786A888274878173847E70837D6F838071807D6E7F7D6E7F7D6E7F7D6E7F7D6E\
7F7D6E7F7D6E7F7D6E7F7D6E7F7D6E7E7C6D7D7B6C7D7B6C7C7A6B7B796A7B796A
7E786A7E786A7E786A7E786A7E786A7E786A7E786A7E786A7C76687C76687B75677A74667A7466\
797365787264787264
C4D6EEC4D6EEC4D6EEC4D6EEC4D6EEC4D6EEC4D6EEC4D6EEC9DBF3C9DBF3C9DBF3C9DBF3C9DBF3\
C9DBF3C9DBF3CADAF1CAD9F0CCD8EECCD8EECCD8EECCD8EECCD8EECCD8EECCD8EE
CEDAF0CEDAF0CEDAF0CEDAF0CEDAF0CEDAF0CEDAF0CEDAF0BBC6DAC3CEE2C5D0E2C0CBDDC3CCDD\
C9D2E3C9D0E0C2C9D9C4CAD8C5CBD9CACCD9CBCDDACBCDD9CACCD8CACAD4CAC9D1
BEBCC1302B2FA19CA0C3BEC2BCB8B9C8C4C3C7C3C2C9C5C2C7C4BFC7C4BFC8C5BEC9C6BFC9C6BD\
CAC7BECBC8BFCBC8BFCBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1
CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1C9C6BFC9C6BFC8C5BEC7C4BDC7C4BD\
C6C3BCC5C2BBC5C2BBC5C2BBC5C2BBC4C1BAC3C0B9C3C0B9C2BFB8C1BEB7C1BEB7
BFBCB5BFBCB5BEBBB4BDBAB3BDBAB3BCB9B2BBB8B1BBB8B1B9B6AFB9B6AFB8B5AEB7B4ADB7B4AD\
B6B3ACB5B2ABB5B2ABB1AEA7B0ADA6AEABA4ACA9A2AAA7A0A8A59EA6A39CA5A29B
A4A19AA3A099A29F98A19E979F9C959E9B949D9A939C999098958C979589969488959387939185\
929084918F83908E82908E828F8D818E8C808D8B7F8B897D8A887C89877B888679
8C867A7A74666D6759726C5E7B75657C76667A75627B76637B76627B76627A755F7A755F79755C\
78745B78745977735A79745E736E5A716C58736E5A726D59706B5778735F86816D
87826E88836F8984708A85718C87738D88748E89758F8A76908B77918C78938E7A948F7B95907C\
95907C948F7B938E7A96917D908B779994808E897596917D938E7A75705C8F8A76
8E89758B86728984708B86728F8A76918C788F8A768D88748F8A768F8A768E89758E89758D8874\
8C87738C87738B86738B85758B85778A84768A8476898375888274888274878173
5D57496B65577E786A888274878173847E70837D6F838071807D6E7F7D6E7F7D6E7F7D6E7F7D6E\
7F7D6E7F7D6E7F7D6E7F7D6E7F7D6E7E7C6D7D7B6C7D7B6C7C7A6B7B796A7B796A
7E786A7E786A7E786A7E786A7E786A7E786A7E786A7E786A7C76687C76687B75677A74667A7466\
797365787264787264
C5D7EFC5D7EFC5D7EFC5D7EFC5D7EFC5D7EFC5D7EFC5D7EFC8DAF2C8DAF2C8DAF2C8DAF2C8DAF2\
C8DAF2C8DAF2C9D9F0CBDAF1CDD9EFCDD9EFCDD9EFCDD9EFCDD9EFCDD9EFCDD9EF
CFDBF1CFDBF1CFDBF1CFDBF1CFDBF1CFDBF1CFDBF1CFDBF1BDC8DCC4CFE3C4CFE1BFCADCC1CADB\
C7D0E1C8CFDFC1C8D8C4CAD8C5CBD9CACCD9CBCDDACBCDD9CACCD8CACAD4CAC9D1
BEBCC1302B2FA19CA0C3BEC2BCB8B9C8C4C3C7C3C2C9C5C2C7C4BFC7C4BFC8C5BEC9C6BFC9C6BD\
CAC7BECBC8BFCBC8BFCBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1
CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1C9C6BFC9C6BFC8C5BEC7C4BDC7C4BD\
C6C3BCC5C2BBC5C2BBC5C2BBC5C2BBC4C1BAC3C0B9C3C0B9C2BFB8C1BEB7C1BEB7
BFBCB5BFBCB5BEBBB4BDBAB3BDBAB3BCB9B2BBB8B1BBB8B1B9B6AFB9B6AFB8B5AEB7B4ADB7B4AD\
B6B3ACB5B2ABB5B2ABB1AEA7B0ADA6AEABA4ACA9A2AAA7A0A8A59EA6A39CA5A29B
A3A099A3A099A29F98A09D969F9C959D9A939C99929C999097948B979589969488949286939185\
918F83908E82908E828F8D818F8D818E8C808C8A7E8B897D89877B88867A888679
8C867A7A74666D6759726C5E7B75657C76667A75627B76637A75617A756179745E79745E78745B\
77735A77735876725979745E736E5A716C58736E5A726D59706B5778735F86816D
87826E87826E88836F8A85718B86728D88748E89758E89758F8A76908B77928D79948F7B948F7B\
948F7B938E7A938E7A95907C8F8A7698937F8D887496917D928D79746F5B8E8975
8D88748A85718984708A85718E8975908B778F8A768C87738E89758E89758D88748D88748C8773\
8B86728B86728A85728A84748A8476898375898375888274878173878173868072
5D57496B65577E786A888274878173847E70837D6F838071807D6E7F7D6E7F7D6E7F7D6E7F7D6E\
7F7D6E7F7D6E7F7D6E7F7D6E7F7D6E7E7C6D7D7B6C7D7B6C7C7A6B7B796A7B796A
7E786A7E786A7E786A7E786A7E786A7E786A7E786A7E786A7C76687C76687B75677A74667A7466\
797365787264787264
C5D7EFC5D7EFC5D7EFC5D7EFC5D7EFC5D7EFC5D7EFC5D7EFC6D8F0C6D8F0C6D8F0C6D8F0C6D8F0\
C6D8F0C6D8F0C7D7EECBDAF1CDD9EFCDD9EFCDD9EFCDD9EFCDD9EFCDD9EFCDD9EF
CFDBF1CFDBF1CFDBF1CFDBF1CFDBF1CFDBF1CFDBF1CFDBF1C0CBDFC6D1E5C5D0E2BFCADCC0C9DA\
C7D0E1C8CFDFC2C9D9C4CAD8C5CBD9CACCD9CBCDDACBCDD9CACCD8CACAD4CAC9D1
BEBCC1302B2FA19CA0C3BEC2BCB8B9C8C4C3C7C3C2C9C5C2C7C4BFC7C4BFC8C5BEC9C6BFC9C6BD\
CAC7BECBC8BFCBC8BFCBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1
CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1C9C6BFC9C6BFC8C5BEC7C4BDC7C4BD\
C6C3BCC5C2BBC5C2BBC5C2BBC5C2BBC4C1BAC3C0B9C3C0B9C2BFB8C1BEB7C1BEB7
BFBCB5BFBCB5BEBBB4BDBAB3BDBAB3BCB9B2BBB8B1BBB8B1B9B6AFB9B6AFB8B5AEB7B4ADB7B4AD\
B6B3ACB5B2ABB5B2ABB1AEA7B0ADA6AEABA4ACA9A2AAA7A0A8A59EA6A39CA5A29B
A29F98A29F98A19E979F9C959E9B949C99929B98919B988F96938A969488959387939185929084\
908E828F8D818F8D818E8C808E8C808D8B7F8B897D8A887C88867A878579878578
8C867A7A74666D6759726C5E7B75657C76667A75627B76637A756179746079745E78735D77735A\
77735A76725776725979745E736E5A716C58736E5A726D59706B5778735F86816D
86816D86816D87826E8984708A85718C87738D88748D88748E89758F8A76918C78938E7A948F7B\
938E7A938E7A928D79948F7B8E897597927E8C877395907C918C78746F5B8D8874
8C877389847088836F8A85718E89758F8A768E89758B86728E89758D88748D88748C87738B8672\
8B86728A85718A85728A8474898375898375888274878173878173868072868072
5D57496B65577E786A888274878173847E70837D6F838071807D6E7F7D6E7F7D6E7F7D6E7F7D6E\
7F7D6E7F7D6E7F7D6E7F7D6E7F7D6E7E7C6D7D7B6C7D7B6C7C7A6B7B796A7B796A
7E786A7E786A7E786A7E786A7E786A7E786A7E786A7E786A7C76687C76687B75677A74667A7466\
797365787264787264
C4D6EEC4D6EEC4D6EEC4D6EEC4D6EEC4D6EEC4D6EEC4D6EEC5D7EFC5D7EFC5D7EFC5D7EFC5D7EF\
C5D7EFC5D7EFC6D6EDCAD9F0CCD8EECCD8EECCD8EECCD8EECCD8EECCD8EECCD8EE
CEDAF0CEDAF0CEDAF0CEDAF0CEDAF0CEDAF0CEDAF0CEDAF0C5D0E4C9D4E8C7D2E4C0CBDDC1CADB\
C8D1E2CAD1E1C4CBDBC4CAD8C5CBD9CACCD9CBCDDACBCDD9CACCD8CACAD4CAC9D1
BEBCC1302B2FA19CA0C3BEC2BCB8B9C8C4C3C7C3C2C9C5C2C7C4BFC7C4BFC8C5BEC9C6BFC9C6BD\
CAC7BECBC8BFCBC8BFCBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1
CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1C9C6BFC9C6BFC8C5BEC7C4BDC7C4BD\
C6C3BCC5C2BBC5C2BBC5C2BBC5C2BBC4C1BAC3C0B9C3C0B9C2BFB8C1BEB7C1BEB7
BFBCB5BFBCB5BEBBB4BDBAB3BDBAB3BCB9B2BBB8B1BBB8B1B9B6AFB9B6AFB8B5AEB7B4ADB7B4AD\
B6B3ACB5B2ABB5B2ABB1AEA7B0ADA6AEABA4ACA9A2AAA7A0A8A59EA6A39CA5A29B
A29F98A19E97A09D969F9C959D9A939C99929B98919A978E96938A959387949286939185918F83\
908E828F8D818E8C808E8C808D8B7F8C8A7E8B897D89877B88867A878579868477
8C867A7A74666D6759726C5E7B75657C76667A75627B766379746078735F78735D77725C767259\
76725975715675715879745E736E5A716C58736E5A726D59706B5778735F86816D
85806C86816D87826E88836F8A85718B86728C87738D88748D88748F8A76908B77928D79938E7A\
938E7A928D79918C78948F7B8E897596917D8B8672948F7B918C78736E5A8C8773
8B867289847087826E8984708D88748F8A768D88748A85718D88748C87738C87738B86728A8571\
8A8571898470898471898373888274888274878173868072868072857F71857F71
5D57496B65577E786A888274878173847E70837D6F838071807D6E7F7D6E7F7D6E7F7D6E7F7D6E\
7F7D6E7F7D6E7F7D6E7F7D6E7F7D6E7E7C6D7D7B6C7D7B6C7C7A6B7B796A7B796A
7E786A7E786A7E786A7E786A7E786A7E786A7E786A7E786A7C76687C76687B75677A74667A7466\
797365787264787264
C2D4ECC2D4ECC2D4ECC2D4ECC2D4ECC2D4ECC2D4ECC2D4ECC7D9F1C7D9F1C7D9F1C7D9F1C7D9F1\
C7D9F1C7D9F1C8D8EFC8D7EECAD6ECCAD6ECCAD6ECCAD6ECCAD6ECCAD6ECCAD6EC
CCD8EECCD8EECCD8EECCD8EECCD8EECCD8EECCD8EECCD8EEC9D4E8CDD8ECCAD5E7C2CDDFC3CCDD\
C9D2E3CCD3E3C7CEDEC4CAD8C5CBD9CACCD9CBCDDACBCDD9CACCD8CACAD4CAC9D1
BEBCC1302B2FA19CA0C3BEC2BCB8B9C8C4C3C7C3C2C9C5C2C7C4BFC7C4BFC8C5BEC9C6BFC9C6BD\
CAC7BECBC8BFCBC8BFCBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1
CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1CBC8C1C9C6BFC9C6BFC8C5BEC7C4BDC7C4BD\
C6C3BCC5C2BBC5C2BBC5C2BBC5C2BBC4C1BAC3C0B9C3C0B9C2BFB8C1BEB7C1BEB7
BFBCB5BFBCB5BEBBB4BDBAB3BDBAB3BCB9B2BBB8B1BBB8B1B9B6AFB9B6AFB8B5AEB7B4ADB7B4AD\
B6B3ACB5B2ABB5B2ABB1AEA7B0ADA6AEABA4ACA9A2AAA7A0A8A59EA6A39CA5A29B
A19E97A09D969F9C959E9B949C99929B98919A979099968D959289949286939185929084908E82\
8F8D818E8C808D8B7F8D8B7F8C8A7E8B897D8A887C88867A878579868478858376
8C867A7A74666D6759726C5E7B75657C76667A75627B766378735F78735F77725C77725C767259\
75715875715674705779745E736E5A716C58736E5A726D59706B5778735F86816D
847F6B85806C86816D87826E8984708A85718B86728C87738D88748E8975908B77928D79928D79\
928D79918C78918C78938E7A8D887496917D8B8672938E7A908B77726D598C8773
8B867288836F86816D88836F8C87738E89758C87738A85718C87738C87738B86728B86728A8571\
898470898470888370888272888274878173878173868072857F71857F71847E70
5D57496B65577E786A888274878173847E70837D6F838071807D6E7F7D6E7F7D6E7F7D6E7F7D6E\
7F7D6E7F7D6E7F7D6E7F7D6E7F7D6E7E7C6D7D7B6C7D7B6C7C7A6B7B796A7B796A
7E786A7E786A7E786A7E786A7E786A7E786A7E786A7E786A7C76687C76687B75677A74667A7466\
797365787264787264
C5D2E5C5D2E5C5D2E5C5D2E5C5D2E5C5D2E5C5D2E5C5D2E5CDDAEDCDDAEDCDDAEDCDDAEDCDDAED\
CDDAEDCDDAEDCED9EDCCD4E7CCD5E6CCD4E7CCD5E6CCD4E7CCD5E6CCD4E7CCD5E6
CED6E9CED7E8CED6E9CED7E8CED6E9CED7E8CED6E9CCD7E9CAD7EACEDBEECBD8EBC2CFE0C2CDDF\
C8D4E4CCD5E6C8D1E0C3CADAC4CCD9C7CDDBCACEDACACEDAC9CDD8C8CAD6C9C9D1
BEBCC1302B2FA19CA0C3BEC2BCB7BBC8C4C5C7C3C2C9C5C2C7C3C0C7C4BFC8C5C0C9C6BFC9C6BF\
CAC7BECBC8BFCBC8C1CBC8C1CBC8C3CBC8C3CBC8C3CBC8C3CBC8C3CBC8C3CBC8C3
CBC8C3CBC8C3CBC8C3CBC8C3CBC8C3CBC8C3CBC8C3CBC8C3C9C6C1C9C6C1C9C4C0C7C4BFC8C3BF\
C6C3BEC6C1BDC5C2BDC6C1BDC5C2BDC5C0BCC3C0BBC4BFBBC2BFBAC2BDB9C1BEB9
BFBCB5BFBCB5BEBBB4BDBAB3BDBAB3BCB9B2BBB8B1BBB8B1B9B6AFB9B6AFB8B5AEB7B4ADB7B4AD\
B6B3ACB5B2ABB5B2ABB1AEA7B0ADA6AEABA4ACA9A2AAA7A0A8A59EA6A39CA5A29B
A19E97A09D969F9C959E9B949C99929B98919A979099968F959289949286949085929084918D82\
8F8D818F8B808D8B7F8E8A7F8C8A7E8C887D8A887C89857A878579878378868277
8C86787A74646D6759726C5C7B75657C77647A75627B766278735F78735D77725C767259767259\
75715674705574705579745E736E5A716C58736E5A726D59706B5778735F86816D
847F6B85806C86816D87826E8984708A85718B86728C87738C87738E8975908B77918C78928D79\
928D79918C78908B77938E7A8D887496917D8A8571938E7A908B77726D598B8672
8A857188836F86816D88836F8C87738E89758C87738984708C87738C87738B86728A85718A8571\
89847088836F888370888272888274878173868072868072857F71847E70847E70
5D57496B65577E786A888274878173847E70837D6F857F71807D6E7F7D6E807D6E7F7D6E807D6E\
7F7D6E807D6E7F7D6E807D6E7F7D6E7F7C6D7D7B6C7E7B6C7C7A6B7C796A7C796A
7E786A7E786A7E786C7E786A7E786C7E786A7E786C7E786A7C766A7C76687B75697A74667A7468\
797365787266787264
C9C9D5C9C9D5C9C9D5C9C9D5C9C9D5C9C9D5C9C9D5C9C9D5CBCBD7CBCBD7CBCBD7CBCBD7CBCBD7\
CBCBD7CBCBD7CBCBD7C9CBD7C9CCD5C9CBD7C9CCD5C9CBD7C9CCD5C9CBD7C9CCD5
C9CBD7C9CCD5C9CBD7C9CCD5C9CBD7C9CCD5C9CBD7C6CCD8C9D9E9C1D4E5BCCDDFBACBDBBDCDDD\
BECEDDC0CDDDBECCD9C3CFDDC0CCD8C1CBD7C3CDD7C6CED9C5CDD8C2C8D4C0C4CD
AFACB3373238A5A0A6BDB8BCBFBABEC9C5C6C0BCBBC7C3C0C5C1BEC5C2BDC6C3BEC7C4BDC7C4BD\
C8C5BEC9C6BFC9C6BFC9C5C2C9C5C2C9C5C2C9C5C2C9C5C2C9C5C2C9C5C2C9C5C2
C9C5C2C9C5C2C9C5C2C9C5C2C9C5C2C9C5C2C9C5C2C9C5C2CAC5C2CAC5C2CBC3C1C8C3C0CAC2C0\
C7C2BFC8C0BEC6C1BEC6BEBCC4BFBCC5BDBBC2BDBAC4BCBAC1BCB9C2BAB8C0BBB8
BFBCB7BEBBB6BDBAB5BCB9B4BAB7B2B9B6B1B8B5B0B7B4AFB9B6B1B8B5B0B7B4AFB6B3AEB4B1AC\
B3B0ABB2AFAAB1AEA9ADAAA5ACA9A4ABA8A3AAA7A2A8A5A0A7A49FA6A39EA5A29D
9F9C979F9C979F9C979E9B969C999499969196938E94918A949087938F86948D85918D84918A82\
8E8A818F88808C887F8E877F8B877E8C857D89857C89827A868279878078867F75
8B85777873606B6555706B587974617A756178735F79745E78735D78745B777358767257767257\
757154747053747055746F59746F5B726D596E69556D6854716C58797460817C68
847F6B85806C86816D87826E8984708A85718B86728C87738E89758E89758F8A76908B77908B77\
918C78928D79928D79908B7795907C8D88748E897597927E88836F7A756188836F
8B867288836F86816D88836F8C87738E89758C87738A85718C87738C87738B86728A85718A8571\
89847088836F888370888272888274878173868072868072857F71847E70847E70
6660525A5446827C6E857F717C76688B8577817B6D817B6D807A6C7E7B6C807A6C7E7B6C807A6C\
7E7B6C807A6C7E7B6C807A6C7E7B6C807A6C7E7B6C807A6C7E7B6C807A6C807A6C
807A6E807A6E7F786E7E786C7E776D7D776B7C756B7C766A7C756B7C766A7B746A7A74687A7369\
797367787167787266
C3C0C9C3C0C9C3C0C9C3C0C9C3C0C9C3C0C9C3C0C9C3C0C9C4C1CAC4C1CAC4C1CAC4C1CAC4C1CA\
C4C1CAC4C1CAC3C2CAC4C3CBC3C3CBC3C3CBC3C3CBC3C3CBC3C3CBC3C3CBC3C3CB
C3C3CBC3C3CBC3C3CBC3C3CBC3C3CBC3C3CBC3C3CBBEC5CFC8D8E8BFD4E7BBCEDFB9CCDDBBCCDE\
BDCEDEBDCDDDBCCCDBC1CFDCBFCDDABFCBD7C0CCD8C5CFD9C4CED8C1C9D4C0C4CF
AEADB3373238A49FA5BDB8BCBFBABEC9C5C6BFBBBAC7C3C2C5C1BEC5C1BEC6C3BEC6C3BEC7C4BD\
C8C5BEC8C5BEC9C6BFC9C5C2C9C5C4C9C5C4C9C5C4C9C5C4C9C5C4C9C5C4C9C5C4
C9C5C4C9C5C4C9C5C4C9C5C4C9C5C4C9C5C4C9C5C4C9C5C4CCC3C4CBC2C3CBC2C3CAC1C2C9C0C1\
C9C0C1C8BFC0C8BFC0C6BDBEC5BCBDC5BCBDC4BBBCC3BABBC3BABBC2B9BAC0BBB8
C0BBB7BEBBB6BDBAB5BCB9B4BAB7B2B9B6B1B8B5B0B7B4AFB8B5B0B8B5B0B7B4AFB5B2ADB4B1AC\
B2AFAAB1AEA9B1AEA9ACA9A4ACA9A4ABA8A3A9A6A1A8A5A0A6A39EA5A29DA5A29D
9F9C979F9C979F9C979E9B969B989398959095928D939089968F87958E86948D85938C84918A82\
9089818F88808E877F8E877F8D867E8C857D8B847C89827A888179878078867F75
8A847477725F6B6653706B5879746079746077725C78735D78745B777358777358767255757154\
757154747152747053746F59746F5B726D596E69556C6753706B57797460807B67
847F6B85806C86816D87826E8984708A85718B86728C87738E89758E89758F8A768F8A76908B77\
918C78918C78928D798F8A7695907C8D88748E897596917D87826E7A756188836F
8A857188836F86816D88836F8C87738E89758C87738984708C87738B86728B86728A8571898470\
89847088836F888370888272878173878173868072857F71857F71847E70847E70
6660525A5446827C6E857F717C76688B8577817B6D817B6D807A6C807A6C807A6C807A6C807A6C\
807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C807A6C
80796F7F786E7F786E7E776D7D766C7D766C7C756B7C756B7C756B7B746A7B746A7A7369797268\
797268787167787167
BEBEC8BEBEC8BEBEC8BEBEC8BEBEC8BEBEC8BEBEC8BEBEC8C0C0CAC0C0CAC0C0CAC0C0CAC0C0CA\
C0C0CAC0C0CABEC1CABEC1CABDC1CABDC1CABDC1CABDC1CABDC1CABDC1CABDC1CA
BDC1CABDC1CABDC1CABDC1CABDC1CABDC1CABDC1CABAC2CDC7D8E8BED3E6BACCE0B8CBDCBBCCDE\
BCCDDDBDCDDDBBCBDAC1CFDCBFCDDABECAD6C0CCD8C4CED8C4CED8C0C8D3BFC3CE
ADACB2363137A49FA3BCB7BBBEB9BDC8C4C5BFBBBAC6C2C1C4C0BDC5C1BEC5C2BDC6C3BEC7C4BD\
C7C4BDC8C5BCC8C5BEC8C4C1C8C4C1C8C4C1C8C4C1C8C4C1C8C4C1C8C4C1C8C4C1
C8C4C1C8C4C1C8C4C1C8C4C1C8C4C1C8C4C1C8C4C1C8C4C1CBC3C1CBC3C1CAC2C0CAC2C0C9C1BF\
C8C0BEC8C0BEC7BFBDC5BDBBC5BDBBC4BCBAC4BCBAC3BBB9C2BAB8C2BAB8BFBAB7
BFBAB6BDBAB3BCB9B2BBB8B1B9B6AFB8B5AEB7B4ADB6B3ACB7B4ADB7B4ADB6B3ACB4B1AAB3B0A9\
B1AEA7B0ADA6B0ADA6ABA8A1ABA8A1AAA7A0A8A59EA7A49DA5A29BA4A19AA4A19A
9E9B949E9B949E9B949D9A939B989198958E95928B939089958E86948D83938C82928B8190897F\
8F887E8E877D8D867C8D867C8C857B8B847A8A8379888177878076867F75857F73
8A847477725F6A65526F6A5778735F79746077725C78735D77735A777358767257767255757154\
747053747152736F52746F59736E5A716C586D68546C6753706B57797460807B67
837E6A847F6B85806C86816D88836F8984708A85718B86728D88748E89758E89758F8A76908B77\
908B77918C78918C788F8A76948F7B8C87738D887496917D87826E79746087826E
8A857187826E85806C87826E8B86728D88748B86728984708B86728B86728A85718A8571898470\
88836F88836F87826F878171878173868072868072857F71847E70847E70837D6F
6660525A5446827C6E857F717C76688B8577817B6D817B6D807A6C807A6C807A6C807A6C807A6C\
807A6C807A6C807A6C7F796B7F796B7F796B7F796B7F796B7F796B7F796B7F796B
7F786E7F786E7E776D7E776D7D766C7C756B7C756B7B746A7B746A7B746A7A73697A7369797268\
787167787167777066
C4C8D4C4C8D4C4C8D4C4C8D4C4C8D4C4C8D4C4C8D4C4C8D4C5C9D5C5C9D5C5C9D5C5C9D5C5C9D5\
C5C9D5C5C9D5C3C9D5C3CBD6C3CBD6C3CBD6C3CBD6C3CBD6C3CBD6C3CBD6C3CBD6
C3CBD6C3CBD6C3CBD6C3CBD6C3CBD6C3CBD6C3CBD6C0CCDAC6D7E9BDD2E5B9CBDFB7C9DDBACBDF\
BCCDDFBCCBDEBBCBDBC0CDDDBECCD9BDC9D7BFCBD7C3CDD9C3CDD7C0C8D3BFC3CE
ACABB1353034A39EA2BCB8B9BDB9BAC7C3C2BEBAB9C5C1BEC3BFBCC4C1BCC4C1BCC5C2BBC6C3BC\
C6C3BAC7C4BBC7C4BDC7C4BFC7C3C0C7C3C0C7C3C0C7C3C0C7C3C0C7C3C0C7C3C0
C7C3C0C7C3C0C7C3C0C7C3C0C7C3C0C7C3C0C7C3C0C7C3C0CAC2C0CAC2C0C9C1BFC9C1BFC8C0BE\
C7BFBDC7BFBDC6BEBCC4BCBAC4BCBAC3BBB9C3BBB9C2BAB8C1B9B7C1B9B7BEB9B5
BEB9B3BDBAB3BCB9B2BAB7B0B9B6AFB7B4ADB6B3ACB6B3ACB6B3ACB5B2ABB4B1AAB3B0A9B1AEA7\
B0ADA6AFACA5AEABA4AAA7A0A9A69FA8A59EA7A49DA5A29BA4A19AA3A099A29F98
9D9A939E9B949D9A939C99929A979097948D94918A928F86948D83948D83938C82918A8090897F\
8E877D8D867C8D867C8C857B8C857B8B847A898278888177867F75857E74857F73
89837376715E6964516F6A5777725E78735F76715B77725C767259767257757156757154747053\
736F52737051726E51736E58726D59706B576D68546B66526F6A5678735F7F7A66
837E6A837E6A847F6B86816D87826E8984708A85718A85718C87738D88748D88748E89758F8A76\
8F8A76908B77908B778E8975938E7A8C87738C877395907C86816D79746086816D
89847086816D85806C86816D8A85718C87738B867288836F8A85718A857189847089847088836F\
87826E87826E86816E868070868072857F71857F71847E70837D6F837D6F827C6E
6660525A5446827C6E857F717C76688B8577817B6D817B6D807A6C807A6C807A6C807A6C807A6C\
807A6C807A6C807A6C7E786A7E786A7E786A7E786A7E786A7E786A7E786A7E786A
7E776D7E776D7D766C7D766C7C756B7B746A7B746A7A73697A73697A7369797268797268787167\
777066777066766F65
C8D1E2C8D1E2C8D1E2C8D1E2C8D1E2C8D1E2C8D1E2C8D1E2C8D1E2C8D1E2C8D1E2C8D1E2C8D1E2\
C8D1E2C8D1E2C8D1E2C8D4E4C7D4E4C7D4E4C7D4E4C7D4E4C7D4E4C7D4E4C7D4E4
C7D4E4C7D4E4C7D4E4C7D4E4C7D4E4C7D4E4C7D4E4C5D5E5C4D6EABDD2E7B9CBE1B7C9DDB9CADE\
BBCCDEBBCADDBACADABFCCDCBDCBD8BDC9D7BECAD6C2CCD8C2CCD8BFC7D4BEC2CD
ACABB1353034A29DA1BBB7B8BDB9BAC7C3C2BDB9B8C4C0BDC3BFBCC3C0BBC4C1BCC4C1BAC5C2BB\
C6C3BAC6C3BAC7C4BBC7C4BFC7C3C0C7C3C0C7C3C0C7C3C0C7C3C0C7C3C0C7C3C0
C7C3C0C7C3C0C7C3C0C7C3C0C7C3C0C7C3C0C7C3C0C7C3C0CAC2C0C9C1BFC9C1BFC8C0BEC7BFBD\
C7BFBDC6BEBCC6BEBCC4BCBAC3BBB9C3BBB9C2BAB8C1B9B7C1B9B7C0B8B6BEB9B5
BDB8B2BCB9B0BBB8AFB9B6ADB8B5ACB6B3AAB5B2A9B5B2A9B4B1A8B3B0A7B2AFA6B1AEA5AFACA3\
AEABA2ADAAA1ACA9A0A8A59CA7A49BA6A39AA5A299A3A097A29F96A19E95A09D94
9D9A919D9A919D9A919B988F99968D96938A939087918E85938C82938D81928C80908A7E8F897D\
8D877B8C867A8C867A8B85798B85798A8478888276878175857F73847E72847E70
88827275705D6964516E695676715D77725E75705A76715B767259757156757156747053736F52\
736F52726F50726E51726D57726D59706B576C67536A65516E695577725E7E7965
827D69827D69837E6A85806C86816D88836F8984708984708C87738C87738D88748D88748E8975\
8F8A768F8A76908B778D8874938E7A8B86728B8672948F7B85806C78735F86816D
88836F85806C847F6B86816D8A85718B86728A857187826E8A857189847089847088836F87826E\
87826E86816D86816E868070857F71857F71847E70837D6F837D6F827C6E827C6E
6660525A5446827C6E857F717C76688B8577817B6D817B6D807A6C807A6C807A6C807A6C807A6C\
807A6C807A6C807A6C7E786A7E786A7E786A7E786A7E786A7E786A7E786A7E786A
7E776D7D766C7D766C7C756B7B746A7B746A7A73697A73697A7369797268797268787167777066\
777066766F65766F65
C5D2E5C5D2E5C5D2E5C5D2E5C5D2E5C5D2E5C5D2E5C5D2E5C4D1E4C4D1E4C4D1E4C4D1E4C4D1E4\
C4D1E4C4D1E4C2D1E4C5D4E7C4D5E7C4D5E7C4D5E7C4D5E7C4D5E7C4D5E7C4D5E7
C4D5E7C4D5E7C4D5E7C4D5E7C4D5E7C4D5E7C4D5E7C3D5E9C3D5EBBCD1E6B8CAE0B6C8DEB8C8DF\
BACBDFBAC9DEB9C8DBBECBDCBCC9D9BCC8D8BDC9D7C2CBDAC1CBD7BEC6D3BDC1CC
ABAAAF343031A19D9EBAB6B5BCB8B7C6C2BFBCB8B5C4C1BCC2BFBAC2BFB8C3C0B9C3C0B7C4C1B8\
C5C3B7C5C3B7C6C3BAC6C3BEC6C3BEC6C2BFC6C3BEC6C2BFC6C3BEC6C2BFC6C3BE
C6C2BFC6C3BEC6C2BFC6C3BEC6C2BFC6C3BEC6C2BFC6C3BEC9C1BFC8C0BDC8C0BEC7BFBCC6BEBC\
C6BEBBC5BDBBC5BDBAC3BBB9C2BAB7C2BAB8C1B9B6C0B8B6C0B8B5BFB7B5BDB8B4
BDB9B0BBB8AFBAB7AEB9B6ADB7B4ABB6B3AAB5B2A9B4B1A8B2AFA6B2AFA6B1AEA5AFACA3AEABA2\
ACA9A0ABA89FABA89FA6A39AA6A39AA5A299A3A097A29F96A09D949F9C939F9C93
9C99909C99909C99909B988F98958C959289928F86908E82938D81928C80918B7F908A7E8E887C\
8D877B8C867A8B85798B85798A8478898377888276868074857F73847E72837D6F
878171746F5C6863506D685576715D76715D75705A75705A757158747055747055736F52726E51\
726E51716E4F716D50716C56716C586F6A566B66526964506D685476715D7E7965
817C68827D69837E6A847F6B86816D87826E88836F8984708B86728B86728C87738C87738D8874\
8E89758E89758F8A768C8773928D798A85718B8672938E7A847F6B77725E85806C
87826E85806C837E6A85806C8984708B867289847086816D89847088836F88836F87826E86816D\
86816D85806C85806D857F6F847E70847E70837D6F827C6E827C6E817B6D817B6D
6660525A5446827C6E857F717C76688B8577817B6D817B6D807A6C807A6C807A6C807A6C807A6C\
807A6C807A6C807A6C7D77697D77697D77697D77697D77697D77697D77697D7769
7D766C7C756B7C756B7B746A7A73697A7369797268797268797268787167787167777066766F65\
766F65756E64756E64
C0D0E7C0D0E7C0D0E7C0D0E7C0D0E7C0D0E7C0D0E7C0D0E7BECEE5BECEE5BECEE5BECEE5BECEE5\
BECEE5BECEE5BDCFE5C1D3E9BFD4E9BFD4E9BFD4E9BFD4E9BFD4E9BFD4E9BFD4E9
BFD4E9BFD4E9BFD4E9BFD4E9BFD4E9BFD4E9BFD4E9BFD4E9C1D5EDBBCFE7B7C9E1B5C7DDB8C8DF\
BACBDFBAC9DEB8C7DABECBDEBCC9DABBC7D7BDC9D7C1CAD9C1CAD9BEC5D5BCC0CB
AAA9AE332F2EA19D9CB9B5B4BBB7B6C5C1BEBCB8B5C3C0BBC1BEB9C2BFB8C2BFB8C3C0B7C4C1B8\
C4C2B6C5C3B7C5C3B7C5C2BBC5C2BBC5C2BDC5C2BBC5C2BDC5C2BBC5C2BDC5C2BB
C5C2BDC5C2BBC5C2BDC5C2BBC5C2BDC5C2BBC5C2BDC5C2BBC8C0BDC8C1BBC7BFBCC7C0BAC6BEBB\
C5BEB8C5BDBAC4BDB7C2BAB7C2BBB5C1B9B6C1BAB4C0B8B5BFB8B2BFB7B4BCB7B1
BCB8AFBAB8ACB9B7ABB8B6AAB6B4A8B5B3A7B4B2A6B3B1A5B1AFA3B1AFA3B0AEA2AEACA0ADAB9F\
ABA99DAAA89CAAA89CA5A397A5A397A4A296A2A094A19F939F9D919E9C909E9C90
9B998D9B998D9B998D9A988C98968A959387929084908E82928C80918B7D908A7C8F897B8D8779\
8C86788B85778A84768A8476898375888274878173857F71847E70837D6F827C6E
878171746F5C67624F6C675475705C76715D746F5975705A747057747055736F54736F52726E51\
716D50716E4F706C4F716C56706B576E69556B66526964506D685476715D7D7864
807B67817C68827D69837E6A85806C86816D87826E88836F8A85718B86728B86728C87738D8874\
8D88748E89758E89758C8773918C788A85718A8571938E7A847F6B76715D847F6B
87826E847F6B827D69847F6B88836F8A857188836F86816D88836F88836F87826E87826E86816D\
85806C85806C847F6C847E6E847E70837D6F837D6F827C6E817B6D817B6D807A6C
6660525A5446827C6E857F717C76688B8577817B6D817B6D807A6C807A6C807A6C807A6C807A6C\
807A6C807A6C807A6C7C76687C76687C76687C76687C76687C76687C76687C7668
7C756B7C756B7B746A7B746A7A7369797268797268787167787167787167777066777066766F65\
756E64756E64746D63
BDD1EABDD1EABDD1EABDD1EABDD1EABDD1EABDD1EABDD1EABBCFE8BBCFE8BBCFE8BBCFE8BBCFE8\
BBCFE8BBCFE8BBCFE8BED4ECBCD4ECBCD4ECBCD4ECBCD4ECBCD4ECBCD4ECBCD4EC
BCD4ECBCD4ECBCD4ECBCD4ECBCD4ECBCD4ECBCD4ECBED4ECC0D4ECBBCFE7B7C9E1B5C7DFB7C7E0\
B9C9E0BAC9E0B8C7DCBECAE0BBC8DBBBC6D8BCC8D8C1CADBC0C9D8BDC4D4BCC0CC
AAAAAC332F2EA09C9BB9B5B2BBB7B4C5C2BDBBB8B3C3C0B9C1BEB7C1BEB5C2BFB6C3C1B5C3C1B5\
C4C2B5C5C3B6C5C3B6C5C2B9C5C2BBC5C2BBC5C2BBC5C2BBC5C2BBC5C2BBC5C2BB
C5C2BBC5C2BBC5C2BBC5C2BBC5C2BBC5C2BBC5C2BBC5C2BBC8C1BBC8C1BBC7C0BAC6BFB9C6BFB9\
C5BEB8C4BDB7C4BDB7C2BBB5C2BBB5C1BAB4C0B9B3C0B9B3BFB8B2BEB7B1BCB8AF
BCB8ADBAB8ACB9B7ABB8B6AAB6B4A8B5B3A7B4B2A6B3B1A5B1AFA3B0AEA2AFADA1AEACA0ACAA9E\
ABA99DAAA89CA9A79BA5A397A4A296A3A195A2A094A09E929F9D919E9C909D9B8F
9B998D9B998D9B998D9A988C979589949286918F83908E81928C7E918B7D908A7C8F897B8D8779\
8C86788B85778A84768A8476898375888274878173857F71847E70837D6F827C6C
86816E746F5C67624F6C675475705C75705C746F59746F59747057747055736F54726E51726E51\
716D50706D4E706C4F706B55706B576E69556A65516964506D685475705C7D7864
807B67817C68827D69837E6A85806C86816D87826E88836F8A85718A85718B86728C87738C8773\
8D88748E89758E89758B8672918C788984708A8571938E7A837E6A76715D847F6B
86816D847F6B827D69847F6B88836F8A857188836F85806C88836F88836F87826E86816D86816D\
85806C847F6B847F6C847E6E847E70837D6F827C6E827C6E817B6D807A6C807A6C
6660525A5446827C6E857F717C76688B8577817B6D817B6D807A6C807A6C807A6C807A6C807A6C\
807A6C807A6C807A6C7C76687C76687C76687C76687C76687C76687C76687C7668
7C756B7C756B7B746A7A73697A7369797268787167787167787167787167777066766F65766F65\
756E64746D63746D63
BACFEABACFEABACFEABACFEABACFEABACFEABACFEABACFEABACFEABACFEABACFEABACFEABACFEA\
BACFEABACFEAB8D0EAB7D1EAB7D1EAB7D1EAB7D1EAB7D1EAB7D1EAB7D1EAB7D1EA
B9D3ECB9D3ECB9D3ECB9D3ECB9D3ECB9D3ECB9D3ECBAD2ECBED4ECB9CDE6B5C6E0B3C5DDB6C6DF\
B7C7DEB8C7DEB6C5DABCC8DEB9C6D9B9C4D8BBC6D8BFC7DABEC7D8BBC2D4BABECA
A1A1A337333095918EBAB6B3BCB8B5B9B6B1BFBCB7BAB7B0BFBCB5C0BDB4C0BEB2C1BFB2C2C0B3\
C2C0B1C3C1B2C3C1B4C3C0B7C4C1B8C4C1B8C5C2B9C6C3BAC6C3BAC7C4BBC7C4BB
C3C0B7C3C0B7C3C0B7C3C0B7C3C0B7C3C0B7C3C0B7C3C0B7C8C1B9C8C1B9C7C0B8C7C0B8C6BFB7\
C5BEB6C5BEB6C4BDB5BFB8B0BFB8B0BFB8B0BEB7AFBEB7AFBEB7AFBDB6AEBBB7AE
B7B3A8B6B4A7B5B3A6B4B2A5B3B1A4B2B0A3B1AFA2B1AFA2AEAC9FADAB9EADAB9EACAA9DABA99C\
AAA89BA9A79AA8A699A3A194A2A093A09E919E9C8F9C9A8D9A988B989689979588
979588969487959386949285929083918F82908E818F8D80938D7F928C7C918B7B8F89798D8777\
8C86768A8474898373857F6F847E6E847E6E837D6D827C6C827C6C817B6B817B6B
837E6B76715E69645166614E6D6854746F5B746F59716C56747057747055736F54726E51726E51\
716D50706D4E706C4F6F6A546F6A566E69556A655168634F6A6551716C5877725E
7B76627D7864807B67837E6A85806C86816D86816D86816D8A85718B86728B86728C87738D8874\
8D88748E89758E897588836F8E897586816D88836F918C78837E6A76715D847F6B
87826E847F6B827D69847F6B88836F8A857188836F86816D88836F88836F87826E86816D86816D\
85806C847F6B847F6C847E6E847E70837D6F827C6E827C6E817B6D807A6C807A6C
625C4E554F417C76687E786A7771638A8476847E70878173857F71837D6F857F718680727D7769\
746E60797365857F717A74667A74667A74667A74667A74667A74667A74667A7466
7C756B7C756B7B746A7A73697A7369797268787167787167787167787167777066766F65766F65\
756E64746D63746D63
B8D0ECB8D0ECB8D0ECB8D0ECB8D0ECB8D0ECB8D0ECB8D0ECB8D0ECB8D0ECB8D0ECB8D0ECB8D0EC\
B8D0ECB8D0ECB7D1ECB7D1ECB6D1ECB6D1ECB6D1ECB6D1ECB6D1ECB6D1ECB6D1EC
B8D3EEB8D3EEB8D3EEB8D3EEB8D3EEB8D3EEB8D3EEB9D3EEBDD2EDB9CDE6B5C6E0B3C4DEB5C5DF\
B7C7E0B7C5DFB6C5DCBBC7DFB9C5DBB9C4DABAC5D9BFC7DCBEC6D9BBC2D5BABECA
A5A5A73A3633989491BDBAB5BFBCB7BCB9B2C3C0B9BEBBB2BEBBB2BFBDB1BFBDB0C0BEAFC1BFB0\
C1BFB0C2C0B1C2C0B1BFBDB1BFBCB3C0BDB4C1BEB5C1BEB5C2BFB6C3C0B7C3C0B7
C0BDB4C0BDB4C0BDB4C0BDB4C0BDB4C0BDB4C0BDB4C0BDB4C1BAB2C1BAB2C0B9B1BFB8B0BFB8B0\
BEB7AFBDB6AEBDB6AEC1BAB2C0B9B1C0B9B1BFB8B0BEB7AFBDB6AEBCB5ADB9B5AA
BEBAAEBCBAADBBB9ACB9B7AAB7B5A8B6B4A7B4B2A5B4B2A5ABA99CAAA89BA9A79AA7A598A5A396\
A4A295A3A194A2A093A6A497A6A497A4A295A2A093A09E919D9B8E9C9A8D9B998C
9A988B9A988B99978A9795889694879492859391849391828E88788E88788D87778C86768B8575\
8983738983738882728E88788E88788D87778D87778C86768B85758B85758A8474
827D6A77725F6D68556C6754736E5A79746078735D746F59747057736F54736F54726E51716D50\
716D50706D4E706C4F6E69536F6A566D68546A655168634F6A6551716C5877725E
7A75617C77637F7A66827D6985806C86816D86816D86816D8A85718A85718A85718B86728C8773\
8D88748D88748D887487826E8D887486816D87826E918C78827D6976715D847F6B
86816D847F6B827D69847F6B88836F8A857188836F85806C88836F87826E87826E86816D85806C\
85806C847F6B847F6C847E6E837D6F837D6F827C6E817B6D817B6D807A6C807A6C
645E505751437D77697F796B7872648B8577857F71888274868072847E70857F718680727D7769\
736D5F777163837D6F7A74667A74667A74667A74667A74667A74667A74667A7466
7C756B7B746A7B746A7A7369797268797268787167787167787167777066777066766F65756E64\
756E64746D63746D63
B6CEEAB6CEEAB6CEEAB6CEEAB6CEEAB6CEEAB6CEEAB6CEEAB7CFEBB7CFEBB7CFEBB7CFEBB7CFEB\
B7CFEBB7CFEBB6D0EBB6D0EBB5D0EBB5D0EBB5D0EBB5D0EBB5D0EBB5D0EBB5D0EB
B7D2EDB7D2EDB7D2EDB7D2EDB7D2EDB7D2EDB7D2EDB8D2EDBDD2EFB8CCE7B4C5E1B2C3DDB5C5DF\
B6C6DFB7C5DFB5C4DBBBC7DFB9C5DBB8C3D9BAC5D9BEC6DBBEC6D9BAC1D4B9BDC9
A3A3A538353095928DBAB7B2BCB9B4BAB7B0C1BEB7BCB9B0BDBBAFBDBBAEBDBBAEBEBCADBFBDAE\
C0BFADC0BFADC0BEAFBFBDB1C0BEB2C0BEB2C1BFB3C2C0B4C2C0B4C3C1B5C3C1B5
C2C0B4C2C0B4C2C0B4C2C0B4C2C0B4C2C0B4C2C0B4C2C0B4C3BCB2C3BCB2C2BBB1C1BAB0C1BAB0\
C0B9AFBFB8AEBFB8AEC3BCB2C2BBB1C1BAB0BFB8AEBDB6ACBBB4AAB9B2A8B7B3A8
B9B5A9B7B5A6B5B3A4B3B1A2B0AE9FAEAC9DACAA9BABA99AB3B1A2B2B0A1B0AE9FADAB9CAAA899\
A8A697A6A495A5A394A3A192A2A091A19F909F9D8E9C9A8B9A9889999788989687
979586979586969485949283939182918F80908E7F908E7F87817187826F87826F87826F86816E\
86816E86816E86816E7B76637B76637B76637A7562797461787360787360787360
797461726D5A6C67546E695675705C79746076715B726D57736F56736F54726E53726E51716D50\
706C4F706D4E6F6B4E6E69536E69556D685469645067624E696450706B5776715D
7A75617C77637F7A66827D69847F6B85806C85806C85806C88836F8984708984708A85718B8672\
8B86728C87738C877387826E8D887485806C87826E908B77827D6975705C837E6A
86816D837E6A817C68837E6A87826E89847087826E85806C87826E87826E86816D86816D85806C\
847F6B847F6B837E6B837D6D837D6F827C6E827C6E817B6D807A6C807A6C7F796B
6660525953457F796B817B6D7973658C8678857F71888274888274857F71868072857F717C7668\
716B5D746E60807A6C7A74667A74667A74667A74667A74667A74667A74667A7466
7B746A7B746A7A73697A7369797268787167787167777066777066777066766F65766F65756E64\
746D63746D63736C62
B7CCE9B5CDE7B7CCE9B5CDE7B7CCE9B5CDE7B7CCE9B5CDE7B8CDEAB6CEE8B8CDEAB6CEE8B8CDEA\
B6CEE8B8CDEAB6CEE8B5CFEAB4D0E8B5CFEAB4D0E8B5CFEAB4D0E8B5CFEAB4D0E8
B7D1ECB6D2EAB7D1ECB6D2EAB7D1ECB6D2EAB7D1ECB7D1ECBCD1EEB7CAE8B3C4E2B1C2DEB4C3E0\
B6C6E0B6C4DFB5C3DDBAC6E0B8C4DCB7C1DAB9C4DABDC5DCBDC5DABAC0D6B9BCCB
9D9D9D312E298D8A85B1AEA7B3B0A9B2AFA6BAB7AEB6B4A8BAB8ABBBB9AABBB9AABCBBA9BDBCAA\
BDBCAABEBDABBEBDABC3C1B4C3C1B5C4C2B6C4C2B6C5C3B7C6C4B8C6C4B8C7C5B9
C7C5B9C7C5B9C7C5B9C7C5B9C7C5B9C7C5B9C7C5B9C7C5B9CCC5BBCCC5BBCBC4BACBC4BACAC3B9\
C9C2B8C9C2B8C8C1B7C3BCB2C2BBB1C0B9AFBDB6ACBBB4AAB8B1A7B6AFA5B3AFA3
ACA99AA9A798A7A596A4A293A09E8F9D9B8C9B998A999788939182918F808F8D7E8C8A7B888677\
858374828071817F70777566767465757364737162706E5F6E6C5D6D6B5C6C6A5B
6B695A6B695A6A6859686657676556656354646253646351605B48605B48605B48615C49615C49\
625D4A625D4A625D4A625D4A625D4A625D4A615C49605B485F5A475F5A475F5A47
6D68556A65526964516C6754716C58736E5A706B556C6751726E55726E53716D52716D50706C4F\
6F6B4E6F6C4D6E6A4D6D68526D68546C675369645066614D696450706B5776715D
7974607B76627E7965817C68837E6A847F6B85806C847F6B87826E87826E88836F88836F898470\
8A85718A85718B867286816D8C877385806C86816D8F8A76817C68746F5B827D69
85806C827D69817C68827D6986816D88836F87826E847F6B86816D86816D85806C85806C847F6B\
837E6A837E6A827D6A827C6C827C6E817B6D817B6D807A6C7F796B7F796B7E786A
6761535A5446807A6C827C6E7A74668C8678857F71888274898375868072868072857F717B7567\
6F695B726C5E7D77697A74667A74667A74667A74667A74667A74667A74667A7466
7A73697A7369797268797268787167777066777066766F65766F65766F65756E64756E64746D63\
736C62736C62726B61
B6CAE5B5CBE3B6CAE5B5CBE3B6CAE5B5CBE3B6CAE5B5CBE3B9CDE8B8CEE6B9CDE8B8CEE6B9CDE8\
B8CEE6B9CDE8B8CEE6B6CEE8B5CFE6B6CEE8B5CFE6B6CEE8B5CFE6B6CEE8B5CFE6
B8D0EAB7D1E8B8D0EAB7D1E8B8D0EAB7D1E8B8D0EAB8D0EABBD0EDB7CAE8B3C4E2B1C2DEB3C2DF\
B5C5DFB5C3DEB4C2DCB9C5DFB7C3DBB7C1DAB8C3D9BCC4DBBCC4D9B9BFD5B8BBCA
9B9B9B2E2B2489867FACA9A2AEABA4AEABA2B7B4ABB4B2A6B8B6A9B8B6A7B9B7A8B9B8A6BAB9A7\
BBBAA6BBBAA6BCBBA9C0BEB1C1BFB2C1BFB2C2C0B3C3C1B4C3C1B4C4C2B5C4C2B5
C5C3B6C5C3B6C5C3B6C5C3B6C5C3B6C5C3B6C5C3B6C5C3B6CAC4B8C9C3B7C9C3B7C8C2B6C7C1B5\
C7C1B5C6C0B4C6C0B4BFB9ADBEB8ACBCB6AABAB4A8B7B1A5B5AFA3B3ADA1B0ACA0
A8A596A5A492A3A290A09F8D9C9B899998869695839594828E8D7B8D8C7A8B8A78878674848371\
81806E7E7D6B7D7C6A7A796779786678776576756373726071705E706F5D6F6E5C
6E6D5B6E6D5B6D6C5A6B6A586A695768675567665467665466614E67624E67624E67624E68634F\
68634F68634F69645069645069645068634F67624E67624E66614D65604C65604C
6A65526A65526B66536E6956726D59726D596F6A546C6751726E55716D52716D52706C4F6F6B4E\
6F6B4E6E6B4C6E6A4D6C67516D68546B665268634F66614D68634F6F6A5675705C
78735F7A75617D7864807B67827D69847F6B847F6B847F6B85806C86816D86816D87826E88836F\
88836F89847089847085806C8B8672847F6B85806C8F8A76807B67736E5A827D69
847F6B817C68807B67827D6986816D87826E86816D837E6A86816D85806C85806C847F6B837E6A\
837E6A827D69827D6A827C6C817B6D817B6D807A6C7F796B7F796B7E786A7E786A
6862545A5446807A6C817B6D7973658A8476837D6F868072888274857F71857F71847E707A7466\
6E685A716B5D7C76687A74667A74667A74667A74667A74667A74667A74667A7466
7A7369797268797268787167777066777066766F65766F65766F65756E64756E64746D63736C62\
736C62726B61726B61
B5C9E2B5C9E2B5C9E2B5C9E2B5C9E2B5C9E2B5C9E2B5C9E2B8CCE5B8CCE5B8CCE5B8CCE5B8CCE5\
B8CCE5B8CCE5B8CCE5B7CDE5B5CDE5B5CDE5B5CDE5B5CDE5B5CDE5B5CDE5B5CDE5
B7CFE7B7CFE7B7CFE7B7CFE7B7CFE7B7CFE7B7CFE7B9CEE9BBCEECB6C9E9B2C3E1B0C1DFB2C1E0\
B4C3E0B4C2DDB3C1DCB8C4DEB6C2DCB6C0D9B7C1DABCC4DBBBC3DAB8BED4B7BAC9
9E9E9E302D268A8780ADAAA1AFACA3AFADA1B9B7ABB6B4A7B6B4A5B6B4A5B6B5A3B7B6A4B8B7A3\
B9B8A4B9B8A4B9B8A6B8B6A7B9B7AAB9B7AABAB8ABBBB9ACBBB9ACBCBAADBCBAAD
BBB9ACBBB9ACBBB9ACBBB9ACBBB9ACBBB9ACBBB9ACBBB9ACBCB6AABBB5A9BBB5A9BAB4A8B9B3A7\
B9B3A7B8B2A6B8B2A6B9B3A7B8B2A6B7B1A5B5AFA3B3ADA1B1AB9FB0AA9EADAA9B
AEAB9CACAB99AAA997A7A694A4A391A2A18FA09F8D9F9E8CA7A694A6A593A4A391A1A08E9F9E8C\
9C9B899A998799988699988698978596958394938192917F908F7D8E8D7B8E8D7B
8D8C7A8C8B798B8A788A8977888775878674868573858470847F6B847F6B847F6B847F6B837E6A\
837E6A837E6A837E6A78735F78735F78735F77725E76715D75705C75705C75705C
716C59726D5A736E5B75705D75705C75705C746F59736E58716D54706C51706C516F6B4E6E6A4D\
6E6A4D6D6A4B6D694C6B66506C67536A655167624E65604C67624E6E6955746F5B
77725E7974607C77637F7A66827D69837E6A837E6A837E6A847F6B847F6B85806C85806C86816D\
87826E87826E88836F847F6B8A8571837E6A847F6B8E89757F7A66736E5A817C68
837E6A817C687F7A66817C6885806C87826E85806C827D6985806C847F6B847F6B837E6A827D69\
827D69817C68817C69817B6B807A6C807A6C7F796B7E786A7E786A7D77697D7769
6761535953457E786A7F796B767062878173807A6C837D6F868072837D6F847E70837D6F797365\
6F695B726C5E7D77697A74667A74667A74667A74667A74667A74667A74667A7466
797268787167787167777066766F65766F65756E64756E64756E64746D63746D63736C62726B61\
726B61716A60716A60
B5C7DFB5C7DFB5C7DFB5C7DFB5C7DFB5C7DFB5C7DFB5C7DFB9CBE3B9CBE3B9CBE3B9CBE3B9CBE3\
B9CBE3B9CBE3B7CBE3B6CCE3B6CCE3B6CCE3B6CCE3B6CCE3B6CCE3B6CCE3B6CCE3
B8CEE5B8CEE5B8CEE5B8CEE5B8CEE5B8CEE5B8CEE5B8CEE6BBCEECB5C8E8B1C1E2AFC0DEB2C1E0\
B4C3E0B4C2DDB2C0DBB8C4DEB6C2DCB5BFD8B7C1DABBC3DABBC3DAB8BED6B6B9CA
9C9C9C2E2B2488857CA9A69DABA89FACAA9EB7B5A9B5B3A6B4B2A3B4B2A3B5B4A2B5B4A2B6B5A1\
B7B6A2B7B6A2B8B7A5B5B3A4B5B3A6B5B3A6B6B4A7B7B5A8B8B6A9B8B6A9B8B6A9
B6B4A7B6B4A7B6B4A7B6B4A7B6B4A7B6B4A7B6B4A7B6B4A7B6B0A4B6B0A4B5AFA3B5AFA3B4AEA2\
B3ADA1B3ADA1B2ACA0B3ADA1B2ACA0B1AB9FB1AB9FAFA99DAFA99DAEA89CABA899
ACA99AAAA997A9A896A7A694A6A593A4A391A3A290A2A18F999886999886979684969583949381\
92917F91907E908F7D8C8B798C8B798A897788877586857383827082816F81806E
81806E807F6D7F7E6C7D7C6A7C7B697B7A6879786679786479746078735D77725C76715B75705A\
746F59736E58736E5879745E78735D78735D77725C76715B76715B75705A75705C
76715E77725F77725F76715E746F5B736E5A746F5975705A706C53706C516F6B506F6B4E6E6A4D\
6D694C6D6A4B6C684B6B66506B66526A655167624E645F4B67624E6D6854736E5A
77725E7974607C77637F7A66817C68827D69827D69827D69837E6A837E6A837E6A847F6B85806C\
86816D86816D86816D847F6B8A8571827D69847F6B8D88747F7A66726D59807B67
837E6A807B677E7965807B67847F6B86816D847F6B827D69847F6B847F6B837E6A837E6A827D69\
817C68817C68807B68807A6A807A6C7F796B7F796B7E786A7D77697D77697C7668
655F515751437C76687D7769746E60857F717D77697F796B837D6F807A6C827C6E827C6E797365\
6F695B736D5F7F796B7A74667A74667A74667A74667A74667A74667A74667A7466
787167787167777066777066766F65756E64756E64746D63746D63746D63736C62736C62726B61\
716A60716A6070695F
B3C7E0B3C7E0B3C7E0B3C7E0B3C7E0B3C7E0B3C7E0B3C7E0B7CBE4B7CBE4B7CBE4B7CBE4B7CBE4\
B7CBE4B7CBE4B7CBE4B6CCE4B6CCE4B6CCE4B6CCE4B6CCE4B6CCE4B6CCE4B6CCE4
B8CEE6B8CEE6B8CEE6B8CEE6B8CEE6B8CEE6B8CEE6B8CDE8BACDEBB5C8E8B1C1E2AFC0DEB1C0DF\
B3C2DFB4C2DDB2C0DAB8C4DEB5C1D9B5BFD8B6C1D7BBC3DABAC2D9B7BDD5B6B9CA
98969729261F837E78A3A097A6A299A6A498B2AEA3B0AEA1B4B0A4B3B1A2B5B2A3B4B3A1B6B3A2\
B6B5A1B7B4A1B7B6A4B8B5A6B7B5A8B9B5A9B8B6A9BAB6AABAB8ABBBB7ABBBB9AC
B7B3A7B6B4A7B7B3A7B6B4A7B7B3A7B6B4A7B7B3A7B7B3A7BCB6A8BBB5A7BBB5A7BAB4A6B9B3A5\
B9B3A5B8B2A4B8B2A4AEA89AAEA89AAEA89AAEA89AADA799ADA799ADA799ADA799
A29F8EA1A08CA19E8D9F9E8A9F9C8B9D9C889D9A899C9B879A9786999884999685979682979483\
95948095928194937F94918092917D918E7D8E8D798D8A798A8975898675878672
88857486857186837284836F83806F81806C817E6D807D6A837E68827D67817C667F7A647D7862\
7B76607A755F79745E75705A746F59746F59736E58726D57726D57716C56716C56
75705C76715D75705C726D596F6A566E6953706B55726D57706C53706C536F6B506E6A4D6E6A4F\
6D694C6C684B6C684D6B66506B66526A655166614D645F4B66614D6D6854736E5A
77725E78735F7B76627E7965817C68827D69827D69827D69827D69827D69837E6A837E6A847F6B\
85806C85806C86816D837E6A898470827D69837E6A8D88747E7965726D59807B67
827D6A807B687E7966807B68847F6C86816E847F6C817C69847F6C847F6C837E6B827D6A827D6A\
817C69807B68807B68807A6A807A6C7F796B7E786A7E786A7D77697C76687C7668
645E505650427B75677B7567726C5E837D6F7B75677D7769817B6D7D7A6B807A6E7F7C6D797367\
6E6B5C756F637F7C6D7A74687875667A74687875667A74687875667A7468787468
787167767267777066747065766F65736F64746D63726E63746D63726E63736C62706C61726B61\
6F6B6070695F6E6A5F
AFC9E4AFC9E4AFC9E4B0CAE5B0CAE5B0CAE5B1CBE6B1CBE6ADC7E2ADC7E2ADC7E2ADC7E2ADC7E2\
ADC7E2ADC7E2AEC6E2B5CAE7B6C9E7B6C9E7B6C9E7B6C9E7B6C9E7B6C9E7B6C9E7
B4C7E5B4C7E5B4C7E5B5C8E6B6C9E7B7CAE8B7CAE8B7CAE8B6C9E7B0C3E1ADBEDCABBCDAAEBDDC\
B0BFDCB1BFDAAFBDD7B4C0DAB3BFD7B4BED7B6C1D7BBC3DAB9C1D6B5BBD1B3B6C5
8C8A8D322D2788817B9D9990AAA39BA8A499AEA79DB1ADA1B2ACA0B1AE9FB3AD9FB2AF9EB5AF9F\
B3B09FB6B0A0B4B1A0B6B0A2B4B1A2B6B0A2B4B1A2B6B0A2B4B1A2B6B0A2B4B1A2
B8B2A4B6B3A4B8B2A4B6B3A4B8B2A4B6B3A4B8B2A4B8B2A4B6B0A0B6B19EB5B09DB5B09DB4AF9C\
B3AE9BB3AE9BB2AD9AB2AD9AB1AC99B0AB98AFAA97ADA895ACA794ABA693AAA592
A8A390A5A38EA5A08DA19F8AA19C899D9B869D98859B99849A958297958098938095937E95907D\
92907B938E7B908E798E89768B89748C877489877289847186846F87826F84826D
847F6C817F6A827D6A7F7D687F7A677C7A657D78657C77637C77617C785F7B775E7B775E7A765D\
79755C79755C78745B767259767259757158757158747057736F56736F56726E55
706B55706B556F6A546E69536E69536D69506C684F6C684F6E6A516E6A516D69506D694E6C684F\
6B674C6B674C6A664D69644E67624E645F4B625D49645F4B68634F6D6854716C58
78735F7974607A75617B76627D78647E79657F7A66807B67827D69837E6A837E6A847F6B85806C\
85806C86816D86816D847F6B8A8571827D69847F6B8D88747F7A66726D59807B68
827C6C807A6A7D77677F7969827C6C837D6D817B6B7E7868807A6A807A6A807A6A807A6A807A6A\
807A6A807A6A807A6A7E786A7E786A7E786A7E786A7E786A7E786A7E786A7E786A
6C6658554F417771637E786A777163827C6E7771637C7668827E727D7B6E7E7A6F7F7D707A766B\
6F6D60706C61777568787469777568777368757366767267747265747065737165
767267757367757166737165747065727064726E63716F63726E63716F63716D626F6D61706C61\
6E6C606E6A5F6D6B5F
AEC7E5AEC7E5AEC7E5AEC7E5AEC7E5AEC7E5AFC8E6AFC8E6ADC6E4ADC6E4ADC6E4ADC6E4ADC6E4\
ADC6E4ADC6E4AEC5E4B5C8E8B5C8E8B7C7E8B5C8E8B7C7E8B5C8E8B7C7E8B5C8E8
B5C5E6B4C7E7B6C6E7B5C8E8B8C8E9B6C9E9B9C9EAB7CAEAB4C7E5AFC2E0ACBDDBAABBD9AEBDDA\
B0C0DAB0BED9AEBCD6B4C0D8B2BED6B3BED4B6C1D7BAC2D7B9C1D6B4BAD0B2B5C4
8D888C332B2887807A9E9791A9A29AA9A29AADA69CB2ABA1B2ACA0B2ACA0B2AC9EB3AD9FB4AE9E\
B5AF9FB5AF9FB5AF9FB6B0A2B6B0A2B6B0A2B6B0A2B6B0A2B6B0A2B6B0A2B6B0A2
B7B1A3B7B1A3B7B1A3B7B1A3B7B1A3B7B1A3B7B1A3B7B1A1B5B09DB5B09CB4AF9BB4AF9BB3AE9A\
B2AD99B2AD99B1AC98B1AC98B1AC98AFAA96AEA995ADA894ABA692AAA591A9A490
A7A28EA6A18DA5A08CA29D89A09B879E99859C97839C978399948099948097927E96917D95907C\
938E7A928D79918C788D88748D88748C87738A857189847087826E86816D86816D
837E6A837E6A827D69807B677F7A667D78647C77637C77617B76607B775E7B775E7A765D79755C\
78745B78745B78745B757158757158757158747057736F56726E55726E55726E55
706C536F6B526F6B526E6A516D69506D69506C684F6C684F6D69506D69506D69506C684F6B674E\
6A664D6A664D6A664D69645067624E645F4B625D49645F4B68634F6D6854706B57
78735F78735F7974607B76627C77637E79657F7A667F7A66827D69827D69827D69837E6A847F6B\
85806C85806C85806C837E6A898470827D69837E6A8D88747E7965726D59807B68
827C6C7F796B7D77697E786A817B6D837D6F807A6C7D7769807A6C807A6C807A6C807A6C807A6C\
807A6C807A6C807A6C7E786A7E786A7E786A7E786A7E786A7E786A7E786A7E786A
6B6557544E407670627D7769777163827C6E7872647B78697B776C77756978766A7C7A6E777569\
6F6D61706E6279776B777569767468767468757367747266747266737165737165
757367747266747266737165727064727064716F63716F63716F63706E62706E626F6D616E6C60\
6E6C606D6B5F6D6B5F
AFC6E5AFC6E5AFC6E5AFC6E5AEC5E4AEC5E4AEC5E4AEC5E4AFC6E5AFC6E5AFC6E5AFC6E5AFC6E5\
AFC6E5AFC6E5B1C6E5B8C8E9B8C8E9B9C8E9B8C8E9B9C8E9B8C8E9B9C8E9B8C8E9
B8C7E8B7C7E8B8C7E8B8C8E9BAC9EABACAEBBBCAEBBACAEBB0C3E1ACBFDDAABBD9A9BAD8ADBCD9\
AFBFD9AEBCD7ACBAD4B2BED6B1BDD5B2BDD3B4BFD5B9C1D6B7BFD4B3B9CFB1B4C3
8B868A322A27867F799D9690A7A098A7A098ABA49AB0A99FB0AA9EB1AB9FB1AB9DB2AC9EB3AD9D\
B3AD9DB4AE9EB4AE9EB4AEA0B4AEA0B4AEA0B4AEA0B4AEA0B4AEA0B4AEA0B4AEA0
B6B0A2B6B0A2B6B0A2B6B0A2B6B0A2B6B0A2B6B0A2B6B0A0B3AE9BB3AE9AB3AE9AB2AD99B1AC98\
B0AB97B0AB97B0AB97AFAA96AFAA96AEA995ACA793ABA692A9A490A8A38FA8A38F
A5A08CA49F8BA39E8AA19C889E99859C97839B96829A958197927E97927E96917D948F7B938E7A\
918C78908B77908B778C87738C87738B867289847088836F86816D85806C85806C
827D69827D69817C687F7A667E79657C77637B76627B76607A755F7A765D79755C79755C78745B\
77735A77735A767259747057747057736F56736F56726E55716D54716D54706C53
6F6B526F6B526E6A516E6A516D69506C684F6C684F6B674E6C684F6C684F6B674E6B674E6A664D\
69654C69654C68644B68634F66614D635E4A625D49635E4A67624E6C6753706B57
77725E77725E78735F7A75617B76627D78647E79657E7965807B67817C68817C68827D69837E6A\
837E6A847F6B847F6B837E6A898470817C68837E6A8C87737E7965716C587F7A67
827C6C7F796B7C76687E786A817B6D827C6E807A6C7D77697F796B7F796B7F796B7F796B7F796B\
7F796B7F796B7F796B7D77697D77697D77697D77697D77697D77697D77697D7769
696355534D3F756F617C7668767062827C6E7872647B786976726772706474726679776B767468\
6F6D61716F637A786C767468767468757367757367747266737165737165727064
747266747266737165737165727064716F63716F63706E62706E62706E626F6D616F6D616E6C60\
6D6B5F6D6B5F6C6A5E
AEC1E1AEC1E1AEC1E1ADC0E0ADC0E0ACBFDFACBFDFACBFDFAFC2E2AFC2E2AFC2E2AFC2E2AFC2E2\
AFC2E2AFC2E2B1C1E2B5C4E5B6C3E5B6C3E5B6C3E5B6C3E5B6C3E5B6C3E5B6C3E5
B5C2E4B6C3E5B6C3E5B7C4E6B8C5E7B8C5E7B9C6E8B8C7E8AEBFDDA8BBD9A8B9D7A8B9D7ACBBD8\
ADBDD7ADBBD6AAB8D2B1BDD5B0BCD4B0BBD1B3BED4B7BFD4B6BED3B1B7CDAFB2C1
8984882F2724837C769A938DA59E96A59E96A9A298AEA79DAFA99DAFA99DB0AA9CB0AA9CB1AB9B\
B2AC9CB2AC9CB3AD9DB3AD9FB3AD9FB3AD9FB3AD9FB3AD9FB3AD9FB3AD9FB3AD9F
B3AD9FB3AD9FB3AD9FB3AD9FB3AD9FB3AD9FB3AD9FB3AD9DB1AC99B1AC98B0AB97B0AB97AFAA96\
AEA995AEA995ADA894ADA894ACA793ABA692AAA591A8A38FA7A28EA6A18DA5A08C
A39E8AA29D89A09B879E99859C97839A958198937F98937F95907C948F7B938E7A928D79908B77\
8F8A768E89758D88748B86728A857189847088836F86816D85806C847F6B837E6A
817C68807B677F7A667E79657C77637B76627A756179745E79745E78745B78745B77735A767259\
767259757158757158736F56726E55726E55716D54706C53706C536F6B526F6B52
6E6A516E6A516D69506D69506C684F6B674E6B674E6A664D6B674E6A664D6A664D69654C68644B\
68644B67634A67634A67624E65604C625D49615C48625D4967624E6C67536F6A56
75705C76715D77725E78735F7A75617B76627C77637D78647F7A667F7A66807B67807B67817C68\
827D69827D69837E6A827D6988836F817C68827D698B86727D7864706B577E7966
817B6B7E786A7C76687D7769807A6C817B6D7F796B7C76687E786A7E786A7E786A7E786A7E786A\
7E786A7E786A7E786A7C76687C76687C76687C76687C76687C76687C76687C7668
686254514B3D736D5F7B7567767062817B6D7872647B786979756A7472667674687A786C777569\
6F6D61716F6379776B757367757367747266747266737165727064727064716F63
737165737165727064727064716F63706E62706E626F6D616F6D616F6D616E6C606E6C606D6B5F\
6C6A5E6C6A5E6B695D
A4B3D4A3B2D3A3B2D3A2B1D2A1B0D1A0AFD09FAECF9FAECFA4B3D4A4B3D4A4B3D4A4B3D4A4B3D4\
A4B3D4A4B3D4A5B2D4A8B2D5A8B2D5A8B2D5A8B2D5A8B2D5A8B2D5A8B2D5A8B2D5
A9B3D6A9B3D6A9B3D6AAB4D7ABB5D8ACB6D9ACB6D9AAB7D9A9BAD8A4B7D5A5B6D4A7B8D6ABBAD7\
ACBCD6ABB9D4A7B5CFAFBBD3AEBAD2AFBAD0B1BCD2B6BED3B4BCD1B0B6CCAEB1C0
8681852D2522817A7498918BA29B93A39C94A69F95ACA59BADA79BAEA89CAEA89AAFA99BB0AA9A\
B0AA9AB1AB9BB1AB9BB1AB9DB1AB9DB1AB9DB1AB9DB1AB9DB1AB9DB1AB9DB1AB9D
B1AB9DB1AB9DB1AB9DB1AB9DB1AB9DB1AB9DB1AB9DB1AB9BAFAA97AEA995AEA995ADA894ACA793\
ACA793ABA692ABA692ABA692AAA591A9A490A8A38FA6A18DA5A08CA49F8BA39E8A
A09B87A09B879E99859C97839A958198937F96917D95907C938E7A928D79918C78908B778E8975\
8D88748C87738B867289847088836F87826E86816D847F6B837E6A827D69817C68
7F7A667E79657D78647C77637A756179746078735F77725C77725C77735A767259767259757158\
747057747057736F56716D54716D54706C53706C536F6B526E6A516E6A516D6950
6E6A516D69506D69506C684F6B674E6B674E6A664D6A664D69654C69654C68644B68644B67634A\
66624966624965614867624E645F4B615C48605B47615C4866614D6B66526E6955
736E5A746F5B75705C76715D78735F7974607A75617B76627D78647E79657E79657F7A66807B67\
807B67817C68817C68817C6887826E807B67817C688B86727C77636F6A567E7966
807A6A7D77697B75677C76687F796B807A6C7E786A7B75677E786A7E786A7E786A7E786A7E786A\
7E786A7E786A7E786A7C76687C76687C76687C76687C76687C76687C76687C7668
6660524F493B726C5E7A7466756F61817B6D7872647B7869807C717B796D7C7A6E7E7C7079776B\
6F6D61706E6278766A757367747266747266737165727064727064716F63716F63
737165727064727064716F63706E62706E626F6D616F6D616F6D616E6C606E6C606D6B5F6C6A5E\
6C6A5E6B695D6B695D
97A1C497A1C496A0C3959FC2939DC0929CBF919BBE909ABD959FC2959FC2959FC2959FC2959FC2\
959FC2959FC2959FC2979FC3979FC3999FC3979FC3999FC3979FC3999FC3979FC3
9AA0C498A0C49BA1C599A1C59CA2C69BA3C79DA3C79BA5C8A4B5D3A1B4D2A3B4D2A5B6D4AAB9D6\
ABBBD5A9B7D2A5B3CDAEBAD2ACB8D0ADB8CEB0BBD1B4BCD1B3BBD0AEB4CAACAFBE
847F832B23207F7872958E88A09991A09991A49D93A9A298ACA69AACA69AADA799ADA799AEA898\
AFA999AFA999B0AA9AB0AA9CB0AA9CB0AA9CB0AA9CB0AA9CB0AA9CB0AA9CB0AA9C
AEA89AAEA89AAEA89AAEA89AAEA89AAEA89AAEA89AAEA898ACA794ACA793ACA793ABA692AAA591\
A9A490A9A490A9A490A8A38FA8A38FA7A28EA5A08CA49F8BA29D89A19C88A19C88
9E99859D98849C97839A958197927E95907C948F7B938E7A908B77908B778F8A768D88748C8773\
8A857189847089847087826E87826E86816D847F6B837E6A817C68807B67807B67
7D78647D78647C77637A756179746077725E76715D76715B76715B757158757158747057736F56\
736F56726E55726E55706C536F6B526F6B526E6A516D69506D69506C684F6C684F
6D69506C684F6C684F6B674E6A664D6A664D69654C69654C68644B67634A67634A666249656148\
65614864604764604766614D645F4B615C485F5A46615C4865604C6A65516E6955
726D59726D59736E5A75705C76715D78735F7974607974607C77637C77637D78647D78647E7965\
7F7A667F7A66807B67807B6786816D7F7A66807B678A85717B76626F6A567D7865
7F79697C76687A74667B75677E786A807A6C7D77697A74667D77697D77697D77697D77697D7769\
7D77697D77697D77697B75677B75677B75677B75677B75677B75677B75677B7567
645E504E483A716B5D797365746E60817B6D7872647C796A837F747E7C707E7C70807E7279776B\
6F6D616F6D61777569747266737165737165727064716F63716F63706E62706E62
727064716F63716F63706E626F6D616F6D616E6C606E6C606E6C606D6B5F6D6B5F6C6A5E6B695D\
6B695D6A685C6A685C
979DC1969CC0959BBF9399BD9298BC9096BA8F95B98E94B89298BC9298BC9298BC9298BC9298BC\
9298BC9298BC9298BC9298BC9298BC9397BC9298BC9397BC9298BC9397BC9298BC
9599BE949ABE9599BE959BBF979BC0979DC1989CC1959DC1A2B1D09EB1CFA1B2D0A4B5D3A9B8D5\
AABAD4A7B5D0A3B1CBACB8D0ABB7CFACB7CDAFBAD0B3BBD0B2BACFADB3C9ABAEBD
827D8129211E7D7670948D879E978F9F9890A29B91A8A197ABA599ABA599ABA597ACA698ADA797\
AEA898AEA898AEA898AEA89AAEA89AAEA89AAEA89AAEA89AAEA89AAEA89AAEA89A
ADA799ADA799ADA799ADA799ADA799ADA799ADA799ADA797ABA693AAA591AAA591A9A490A8A38F\
A8A38FA7A28EA7A28EA7A28EA6A18DA5A08CA39E8AA29D89A19C889F9A869F9A86
9C97839C97839A958198937F96917D938E7A928D79918C788F8A768E89758D88748B86728A8571\
89847087826E87826E86816D86816D85806C837E6A827D69807B677F7A667F7A66
7C77637C77637B766279746078735F76715D75705C75705A746F59747057747057736F56726E55\
716D54716D54716D546E6A516E6A516E6A516D69506C684F6B674E6B674E6B674E
6C684F6C684F6B674E6B674E6A664D69654C69654C68644B666249666249666249656148646047\
635F46635F46635F4665604C635E4A605B475F5A46605B47645F4B6A65516D6854
716C58716C58726D59746F5B75705C77725E78735F78735F7B76627B76627B76627C77637D7864\
7E79657E79657E7965807B6786816D7E7965807B678984707B76626E69557C7764
7F79697C76687973657B75677E786A7F796B7D77697A74667C76687C76687C76687C76687C7668\
7C76687C76687C76687A74667A74667A74667A74667A74667A74667A74667A7466
625C4E4C4638706A5C797365746E60817B6D7872647C796A7E7A6F79776B7A786C7D7B6F78766A\
6F6D61706E6278766A737165737165727064727064716F63706E62706E626F6D61
716F63716F63706E62706E626F6D616E6C606E6C606D6B5F6D6B5F6D6B5F6C6A5E6C6A5E6B695D\
6A685C6A685C69675B
9DA1C69CA0C59B9FC4999DC2979BC09599BE9498BD9397BC969ABF969ABF969ABF969ABF969ABF\
969ABF969ABF969ABF969ABF969ABF969ABF969ABF969ABF969ABF969ABF969ABF
989CC1989CC1999DC29A9EC39A9EC39B9FC49CA0C599A1C5A0AFCE9CAFCDA0B1CFA4B5D3A9B8D5\
A9B9D3A6B4CFA2B0CAACB8D0ABB7CFACB7CDAEB9CFB2BACFB1B9CEACB2C8AAADBC
817C8028201D7C756F938C869D968E9E978FA19A90A7A096AAA498AAA498ABA597ABA597ACA696\
ADA797ADA797AEA898AEA89AAEA89AAEA89AAEA89AAEA89AAEA89AAEA89AAEA89A
ACA698ACA698ACA698ACA698ACA698ACA698ACA698ACA696AAA592A9A490A9A490A8A38FA7A28E\
A7A28EA6A18DA6A18DA6A18DA5A08CA49F8BA39E8AA19C88A09B879F9A869E9985
9B96829B968299948097927E95907C938E7A918C78908B778E89758D88748C87738B8672898470\
88836F87826E86816D86816D85806C847F6B837E6A817C68807B677F7A667E7965
7C77637B76627A756179746077725E76715D75705C746F59746F59736F56736F56726E55716D54\
716D54706C53706C536E6A516D69506D69506C684F6B674E6B674E6A664D6A664D
6C684F6C684F6B674E6A664D6A664D69654C68644B68644B666249656148656148646047635F46\
635F46625E45625E4565604C635E4A605B475E5945605B47645F4B6964506D6854
706B57716C58726D59736E5A75705C76715D77725E78735F7A75617A75617B76627B76627C7763\
7D78647D78647E79657F7A6685806C7E79657F7A668984707A75616E69557C7764
7E78687B75677973657A74667D77697F796B7C76687A74667C76687C76687C76687C76687C7668\
7C76687C76687C76687A74667A74667A74667A74667A74667A74667A74667A7466
625C4E4C46386F695B787264746E60817B6D7872647C796A7773687371657573677A786C767468\
6F6D61716F637A786C737165737165727064716F63716F63706E626F6D616F6D61
716F63716F63706E626F6D616F6D616E6C606D6B5F6D6B5F6D6B5F6D6B5F6C6A5E6B695D6B695D\
6A685C69675B69675B
9698BE9698BE9698BE9698BE9698BE9698BE9698BE9698BE9193B99294BA9294BA9395BB9496BC\
9496BC9597BD9597BD9296BB9397BC9397BC9498BD9599BE9599BE969ABF969ABF
969ABF9599BE9599BE969ABF989CC19A9EC39DA1C69BA3C7A7B6D5A1B4D2A1B2D0A2B3D1A6B5D2\
A7B7D1A6B4CFA3B1CBA9B5CDAEBAD2AEB9CFAAB5CBAEB6CBB1B9CEACB2C8A4A7B6
807B7F2D2522817A74928B859D968EA49D95A8A197A7A096A49E92A49E92A59F91A6A092A6A090\
A7A191A8A292A8A292AAA496AAA496AAA496AAA496AAA496AAA496AAA496AAA496
AAA496AAA496AAA496AAA496AAA496AAA496AAA496AAA494A8A390A8A38FA7A28EA7A28EA6A18D\
A5A08CA5A08CA49F8BA29D89A19C88A09B879F9A869D98849C97839B96829A9581
96917D95907C948F7B938E7A918C78908B778F8A768E89758C87738C87738A857189847088836F\
86816D85806C847F6B827D69817C68807B677F7A667D78647C77637B76627A7561
78735F78735F77725E77725E76715D75705C75705C746F59726D57726E55716D54716D54706C53\
6F6B526F6B526E6A516E6A516E6A516D69506D69506C684F6B674E6B674E6A664D
6A664D6A664D69654C69654C68644B67634A67634A666249666249666249656148656148646047\
635F46635F46625E45605B475E59455B56425A55415C5743615C4866614D6A6551
6C67536D68546F6A56716C58736E5A75705C77725E78735F7A75617B76627B76627C77637D7864\
7D78647E79657E796578735F847F6B7C776377725E817C687A75616F6A56797461
7B75657872647670627872647C76687E786A7C76687A74667C76687C76687B75677A74667A7466\
7973657872647872647A74667A7466797365787264787264777163767062767062
635D4F4D4739716B5D7A7466736D5F7D7769716B5D7370616A665B6B695D6F6D61737165757367\
747266737165716F63737165737165727064716F63716F63706E626F6D616F6D61
6F6D616F6D616E6C606D6B5F6D6B5F6C6A5E6B695D6B695D6F6D616F6D616E6C606E6C606D6B5F\
6C6A5E6C6A5E6B695D
A7A9CFA7A9CFA7A9CFA7A9CFA7A9CFA7A9CFA7A9CFA7A9CFA5A7CDA5A7CDA6A8CEA6A8CEA7A9CF\
A8AAD0A8AAD0A8ACD1A8ACD1A8AED2A9ADD2A9AFD3ABAFD4AAB0D4ACB0D5ABB1D5
ADB1D6ABB1D5ABAFD4A9AFD3AAAED3ABB1D5ADB1D6ABB3D7A5B4D39FB2D09FB0CEA0B1CFA5B4D1\
A6B6D0A5B3CEA2B0CAA6B2CAABB7CFABB6CCA7B2C8AAB2C7AEB6CBA9AFC5A1A4B3
7D787C29211E7D76708E878199928AA09991A49D93A39C92A29C90A29C90A39D8FA39D8FA49E8E\
A59F8FA59F8FA6A090A8A294A8A294A8A294A8A294A8A294A8A294A8A294A8A294
A7A193A7A193A7A193A7A193A7A193A7A193A7A193A7A191A5A08DA5A08CA49F8BA49F8BA39E8A\
A29D89A29D89A19C889F9A869F9A869E99859C97839B968299948098937F98937F
938E7A938E7A928D79908B778F8A768D88748C87738C87738B86728A857189847088836F86816D\
85806C847F6B837E6A817C68817C687F7A667E79657D78647B76627A7561797460
77725E77725E77725E76715D75705C746F5B746F5B746F59716C56716D54716D54706C536F6B52\
6E6A516E6A516E6A516D69506D69506D69506C684F6B674E6A664D6A664D6A664D
69654C69654C69654C68644B67634A666249666249666249656148656148656148646047635F46\
625E45625E45625E45605B475E59455B56425A55415B5642605B4765604C696450
6C67536D68546E6955706B57736E5A75705C76715D77725E7A75617A75617A75617B76627C7763\
7D78647D78647D786478735F837E6A7B766276715D817C687A75616F6A56787360
7A74647872647670627872647C76687E786A7C76687973657C76687B75677B75677A7466797365\
7973657872647872647A7466797365797365787264777163777163767062767062
655F514E483A706A5C787264746E60827C6E7A74667F7C6D757166757367767468767468767468\
747266727064716F63737165727064727064716F63706E62706E626F6D616F6D61
6F6D616E6C606E6C606D6B5F6C6A5E6C6A5E6B695D6B695D6E6C606E6C606E6C606D6B5F6C6A5E\
6B695D6B695D6B695D
A8ACD1A8ACD1A8ACD1A8ACD1A8ACD1A8ACD1A8ACD1A8ACD1A8ACD1A8ACD1A9ADD2AAAED3AAAED3\
ABAFD4ACB0D5ACB0D5ADB3D7ACB4D8AEB4D8ADB5D9B0B6DAAEB6DAB1B7DBAFB7DB
B3B9DDB0B8DCB0B6DAADB5D9AEB4D8ACB4D8AFB5D9ADB7DAA5B6D4A0B3D19FB0CEA1B2D0A5B4D1\
A6B6D0A5B3CEA2B0CAA6B2CAAAB6CEABB6CCA6B1C7AAB2C7AEB6CBA9AFC5A0A3B2
797478261E1B7A736D8A837D958E869B948C9F988E9E978D9F998DA09A8EA09A8CA19B8DA29C8C\
A29C8CA39D8DA39D8DA59F91A59F91A59F91A59F91A59F91A59F91A59F91A59F91
A49E90A49E90A49E90A49E90A49E90A49E90A49E90A49E8EA29D8AA29D89A19C88A19C88A09B87\
9F9A869F9A869E99859C97839C97839B968299948098937F96917D95907C95907C
918C78908B778F8A768E89758C87738B86728A857189847089847088836F87826E85806C847F6B\
837E6A817C68817C687F7A667F7A667E79657C77637B766279746078735F78735F
76715D76715D75705C75705C746F5B736E5A736E5A726D57706B55706C536F6B526F6B526E6A51\
6D69506D69506C684F6C684F6C684F6B674E6B674E6A664D69654C69654C68644B
68644B68644B67634A67634A666249656148656148646047646047646047635F46635F46625E45\
615D44615D44605C435F5A465D584459544058533F5954405E5945635E4A66614D
6B66526B66526D68546F6A56716C58746F5B75705C76715D78735F7974607974607A75617B7662\
7B76627C77637C776377725E837E6A7B766276715D807B677974606E6955787360
7A7464777163756F617771637B75677D77697B75677973657B75677B75677A74667A7466797365\
787264787264777163797365797365787264787264777163767062767062756F61
5D5749453F31655F516C6658676153756F616F695B747162777368767468757367757367747266\
737165737165737165727064727064716F63716F63706E626F6D616F6D616E6C60
6E6C606E6C606D6B5F6D6B5F6C6A5E6B695D6B695D6A685C6D6B5F6D6B5F6C6A5E6C6A5E6B695D\
6A685C6A685C69675B
9CA0C59BA1C59CA0C59BA1C59CA0C59BA1C59CA0C59BA1C59EA2C79EA4C89FA3C89FA5C9A1A5CA\
A0A6CAA2A6CBA1A7CBA1A9CDA0AACDA1ABCEA1ABCEA2ACCFA3ADD0A3ADD0A4AED1
A5AFD2A4AED1A3ADD0A2ACCFA2ACCFA4AED1A5AFD2A4B1D3A3B4D29EB1CF9EAFCD9FB0CEA4B3D0\
A5B5CFA4B2CDA1AFC9A6B2CAABB7CFABB6CCA7B2C8AAB2C7AEB6CBA9AFC5A1A4B3
787377251D1A78716B89827C938C849891899C958B9B948A9F998D9F998D9F998BA09A8CA19B8B\
A29C8CA29C8CA29C8CA59F91A59F91A59F91A59F91A59F91A59F91A59F91A59F91
A39D8FA39D8FA39D8FA39D8FA39D8FA39D8FA39D8FA39D8DA19C89A19C88A09B879F9A869F9A86\
9E99859D98849D98849B96829A958199948098937F96917D95907C948F7B938E7A
908B77908B778F8A768D88748C87738A857189847089847085806C85806C847F6B827D69817C68\
7F7A667E79657E79657D78647C77637B76627A756178735F77725E76715D75705C
75705C746F5B746F5B736E5A726D59726D59716C58716C566F6A546E6A516E6A516D69506C684F\
6C684F6B674E6B674E6B674E6A664D6A664D69654C68644B68644B67634A67634A
67634A666249666249656148646047646047635F46635F46635F46625E45625E45615D44605C43\
605C435F5B425F5B425E59455B564258533F56513D57523E5B56425F5A46635E4A
6964506A65516C67536E6955706B57726D59746F5B75705C77725E77725E78735F78735F797460\
7A75617A75617B766277725E827D697A756175705C7F7A6678735F6E695577725F
797363767062756F617670627A74667C76687B75677872647A74667A7466797365797365787264\
777163777163767062787264787264777163777163767062756F61756F61746E60
6A6456534D3F736D5F797365716B5D7B7567716B5D747162706C616F6D616F6D61706E62716F63\
737165747266757367716F63716F63706E62706E626F6D616E6C606E6C606D6B5F
6D6B5F6D6B5F6C6A5E6C6A5E6B695D6A685C6A685C69675B6C6A5E6B695D6B695D6A685C69675B\
69675B68665A68665A
9197BB8F97BB9197BB8F97BB9197BB8F97BB9197BB8F97BB9399BD929ABE949ABE939BBF969CC0\
949CC0979DC1959DC1919EC0919EC0929FC193A0C293A0C294A1C395A2C495A2C4
94A1C394A1C394A1C396A3C598A5C79CA9CB9FACCEA0AFD09BACCA96A9C796A7C597A8C69CABC8\
9DADC79CAAC599A7C1A0ACC4A5B1C9A5B0C6A1ACC2A4ACC1A8B0C5A3A9BF9B9EAD
797478251D1A78716B88817B928B839790889A93899992889E988C9E988C9F998BA09A8CA09A8A\
A19B8BA29C8CA29C8CA49E90A49E90A49E90A49E90A49E90A49E90A49E90A49E90
A29C8EA29C8EA29C8EA29C8EA29C8EA29C8EA29C8EA29C8CA09B889F9A869F9A869E99859D9884\
9D98849C97839C978399948099948098937F96917D95907C938E7A928D79928D79
908B778F8A768E89758D88748B86728A857189847088836F827D69827D69817C687F7A667E7965\
7C77637B76627B76627B76627A756179746078735F76715D75705C746F5B736E5A
736E5A736E5A726D59726D59716C58706B57706B576F6A546D68526D69506C684F6C684F6B674E\
6A664D6A664D69654C69654C69654C68644B68644B67634A666249666249656148
656148656148646047646047635F46625E45625E45615D44615D44615D44605C43605C435F5B42\
5E5A415E5A415D59405C57435A554156513D544F3B544F3B57523E5C57435F5A46
67624E68634F6A65516C67536E6955706B57726D59736E5A75705C76715D76715D77725E78735F\
78735F79746079746076715D817C68797460746F5B7E796577725E6D685476715E
787262756F61746E607670627A74667B75677A74667771637A7466797365797365787264777163\
777163767062767062787264777163777163767062756F61756F61746E60746E60
5F594B4A44366E685A7670626F695B767062686254686556716D62716F63716F63727064727064\
727064727064727064716F63706E62706E626F6D616E6C606E6C606D6B5F6D6B5F
6D6B5F6C6A5E6C6A5E6B695D6A685C6A685C69675B69675B6A685C6A685C69675B69675B68665A\
676559676559666458
838BAF828CAF838BAF828CAF838BAF828CAF838BAF828CAF858DB1848EB1868EB28690B3878FB3\
8791B48991B58892B58392B38292B38392B38393B48594B58595B68695B68595B6
8493B48494B58695B68898B98C9BBC90A0C195A4C596A6C792A5C38FA2C08FA0BE90A1BF94A3C0\
95A5BF94A2BD919FB997A3BB9CA8C09CA7BD98A3B99CA4B9A0A8BD9BA1B79295A4
787377241C1977706A867F79908981958E86979086968F859B95899B95899C96889C96889D9787\
9E98889E98889F9989A19B8DA19B8DA19B8DA19B8DA19B8DA19B8DA19B8DA19B8D
9D97899D97899D97899D97899D97899D97899D97899D97879B96839B96829B96829A9581999480\
98937F98937F98937F95907C95907C948F7B928D79918C788F8A768E89758E8975
8C87738C87738B867289847088836F86816D85806C85806C7F7A667F7A667D78647C77637B7662\
79746078735F77725E78735F78735F77725E75705C746F5B726D59716C58716C58
726D59716C58716C58706B576F6A566F6A566E69556E69536C67516B674E6B674E6A664D69654C\
69654C68644B68644B68644B67634A67634A666249656148656148646047646047
646047635F46635F46625E45615D44615D44605C43605C43605C435F5B425F5B425E5A415D5940\
5D59405C583F5C583F5B564258533F544F3B524D39524D3955503C5954405C5743
66614D67624E68634F6B66526D68546F6A56716C58716C58746F5B746F5B75705C75705C76715D\
77725E77725E78735F75705C807B6778735F736E5A7E796577725E6C675375705D
777161756F61736D5F756F617973657B7567797365767062797365787264787264777163767062\
767062756F61756F61777163767062767062756F61746E60746E60736D5F736D5F
5E584A4943356D6759756F616E685A7771636A64566B6859736F64737165757367767468757367\
7270646E6C606B695D706E626F6D616F6D616E6C606D6B5F6D6B5F6C6A5E6C6A5E
6C6A5E6B695D6B695D6A685C69675B69675B68665A68665A69675B68665A68665A676559666458\
666458656357656357
848EB1828FB1848EB1828FB1848EB1828FB1848EB1828FB1858FB28390B2858FB28491B38791B4\
8693B58892B58693B58494B58295B58595B68497B78696B78598B88898B98699B9
8797B88598B88898B9879ABA8C9CBD8EA1C193A3C493A6C696A9C793A6C493A4C294A5C398A7C4\
99A9C398A6C195A3BD97A3BB9CA8C09CA7BD98A3B99BA3B89FA7BC9AA0B69295A4
746F73201815736C66827B758B847C908981938C82918A80958F83958F83958F81969082979181\
9892829892829892829A94869A94869A94869A94869A94869A94869A94869A9486
97918397918397918397918397918397918397918397918195907D948F7B948F7B938E7A928D79\
928D79918C78918C788F8A768E89758D88748B86728A857189847087826E87826E
86816D86816D85806C837E6A827D69807B677F7A667F7A667D78647C77637B76627A756178735F\
77725E76715D75705C77725E76715D75705C736E5A726D59716C586F6A566F6A56
706B57706B57706B576F6A566E69556D68546D68546D68526A654F6A664D6A664D69654C68644B\
67634A67634A67634A666249666249666249656148646047635F46635F46635F46
625E45625E45625E45615D44605C435F5B425F5B425F5B425E5A415E5A415E5A415D59405C583F\
5B573E5B573E5B573E5A554157523E534E3A504B37504B37524D3956513D595440
65604C66614D67624E6964506C67536E69556F6A56706B57736E5A736E5A736E5A746F5B75705C\
76715D76715D76715D75705C807B6778735F736E5A7D786476715D6B665275705D
777161746E60726C5E746E607872647A7466787264767062787264787264777163777163767062\
756F61756F61746E60767062767062756F61756F61746E60736D5F736D5F726C5E
736D5F585244726C5E726C5E6660526F695B6660526966575E5A4F6260546A685C716F63737165\
716F636D6B5F6A685C6F6D616F6D616E6C606E6C606D6B5F6C6A5E6C6A5E6B695D
6B695D6B695D6A685C6A685C69675B68665A68665A676559676559676559676559666458656357\
646256646256646256
93A0C393A0C293A0C393A0C293A0C393A0C293A0C393A0C293A0C393A0C294A1C495A2C495A2C5\
96A3C597A4C796A5C697A7C997A7C898A8CA99A9CA99A9CB9AAACB9BABCD9BABCC
9CACCE9BABCC9BABCD9BABCC9CACCE9EAECFA1B1D3A2B2D3A3B2CFA0B0CA9FADC8A0AEC9A5B1CB\
A6B2CCA4B0C8A2ADC39EA9BFA2ADC3A4ACC19FA7BCA2A9BCA6ADC0A0A7BA999BAA
716D6E1D16107069637F78728780788C857D8E877D8D867C8F887E908A7E908A7E918B7F928C7E\
928C7E938D7F938D7F958F81958F7F958F81958F7F958F81958F7F958F81958F7F
918B7D918B7B918B7D918B7B918B7D918B7B918B7D918B7B8F8A768F8A748E89758E89738D8874\
8C87718C87738B867089847088836D87826E86816B847F6B837E68827D69817C68
817C68817C68807B677E79657D78647B76627A75617A75617C77637B76627A756178735F77725E\
76715D746F5B746F5B76715D75705C746F5B736E5A716C58706B576F6A566E6955
706B576F6A566F6A566E69556D68546D68546C67536C67516A654F69654C69654C68644B67634A\
67634A666249666249666249656148656148646047635F46635F46625E45625E45
625E45615D44615D44605C435F5B425F5B425E5A415E5A415E5A415D59405D59405C583F5B573E\
5B573E5A563D5A563D5A553F57523E524D394F4A364F4A36514C3855503C58533F
645F4B65604C67624E6964506B66526D68546F6A56706B57726D59726D59736E5A736E5A746F5B\
75705C75705C76715D746F5B7F7A6677725E726D597D786476715D6B6652746F5C
767060746E5E726C5C746E5E7872627A7464787262756F5F787262787262777161767060767060\
756F5F746E5E746E5E767062767062756F61746E60746E60736D5F726C5E726C5E
504A3C2E281C3D372B322C201F190D2721151E180C2420153F3D3147473D55554B6363576C6C60\
716F636F6D616D6B5F6F6D616F6D616E6C606E6A5E6E6A5E6D695D6C685C6C685C
6C685D6B695D6B675C69675B6A665B68665A686459676559686459666458676358656357656156\
646256646055636155
8692B88693B68793B98895B88995BB8A97BA8B97BD8C99BC8D99BF8D9ABD8E9AC08F9CBF909CC2\
919EC1929EC493A0C3909EC3909EC1919FC4919FC292A0C593A1C493A1C694A2C5
97A5CA97A5C897A5CA98A6C999A7CC9AA8CB9AA8CD9BA8C89CA3BD9EA5B89EA5B89FA6B9A0A7BA\
A0A7BAA1A8BBA2A7BA9FA4B7A1A6B9A3A8BBA4A9BCA1A6B99CA1B4979CAF9898A4
6B6565322922635A53857C75756C65887F788D847D8077708E857E8F867D8F867D90877E91887F\
91887F928980928A7F948D7D948D7B948D7D948D7B948D7D948D7B948D7D948D7B
928B7B928B79918A7A918A789089798F88768F88788E8775908A74908A728F89738F89718E8872\
8D876F8D87718C866E88826C88826A87816B87816986806A857F67857F69847E68
847F69837E68827D67807B657E79637C77617B76607A755F79745E79745E78735D77725C77725C\
76715B75705A75705A716C56716C56706B556F6A546F6A546E69536D68526D6852
69644E68634D68634D67624C66614B66614B65604A65604A67624C66614B66614B65604A645F49\
645F49635E48635E48625D47625D47625D47615C46605B455F5A445F5A445F5B42
5E5A415E5A3F5E5A3F5D593E5C583D5B573C5B573C5B573C5A563B5A563B5A563B59553A585439\
57533857533857533A504B3555503C58533F524D394A45314A4531544F3B5F5A46
615C48625D49645F4B67624E6A65516D68546F6A56706B576D68546E6955716C58736E5A75705C\
75705C75705C746F5B797460746F5B746F5B7A756178735F706B576D6854726D59
75705D726D5A706B58726D5A76715E78736076715E746F5C746F5C746F5C746F5C746F5C746F5C\
746F5C746F5C746F5C7973636B6555726C5C7771616A64566D6759797367756F63
5751452D261C2F281E3932281D160E171008251E1819140E26261E3A3B3354554D64665B66685D\
64645A66645868665A6E6A5E6E6A5E6E6A5E706A5C706A5C706A5C706A5C706A5C
6E685C6C685D6D665C6A665B6C655B69655A6A63596864596A6359686459696258676358686157\
656156676056646055
7782A27782A27883A37883A37984A47984A47984A47A85A5737E9E737E9E737E9E747F9F747F9F\
7580A07580A07580A0737E9E747F9F747F9F7580A07681A17681A17782A27782A2
7681A17681A17782A27782A27883A37984A47984A47B84A17B80947D808F7E81907F82917F8291\
808392818493818493898C9B8B8E9D8E91A08F92A18D909F898C9B85889785858F
645F5C312821615851827972776E678C837C918881887F78887F78887F78887F788980798A817A\
8B827B8B827B8B82798D86768D86748D86748D86748D86748D86748D86748D8674
8B84728B84728B84728A837189827088816F88816F88816E89836D89836B89836B88826A878169\
868068868068868068827C64817B63817B63807A627F79617F79617E78607E7860
7D78627D78627B76607A755F78735D76715B75705A75705A736E58736E58726D57726D57716C56\
706B55706B556F6A546C67516B66506B66506A654F69644E69644E68634D68634D
68634D68634D67624C67624C66614B65604A65604A645F4966614B66614B65604A65604A645F49\
635E48635E48625D47625D47625D47615C46615C46605B455F5A445F5A445E5943
5C583F5C583D5B573C5B573C5A563B59553A59553A585439585439585439575338575338565237\
5551365551365450374F4A34534E3A534E3A4D483445402C46412D514C385C5743
605B47615C48635E4A66614D6964506C67536E69556F6A566C67536E6955706B57726D59746F5B\
746F5B746F5B746F5B797460736E5A736E5A79746077725E6F6A566D6854716C58
746F5B716C58706B57726D5975705C77725E76715D736E5A746F5B746F5B746F5B746F5B746F5B\
746F5B746F5B746F5B7A74646B6555716B5B7771616D6759706A5C756F63696357
30291F322B214E473F60595148413B2B241E1E1613130E0A14150F2528213F423955584F63655A\
686A5F6E6C60706E626E6A5E6E6A5E706A5C706A5C716A5A716A5A716A5A71695C
6E685C6D665C6D665C6C655B6B645A6B645A6A63596A6359696258696258696258686157676056\
665F55665F55665F55
6A758B6A758B6A758B6A758B69748A69748A68738968738979849A788399788399788399778298\
7782987681977681977F8AA07F8AA0808BA1818CA2818CA2828DA3838EA4838EA4
808BA1818CA2818CA2828DA3838EA4838EA4848FA5868EA1858B99878B97888C98898D99898D99\
8A8E9A8B8F9B8B8F9B8E929E9094A09296A29498A49498A49296A28F939F909098
534E4B2A211A554C456F665F6960597E756E8077707C736C827972827972827972837A73847B74\
857C75857C75857C7388817188816F88816F88816F88816F88816F88816F88816F
857E6C857E6C857E6C847D6B837C6A827B69827B69827B68837D67837D67837D67827C66817B65\
807A64807A64807A647C76607C76607B755F7B755F7A745E79735D79735D78725C
78735F77725E76715D75705C736E5A726D59716C58716C58706B576F6A566F6A566E69556D6854\
6D68546C67536C675369645068634F68634F67624E66614D66614D65604C65604C
66614D65604C65604C645F4B635E4A635E4A625D49625D49645F4B635E4A635E4A625D49615C48\
615C48605B47605B47605B47605B47605B475F5A465E59455D58445D58445D5842
59553C59553C58543B57533A57533A565239555138555138555138555138545037534F36534F36\
524E35514D34514D344F4A344F4A364D483446412D403B27423D294D483457523E
5E59455F5A46615C48645F4B67624E6A65516C67536D68546B66526C67536F6A56716C58736E5A\
736E5A736E5A736E5A78735F726D59726D5978735F76715D6E69556B6652706B57
736E5A706B576E6955706B57746F5B76715D75705C726D59736E5A736E5A736E5A736E5A736E5A\
736E5A736E5A736E5A7B75656B65556F6959777161716B5D746E606F695D565044
20190F4B443A7069617E776F6E67613D3630160E0B120D090A0B05141710292C2343463D5B5D52\
696B606F6D616E6C606C685C6C685C6E685A6E685A6F68586F68586F68586F675A
6D675B6D665C6C655B6C655B6B645A6A63596A6359696258686157686157676056676056665F55\
655E54655E54645D53
3E46513E46513D45503C444F3B434E3A424D39414C38404B363E49353D48353D48333B46323A45\
313944303843303843262E39262E39272F3A28303B28303B29313C2A323D2A323D
29313C29313C29313C2A323D2B333E2C343F2C343F2D343E2D313C2E323B2E323B2F333C30343D\
30343D31353E31353E2A2E372C30392E323B31353E31353E31353E30343D323338
504B48332A23574E47675E57655C55786F68746B64766D667D746D7D746D7E756E7F766F7F766F\
80777081787181786F837B6E837C6A837C6C837C6A837C6C837C6A837C6C837C6A
817A6A817A688079697F78667F78687E77657D76667D76647F78657F79637E77647D77617D7663\
7C76607B74617B755F78715E78725C78715E77715B766F5C756F59756E5B756E5B
746F5B736E5A736E5A726D59716C58706B576F6A566F6A566E69556E69556D68546D68546C6753\
6B66526B66526A655168634F67624E67624E66614D65604C65604C645F4B645F4B
615C48615C48605B47605B475F5A465E59455E59455D58445F5A465F5A465E59455E59455D5844\
5C57435C57435B56425D58445C57435C57435B56425A55415A5541595440595440
57523C57533A565239555138555138545037534F36534F36534F36534F36524E35514D34514D34\
504C334F4B324F4A344F4A364E4935494430423D293D3824403B274A4531534E3A
5C57435D58445F5A46625D4965604C68634F6A65516B66526964506B66526D6854706B57716C58\
726D59716C58716C5876715D706B57716C5876715D75705C6C67536A65516E6955
716C586F6A566D68546F6A56736E5A75705C736E5A706B57726D59726D59726D59726D59726D59\
726D59726D59726D597A74646A64546E6858767060746E60777163686256433D31
3A33296E675D8079717B746C78716B49423C19110E18130F11120C12150E1E2118363930515348\
6264596765596361556B675B6B675B6D67596D67596E67576E67576E67576E6659
6C665A6C655B6B645A6B645A6A6359696258696258686157676056665F55665F55655E54645D53\
645D53635C52635C52
2C32322C32322B31312A3030292F2F282E2E272D2D262C2C383E3E383E3E373D3D363C3C353B3B\
3339393339393238382E34342F35352F3535303636313737313737323838323838
2F35352F353530363631373731373732383833393933393933363B33363B33363B34373C35383D\
36393E36393E36393E34373C35383D373A3F393C413A3D423B3E433B3E433D3E40
4C47443C352F5A534D615A5467605A7B746E736C667D7670736C66746D67746D67756E68766F69\
766F6977706A777068797367797363797365797363797365797363797365797363
777163777161767062767060756F61746E5E746E60736D5D75705D75705C746F5C746F5B736E5B\
726D59726D5A716C58706B586F6A566F6A576E69556D68556D68546C67546C6754
6C67546B66536B66536A65526A655269645169645169645169645169645168635067624F67624F\
66614E65604D65604D635E4B635E4B635E4B625D4A615C49605B48605B48605B48
5E59465D58455D58455C57445B56435B56435A55425A55425C57445B56435B56435A5542595441\
5954415853405853405A55425A554259544158534058534057523F56513E56513D
58533D57523C57523C56513B55503A55503A544F39544F39544F39534E38534E38524D37514C36\
514C36504B35504B35534E3A504B374A4531443F2B413C28443F2B4B4632514C38
5954405A55415C57435F5A46625D4965604C67624E68634F68634F6964506C67536E6955706B57\
706B57706B576F6A56746F5B6F6A566F6A5675705C736E5A6B665268634F6D6854
706B576D68546B66526D6854716C58736E5A716C586F6A56726D59726D59726D59726D59726D59\
726D59726D59726D597670606A64546E6858746E5E736D5F777163625C50352F23
514A407B746A7C756D7069617A736D5D56502A221F1C171316171112150E181B122C2F26484A3F\
5B5D526260545E5C506965596965596B65576B65576C65556C65556C65556C6457
6C665A6B645A6B645A6A6359696258696258686157686157655E54655E54645D53645D53635C52\
625B51625B51615A50
2E302B2E302B2D2F2A2D2F2A2D2F2A2C2E292C2E292C2E2920221D1F211C1F211C1F211C1E201B\
1E201B1D1F1A1D1F1A252722262823262823272924282A25282A25292B26292B26
242621242621252722262823262823272924282A25282A27252928262A2B262A2B272B2C282C2D\
282C2D292D2E292D2E292D2E292D2E2A2E2F2B2F302C30312D31322E3233323232
302C292D2620463F3947403A544D4769625C5E57517069636B645E6C655F6C655F6D66606E6761\
6E67616F68626F6860716A60716B5F716B5F716B5F716B5F716B5F716B5F716B5F
6F695D6F695D6E685C6E685C6D675B6C665A6C665A6B65576D67576D68556C66566C67546B6555\
6A65526A645469645168625268635067615167624F66605065604D655F4F645F4C
645F4C645F4C645F4C645F4C635E4B635E4B635E4B635E4B645F4C645F4C635E4B625D4A625D4A\
615C49605B48605B485F5A475F5A475E59465D58455D58455C57445B56435B5643
5E59465E59465E59465D58455C57445B56435B56435B56435C57445C57445C57445B56435A5542\
5954415954415954415C57445B56435B56435A5542595441595441585340585340
5B56425B56405A553F5A553F59543E58533D58533D57523C57523C57523C56513B56513B55503A\
544F39544F39534E3857523E544F3B504B374C47334A45314B46324E4935514C38
57523E58533F5A55415D5844605B47635E4A65604C66614D66614D68634F6A65516D68546E6955\
6E69556E69556E6955736E5A6D68546D6854736E5A726D5969645067624E6B6652
6E69556B66526A65516C6753706B57726D59706B576D6854716C58716C58716C58716C58716C58\
716C58716C58716C58706A5A696353706A5A726C5C6E685A746E605F594D2E281C
514A4070695F777068736C647F7872746D67453D3A1A151111120C0D100911140B23261D3E4035\
55574C6260546361556864586864586A64566A64566B64546B64546B64546B6356
6B65596A63596A6359696258686157686157676056676056645D53635C52635C52625B51615A50\
615A5060594F60594F
22231D23241E23241E23241E24251F24251F2526202526202E2F292E2F292E2F292F302A2F302A\
30312B30312B30312B22231D23241E23241E24251F252620252620262721262721
272822282923282923292A242A2B252A2B252B2C262B2C272A2C292A2C2B2B2D2C2C2E2D2C2E2D\
2D2F2E2E302F2E302F2D2F2E2D2F2E2C2E2D2C2E2D2D2F2E2E302F2F313031312F
3834313B36324D4844433E3A524D49635E5A524D4968635F6B66626B66626C67636C67636D6864\
6E69656E69656F6A64716D64716D62716D62716D62716D62716D62716D62716D62
6F6B606E6A5F6E6A5F6D695E6C685D6C685D6B675C6B675C6D6A5B6C69586C695A6B68576A6758\
6A6756696657696655696657686554686556676453666354666352656253656251
666050666050666050666050666050676151676151676151686252676151676151666050655F4F\
655F4F645E4E645E4E645E4E635D4D635D4D625C4C615B4B615B4B605A4A605A4A
645E4E635D4D635D4D625C4C615B4B615B4B605A4A605A4A625C4C615B4B615B4B605A4A5F5949\
5F59495E58485E5848615B4B615B4B605A4A605A4A5F59495E58485E58485D5845
605B475F5A465F5A465E59455D58445D58445C57435C57435C57435B56425B56425A5541595440\
59544058533F58533F5C57435A554157523E56513D55503C55503C534E3A524D39
55503C56513D58533F5B56425E5945615C48635E4A645F4B65604C67624E6964506B66526D6854\
6D68546D68546D6854726D596C67536C6753726D59706B5768634F66614D6A6551
6D68546A65516964506B66526E6955706B576F6A566C6753706B57706B57706B57706B57706B57\
706B57706B57706B576A6454696353726C5C706A5A6963556F695B5D574B2E281C
5750466861577A736B7A736B77706A7C756F5B53501A15110E0F090B0E070E11081C1F1634362B\
4A4C415D5B4F636155666256666256686254686254696252696252696252696154
6A64586A6359696258696258686157676056676056665F55625B51625B51625B51615A5060594F\
5F584E5F584E5F584E
41403E41403E42413F4342404443414544424645434746444F4E4C504F4D51504E52514F535250\
545351555452555452545351545351555452565553565553575654585755585755
636260636260646361656462656462666563676664676664666664656764676765676966686866\
686A676A6A68696B6870706E6E706D6E6E6C6C6E6B6D6D6B6C6E6B6F6F6D70716C
6D6966726D697D78756A656175706D807B776964617F7A76726D6A736E6A736E6B746F6B75706D\
75706C76716E76716D78736D78746B78736D78746B78736D78746B78736D78746B
76716B76726975706A757168746F69736F66736E68726E65747064747064736F63736F63726E62\
716D61716D61706C60706C60706C606F6B5F6F6B5F6E6A5E6D695D6D695D6C695A
6D67596E68586E68586E68586F69596F69596F69596F6959716B5B706A5A706A5A6F69596E6858\
6E68586D67576D67576D67576C66566C66566B65556A64546A6454696353696353
686252686252686252676151666050655F4F655F4F655F4F666050666050666050655F4F645E4E\
635D4D635D4D635D4D676151666050666050655F4F645E4E645E4E635D4D635D4D
635E4B625D49625D49615C48605B47605B475F5A465F5A465F5A465E59455E59455D58445C5743\
5C57435B56425B5642605B475E59455D58445D58445D58445B564257523E534E3A
544F3B55503C57523E5A55415D5844605B47625D49635E4A645F4B66614D68634F6B66526C6753\
6D68546C67536C6753716C586B66526C6753716C58706B5767624E65604C696450
6C67536A655168634F6A65516E6955706B576E69556B6652706B57706B57706B57706B57706B57\
706B57706B57706B57666050696353736D5D6F6959655F516C66585C564A2F291D
6760566C655B817A727B746C67605A766F69665E5B1E191510110B0D10090F1209181B122B2D22\
3F41365452465D5B4F666256666256686254686254696252696252696252696154
6A64586A6359696258686157686157676056665F55665F55625B51615A50615A5060594F5F584E\
5F584E5E574D5E574D
56515756515757525857525858535959545A59545A5A555B605B61615C62615C62625D63635E64\
635E64645F65645F65625D63625D63635E64645F65645F65656066666167666167
6B666C6B666C6C676D6C676D6D686E6E696F6E696F6D6B6E807F7D7475706C6B676A6B666C6B67\
6B6C676F6E6A73746F7A79756D6E696564606768636E6D696F706B706F6B706F6B
74706D75716E76727177737077737275716E74706F736F6C76727176726F767271777370787473\
7975727975747975727A77727A77707A77727A77707A77727A77707A77727A7770
75726D75726B75726D75726B75726D75726B75726D75726B7A776E79776B78766A777569767468\
757367747266747266727064727064716F63716F63716F63706E62706E62716D62
7A7466605A4C878173686254716B5D635D4F7670626D6759746E60746E60736D5F726C5E726C5E\
716B5D706A5C706A5C706A5C6F695B6F695B6E685A6D67596D67596C66586C6658
6C66586C66586B65576A64566A64566963556862546862546A64566A64566A64566A64566A6456\
6A64566A64566A6456686254676153676153666052655F51655F51645E50645E4E
66614E66614E65604D645F4C645F4C635E4B625D4A625D4A645F4C645F4C645F4C645F4C645F4C\
645F4C645F4C645F4C5E59455E59455E59455E59455E59455E59455E59455E5945
55503C56513D57523E5954405B56425C57435E59455E5945625D49635E4A645F4B65604C67624E\
68634F6964506A6551726D596D68546D6854726D59706B5767624E65604C696450
6B665268634F66614D68634F6C67536E69556C67536A65516C67536C67536C67536C67536C6753\
6C67536C67536C67536D67576F69596E68586B65556D6759676153504A3E373125
655E54655E54625B53665F5778716B7D76705A524F2A25210D0E0811140D11140B12150C222419\
3E40355755495F5D51615D51625E52666052676153696252696252686151675F52
686256686157676056676056665F55655E54655E54645D53645D53645D53635C52635C52625B51\
615A50615A5060594F
69636F69636F6A64706A64706B65716C66726C66726D67736A64706A64706B65716B65716C6672\
6D67736D67736E68746C66726C66726D67736E68746E68746F6975706A76706A76
6F69756F69756F6975706A76716B77726C78726C78726D7469676871706C787773797874797874\
7B7A767D7C787C7B7771706C79787481807C807F7B777672706F6B73726E7B7A76
71706E7372707874737978767D79787B7A787D79787B7A787C78777A79777D79787B7A787E7A79\
7D7C7A7F7B7A7E7D7B7D79767B7A757D79767B7A757D79767B7A757D79767B7A75
7E7A777C7B767E7A777C7B767E7A777C7B767E7A777C7B76807D767D7D737F7C757C7C727D7A73\
7A7A707B787179796F79766F77776D78756E75756B76736C73736975726B747168
7B776B605A4C756F61635D4F7D7769797365888274787264746E60746E60736D5F726C5E726C5E\
716B5D706A5C706A5C716B5D716B5D706A5C6F695B6F695B6E685A6D67596D6759
6C66586C66586B65576B65576A64566963556963556862546A64566A64566A64566A64566A6456\
6A64566A64566A64566C66586C66586B65576B65576A6456696355696355686254
66605066614E65604D65604D645F4C635E4B635E4B625D4A645F4C645F4C645F4C645F4C645F4C\
645F4C645F4C645F4C5F5A465F5A465F5A465F5A465F5A465F5A465F5A465F5A46
5C57435C57435B56425B56425A55415A5541595440595440605B47615C48625D49645F4B66614D\
68634F6A65516A65516F6A566964506964506E69556D6854645F4B615C4866614D
6A655167624E66614D68634F6B66526D68546C67536964506C67536C67536C67536C67536C6753\
6C67536C67536C67536C66566E68586D67576B65556D6759676153504A3E373125
575046736C62756E665E574F625B5577706A665E5B37322E0C0D070F120B0F120910130A202217\
3C3E335553475C5A4E605C50615D51655F51676153696252686151676050675F52
676155676056676056665F55655E54645D53645D53645D53635C52635C52635C52625B51615A50\
60594F60594F60594F
6A66746A66746B67756C68766C68766D69776E6A786E6A786E6A786E6A786E6A786F6B79706C7A\
716D7B716D7B716D7B706C7A716D7B716D7B726E7C736F7D736F7D74707E74707E
706C7A716D7B716D7B726E7C736F7D736F7D74707E74717A6863677B7776827E7D787473736F6E\
7975747A7675726E6D736F6E7773727B77767A7675777372777372797574797876
7C7A7B7C7C7C7F7D7E808080828081818181817F808080807D7B7C7D7D7D7E7C7D7E7E7E807E7F\
7F7F7F817F8080807E807F7D7F807B807F7D7F807B807F7D7F807B807F7D7F807B
7D7C7A7C7D787D7C7A7C7D787D7C7A7C7D787D7C7A7C7D787D7C777B7C747C7B767A7B737B7A75\
797A727A797478797179787377787077767174756D73726D7071696F6E696F6F67
7B776C767064807A6E726C607B75696660546B65595D574B746E62746E62736D61726C60726C60\
716B5F706A5E706A5E736D61736D61726C60716B5F716B5F706A5E6F695D6F695D
6D675B6C665A6C665A6B65596A64586A64586963576963576A64586A64586A64586A64586A6458\
6A64586A64586A64586C665A6C665A6B65596B65596A6458696357696357686254
676151666050666050655F4F645E4E645E4E635D4D635D4D645E4E645E4E645E4E645E4E645E4E\
645E4E645E4E645F4C625D49625D49625D49625D49625D49625D49625D49625D49
635E4A625D49605B475D58445A554158533F56513D544F3B5D58445E5945605B47625D4965604C\
67624E6964506A65516A6551645F4B65604C6A6551696450615C485E5945635E4A
69645066614D645F4B66614D6A65516C67536B665268634F6A65516A65516A65516A65516A6551\
6A65516A65516A65516B65556D67576C66566A64546C6658676153504A3E373125
534C4270695F686159463F37554E488079736F6764322D290A0B050E110A0D10070E11081E2015\
393B3052504459574B5F5B4F605C50645E50666052676050676050665F4F665E51
666054665F55655E54655E54645D53635C52635C52625B51625B51625B51615A50615A5060594F\
5F584E5F584E5E574D
64606E64626F65616F6563706763716664716864726765726B67756A68756C68766B69766D6977\
6D6B786E6A786E6C796E6A786E6C796F6B796F6D7A716D7B706E7B726E7C716F7C
716D7B706E7B726E7C716F7C736F7D73717E74707E75727B736E72807C7B7D797A6C68676B6768\
7A76757D797A706C6B8884857B77766A6667656160706C6D7B7776757172686465
6161616161616060605F5F5F5C5C5C595959555555535353525252525252525252535353545454\
5555555555555555555A5A5A5A5A585A5A5A5A5A585A5A5A5A5A585A5A5A5A5A58
575757575755575757575755575757575755575757575755585954585953575853575852575853\
57585257585357585257585356575154555051524C4F504B4C4D474A4B464A4A42
3531265D574B6C665A7670647C766A6761557872667E786C746E62746E62736D61726C60726C60\
716B5F706A5E706A5E746E62746E62736D61736D61726C60716B5F716B5F706A5E
6E685C6D675B6D675B6C665A6B65596B65596A64586A64586A64586A64586A64586A64586A6458\
6A64586A64586A6458686256676155676155666054655F53655F53645E52645E52
686254676151676151666050655F4F655F4F645E4E645E4E645E4E645E4E645E4E645E4E645E4E\
645E4E645E4E645E4E645F4C645F4B645F4B645F4B645F4B645F4B645F4B645F4B
645F4B635E4A615C485F5A465C574359544057523E56513D5A55415B56425D5844605B47635E4A\
65604C67624E69645068634F625D49635E4A69645068634F605B475E5945635E4A
67624E65604C635E4A65604C6964506B665269645066614D696450696450696450696450696450\
6964506964506964506963536B65556B65556963536C6658676153514B3F383226
665F5560594F4740383F38306D66609A938D78706D2F2A26090A040C0F080C0F060C0F061B1D12\
37392E4F4D415654485D594D5F5B4F625C4E645E50665F4F665F4F655E4E645C4F
655F53645D53645D53635C52625B51625B51615A50615A50615A5060594F60594F5F584E5E574D\
5E574D5D564C5D564C
66656B65666B66656B66676C68676D68696E69686E68696E67666C66676C68676D68696E69686E\
696A6F6B6A706A6B706B6A706B6C716C6B716C6D726E6D736D6E736F6E746E6F74
6D6C726C6D726E6D736E6F746F6E746F7075717076717076716C70797375777175716B6D797377\
888284847E82736D6F6862666E686A6D676B676163686266706A6C6C666A605B5F
6161636061635F60625E5F615B5C5E58595B5455575253554F5052505153505153515254525355\
52535553545653545658595B585A5958595B585A5958595B585A5958595B585A59
606163606261606163606261606163606261606163606261636562636560636562636560636562\
6466616466636466616567646466616264615F615C5D5F5C5A5C57585A57585953
605C53837C725D564C6D665C7B746A6F685E7A73697F786E746D63746D63736C62726B61726B61\
716A6070695F70695F746D63746D63736C62736C62726B61716A60716A6070695F
6E675D6E675D6D665C6D665C6C655B6B645A6B645A6A63596A63596A63596A63596A63596A6359\
6A63596A63596A6359686157676056676056665F55655E54655E54645D53645E52
686254686254676153676153666052655F51655F51645E50645E50645E50645E50645E50645E50\
645E50645E50645E4E65604D65604C65604C65604C65604C65604C65604C65604C
615C48615C48605B475F5A465E59455D58445D58445C57435954405954405B56425E5945605B47\
625D49645F4B65604C67624E625D49635E4A69645068634F615C485F5A46645F4B
66614D635E4A615C48635E4A67624E69645067624E65604C67624E67624E67624E67624E67624E\
67624E67624E67624E6761516A64546963536862526B6557676153514B3F383226
6B645A534C42423B33575048857E7899928C766E6B443F3B0A0B050C0F080C0F060B0E051A1C11\
35372C4D4B3F5452465C584C5D594D615B4D625C4E645D4D645D4D635C4C625A4D
635D51635C52625B51625B51615A5060594F60594F5F584E5F584E5F584E5E574D5E574D5D564C\
5C554B5C554B5B544A
626463616564636564626665656766636766666867646867676968656968686A69666A69696B6A\
686C6B6A6C6B696D6C6C6E6D6A6E6D6D6F6E6C706F6E706F6D71707072716E7271
6A6C6B686C6B6A6C6B696D6C6C6E6D6B6F6E6D6F6E6E6E706F6A6E726C70766F767B75797D767D\
7771756A636A5E585C827B82B5AFB3DFD8DFE2DCE0D8D1D8DCD6DAE9E2E9EFEAEE
F2F2F4F3F4F6F5F6F8F7F8FAF8F9FBF8F9FBF7F8FAF6F7F9F1F2F4F1F2F4F2F3F5F2F3F5F3F4F6\
F4F5F7F4F5F7F5F6F8F3F4F6F3F4F6F3F4F6F3F4F6F3F4F6F3F4F6F3F4F6F3F4F6
F9FAFCF9FAFCF9FAFCF9FAFCF9FAFCF9FAFCF9FAFCF9FAFCFDFFFEFDFFFCFDFFFCFEFFFDFEFFFD\
FEFFFDFEFFFDFEFFFDFEFFFDFEFFFDFEFFFDFDFFFCFBFDFAF9FBF8F7F9F6F8F9F4
E8E3DDE1DAD0615A50625B517A7369756E646F685E615A50746D63746D63736C62726B61726B61\
716A6070695F70695F736C62736C62726B61716A60716A6070695F6F685E6F685E
6F685E6F685E6E675D6E675D6D665C6C655B6C655B6B645A6A63596A63596A63596A63596A6359\
6A63596A63596A63596C655B6C655B6B645A6B645A6A6359696258696258686157
696357696355686254686254676153666052666052655F51645E50645E50645E50645E50645E50\
645E50645E50645E4E645F4C645F4B645F4B645F4B645F4B645F4B645F4B645F4B
5F5A46605B47605B47605B47615C48615C48615C48615C485954405A55415B56425C57435D5844\
5E59455F5A46605B4765604C5F5A46615C4868634F67624E605B475F5A46645F4B
645F4B615C48605B47625D4966614D68634F66614D635E4A66614D66614D66614D66614D66614D\
66614D66614D66614D655F4F6862526862526761516B6557676153514B3F383226
4A4339463F354F4840645D55736C666D66605D55524F4A460B0C060E110A0D10070C0F061B1D12\
35372C4D4B3F5452465A564A5B574B5F594B615B4D635C4C625B4B625B4B61594C
625C50615A50615A5060594F5F584E5F584E5E574D5E574D5E574D5D564C5D564C5C554B5B544A\
5B544A5A53495A5349
5C615A5B625A5D625B5D645C5E635C5E655D60655E5F665E636861626961646962636A62656A63\
656C64666B64666D65696E67686F676A6F686970686B70696B726A6C716A6C736B
686D66676E66686D66686F676A6F686A71696B70696D6F6A757074716A71766F777F787F756E76\
645D6469626A7E777E9B949CCAC3CAF0E9F1F3ECF3EFE8F0FAF3FAFFFCFFFFFDFF
F8F8FAF9FAFCFCFDFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFCFDFFFDFEFFFDFEFFFEFFFFFEFFFF\
FEFFFFFEFFFFFEFFFFFDFEFFFDFEFFFDFEFFFDFEFFFDFEFFFDFEFFFDFEFFFDFEFF
FAFBFFFAFBFFFAFBFFFAFBFFFAFBFFFAFBFFFAFBFFFAFBFDFCFEFDFCFEFDFDFFFEFEFFFFFEFFFF\
FEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFDFFFEFDFFFEFDFEF9
FFFCF6FEF7EF5F5850635C547E776F837C74847D75807971746D65746D65736C64726B63726B63\
716A62706961706961716A62716A627069616F68606F68606E675F6D665E6D665E
7069616F68606F68606E675F6D665E6D665E6C655D6C655D6A635B6A635B6A635B6A635B6A635B\
6A635B6A635B6A635B6C655D6C655D6B645C6B645C6A635B69625A69625A686157
6A6458696357696357686256676155676155666054666054645E52645E52645E52645E52645E52\
645E52645E52645E50635E4B635E4A635E4A635E4A635E4A635E4A635E4A635E4A
615C48615C48615C48625D49625D49625D49625D49625D495B56425B56425B56425B56425B5642\
5B56425B56425B5642605B475B56425D5844645F4B645F4B5D58445C5743615C48
635E4A605B475F5A46615C48645F4B66614D65604C625D49645F4B645F4B645F4B645F4B645F4B\
645F4B645F4B645F4B645E4E6761516761516761516A6456676153514B3F383226
39322849423857504858514957504A564F494C44413D38340D0E0810130C0F12090D10071C1E13\
36382D4D4B3F5452465955495A564A5E584A605A4C615A4A615A4A60594960584B
605A4E60594F60594F5F584E5E574D5D564C5D564C5D564C5C554B5C554B5C554B5B544A5A5349\
595248595248595248
61665F61675D62676062685E636861646A60646962656B615E635C5F655B5F645D60665C61665F\
61675D62676062685E646A60656B61656B61666C62676D63676D63686E64686E64
696F65696F656A70666A70666B71676C72686C72686F726B7671756D666D726B737F787F766F77\
7069709A939BD5CED5FFFCFFFFFCFFFFFCFFF8F1F8FEF7FFFFFCFFFFFCFFEDE8EE
FBFBFDFAFBFDFBFCFEFCFDFFFCFDFFFAFBFDF9FAFCF8F9FBF7F8FAF7F8FAF7F8FAF8F9FBF9FAFC\
FAFBFDFAFBFDFAFBFDFBFCFFFBFCFFFBFCFFFBFCFFFBFCFFFBFCFFFBFCFFFBFCFF
FBFCFFFBFCFFFBFCFFFBFCFFFBFCFFFBFCFFFBFCFFFBFCFFFAFBFFFAFBFFFCFBFFFCFDFFFEFDFF\
FEFFFFFFFEFFFEFFFFFFFEFFFEFFFFFFFEFFFEFFFFFFFEFFFEFFFFFFFEFFFFFEFF
FEF9F5FFFEF68079737B746C746D67645D556A635D787169746D67746D65736C66726B63726B65\
716A627069637069617069616F685E6F685E6E675D6D665C6D665C6C655B6C655B
70695F70695F6F685E6E675D6E675D6D665C6C655B6C655B6A63596A63596A63596A63596A6359\
6A63596A63596A6359686157676056676056665F55655E54655E54645D53645D53
6A64586A6458696357686256686256676155666054666054645E52645E52645E52645E52645E52\
645E52645E52645E50625C4C625D4A625D4A625D4A625D4A625D4A625D4A625D4A
65604D645F4C645F4C635E4B625D4A615C49605B48605B485C57445B56435B56435A5542595441\
5954415853405853405C574457523F595441605B48615C495A55425954415E5946
625D4A605B485E5946605B48645F4C66614E645F4C615C49645F4C645F4C645F4C645F4C645F4C\
645F4C645F4C645F4C635D4D6660506660506660506A6456676153514B3F393327
4B45395D564C5B544A4B443A554E4669625A564F4929241E100F0A12130D11120A1011091E1E14\
38382C4E4C405652465854485A57485D57495F5949615A48615A486059475F5848
605A4E5F594D5F584E5E584C5D564C5D574B5C554B5C564A5C554B5B55495B544A5A5448595248\
595347585147585246
5F5D5E605F5D605E5F61605E62606162615F636162636260636162646361646263656462666465\
6665636765666766646766626766616867626968636968636A69646B6A656B6A65
6968636968636A69646B6A656B6A656C6B666D6C676D6C686D696A7772767B767C757074726D73\
898488B9B4BAE0DBDFFFFCFFFFFCFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFEFF
FCFCFEFBFCFEFBFCFEFBFCFEFBFCFEFBFCFEFBFCFEFBFCFEFBFCFEFBFCFEFBFCFEFCFDFFFDFEFF\
FEFFFFFEFFFFFEFFFFFDFEFFFAFBFFF7F7FFF9FAFFFDFDFFFEFFFFFEFEFFFEFFFF
FAFAFFFBFCFFFBFBFFFBFCFFFBFBFFFCFDFFFCFCFFFCFCFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFF\
FFFDFFFFFDFFFFFDFFFCF9FFFBF9FFFDFAFFFDFBFFFFFCFFFFFDFFFFFDFFFFFDFF
FFFDFDFFFBF5766E6B837C76675F5C6E676189817E6E6761726A67726B65716966706963706865\
6F68626E66636E676170695F706A5E6F695D6E685C6E685C6D675B6C665A6C665A
6C665A6C665A6B65596A64586A6458696357686256686256666054666054666054666054666054\
666054666054666054686256686256686256686256686256686256686256686256
666052666052666052666052666052666052666052666052625C4E625C4E625C4E625C4E625C4E\
625C4E625C4E625C4E625C4E625C4C625C4C625C4C625C4C625C4C625C4C625C4C
5E58485E58485E58485E58485E58485E58485E58485E5848605A4A605A4A5F59495E58485E5848\
5D57475C56465C56465953435953435A54445A54445B55455B55455B55455B5545
5D57475E58485E58485E58485E58485F59495F59495F5949625C4C625C4C625C4C625C4C625C4C\
625C4C625C4C625C4C645E50666052655F51635D4F676153655F51544E403F392B
3F392B554F43615B4F5F594D615B4F615B4F464034211A10120D0715100C110C060D08021C180F\
39352A4B473C4D473B5A54445B56435B56435C57435D58425D58425E5A415E5945
5E58485E584A5D574B5D57495C564A5B55475B55495A54465A54485A5446595347595345585246\
575143575145565042
615C60615C60615C60625D61635E62645F63645F63645F63656064656064656064666165676266\
6863676863676864656965646965626A66636A66636B67646C68656C68656D6966
6B67646B67646C68656C68656D69666E6A676E6A676F6B6A726E6F726D716E696D696468757074\
9F9A9EDCD7DBFFFDFFFFFCFFFFFCFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFEFF
FDFDFFFCFDFFFCFDFFFCFDFFFCFDFFFCFDFFFCFDFFFCFDFFFAFBFDFAFBFDFBFCFEFBFCFEFCFDFF\
FDFEFFFDFEFFFEFFFFFEFFFFFEFEFFFEFEFFFEFEFFFCFCFFFBFBFFFAFAFFFAFAFF
FEFEFFFEFEFFFEFEFFFEFEFFFEFEFFFEFEFFFEFEFFFEFDFFFFFBFFFFFBFFFFFBFFFFFBFFFFFBFF\
FFFBFFFFFBFFFFFBFFFFFCFFFFFCFFFFFCFFFFFCFFFFFCFFFCF8FFFAF6FFFAF4FE
EDE7E7E4DCD9726A67827A7769615E68605D7D7572615956726A677169667169667068656F6764\
6F67646E66636E6761706A5E6F695B6F695B6E685A6D67596D67596C66586C6658
6C66586B65576B65576A6456696355696355686254686254676153676153676153676153676153\
676153676153676153686254686254686254686254686254686254686254686254
666052666052666052666052666052666052666052666052635D4F635D4F635D4F635D4F635D4F\
635D4F635D4F635D4F625C4E625C4E625C4E625C4E625C4E625C4E625C4E625C4E
605A4C605A4C605A4C605A4C605A4C605A4C605A4C605A4C605A4C5F594B5F594B5E584A5D5749\
5D57495C56485C5648595345595345595345595345595345585244585244585244
5B55475B55475C56485D57495E584A5F594B5F594B605A4C625C4E625C4E625C4E625C4E625C4E\
625C4E625C4E625C4E635D4F655F51635D4F605A4C645E50655F51575143443E30
403A2C514B3D5953455650425A54465D57494943352A2418150E0818110B160F09160F07272016\
443D33554F435751435A54445A55425A55415B56425C57415D59405D59405D5842
5D57475D57495D57495C56485B55475A54465A54465A5446595345595345595345585244575143\
565042565042565042
5F5A5E605B5F605B5F615C60625D61625D61635E62635E62635E62645F63645F63656064666165\
6661656762666763646864636965626965626A66636B67646B67646C68656C6865
6A66636B67646B67646C68656D69666D69666E6A676E6A69747071767175797478817C80948F93\
B8B3B7E2DDE1FFFAFEFEF9FDFEF9FDFFFAFEFFFAFEFFFBFFFFFCFFFFFCFFFFFEFF
FDFDFFFCFDFFFCFDFFFCFDFFFCFDFFFCFDFFFCFDFFFCFDFFF8F9FBF8F9FBF9FAFCFAFBFDFAFBFD\
FBFCFEFCFDFFFCFDFFF5F6FBFCFDFFFEFFFFFEFFFFFBFCFFF7F8FDF8F9FEFBFCFF
E4E5EAE3E4E9E3E4E9E2E3E8E1E2E7E0E1E6DFE0E5E0DFE7DDD9E7DFD9E7DFD9E7DFD9E7DFD9E7\
DFD9E7DFD9E7DFD9E7C7C1CFC5BFCDC2BCCABEB8C6B9B3C1B5AFBDB2ACBAB0AAB4
9E9898A69F99615A547B746E716A646F6862837C766C655F716A64716A647069637069636F6862\
6E67616E67616D665E6F695D6F695B6E685A6E685A6D67596C66586C66586B6557
6B65576B65576A64566A6456696355686254686254676153686254686254686254686254686254\
686254686254686254676153676153676153676153676153676153676153676153
655F51655F51655F51655F51655F51655F51655F51655F51645E50645E50645E50645E50645E50\
645E50645E50645E50615B4D615B4D615B4D615B4D615B4D615B4D615B4D615B4D
625C4E625C4E625C4E625C4E625C4E625C4E625C4E625C4E5F594B5F594B5E584A5E584A5D5749\
5C56485C56485B5547595345595345585244575143565042544E40544E40534D3F
5751435751435953455B55475D57495E584A605A4C615B4D605A4C605A4C605A4C605A4C605A4C\
605A4C605A4C605A4C615B4D635D4F605A4C5C5648605A4C645E505B55474C4638
322C1E423C2E4E483A504A3C554F41554F413E382A211B0F150E06160F09150E08171008272016\
40392F4F493D524C3E5852425954415954405A55415B56405B573E5C583F5C5741
5C56465C56485B55475B55475A5446595345595345585244585244585244575143575143565042\
554F41554F41544E40
5E595D5E595D5F5A5E5F5A5E605B5F615C60615C60625D61625D61625D61635E62635E62645F63\
6560646560646662636763626864616864616965626A66636A66636B67646B6764
6965626A66636A66636B67646C68656C68656D69666D6968605C5D635E626762666661655C575B\
4A45493631352924281E191D1E191D1F1A1E201B1F201B1F211C20221D21201E21
1F1F211E1F211E1F211E1F211E1F211E1F211E1F211E1F211C1D1F1C1D1F1D1E201E1F211E1F21\
1F20222021232021232D2E323A3B3F47484D494A4E4243483E3F434344494A4B4F
53545954555956575C595A5E5C5D625E5F63606166626167625F6A645E6A645E6A645E6A645E6A\
645E6A645E6A645E6A6D67736D67736D67736D67736C66726C66726C66726B666D
7169677D76705E5751756E6877706A716A64837C76736C667069637069636F68626F68626E6761\
6D66606D66606C655D6E685C6E685A6D67596D67596C66586B65576B65576A6456
6A64566A6456696355696355686254676153676153666052696355696355696355696355696355\
696355696355696355666052666052666052666052666052666052666052666052
645E50645E50645E50645E50645E50645E50645E50645E50655F51655F51655F51655F51655F51\
655F51655F51655F51605A4C605A4C605A4C605A4C605A4C605A4C605A4C605A4C
605A4C605A4C605A4C605A4C605A4C605A4C605A4C605A4C5E584A5E584A5D57495D57495C5648\
5B55475B55475A5446595345585244575143554F41534D3F514B3D504A3C4F493B
524C3E544E40554F415852445B55475D57495F594B605A4C5F594B5F594B5F594B5F594B5F594B\
5F594B5F594B5F594B5E584A605A4C5D57495852445C5648625C4E5E584A544E40
2822143933254A4436534D3F5650424E483A302A1C110B001C150D1A130B19120A1D160C2B241A\
3C362A4842344C463857514157514158534058533F5954405A553F5A553F5B5642
5B55455A54465A5446595345585244585244575143575143575143565042565042554F41544E40\
544E40534D3F534D3F
5C58595D595A5D595A5E5A5B5F5B5C5F5B5C605C5D605C5D605C5D615D5E615D5E625E5F635F60\
635F606460616460616763626763606864616864616965626A66636A66636B6764
6965626965626A66636A66636B67646C68656C68656D69687D797A7F7B7C837F808480817C7879\
656162474344302C2D4642434743444743444844454945464945464A4647484647
4848484848484848484848484848484848484848484848484A4A4A4A4A4A4B4B4B4B4B4B4C4C4C\
4D4D4D4D4D4D4E4E505252545F5F616B6A6F6D6D6F66656A62626466656A6C6C6E
61606562626464636867676969686D6C6C6E6E6D726F6E73716E75736D77736D77736D77736D77\
736D77736D77736D77655F69655F6967616B68626C6A646E6C66706D67716E696F
78706D7C756D726B63736C64766F67676058736C64665F577069616F68606F68606E675F6D665E\
6D665E6C655D6C655B6E685C6D67596D67596C66586B65576B65576A64566A6456
6A6456696355696355686254676153676153666052666052686254686254686254686254686254\
686254686254686254666052666052666052666052666052666052666052666052
645E50645E50645E50645E50645E50645E50645E50645E50645E50645E50645E50645E50645E50\
645E50645E50645E50605A4C605A4C605A4C605A4C605A4C605A4C605A4C605A4C
5C56485C56485C56485C56485C56485C56485C56485C56485E584A5D57495D57495C56485B5547\
5B55475A54465A5446585244575143565042544E40524C3E514B3D4F493B4E483A
504A3C514B3D534D3F554F415852445B55475C56485E584A5D57495D57495D57495D57495D5749\
5D57495D57495D57495B55475E584A5C5648575143595345605A4C605A4C585244
342E203B3527413B2D453F314640323E382A282214120C001E170D1B140A1C150B272016352E24\
433D314D4739534D3F554F3F56504056513E57523E58533F58533F595440595440
595343595345585244585244575143565042565042554F41554F41554F41544E40544E40534D3F\
524C3E524C3E514B3D
5B57585B57585C58595C58595D595A5E5A5B5E5A5B5F5B5C5F5B5C5F5B5C605C5D605C5D615D5E\
625E5F625E5F635F5E66625F66625F6763606763606864616965626965626A6663
6864616864616965626965626A66636B67646B67646C6865666261615D5E5D595A615D5E6D696A\
7874757D797A7E7A7B747071757172757172767273777374777374787475787475
7775767676767775767676767775767676767775767676767A78797A7A7A7B797A7B7B7B7D7B7C\
7C7C7C7E7C7D7D7D7D747273797979807E817D7D7D767477707070716F72737373
7A787B78787879777A777777777578757575757376747275787379787379797279787379797279\
787379797279787379766F76757076766F76757076766F76757076766F76767072
79716E736C647A736B6C655D7A736B6A635B736C646A635B6F68606E675F6E675F6D665E6C655D\
6C655D6B645C6B645A6D675B6C66586C66586B65576A64566A6456696355696355
696355686254686254676153666052666052655F51655F51666052666052666052666052666052\
666052666052666052655F51655F51655F51655F51655F51655F51655F51655F51
635D4F635D4F635D4F635D4F635D4F635D4F635D4F635D4F625C4E625C4E625C4E625C4E625C4E\
625C4E625C4E625C4E5F594B5F594B5F594B5F594B5F594B5F594B5F594B5F594B
5A54465A54465A54465A54465A54465A54465A54465A54465D57495C56485C56485B55475A5446\
5A5446595345595345575143575143565042544E40534D3F524C3E514B3D514B3D
4F493B504A3C524C3E534D3F554F415751435953455953455C56485C56485C56485C56485C5648\
5C56485C56485C56485751435D57495D57495852445852445E584A5E584A585244
3F392B3630222A2416241E10241E10241E101E180A181204150F03110B00160F05272115383226\
423C304C4638554F41544E3E544E3E55503D55503D56513E57523E57523F585340
585242575143575143565042554F41554F41544E40544E40544E40534D3F534D3F524C3E514B3D\
514B3D504A3C504A3C
5A56555A56555A56555B57565C58575D59585D59585D59585E5A595E5A595E5A595F5B5A605C5B\
615D5C615D5C615D5C65615E66625F66625F676360686461686461696562696562
6763606864616864616965626A66636A66636B67646B6764837F7E7773726864635F5B5A5F5B5A\
64605F6A66656D6968706C6B716D6C716D6C726E6D736F6E736F6E74706F74706F
736F6E71706E736F6E71706E736F6E71706E736F6E71706E757170747371767271757472787473\
7675737975747776748682818483818480817F7E7C7E7A7B797876797576767573
7D797A7A79777B7778777674777374737270747071736F70746E70746E72766D72746E72766D72\
746E72766D72746E72736A6F706A6E72696E6F696D70676C6D676B6E656A6E6566
706963625B51797268645D5380796F716A6078716770695F6E675D6E675D6D665C6D665C6C655B\
6B645A6B645A6A63596C665A6C66586B65576B65576A6456696355696355686254
686254686254676153676153666052655F51655F51645E50635D4F635D4F635D4F635D4F635D4F\
635D4F635D4F635D4F645E50645E50645E50645E50645E50645E50645E50645E50
625C4E625C4E625C4E625C4E625C4E625C4E625C4E625C4E5F594B5F594B5F594B5F594B5F594B\
5F594B5F594B5F594B5E584A5E584A5E584A5E584A5E584A5E584A5E584A5E584A
5C56485C56485C56485C56485C56485C56485C56485C56485C56485C56485B55475B55475A5446\
595345595345585244565042565042565042554F41554F41554F41554F41544E40
504A3C514B3D514B3D524C3E534D3F544E40554F41554F415A54465A54465A54465A54465A5446\
5A54465A54465A5446544E405D57495F594B5A54465953455D57495C5648565042
4640323933252B2517272113282214282214251F11231D0F221C0E1A14061F190D312B1D3F392B\
433D2F4A4436534D3F534D3D534D3D534D3D544E3E554F3F56513E565040565040
565042565042565042554F41544E40534D3F534D3F534D3F524C3E524C3E524C3E514B3D504A3C\
4F493B4F493B4F493B
5955545955525A56555A56535B57565C58555C58575D59565D59585D59565E5A595E5A575F5B5A\
605C59605C5B615D5A65615E65615E66625F676360676360686461696562696562
6763606763606864616965626965626A66636B67646B676464605D6763606C6867716D6A736F6E\
716D6A6C6867686461706C6B706C69716D6C716D6A726E6D736F6C736F6E74706D
726E6D726E6B726E6D726E6B726E6D726E6B726E6D726E6B726E6D726E6B736F6E736F6C74706F\
75716E75717076726F79757475716E716D6C706C69736F6E74706D736F6E716D6A
726E6D726E6B726E6D726E6B736F6E736F6C736F6E746E6E766D6E766D6E766D6E766D6E766D6E\
766D6E766D6E766D6E72696A736A6B736A6B736A6B746B6C746B6C756C6D756D6B
787169645D537F786E625B5180796F6C655B6B645A5F584E6E675D6E675D6D665C6C655B6C655B\
6B645A6A63596A64586C66586C66586B65576A64566A6456696355686254686254
686254686254676153666052666052655F51645E50645E50625C4E625C4E625C4E625C4E625C4E\
625C4E625C4E625C4E645E50645E50645E50645E50645E50645E50645E50645E50
625C4E625C4E625C4E625C4E625C4E625C4E625C4E625C4E5E584A5E584A5E584A5E584A5E584A\
5E584A5E584A5E584A5E584A5E584A5E584A5E584A5E584A5E584A5E584A5E584A
5E584A5E584A5E584A5E584A5E584A5E584A5E584A5E584A5C56485C56485B55475A54465A5446\
595345585244585244554F41554F41565042565042565042575143575143575143
514B3D514B3D514B3D524C3E524C3E524C3E524C3E534D3F5A54465A54465A54465A54465A5446\
5A54465A54465A5446534D3F5D5749615B4D5C56485953455C56485A5446544E40
504A3C4A44364943354F493B524C3E4A44363D3729342E20443E303A34263B35274A4436524C3E\
4F493B514B3D595345524C3C524C3C534D3D534D3D544E3E554F3F554F3F565040
565042554F41554F41544E40534D3F534D3F524C3E524C3E524C3E514B3D514B3D504A3C4F493B\
4F493B4E483A4E483A
5955525A57525A56535B58535C58555C59545D59565D5A555F5B58605D58605C59615E59625E5B\
625F5A635F5C635F5C635F5C64605D64605D65615E66625F66625F676360676360
64605D66625F6864616A66636A666368646166625F64605D6965626966616A66636B68636B6764\
6C69646D69666D6A656F6B686F6C676F6B686F6C676F6B686F6C676F6B686F6C67
726D6A726D69726D6A726D69726D6A726D69726D6A726D6975706D746F6B736E6B726D69736E6B\
746F6B76716E77726E7E7976797470736E6B706B67726D6A736E6A726D6A706B67
736E6B736E6A736E6B736E6A726D6A726D69726D6A716C68746C69756B69756B69756B69756B69\
756B69756B69756B69766C6A766C6A766C6A766C6A746A687268666F65636E6560
726B61726C60716B5F716B5F706A5E6F695D6F695D6E685C6E685C6E685C6E685C6D675B6C665A\
6B65596B65596B65596A6456696355696355696355686254686254686254686254
696355655F51635D4F655F516B65576C6658676153615B4D625C4E625C4E625C4E625C4E625C4E\
625C4E625C4E625C4E666052666052655F51655F51645E50635D4F635D4F625C4E
625C4E625C4E625C4E625C4E625C4E625C4E625C4E625C4E5E584A5F594B605A4C605A4C5F594B\
5E584A5C56485B55475E584A5E584A5E584A5E584A5E584A5E584A5E584A5E584A
5E584A5D57495B55475A54465A54465B55475D57495E584A5C56485C56485B55475B55475A5446\
595345595345585244585244585244575143565042565042554F41544E40544E40
544E40544E40534D3F524C3E524C3E514B3D504A3C504A3C4E483A514B3D554F415953455B5547\
5B55475953455852445A54465A54465B55475A5446595345575143554F41544E40
453F314741334943354D47394F493B504A3C504A3C504A3C423C2C433D2D453F2F4842324B4535\
4E4838504A3A514B3B544E40544E40544E40544E40544E40544E40544E40544E40
524C3E524C3E514B3D514B3D504A3C4F493B4F493B4E483A4E483A4E483A4D47394D47394C4638\
4B45374B45374A4436
5956515956515956515A57525B58535C59545C59545C59545F5C575F5C575F5C57605D58615E59\
625F5A625F5A625F5A635F5C635F5C635F5C64605D65615E66625F66625F66625F
64605D66625F68646169656269656268646166625F64605D6966616966616A67626A67626B6863\
6C69646C69646D6A656F6C676F6C676F6C676F6C676F6C676F6C676F6C676F6C67
726D69726D69726D69726D69726D69726D69726D69726D69746F6B736E6A726D69726D69726D69\
746F6B76716D77726E7D787278736D726D67706B65726D67736E68726D67706B65
716C66716C66716C66716C66716C66706B65706B65726B65756C67756C65756C65756C65756C65\
756C65756C65756C65746B64746B64756C65746B64736A637067606E655E6C635C
716B5F706A5E706A5E6F695D6E685C6E685C6D675B6D675B6C665A6C665A6C665A6B65596A6458\
696357696357696357676153676153676153666052666052655F51655F51655F51
635D4F5F594B5D57495F594B645E50655F51625C4E5E584A625C4E625C4E625C4E625C4E625C4E\
625C4E625C4E625C4E655F51655F51655F51645E50635D4F625C4E625C4E625C4E
625C4E625C4E625C4E625C4E625C4E625C4E625C4E625C4E5E584A5F594B605A4C605A4C5F594B\
5D57495B55475A54465E584A5E584A5E584A5E584A5E584A5E584A5E584A5E584A
5D57495C56485B55475A54465A54465B55475C56485D57495B55475B55475B55475A5446595345\
585244585244585244585244575143575143565042554F41554F41544E40544E40
544E40534D3F534D3F524C3E514B3D514B3D504A3C504A3C4E483A504A3C524C3E554F41575143\
575143575143575143585244595345595345595345585244575143554F41534D3F
4741334943354C46384F493B514B3D524C3E524C3E524C3E4842324944314A44344C46364F4939\
514B3B524C3C534D3D544E40544E40544E40544E40544E40544E40544E42544E40
514B3D514B3D514B3D504A3C4F493B4E483A4E483A4E483A4D47394D47394D47394C46384B4537\
4A44364A44364A4436
57544D58554E58554E59564F5A57505A57505B58515B58515D5A535E5B545E5B545F5C55605D56\
605D56615E57615E59615D5A625E5B625E5B635F5C64605D64605D65615E65615E
64605D65615E67636068646168646167636065615E64605D68656069665F69665F6A67606B6861\
6B68616C69626C69626D6A636D6A636D6A636D6A636D6A636D6A636D6A636D6A63
706B65726B65726B65726B65726B65726B65726B65726B65756E68746D67736C66736C66746D67\
766F6978716B79726C7D766E787169746D65736C64746D65756E66736C64716A62
70696170696170696170696170696170696170696170695F746B62756B62756B62756B62756B62\
756B62756B62756B6272685F73696073696073696071675E6F655C6C62596A6257
6E685C6E685A6D67596D67596C66586B65576B65576A6456696355696355686254686254676153\
666052666052655F51645E50645E50635D4F625C4E615B4D615B4D605A4C605A4C
5F594B5C56485A54465B55475F594B625C4E615B4D605A4C615B4D615B4D615B4D615B4D615B4D\
615B4D615B4D615B4D645E50645E50635D4F635D4F625C4E615B4D615B4D605A4C
605A4C605A4C605A4C605A4C605A4C605A4C605A4C605A4C5D57495E584A5F594B5F594B5E584A\
5D57495B55475A54465D57495D57495D57495D57495D57495D57495D57495D5749
5D57495C56485B55475A54465A54465B55475C56485D57495A54465A5446595345595345585244\
575143575143565042575143575143565042565042554F41544E40544E40534D3F
534D3F534D3F524C3E524C3E514B3D504A3C504A3C4F493B4E483A4E483A4E483A4E483A504A3C\
524C3E544E40565042565042565042575143575143575143554F41534D3F524C3E
4842344A44364D4739504A3C524C3E544E40544E40544E3E4F4A374F4A36504B38514C39524D3A\
534E3B534D3D544E3E524C3E524C3E524C40524C40524C40524C40524B41524C40
504A3C504A3C4F493B4F493B4E483A4D47394D47394C46384C46384C46384B45374B45374A4436\
494335494335484234
56534C56534C57544D57544D58554E59564F59564F5A57505C59525C59525D5A535D5A535E5B54\
5F5C555F5C55605D56605D58605C59615D5A615D5A625E5B635F5C635F5C64605D
65615E65615E66625F66625F66625F66625F65615E65625D67645D68655E68655E69665F6A6760\
6A67606B68616B68616C69626C69626C69626C69626C69626C69626C69626D6862
716A64716A64716A64716A64716A64716A64716A64716A64736C66726B65726B65726B65736C66\
766F6978716B79726A7A7369766F65736C62736C62756E64766F65736C6270695F
6D665C6D665C6D665C6E675D6E675D6F685E6F685E70685D746A60746A5E746A5E746A5E746A5E\
746A5E746A5E746A5E70665A71675B71675B71675B6F65596D63576A6054695F53
6D65586C66586B65576B65576A6456696355696355686254666052666052666052655F51645E50\
635D4F635D4F635D4F615B4D605A4C5F594B5E584A5D57495C56485B55475A5446
5E584A5B55475953455953455C5648605A4C635D4F655F51605A4C605A4C605A4C605A4C605A4C\
605A4C605A4C605A4C635D4F625C4E625C4E615B4D605A4C605A4C5F594B5F594B
5F594B5F594B5F594B5F594B5F594B5F594B5F594B5F594B5D57495D57495E584A5E584A5E584A\
5C56485A54465953455C56485C56485C56485C56485C56485C56485C56485C5648
5C56485B55475A54465953455953455A54465B55475C5648595345585244585244575143565042\
565042554F41554F41565042565042554F41554F41544E40534D3F534D3F524C3E
524C3E524C3E514B3D514B3D504A3C4F493B4F493B4E483A4E483A4C46384A44364943354A4436\
4D4739504A3C534D3F524C3E534D3F544E40554F41554F41544E40524C3E514B3D
4640324842344B45374E483A514B3D524C3E524C3E524C3C524D39524D39524D39524D39524D3A\
514C39514B3B514B3B514B3D514B3D514B3F514B3F514A40514A40514A40514A40
4F493D4E483A4E483A4D47394C46384C46384B45374B45374B45374A44364A4436494335484234\
484234474133474133
54514855524955524956534A57544B57544B58554C58554C5A574E5B584F5B584F5C59505D5A51\
5D5A515E5B525E5B545E5B565F5B585F5B58605C59615D5A615D5A625E5B625E5B
65615E65615E64605D64605D64605D64605D65615E65625D67645D67645B68655C68655C69665D\
6A675E6A675E6B685F6A675E6A675E6A675E6A675E6A675E6A675E6A675E6B675E
6F6860706760706760706760706760706760706760706760726962726962716861726962746B64\
766D667970697B726B786F66756D62736B60746C61776F64776F64746C6170685D
6C64596C64596D655A6E665B6F675C70685D70685D71695E746B5C766A5C766A5C766A5C766A5C\
766A5C766A5C766A5C7165577266587266587266587064566E62546B5F51685F50
6C65556B65556A64546A6454696353686252686252676151655F4F645E4E645E4E635D4D625C4C\
625C4C615B4B615B4B5E584A5E584A5D57495B5547595345585244565042565042
565042544E40524C3E504A3C524C3E5852445F594B655F51605A4C605A4C605A4C605A4C605A4C\
605A4C605A4C605A4C615B4D615B4D605A4C605A4C5F594B5E584A5E584A5D5749
5D57495D57495D57495D57495D57495D57495D57495D57495C56485D57495D57495E584A5D5749\
5B55475953455852445C56485C56485C56485C56485C56485C56485C56485C5648
5B55475A54465953455852445852445953455A54465B5547575143575143565042565042554F41\
544E40544E40534D3F565042554F41554F41544E40534D3F534D3F524C3E524C3E
524C3E514B3D514B3D504A3C4F493B4F493B4E483A4E483A4D47394B4537484234474133474133\
4A44364D47394F493B4F493B504A3C514B3D524C3E524C3E524C3E514B3D504A3C
433D2F453F314842344B45374D47394E483A4E483A4E4838514C38504B35504B354F4A344F4A36\
4E49364E48384D47374F493B4F493B4F493D4F483E4F48404F48404F48404F4840
4D473B4D47394C46384C46384B45374A44364A4436494335494335494335484234484234474133\
464032464032453F31
53504753504754514854514855524956534A56534A57544B59564D59564D5A574E5A574E5B584F\
5C59505C59505D5A535D5A555D59565E5A575E5A575F5B58605C59605C59615D5A
66625F65615E635F5C625E5B625E5B635F5C65615E66635E66635C66635A67645B67645B68655C\
69665D69665D6A675E69665D69665D69665D69665D69665D69665D69665D6A665D
6E675F6F665F6F665F6F665F6F665F6F665F6F665F6F665F706760706760706760716861736A63\
766D667970697B7269756D62736B60726A5F746C61776F64776F64736B606F675C
6B63586C64596D655A6E665B70685D71695E726A5F726A5D75695B756959756959756959756959\
7569597569597569597266567266567367577266567165556E62526C6050685F4E
6D66566B65556B65556A6454696353696353686252686252655F4F645E4E645E4E635D4D625C4C\
625C4C615B4B615B4B5E584A5D57495B5547595345575143554F41544E40534D3F
494335484234453F31423C2E433D2F4A44365650425F594B5F594B5F594B5F594B5F594B5F594B\
5F594B5F594B5F594B605A4C5F594B5F594B5E584A5D57495D57495C56485C5648
5C56485C56485C56485C56485C56485C56485C56485C56485B55475C56485D57495D57495C5648\
5A54465953455751435B55475B55475B55475B55475B55475B55475B55475B5547
5A54465953455852445751435751435852445953455A5446565042554F41554F41544E40534D3F\
534D3F524C3E524C3E554F41544E40544E40534D3F524C3E524C3E514B3D514B3D
514B3D504A3C504A3C4F493B4E483A4E483A4D47394D47394B45374A4436494335484234484234\
4943354A44364B45374B45374C46384E483A504A3C504A3C504A3C4F493B4E483A
413B2D433D2F4640324943354B45374C46384D47394C46364D48324D49304D48324D48324C4733\
4C47334C47344C46364E483A4E483C4E473D4E473D4E473F4E473F4E47414E473F
4C463A4B45374B45374A4436494335494335484234484234484234474133474133464032453F31\
453F31443E30443E30
524F46524F46524F4653504754514855524955524955524958554C58554C58554C59564D5A574E\
5B584F5B584F5B58515C59545C58555C58555D59565E5A575F5B585F5B585F5B58
66625F64605D625E5B615D5A615D5A625E5B64605D66635E65625B66635A66635A67645B68655C\
68655C69665D69665D67645B67645B67645B67645B67645B67645B67645B68645B
6C655D6D645D6D645D6D645D6D645D6D645D6D645D6D645D6F665F6F665F6F665F706760736A63\
766D667970697B7269726A5F71695C71695C746C5F787063776F62736B5E6F675A
6C64576D65586E66596F675A71695C736B5E746C5F756E5E746858746957746957746957746957\
7469577469577469577368567469577469577469577267557065536D62506A6150
6E67576D67576C66566C66566B65556A64546A6454696353655F4F655F4F645E4E645E4E635D4D\
625C4C625C4C615B4B5E584A5D57495B5547595345575143544E40534D3F524C3E
413B2D413B2D3E382A3A34263A3426433D2F514B3D5D57495E584A5E584A5E584A5E584A5E584A\
5E584A5E584A5E584A5E584A5E584A5E584A5D57495C56485B55475B55475B5547
5A54465A54465A54465A54465A54465A54465A54465A54465B55475B55475C56485C56485C5648\
5A54465852445751435A54465A54465A54465A54465A54465A54465A54465A5446
5A54465953455852445751435751435852445953455A5446544E40544E40544E40534D3F524C3E\
514B3D514B3D514B3D544E40544E40534D3F534D3F524C3E514B3D514B3D504A3C
504A3C504A3C4F493B4F493B4E483A4D47394D47394C46384943354A44364B45374B45374B4537\
4A44364943354842344943354A44364C46384E483A4F493B4F493B4E483A4E483A
423C2E443E304741334A44364D47394E483A4E483A4E48384C47314C482D4C482F4C47314D4834\
4D48344D48354D47374C46384C463A4C453B4C453B4C453D4C453F4C44414C453F
4A44384A44364A4436494335484234474133474133474133464032464032464032453F31443E30\
433D2F433D2F433D2F
514E45514E45524F46524F4653504754514854514855524957544B57544B58554C58554C59564D\
5A574E5A574E5B58515B58535B57545C58555C58555D59565E5A575E5A575F5B58
66625F64605D625E5B605C59605C59625E5B64605D66635E65625B65625966635A67645B67645B\
68655C69665D69665D67645B67645B67645B67645B67645B67645B67645B68645B
6C655D6D645D6D645D6D645D6D645D6D645D6D645D6D645D6E655E6E655E6E655E706760736A63\
766D667970697B726971695E70685B71695C746C5F787063787063736B5E6E6659
6C64576D65586E665970685B726A5D746C5F756D60766F5F746858746957746957746957746957\
746957746957746957746957756A58756A58756A587368567166546E63516B6350
6F68586E68586D67576D67576C66566B65556B65556A6454666050666050655F4F655F4F645E4E\
635D4D635D4D625C4C5F594B5E584A5C5648595345575143544E40524C3E514B3D
413B2D413B2D3F392B3A34263A3426433D2F534D3F605A4C5E584A5E584A5E584A5E584A5E584A\
5E584A5E584A5E584A5E584A5D57495D57495C56485B55475B55475A54465A5446
5A54465A54465A54465A54465A54465A54465A54465A54465A54465B55475C56485C56485B5547\
5A54465852445650425A54465A54465A54465A54465A54465A54465A54465A5446
5A54465953455751435650425650425751435953455A5446544E40534D3F534D3F524C3E514B3D\
514B3D504A3C504A3C544E40544E40534D3F524C3E524C3E514B3D504A3C504A3C
504A3C504A3C4F493B4E483A4E483A4D47394C46384C46384842344943354C46384E483A4D4739\
4B45374842344640324741334943354B45374D47394E483A4E483A4E483A4D4739
453F314640324943354C46384F493B504A3C504A3C504B384C47314C482D4D49304D49304E4935\
4F4A364F4A37504A3A4C46384C463A4C453B4C453B4C453F4C453F4C44414C453F
4A4438494335494335484234474133474133464032464032464032453F31453F31443E30433D2F\
433D2F423C2E423C2E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[3]:=",
  ImageSize->{596.313, 212.813},
  ImageMargins->{{0, 0}, {0, 4}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0000e1000`40O003h00OogooogooEWoo003o
OoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogoo
EWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo000EOol0148?AS1>LUJC0UJd00=BTe9b
E[@01eJd6EZd0UJd00EFTe:CDY=FTeJc00AJ]0ENe0AJ]004G]ANeEkEF[@2G]D2E[@02EkFG_INeUkF
F]EJ]5JdF[ENeP02G_H015[EF_INmUkf15[f00=NmUkgGaL00V<h00UNmU:dBW8Q2AcW58D<H`Q32480
0PQ300<48PQ224<00`aS0PQ300<48PA224<01`QS0PaT00@8H`Q314848@@48P041488@PQ326<Y1286
02800`1216<4@`03028204800`0R12848P0F12830242128314800`0Q0200800502000`0Q02008002
020202401@@Q248480@02480111S0QB400HDY1S57<HLib3W8@LXOol2CW800dicDY=BT`03DY<00e:D
D[AF]002E[@00eJeE]EJe@04F]D015[FG_INmUkf0U[F00=JmUkfG_H01ekf1V;g0V<G0fLH00=W>6<G
HaH00V<F15lF1F<G00=S=fLhIcP00f<G00=S=fLgIcP00VLh0fLg0f<g0V<G1F<g0f<G00QS5VmIKeU>
DBD76:@PiR3621c52Ac65ac541RU21RT0QRU0aRT0aB41aRT00@DY1B558DDQ@DDY@8@Q00346@@Ha1S
008@H`0536<<I0aT36<<@`0624<020Q212848P@Q10400@@R14441482144314800`A112448@0K1240
0`Q236<@Q00348@00`aSOomoo`0EOol001Eoo`04BU5>DDibDY<2EY<2DY<8E[@HF[@00e[EF[EJ]005
E[@3EY<01EZcF[ANe5kDG]D00UZd0ekD0UZd00aJ/e[EG]INeU[EG]ENmU[EEY=J]E[EG]H2H_L01Ekf
F[EFU5kfF_H00U[E00mJmUlGIcU[FFLiF_I>LSg^;H/Q:1C548<@QA1T36<02@Q300@<@`Q324<8@`84
8P042488H`aS36@238@00`QS36@<I00236@00`QS14848P04128010A22488@`QS:@@R1P0R00<0@PAS
14<00`0R0P1200<08P@R12806`@R0P0R00L08@A21484@@@Q02408002000602400`@Q144480021200
3@PQ348DQ1S57>HQ1bD89BPY:Be:<F/aRcF<02Qoo`8HaP<LiP8Li`047>HDY1BU5:D46<D011S68@LQ
224812DX00DU:BUZ;FX]JRe[00<aR`07<H`e[3V/>JdicCg>?Nh00T7_0dH@00=6<4X`BS400TXa0eJd
00=Je5[EG_H00Ukf16<G00AS=fLhIcQW>0A[F@06JgU_NFmjKgY_VW>J1W>K0V]i1Fmj00U_NF/hJcQR
mT7^6:@@HQbU6:D021c52Ac65ac541RU21RT0QRU0aRT0aB41aRT00<DY1B558@00QB4212400D@I11S
46<<Ha1T00<<I0@<H`0324<8@PQ200848P0512440@0Q1284@@0414800`A11248@P0414800`A11244
8@0H12400`Q236<<H`0348@236<GOol001Eoo`=BT`9BL`03DY=FTeJD00MF]003F[AJ]EZe01IJ]@IJ
e@03F[EJ]5JC009FT`9J/`=J]003EY=J/eZd009Ne@04G]AJ]5JcF[D3F]D02UkFH_MNmUZeH_MNeUZe
F[AJ]E[E0UkF00=JeE[fGaL00V<h00QJmU:CAU4YJR4X6>H@Y1230`b300@<H`aT46@@Q@8DY@0348D<
I0aT008<H`D8@`041284@PA224<926<00`Q214848P04128010A22488@`QS:@@R1P0R00<0@PAS14<0
0`0R0P1200<08P@R12805P@R1@0Q0`0100<08@0P02400P0Q10@Q100Q01<48@A1144000Q134888A1S
8@LaJcF<=Jdi[CW=>LhmcSg_@Nm23`0XOol348<248@348<00`aS38<@P`0348<248@25:D00aC56<DH
a@036<D37>H28@L0124X9BPU:2DX0RTY00@YBBe:;FXaJPDaJ`8aR`8eR`0;<H/aZcF/>L`icCg^?Pi2
3TH`AU1:D002BU400dYaCW9>LP05DY<015:cE[AF]5[D0U[E1E[e00ANmUlFHaMS5`9S=`9W=`08JcQS
5eZd?LdPiQc59>LLa@PHY@LLaQ4La@PHaA4HY@LHY0<HY@<HY08DQ0LHY0035:@DQAB4008@Q00446<<
H`a3348636<234<636<234<224800`PR12848P021240100Q12448@A10PA200<4@@@Q12400`Q21@A2
20Q23@@Q0`Q220aS5goo000EOol01eJCDY=BTe9bDW=BTeJC00IF]0=J]1YJe@=Ne@9Je@AJ]09J/`=F
T`04DW9FTUJCF[@4G]D2F[@025JDEY=FU5ZeG]ENeUkfF]D2F[@025kFH_MW>6/iBW8icR4X4:@32680
1PQ22688HPaR38<@Q08@Y00848@DYABV5:HHaQS76<HDYP8@Q@0348@<I0a300P8@`0414848P@Q0244
148010@R12408@0110@R00@4@PQ224<8HbT48PH08P030484H`A300<08P80@P0302848P@R01H48PD0
8@0502848P@R0000800202401@@Q1444@PA21240100Q00@48@A114448@8<H`03348HaCF]009:<@=6
<0964003@Q123d8?02Qoo`H@P`0538<<H`000000800512060002020500031208100?00000`0P0000
0003000402030000100P120480A00P@P00@4@0Q02404@0@480041408@@aR3682468020a1244@HQ1R
448HQ1c558<86:DH7<DK6:D56:@46:D;6:@02ABT58DDQ12446<<H`Q222888@02228522400`@Q2284
8P04228212800`Q222848P02128212400`0Q12448@0612451483144@1248248836<GOol001Eoo`9B
LP04DW=BTe:CDY<2EY<4E[@4F[@HF]D00eZdF]EJe@02G]D2F]D015ZdG]ENeEkD0UZd00=F/eJCEY<0
0e9b0UJC0UZd00aNeF;fH_MRmekfF]EJ]E[EG_IF]E[EG_L2IaP03UkgE[A>Ld8`<H/Da@A1000080@Q
144<Ha235:D25<D00aBT48@<P`025:H25:D25:H01aB548DDYAB548@<I0a300<8@`0836<8H`QS24<8
@PA212408@@48P0412408@0Q0044128010A22488@`QS:@@R1P0R00<48PQ314800`0R8`@R0PA200@4
@@@Q12408@8080848@<08@848@081448@Pa2348<HRD8AQ1BL`9:D@9:<@03AS1644H@00923bQoo`D<
HP88@P032448@PQ20088HP@<HP032448@PQ200D8@P@8@@@8@P033488@PQ20088@@<88@<48@D88@P8
@@031448@@Q100D8@@H480L8@@0312008000008000041204@@Q13682468020a1244DPac57<HU1bD8
7:DA6:D?6<DL6:D46:@56:D:6:@01aBT58DDQ12446<<@`Q200<88@T48@<48P848@0300448P@R0084
8P<48@0302448@@Q00D48@0302448@@Q01H48@H8@PT<H`0348Aoogoo01Eoo`005Goo0Tib00ABLe:C
EYAFU09FT`=F]0=J]09J]AQJe@03F[AJ]E[E00EJe@04F]AJ]5ZdF[@3F]@015kDEY=FTe:B0e9b00EF
TUJCDW=BU5Ze009NmP0GF[EF]E[EG_MJeUJDBU91kc6;9@PHa@aR2688@PQR36<8HPA10204@@QR38<@
Y0025<D011SV7>LDYABU0Q2500<DYABV5:H00aBV00@DQA2536@<I08<H`0324<8H`QS00<8H`88@`<4
@PT48P041488@PQ326<Y128602800`@R24<4@P03028K12840242004600000`0P02408@06124010A1
1488@PQ10PPQ00DDQ2eZBS5>DT8@00Q6<2Qoo`D@P`0338<<H`aR00P080P480<48@D480<400<48084
8@P480@0008080848005244<HPaR368<P`0436842442368248<02a2T5:@@Y1233688@@A12448H@aR
48<00QBT0QS500@U1ac57<DLa@<DQ003344HYARU03HHY@8Ha@<HY@<HY0LHY@PHY00:5:@DYABU58@@
Q11S36<<@PQ23487248020PR2488@PQ324848P@Q10431285124302421247024F1244248736<348@G
Ool001Eoo`05DW9BTe:CEY=FU005E[@3F[@2F[DOF]D2G]D2F[@00e[DF]EJe@02F]D01ekEF[AJ]5Zd
E[AF/eJC009BT`04G_IF]EJeG_L2HaP2HaL01TH`>LhYBQS636<88@8000032440800000800005144<
PaBU38<@Q0025:D34:@00aBU6<HDYP025:H01AS66<LHaQBV6:H00QBV00<DYA2548@00PaT00<8@PQ3
24<00PQS0PQ300<8@PA214802P@R00@4@PQ224<8HbX48P0402808@0Q0282128010Q314808P0Q5@@R
1`@Q0P010P@Q00@48PA22488@P848@041488@PQ2268236<:24801Q239@PmcTYABS523`A6<004AS5:
<DXaBS4XOol2248336842487244524832448248?124010@P12448@A10`Q10PQ200@48@Q1368<H`<@
P`0338<<HPQ200<8@@03248<HQ23008@P`8@Q00448<<HPQ1144200003P@P244<HPaR46<@PaRU48<H
YAc56:@LaBD78>LA6:DG6:@@6:D00ac56<DHa@036:D26:@86:D76:@01ABT6:DDYABU58@00Q241A1S
1@aS00T<@`aS36<<H`Q324848P@112801`@Q00<00@0Q0240100Q00@0800Q02408AD48@<8@P@<H`T@
Q1Moo`005Goo00=F]5JDEY<00UJC0UJd00=J]5JdE[@00eZd00=J]E[EF]D07U[E0Ukf0UkE0U[E00IJ
e5ZdF[AJ]5[EG]D3G_H01EkEF]AF]2U948@00P000PQ200<88P@Q12400`@Q00<88PQ224800P@Q00D4
@@Q22484@P0Q00800006148<HaBU6>HHaQC60QC500<HaQBV5:H00QS600@HYQBU48@HYP8HaP056:HD
YQ2548@<I002248214801P@R12408@0112848@H08@@48P041488@PQ326<[128202401`0R12848PQ3
14848P0Q01@48PP48@061288@PaS48@DYAS60QcW00LU:B4Y8@PLiaS64:D@Q00236<010QS2488HPQ2
0`aS0Q2400HLiSF<BS5>DTYAAS02BS4014HaAS16<4H`0TH@:7oo20Q24`@Q00<8@@Q224801@Q20P@Q
00<48000000040@Q00D8@@Q238<@Y1BU008Ha@075<D<H`aR2488@@Q236800Q230PaR00`<Pa2338<<
HPQ11244@@Q1268<Pa245:@26:D01aS56:@PiR3W6:DDQ1bU018HYALHY10HY@8La@046<DHYARU6:D2
6:@86:D76:@00aBT6:DHY@025:D00aB558@DQ00248@246@446<336<01PaT36<8@`Q212400@P48@03
0040800Q00<08@03020000@Q00<48@041444@PA214882488124336<348@35:D36<H35:D00a24Oomo
o`0EOol001Eoo`04DY=FTeJCEY@6E[@3F[@00eZeF]EJe@0FF]D015ZdE[AJeEZd0eJd00=J]EkEG_H0
0U[E0UZd00MJ]E[EG]ENmUJdF[ANe@02G_H01EJdCU5641cW36<00P@Q01P8@`A2004000@R12448P@Q
12848@@R12448P@Q12848@@R12448P@Q26<<Ha2U5<H26>L00aS65<HHaP046<H26:H01aBV6<HHaQBV
5:D@QA24008<I00312408@0Q00d08@0812808@A212800@Q338@8@bP48P0A02448P@R12848@0Q1284
@PaT02400@0Q0048@PQ300048@04128222800`Q212848P021242104212401@0012048@@Q22401@Q2
00@<Ha245:DHaP8Li`8Q20037>LHaQBU00<@Q0@8@P8<H`0:46<<Ha246:DU23F/AS1>LTYAAQ02BS40
0dHaAS16<003AQ0XOol00`@R12448P05248@124824803`@R12448P@Q12848@@R12448P@Q12848@@R
12448P0:12401PQ136<@Q1BU6<DDY@8@Q00538<<H`aR36<<P`0236<00`Q2368@P`0248<01`aR2444
80@Q244<HQ23008DY0035:DDY1RU01PHYALHY0PLa@PHY@8La@046<DHYARU6:D26:@96:D26:@358@0
0aRT5:@DY@025:D00aB558@DQ00258@748@0311T48@@Q11T36@<H`Q212848@0112488P88@`052484
8P@Q0040800602400`0P02408@0212400`A11484@P0824841242248436<248@25:D26<H85:DGOol0
01Eoo`04DY=FTeJCEY@5E[@3F[@2F[DBF]D02eZdF[EJeE[EG]ENmV;fH_MF]5[EG_H00V;f00=NeUZd
EY@015kf019RmekfF[EBTf<GF]E>DSW=;DXLiQ23248<P`@Q00008@Q21282124@128010QS36<@Q1BV
0QS600DDaQBU6<HHaQRV00DDYP065:DDQA2548@<I0aS0PQ300<48@0Q02403@0Q00P48P0Q14848P01
24<<Q0Q3:0@R0P@Q00@48P@Q12448@848P0338@8@P@R00848P0424<<H`@Q12851242004512400`@R
2488@P023482368436<248<01A1S36<<H`aR34800PQ200<88P@Q12400P@Q00<88@PR34801`aS00P@
Q1cW<H]244iBCW9:DTXa0THa0dH`0dH@:7oo0P@Q0`@R0`Q240@Q20Q240@R20@Q00@8@@Q236<DY@<H
aP8DY@0348@<H`aR00@<H`072448@PaS48<<H`aR24400P@Q00@8@PaS48@DY0<DYATHYALHY0PLa@PH
Y@8La@046<DHYARU6:D26:@96:D66:@26:D75:D548@00a1T46<<H`0336@020aS24<8@P@R12448PQ2
34<236@010aS24<8@P@Q2@0Q0P@Q0PA23`Q200<<Ha2448@00a240QBU1QS61ABU5goo000EOol2EY<0
0eJDE[AF]002E[@5F[@00eZeF]EJe@0AF]D015kfG]IJeEZd0eJd00AJ]5kfG_IJe@9J]005F[EJeEkF
G]IFe@02E[@2F]D03eJdCY<YBB476:D@P`aR2488@@Q212400@000244@P0C128010Q326<<Q12U0QBV
00<@YA2548D011250a2400D<I0aS36<8@`Q200848P848@l08@0812808@A212800@Q338@8@bP48P03
00448@@Q00@48@<8@P0324<8@PQ20088@P090008@P@Q12848@@R12448P@Q0088@P0312848@Q200<8
@P0336<<HPaR00D<HPH<@P88@P0346<<H`aS00<<H`8@H`0334<@HaB4008DQ0065:DHaQcW9@PaRd8@
0TiB00=:<DYACU801TH`0TH@:7oo0`@Q;@@R20@Q0PQ200@<HaBU6<HLi`<HaP0348@<H`Q200@8@P03
1248@PQ2008<H`0724848@@Q1248@PaS48@00QBU00@HYABU5:DDY@8HY@<HQA8HY@lHY0PHY@PLa@PH
Y@8La@046<DHYARU6:D26:@86:D56:@46:D55:D258D348@246<536<02@a324<8@P@R12440@@Q1288
@P0324<00`PR12848@08024212401@A11488@PQ226802`Q20PaS0Q2411BU1AS600<LiaS66<H01ABU
5goo000EOol2EY<015JDE[AF]5Jd15Zd0UZe5e[E01INeEkfG_IRmV;gG]EJeEZdE[AJeEkfIcQ[FDic
?NlUBAC538<8@P@P00048@<480041448@@A1124214801@Q224<4@P@R02404@@R00D8@PQS38@@QA24
008<Q00336@8@`Q300@8@`@8@P0422848P@Q104200400`@Q02408@0=024020@R0244@P@R0048@`b4
24<W12800`@Q00048@0512400`Q26<HU:@03:DX00bDY6<H<H`03248236<348@336<5248:34801PaR
46<@Pa2458@DY0<DQ00748@DQ1B458DDYAB46:D00QS600`HYAc69@P]BT7_AS5>DTYBAQ123dHaCW83
AS05AQ0XOol00`@112448@03124[128912400`aS48@HaP026<H011BU6<H@Q0Q220@Q0`Q20P@Q00@4
@@Q236<@Q08DY@8HY@8DY@8HY@@HQA4HY@lHY0PHY@PLa@PHY@8La@046<DHYARU6:D26:@86:D36:@3
6:D00aRT5:@DQ00458@448@0111T46<<H`a30Pa200<8@PQ324<00PQ200@48P@Q12440@800@071244
8P@R12848@0Q12402@0Q0P@Q00<4@PQ2248020Q210aS0Q240QBU31S61ABU5goo000EOol2EY@3E[@4
F[@2F[DJF]D04EJdEY=BTeJdF]ES5fLhIaQNmUJdDY=:DCF/7>H8HP@P02000P0000<8@PQ124400PQ1
00T4@@000004@PQS26@8H`A212800P0Q40@R00D4@PQS36@<Q0aT0088@`0326<48P@R00D48P041244
8P@R1282124300400`@Q02408@0=024020@R0244@P@R0048@`b424<W128010@Q000480@Q0P@P00D4
8@Q236<@Q2U:008aS004>Ld]BPaS000224800`aR36<<H`0348@00`aS3688@P052483368246<00a23
58<DQ00:58@011B55:DHYARV0Qc600<HaQc67<L00Qc600<Pibe:=H`00Tic00I>LTYAAS1644H`BS42
AS06AQ0XOol00`0110440@03124b128010@Q128<Ha250aS600DDYAS648D<H`@R00@48@0300448@@Q
00H48P03248<Ha24008DY@036:DDYARU01PHY@lHY0PHY@PLa@PHY@8La@046<DHYARU6:D26:@86:D0
1AB46:@HYARU6:@01QB41A240Q1S00<<H`a224801@Q20P@R0`@Q0P@100@48@@R12888P848P@48@@0
8@0302008@0Q00<48@031444@PA20088@P848@88@P8<H`<@Q08DY@/HaP045:DHaQS66<H25:D248@G
Ool001Eoo`03EYAF]5Jd009F]09J]09J]AUJe@0@G]ENmUkfG_INeE[EHaMNmU[EDW923cF;9BPLiQ23
2442000040@Q368<P`b31444800P1204@@Q23688H`0Q1488@`A20`@R00<08@@R12803P@R00T8@`QS
36@<I0Q31284@PQ324800PPR20@R0`@Q00<40@0Q12403`0Q00P48P0Q14848P0124<<Q0Q39`@R1P@Q
00/8@@aR48<]JdicE[ABU5kgCU8Q20aS00L<HPD8@P04368<H`aS48<246<0112358@DQ1BT2QRU0QcW
0ac600/HaQc67<HHYAS67<LPj2TY<F`mkdXa009:DP=>DP03BU56<DH@00=6<0964003@Q123d8?02Qo
o`840@<48C@48P0:248<HaBU6<HHaaS65:HHaQ2536<524861242128010@Q248<Ha2411BU6ARU1aRT
21RU21S521c521RU0Qc500@HaARU6:DHY@8HY0PHY@0458@HY1RT6:@258@246<00aB448@@Q00548@0
10aS34<8@PPR0`PQ0PPR0P@R1`@Q1P@R00@8@PA21484@A048@03248<Ha24008@Q08DY@XHaP<DY@@H
aP045:D@Q12436<GOol001Eoo`AF]09J]003F[EJeE[E01MJe@AF]00=F[ENeF;fHaM6<3g^;FXLiQ23
2244000024400`@Q00L4@@Q112448@b326848@0202021240100Q00448P@R0P0Q00<4@P@R004040@R
00P8@`aT38@<I0A202448PA20PQ20PPR1@@R20@Q3`0Q00P48P0Q14848P0124<<Q0Q39`@R1P@Q00/8
@PaS48@mkekfF]IF]FLhDY@U:0aS008@P`H<H`0648<@Q12448@DY1BU0QS60aS50ac60QcV0Qc600@L
iR3W8>LQ1`8U20038>LPj23X008Pj00>8@PU22D8:DX]Bc6<>Ji1kdXaCW=BU4XaBU5:DP9>DP03BU5:
<DH`009:<@04AS1644H@@Pl2@NlXOol3124f12800`Q236<@Q@026<H01ABV5:D@Q@aT24<010Q200<4
8P@Q124010@Q0P@R00H48@@R24<<I1245:D258D25:D26:D468DA6:D76:@86:D@7<D86:D27<D011S5
6:DHYARU0QRT21RU00HDQ1RT6:@HY1B446<234800a1S36<<H`0336<234<00`a224888@03124010PQ
24888P@R10@Q0P@R10Q20`Q300D8@PaS26<8H`QR00<8@P@4@P<48@808@@48@03248<HaBU00<DYA0H
aPDDY@036<Ioogoo01Eoo`005Goo15Jd00=J]5JdF[D06E[E00Q[FEkfBU4aS1cW36<480000P@010@P
0P@Q1`Q20148HPQ114448@A12488@@@Q0244@PQ312800@0Q14848P0001048P0724<<I12436@48P0Q
12401P@R2`@Q400Q00P48P0Q14848P00248<Q0Q220@Q4@@R00h48@@R12448P@Q12848@@R12448P@Q
12848@@R1@@Q00`88@Q248<DY5:DJeYS65ZeJeUJeRe:5:D35:@55:D00acW7>HLiP037>L00b478@PU
:@03:BP4:BT2;DT6:DT01bU:;DXaS3V]@Nm:<Dic00=BU00:EYAF]EJeDYA>LdYBCW=>LTYBAS42AS00
0dXaBU9:D@02AS400dH`@Q123`02?NlXOol3124e1282124020Q348@DYABU48D@Q0aS248612400`@R
12448@0412401@@R02048@Q236<00Q240QB421B54ARU00LHY1RU6:@HYART6:DHY0086:D@7<D86:D2
7<D>6:D00aB46:@HY@0258@0111S34888@Q20PPR00L88@PR12488@@Q24888P0212401@@112488PQ2
12801@@Q0P@R112400<@QA2448D00a2400<<Q0aS36<00`QS00<8HPQ224800PA200`48@0Q02400@00
00448@Q248@DYAS65:H36<H00acW6<HHaP026<H00ac66<HHaP046<H021BU5:@@Q12348@HaB479BPG
Ool001Eoo`0;DY=F]5[EF_EJeEKDF]AJeE[DE]AJe002F]D00e[eG_INmP02F]D025JdF]ENmEkeF]EF
]5keF_D2F]D00ekeF_EJe@02E]D01Dic>LhQ:A2524802P@Q20Q200<<H`Q212401@@Q40@R00<8@`@S
12801@@R00D8@`aT48D@Q0Q200848@T48P0802808@0R02408P0Q02808@800@<08@<08P0400408@A2
148202402P0R1488@P0P1248@P@Q36<@Q0Q21`@Q00@4@@@Q12448@L08@<48@<4@P`48@041284@@Q2
24822242124010PQ36<DQ1BU15kF00MS65[F>JdDQ1S66:HHY@035:D26:D00acW8>LPj0048@P01b47
9@PU22D89BPY:BU9008]BP0=:BPY:BTY:DT]BReZ<FXaJcF/=JdicT8@AS400TYB00=>De:DDY@00e:D
14ic00=>LTYBBU800TYB00Y6DDHaBU96<D8@?Nle[C6<;F/YJRQoo`0712408@0Q02448PA212806@@Q
40@R2@@Q00<8@PaS38@00`aS00<8H`@Q12403`@Q00D4@@Q236<@Pa24008@H`DDQ00368DHYARU00@D
Q0PHY0`HYA0LaA<HY@<HY0XHY@037:HHYAR5008DQ00646<@@`a222848PPR0P@R00<48@@R124020@R
0`Q21@@Q0PaS0Q2400H@QA2448@<Ha2448<736<010QS2484@PA210@R00L4@P@R02448Q245:HDaP03
7>L00aS76<HDYP026<H00aRV7:HLYP037<H011bV6:DDQ1B40QBT00@LiB47:DP]JAMoo`005Goo00AF
]5KDE[AF/`9BT`06E[AJeEJdF]AJeE[e0U[E00AF]5JcG_EJe@9Je004F]EJmEkfG_D2F]D02UkfG_EF
e4ib?Phe[1cW5<H<Q0A20`0Q20@R00<48@@R24800PQ21@aS00<8@P@Q124010@Q40@R00<88`@S12<0
1@@R00D8@`aT48D@Q0Q200848@T48PL08P030244@PA20084@P@08P0300000@0Q00D08@0:12400000
020000Q136<48@Q1144612481487024612432488124210001PPQ36<@Ha1S58@HaP9Rm`0:G]MNeV<H
H_M6<BU:5:DHYAc68>L38>P02R3W7<LLib3W9@PY:BU:;D/aJbe:0bU90bTY00LYBC6;=H/eS3V]?Ldm
kP02@Nl3AS401DYBCW=BU5JeF]H01U:D0Tic011BU4YcAU5243g_>Lha[C6<:DXU:B486>LDY@b426<8
@RQoo`0612408@0Q02448@A26P@Q3`@R2@@Q00H08@A226<<H`QS2482148A124010A1248<Ha230Q24
00<@PaB458@00QB40QR400<HY1RU6:@00aRT51RU41c541RU0ac52QRU0aR500<HYAR558@00aB400<@
H`a336@00PaS00<8@`Q222802P@R0`Q21@@Q00<8@PaS36<00a240PaS00<@Pa1S46<01`aS00<8H`Q3
14800`A200L08@@Q12448@Q248DHa`027>L00acX7>LLi`047>L03Qc77<HPaabV6:DHQ1AS46<PibDX
;FTeZcW<?Nd2>L`GOol001Eoo`EF]007E]AJmEkfD[=F]5[DF_D00Ukf0UlF00EF]5[DF_ENmUke009J
m@07G_ENmUJdAS0e[24748<00`000`010P0Q00<48PA212801P@R0P@Q0PQ200<<Ha2448@00QBU00<<
H`Q212401@@Q40@R0P@S1@@R00H88PQ346@@QA242482124912880242124602441482248010A21448
@P@Q0PQ100@48@b35:D<P`88@@0314448@@P00<080<48@D4@P@48@@4@P031448@PQ20088@P<<H`D@
Q0<<H`0846@8@PPR36<<@`aS7>Le[@9S6006G_MNeV;hIaQJ]DXa1BD80RD900DU:C5[;D/]BRU:008Y
:P0;:DX]BS6;=H/e[3V]?Li1kd8?AQ1>D@02CU800dibDW=BL`02DY<015JdDYA>Ldic0TYB0Tic15Je
0U:D0Tic00PaS2e[9DXQ:1cW6<H@Y@b40PA20P@Q00@08@0P000002Qoo`0612408@0Q02448@A26P@Q
3`@R2@@Q00D08@A12488@PA201@48@051448HPb348@DY00558@26:@?6:D<7<D87<H87<D@6:D57<D6
6:D668D03QB558@DQ1R558DDI11S5:D@QA2436@<H`Q3248:128424841242248536<246<636<00`aT
36<<H`0224<00`Q21488@P0412400`Q25:DLi`028>L67>L27<L00ac67:HLYP027<H28>L022DX:DTa
RcW<?Ldic3F[<HXGOol001Eoo`03E[=F]5[E00=Je@05F]AFe5kfG_EJe@03E[@2F]D02UkfHaINmU:C
?NhYBAS548<8@@@P0P0000D480aR48<DY0Q20088@`032484@PA20084@PL48P848@03248<Ha24008D
Y@8HaP0336<8@P@Q00D48AH48P082288@PaS48@@QA24248000848@P48PP08@<0800312048@@Q00<4
8@031200000P00848@040200000000021200100036<DY0aR10@Q0P@P00<0800014802@A20`Q20`QS
10Q220aS10Q201LDY@aS46<DYA1S36<]BU9cHaQW66;hG_MRmfLHHaQJeUkgF[E>DdH@@Nm1l4H@009:
<@07BS9>DTiCDW=BU5JEE[D00eJd0UJD0U:C1E9c0U:C0UJD00QBTdicCW=:DSg_=JdYBRDY0a2400P<
H`Q212448@0026<8@PA10`@Q100000@08@@Q1444@P88@RQoo`0612408@0Q02448@A26P@Q3`@R2P@Q
00D4@PQ22484@@0Q008081448@03144<HQ23008DY0035:DDY1BT00@HY@8LY@037<DHYARU008HY@HL
aAhLaPPLa@lHY@036:@HYARU008HY@HHQ@0>58@DQAR558DDI11S58D@QA2436@<H`Q324888PT48P03
1248@PQ20088@P@48@88@Ph<H`0324<8@PQ200<8@P0:12088@PQ224<@QBT7>HPiR3W7>H27<H27>H2
7<H021RU68DHYAbV9>P]BSV/?Lh2?Ld013W=>L`ic3V/0SF[5goo000EOol4F]D00eKEE[ABT`02DY<0
0e:dE[AF]002F]D02e[fG_IW>6<hG_I>LSG=8@L@P`QR144010Q100<4800000000P@Q0`0Q00<48@A2
14801`@R0P@Q00@8@PaS48@DY@<HaP88@PH48AH48P88@P0736@@Q12536<8@P0012000`@Q00H48P@Q
12848@@R1247024912400`Q11244800212001@@Q2448@@@Q14400`aR00<HaAcV36<00PQ110Q200D8
@@Q226<8H`QR0088@PL4@P`8@P<48@H8@P0:348DYB3W6:DDQC6<F]IRmf<HH_P2G_L2HaP02F;gIcUR
meJEBU96<DHABS5:DP02DY@00eJeF[EJ]@02F[D00eJeDYAFU004EY@2DY<2EY@2DY@4DY<2CW<01TYB
@Q0icRe[8@PLi`@8@P051240000000048@0202400`@Q1488@P021482248214821242024XOol01P@Q
02408@0Q1244@QX48@l48PT48@051444@PQ224848@03024A124010Q1368@PaBT0aBU0aRU0Qc50ac6
00@HYAc57<DLa@`LaPPPiQ0LaPPLa@lHY@036:@HYARU00PHY@0558DDQ1B558@@H`0436<224<22480
0`PR12848P061282124424851242248<36<624800`Q11008800234401a1R7:@PiR3V9>HPiR35008L
a@8Pi@0=8>HLaR369>P]:C5[>H`mcD7>@NhmkSg=>J`00cF[00<e[7ooOol05Goo000EOol01U[EE[AF
]5JdF]EJmP9NmP08F]ENmV<GHcQS5e[EDY=:D@8U:0048@LHaABT4:@25:@010A1120480Q10`aR00@8
HP@R12808@800@0302448PA200L48P848@03248<Ha2400@DY@88@PH48AH48P88@P0736@@Q12436<4
8@0012002@@Q1`0Q00<48@PP220010@P0P@01@@P00D8@A1R5:@HaAS6008Q1`069@P]JRU948<<HPaS
0Q2300@@Q12348<@P`<8@P<4@P0414448@@Q124214431489248636<348@0211S58@HYABU7>M246Li
G_L3H_L4G_L026LHHaQS66;gG_MNeekFF]H2E[D2F[D015JeEYABU59d0UJd0eZe011F]5JDDYA>LTiB
AS51kcW==H`aJbeZ5:D@Q0aS24848@<000@8@P8<H`042488HPQR2482148224800`A212448@031244
024XOol01P@Q02408@0Q1244@QX48@l48PT48@051488@PQ224848@02024B12400`Q1368@P`045:@4
6:D01AbU7<HLaQc66:D00ac52Ac62b3V41c621c521RU00<LaARU6:D02QRU00DHQAB558DHYAB500@D
Q00346<<@`Q20088@P888P/48P848@D8@P<48@<8@P/<H`<8@P0;24488@PQ2248@@@0340@HAAR6:<P
i@029@H39>H0223U8<DPiBT7;BPaJSF<?Jd2@Lh00cV]=F/]B@02<FX0136:<H/aRS6:0ReY5goo000E
Ool2E[@04EJeF]ENmU[FE[ABTe[FF]EF]Dic@PlaS2DX6>HQ1acV6<D011BT00<@Y0aR24400`0000L4
8@QR368<H`QS24<4@P0;128212400`Q236<<H`0248@236<22486124E12800`PR2488@P0348@010aS
1240000P40@Q00<480@012000`PP00/8@0a0344880Q0344<@0a158<Q1Re9008aR`8e[003>Le23cF<
00<@P`@DY08@P`<8@P88HP03368<H`aS00<<H`<<P`8@P`H@Q08DY@0336<@Q12400D@Q0087>LHaQS6
8>P]BSg_E[E_FP9Nm`=Rm`=Nm`03EYAF]EZf00=JeP04F[IF]E[FF]H2E[D015ZfF]INmekg0U[F00aF
]4icAS0icS6<;F/Q22476<HDY0aS124200000`aS24848@02124224800`aS0000000612400`Q21484
8@0312400`0P0000000200001@0Q1244@PA22480:7oo00H48@0Q02408@@Q148J124?128:124010A2
2484@P@Q0P0Q4P@Q00D8@@aR48<@Q1BT008DQ08DY0036:@HYARU00DHY@<La@TLaQ8PiQ0LaPXHY@03
58@DPa1S008DQ0036:@DQAB500PDQ00746@@Q1B448@@H`aS24800`PR30@R0P@Q0PQ200@<H`Q22484
8@D8@PT<H`8<HP8<@P032488@@Q10088@@06344@@AR27:<LY2340RCU00@PaB349>DTi@8Pa0049>D]
:3F:@Ld3@Lh01cV]=H/]BBTX<FXeRcV/008ic003>J`eZc6:01Moo`005Goo00UF]5[EG_MS5e[FBU4e
[2DX4:@00Q2400TDY1BU6<DLiQcW5:DDaAS57>H00R4700DHaQBT1244@@Q1008<HP03244480000080
8@@48P808@L48P0312448PQ200@<H`@8@PH48A<48P0312448PQ20088@P<@Q00436<48@00020:1240
1`@P124480@Q12048@@P0088800H340@HAB36:@La1c5:BP]BCEZ<FXeRSg=DW9RmUZdF[ENeUkfH_IW
>59c:DTDPaB40aBT00@@Pa1R368@P`8@Q0035:@DYAS500LHaP036>HLiQcV008HaP@Li`XQ20095:DL
ibe;AQ1JeVLHHaQJeV<H00ARm`9Nm`03H_MW6F<H00IS6006DW=6<CW>:DXHaQ240PaS0P@Q00H88PQ1
22848@@00004124010PR2488@PQ20`@Q0`Q20P@Q0`aS0`Q20P@Q00D4@P@Q12448@A20088@P031484
@@A100<48@<08BQoo`0612408@0Q02448@A26P@Q3`@R2`@Q00<4@P@Q02400P0Q4P@Q00<8@@aR48<0
0Q2400<DQ12358@011B400<HQ1RT6:@011RU0ac51ac64R3V41c621RU00<DQ1B346800`a200<@HaB3
48@00a241A1T0Q1S00D@I12448@@I0aS0088@`<8@P0322848P@R00P48P848@03248<H`aS0088@P03
1248@PQ200<8@PT<H`03368<@PaR008<@PD<@@037:<Pa2CU00<Ti@0B8<@LXQR28:<Pa22S7:<Pa358
?J/m[3V;<DTY:2D7:BP]BC5Z13F;00@aRc6:<HXaRQMoo`005Goo00aF]E[EF]IJeE:C?NlYBQcV248<
HaBT6<D36<H00aC56<HHaP027>H011cW7>HHaQS60PQ11`@Q1`@R0PA21@@R00@4@PQ32488@P8<H`84
8@0324848@@Q00H48A048P888P848P848@03248<H`aS008DY@0436848@@Q124412001@0P000000@P
12400P@P01H48@@P120480Q1368<@A1Q568HXac48>DTiRD6<FTeJSV:>J/mZdH>DW5N]09RmP07F]EJ
]6;fHaMBLSF/5:@00QRT00XHa1RT5:@@Pa1S36<@PaBT6<DHaP<Ha@8HaP8LiP8Li`048>LLiacW7>L4
8@P27>L48@P37>L28@P032TY>Je>DU[FG_MRmf;hG_MRmf;hG_MRm`9W6004HaQW>F<HG_L2F]H025Je
DYA>LdHa>Nl]Jb485:D236<020QR12448@@R12448P@Q128A124010Q212448@@Q0PQ24P@Q:7oo00L4
8@0P0244@PA10200000I124?128:124224801@0Q0000000Q000040@Q0PQ200@8HPaR36<<H`8<HP04
46<@PaB358<558@26:@36:D27<D87<H88>HH7<H27<D66:D021B446<88@PP224@HQB46:@358@011B5
58@@Q11T1A1S10aS00@8@`Q22488@Pd48P848@8<H`D8@PX<H`@8@P8<@P07368<@@a1344@HQR39>D0
0bCT00<Ta2348<<00b330R2S00XPa2SU;BHaAcEY<FXaJC59;DT]:08Y:008;DTeRcV/<HX]JC5Z;FX]
JAMoo`005Goo00I>Ld8@;F/Lia232442000010Q1248@PaBU11S60QcW00<Q1b488@P00R4800<Q1`Q1
24401`@Q1`@R0PA21@@R00H4@PQ2248<Ha2436<212400`Q212448@06124C128312401PQ2368DYAC5
5:@8@P<480030208@@Q100D8@@03368000@P0088@@0Y368@Pa235:@PiBCV:@L]B3EY>H/mc47<CRm>
D59aDU5BD59aFY=Ne5ZcF]EJ]5JdF]ERmUZdBS0Y:2D77>HHaART6<DLiR466:@HaAcV8>LQ20089BP0
0b488@LQ1`027>L48@P29BT27>L03R489BTYBS6<=JdicTiCDW=JeVLiKg][FVLHHaP2IcT03VLHH_MN
mf;gG]IF]DYBAS4ikS6<9BTHia2426<224801P@Q0200000002048@P48Q048@0424848@@Q1242248B
124XOol01@@Q02408@Q226800PA200<8@P@Q12405P@Q3`@R2@@Q00P8@PaS36<8@P@Q14448@0Q2000
1`@Q00D480@Q1448@PaR008<H`H@H`0458<DQ1B458@26:@46:D27<D87<H88>HH7<H27<D76:D011RT
58<@Ha1S0QB400@HYAB448@DQ@8DY@0658@@Q12446<<Ha1S1@aS00@8@`Q22488@Pd48P848@8<H`<8
@PX<H`0426<8@`Q22483244222000`a1588LY0028<D00b348<<P``028<<01b2S7:8LXR338:<LXQb2
008LXP0B8<<Pa1c47<@PiBD6:BL]:2e9<FTaJSF;<HXaJS6;>J`eZbeZ5goo000EOol00aBU48@8@P02
00001@@Q2488@P@Q24800PaS0Q2411BU0aS60acW0PQ21`@Q1`@R00<4@P@R12800`@R0PA20PQ200<<
Ha2436<02`@Q40@R00<48@@R12800`@Q0PaS00<DY12426800P@P0PQ100<8@00000000`@000/480Q0
344<HQB37<DU1bTX:DT]JS5Z0091k@0;APi:;di@DW5FTUJCF[=Ne6;EG]EJ]002F[<015ZdDW9J]5Zd
0UJC0UkE00UJ]36:;DTU1ac57<@LaB3V8@L00RTX0RDX0R4700@Pib3V8@LQ1`<U1`<Q1`<]J`05:DX]
Jbe[<H`e[@02AS4014YBDYAJeUkg0U[F00=S66;gH_L00VLi00eS65kgG_MJ]UJECU9243g>=H`Y:AS6
36<8H`0324801`A212408@0002448@A200@8@Pl48PT48@0424848@@Q1242248B124XOol01P@Q0000
00A22688@QX48@l48PT48@040248@PQS148212400`0Q0008@P0?24801@0P12048@Q124800`aR111S
0aB400<HQ1RU6:D011RU0Qc51Ac60b3V223W223V41c60ac51ARU00@LaQRU58@@H`8@HP0358<DY1BU
00<DY@0558D@Q12448@@H`0536<2248224<224800`PR12848P0:1282124236<3248936<00`QS24<8
@`02248224402Pa2344<@AB38<DY1RT7:@HTa2342B331AbR00/HPQRS7:<La23U9>HU1RD7:DPaJC6:
008]J@03<FXaRc6;01Moo`005Goo00<48@Q236<00a2400<<H`Q224802@Q20`aS0a240PQ21P@Q3P@R
0PA200D8@PaS48@@Q0aS00/48A448PD8@P0536<@Y1S548@8@@0212004@Q1364<HAcU8>HU1bDX:DP]
JC6:=J]1kTH_DW9J]5kEG_D00V;f0eZd0UkD0ekE00EFTeZdG]ENeEZd00AJ/`9Ne@0<F[=FTeZdF]AJ
]6;fH_ENeEZdEY9>LDi@0TX`00E:<DYACW9BTeJd009Je@05G]ENmUkfHaMW5`03IcP3G_L2HaP00fLi
JeY[FP05IcT01ekgCW=242TZ8>LHaQRU008HYP047<HPib488>L27>L02B489@PLaQ1T12408@0P0244
@@0214800`@Q2488@P0324800`@Q02400@0A1287124010Q212448@@Q0PQ24P@Q:7oo00P4@P0Q0004
@PQS14808@0060@Q3`@R2P@Q00H8@PQR14448@A114891248000010A12448@@Q210aR00D@Ha2358<D
Q1R400LHY@8La@@LaP<PiP/Pi`TPiQ0LaP<La@@HY@087<HHYAB3344880PQ46<DQ08DY@@@Q08<H`03
48@<H`aS00<<H`88@P<8@`88@P`48P848@8<H`@8@PH<H`@8H`0;24<8@PQ2244<@A1R568HXb359>HY
1P029>D00b348<<Pa0058<<27:<011c38<<P`b330Qc30R341Qc400PLiBU8=H/]JBD78@H]JCW=5goo
000EOol836<0112436<<H`Q21@@Q0P@R0`Q20PQ30PQ20`@R0`@Q3@@R0`A200D8@Q245:D@Q0Q200/4
8A048P848@<8@P0G368@Q1BT7>LDY0aR244<HPb248<DXaS47>DU1bU8;FTeRcW<?Ne6;diAEY=J]004
F]@3H_H2G]D00ekDF[AJ]002F[@2F]@2F[@4G]D01ekDF[AJ]5ZdF[=BLUkD00=Ne@04F[AFTTiABS02
CU402dibDW9FTeZdF]ENeEJcE[AJ]5kEG_H00f;f00EW>6LiIcUW>F]J00=W>@0<Kg][FV<HG_MF]DYB
>Lh]Jac65:D@Q1B40QBU00`HYAc67<HLaQS67>LU:BU:9@THaPQ21482144214800`A102408@030240
100P02408@0Q4@@R1`@Q00@8@P@Q12448@88@Q848BQoo`072484@@A126<<P`QS14806@@Q3`@R2@@Q
00P<Pa2438@8@P@Q1488@PA220Q220@Q00L8@PQ1248<HPaS48<DQ0035:@26:D00abU7<HLaP097<H0
0b3V8>LPi`0E8>L28>H@7<H37<D36:D011c56:DDQ11R0Pa200<@HQ1S36<010aS00D<Pa2448@<P`aS
0088@P88H`032484@PQ30088@`88@P0322848P@R00T48P848@8<H`<8@PT<H`<8H`88@P08348<@@a1
68<TiBT69>DPa0<LX`037<<LXabS00<LX`047:8HPQRR6:827:<00ac37:<LX`047<<47<@011RT8>HY
:2U80RDX00<]JCF/Ool05Woo000EOol020011288@`aS48@@QABU6<H348@336<224<00`Q212848@04
12400`@R2488@P031283124:12800`@Q12848P02148224800a245:D@Q00<124?12800`@Q00448@02
12400`Q236<@Q0025:D248<03aBT7>HQ1bU8;FXi[3g=@Pi:<4iaDY9F/e[DG]ERmP03IaL016<FH_IR
mUkE0e[E00MJ]EZdF[AF]5kEF]EJ]@03F[@01U[EG]ENeEZdF[=J]09Ne@04F[AFTUkEG]D4G]@2G]D0
1FLGHaMS5f<GHaH00f;f1FLh0VLG01ES5fLiIcUS65[FDYA:DT8@?Nl]JbDY7>LDYA2436<8@P@Q2248
8Q1T7>L00RDY0RD800@YBRTY9@PPi`8Li`035:D8@P00008000050244@PQ22688@P02148314400`A2
2488H`0A1287124010Q212448@@Q0PQ24P@Q:7oo00P<H`QS36<@Q0b424848@A160@Q3`@R2@@Q00@8
H`aS26<08@@001048@08000080@Q244<HQ235:@HY@DLaP038<HPiR3V00PPiQPPi`@PiQ0LaP<La@09
6:D<@Q1R46<DPaB446<<@PPQ00<48@062488H`aS48@@Y0aS0`Q200@8H`aS2484@P@8@`88@P032284
8P@R00P48P848@8<H`<8@P8<H`<@Q0<<H`<8H`0324<8@PQ10088@@08344HY2T7;BLXiB348<<Pa0PL
``8LX`@L``DLX`037:8HXaRS00<HX`07488DPb3V;DT]JRU88@L05goo000EOol01PQ348@DYQS65:D@
Q08<H`@@Q@@@Q00436<8@`Q21284124224831283124812831242128214802@Q236<DYAS636<48@00
1248@P08124?1283124224805@aR48<DYAS6;FXYJRf;>L`mkT8>BU1BTUJcF[ANeF;eH_IS5VLFIcMN
e002G_D00ekDF]AJ/`02F[@025[DF]EJeE[EF[EF]5ZeE[@2F]D00eZeE[AF]003E[@015kEF[AJ/eZd
0UkE00=Ne5ZdG]@015Zd00=NeF;eH_H00UZd00=JeEkEG]D00UkE01AJeFLgIaMS5f;fG_EJeEZdE[@e
[36<:DXQ21S648@8@P@Q36<8@P@Q0`0000H48@Q2000400aS7<H28@P27>L02`a236<<H`a236<@Q11S
2488H`Q214400P@Q00D08@000004@@@Q00<08@80800302448P@R00l48PL48@0424848@@Q1242248B
124XOol27>L01Qd87>L@Y@A200008AP48@l48PT48@04148<H`b436<326<00`A212448@0>124020Q2
268<HPaS48<DY1S57<HD8>L<9@L98>L38>H@7<H47<D010a222488@a20QB400<@H`PQ24800PA100<4
@PQ224800PaS00@8H`Q21244@P8<H`032688@Pa300<8@`<8@P0322848P@R00L48P848@8<H`<8@PH<
H`072488@`Q314<4@PQ212400PPQ00L880a0568LY2348:<LXP028:<00aRR6:<HX`056:<011c47<<L
`ac311RS0Qc200@LXQRR6:8HXP8DPP087>DHXaS49BPaJRe97>HDY1Moo`005Goo0PQ20`a300<<HaB5
6<H011BU00PDQA2548@@Q1BU48D@Q0aS1PQ20`@R0`@Q20@R10@Q00P48PA22488@PaS5:DHaPaS0P00
00<48@Q212405`@Q0PQ20PaS00h@Q1BU6>HQ1ekgG_IO5f<hHaMJmEkfIcMNmF;e0V<F00ARmEkeG_EN
m@9RmP06H_ENmE[DF]ANe5ke0ekE0e[E00=J]EZdF[@00UZd0e[E00AJ]5JdG]EJ]09J/`9J]004G]AN
eE[DG]@4G]D045kDF]AW=f<FF]E>LT8?<H/Y:24658<@Pa1S3688@@@P0P000P@Q00<08@0002000P@Q
00<8@P0P12400PA20`@Q00L8@PaS24888PQ324848@0200001@@Q24888P@Q10400P@Q100000D08@A2
2488HPQ200848@84@P042484@PA2148A1287124010Q212448@@Q0PQ24P@Q:7oo0SW>00@icBf<7@L8
Ha`48@0=12848@@R12448P@Q12848@@R12448P@Q12802@@Q00P@Q1SV9BTYBBU:;F/YJRE922U:22DX
0Qd70acV00<M1b478@L0123W123V22D70b3W0bD700<U22D79@L01bD72R3W0b3V41c60ac500`HYA1S
2248@AB36<DLaQRU48<<H`QR2484124010Q214448@@R0`aS00@8@PQS24<8@`@8@P0314848P@R00L4
8P0502448@QS36<8@`0824801@@R1244@PA212800P@Q00<480@010000P@000@880`P320<808@@08<
@08<H0@@H08DPP8DP@@DPP8DP@04588HXQRS7<<27<@01RTW;DTeZcg==H/U1`8LaQMoo`005Goo00@8
8PQ2348<@`8@H`0348@DQ1B500HDQ@045:D@Q12436<2248:12400`@R02808P05028502402@A22688
H`A238@DYQBU36<48@0224800`@Q12848P061242144712403`0Q0200800P1448@PQR1448@@Q236<@
Q1BU8@P]J`02HaP2HaL01ekgG_INmUkfG]ENmF;e009S5P03H_INmEke00QNm@=Ne@03G[AJ]5Zd009J
]09Ne@07G[ANe5kEG]EJ]5ZcF]@00e[C00EJe5[CE]AFe5[D009F]00AF]ES5f<GHaMNmV<GGaIBTcW^
;FXQ:1cV4:@<HPQR144480020202120:1242024212401P@R14848@0R12808P@08@84@PD48P031480
000P01h48@88@PH48@0848@0000048@8@P0036<000d48@031488@PQ202Qoo`08AS4ikTYB@S0DY@@Q
368000<48@0312848@@Q00X48@042484@PQ2144B124224800`@112448@02104020@Q2488@PaS9BTe
S36<=J`2<H/00cW=<H/aR`02<H/0135[;F/aJbe[0c6;0S5[12eZ0RUY0bU900@YB2TX;DTQ1P8]B@04
9@LPaQB39@L88>L29@L58>L00b3V8>LPi`098>L00b3V8>LPiP028>H28>L38>H@7<H03Ac57:DLYAB4
46<<@PaR48<DY1B448<<HPQ200<8@@<8@P031248@PaS008<H`0424<88P@R24<424802@A212848@@R
12448P@Q12848@021282024010A226<8H`QS0PA21`@R0P@Q0P@P0P0000D400@P120400PP0088@0<8
8003240<@0a000H<@0T@H@0?6:@DPPa158<La23V:BPeRc6;>J`icC5[8>LHYAS601Moo`005Goo0a1S
00<@I1AT58@02QB40PaS0PQ22`@Q00<48P0R02801@0R00<08@A214800PA200T4@@A226<<HaBU5:H@
Q0Q200000P@Q00<00@Q224800`@R0`Q200P48@111240@@@Q0444@@110`0P00<0@@A126800Pb300P@
Y0aR36<DY@aS248U:Dic1ekg00ENmV<FH_INmEkE009Ne09Nm@ENe09Je09J]09N]0EJ]005DW9BDE9A
DW9FT`03F[@4E[83E[<02EJdIeQS5ekfF]IJeEJdCW=:D@02<J`02BU:6>H@Y0b336<4@@QR2444@@04
020:124402400`@Q1484@P0414802P@R02408P0Q02808@0R02400@0Q0P0110Q20`@Q00<8@P@Q1240
5P@Q00<8@P@Q12401@@Q0PaS00H48A2436<48A2436<<1244000XOol025JdBU9F]4ib7>L8@PaS1247
24<C248>124322800`@Q224<@P0246<0223WAS1NmV<GHaINmU[EG_H2H_H6G_H2F]D00eZeF[AF]002
E[@01EJcDY=BTe:CDY800TjB0Tib00IF/diADY9:D47^=H/28>H88>L29@L012478>LPib3W0R3V2b3W
1B3V0R3W0b3V31c600@PaQc67<HLaP<LY@037<HDQ0a200<88@07124480Q124448@A124401@Q200L8
@`a324<8@`PR1288@`03248214800`A112448@0612402@A10240@PA216<8H`AS14<4@P0200400`02
02800P0200800`01000400021204220020PQ344@PaBT6<DDY12346882408220020@0240480PP7<D]
BC5Z>J`2=H`01SV]?LheK23W6:HLaQMoo`005Goo112400@@I12446@@I0P@H`033488@PQ200`48@84
8PP08P0=12848@0Q02448@QS48@DYQ2524<48@0112800PQ21P@Q00<48PQ212400P@Q1@A100D<H`b3
38<<Pa2300<@Y008268<HQBT7>HLibDX@PmNm`INmP03G_MNmUkf009Nm@03G]ENmF;f009S5PARmP04
G_ENeEkEF]@;G]D2H_H00ekEF[AFT`08G_D023W==J`]JbU:9BTQ1aS548@238<00`QR144080021440
100P1484@@@Q0`0P00<48@A1124020@Q100Q00<48@A214801@@R0`0Q10A200D8@`A21484@P0100H4
8@0324848@@Q01d48@0724848B488@PYBRDY24800P0020@Q20Q2:7oo00QJeE:CF]E>LR47368<H`Q2
0PaS1PQ320Q24`aS1@Q200`<@PPR12448@PR348@Ha237>I>DV]IJcP2IaL016<GIcQW66LH16LG0f<G
00=Rmf;fH_H015kf0U[e0U[E1E[D00MFTekEEY9BLTX`:BPHY0088@L29@L012478>LPib3W0R3V2b3W
1B3V0R3W0b3V31c600@PaQc67<HLaP<LY@067<HDQ0a212488@Q10PQ200H<HPQ2248<HPaS38<236<2
24800`Q32488@P0224800`A224<8@P02248214800`A112448@06124010A10240@PAS0PQS00@4H`A2
148000D00@0:10848@00000400@P244<HA1R48<26:@01QS47>DQ1R3V7<DHY108@0888004000882TX
>J`2?Ld023V]>J`i[Cg>=H`PiaRU7<HGOol001Eoo`0546@@H`aS36<<@`03248822800`Q212448@0<
124912802`010000000Q1488@Pb34:@Lia2524800P@Q00<48PQ224802`@Q00<4@@Q124800PQ200D4
8@A12488HPaR00@<H`8DY0044:@YBE:CHaL2F]D2F_H5G_H00e[EG]ENm@03H_H00ekeG]ENm@03G_D2
G]D2F]@01E:CEY=FU5JDE[@00UZe00iJeEkfG_INmUkFEYA6<3F<:DT<H@QQ2444@0@P0`0000/<HPQ2
2448@PaS24848@002484@PA100808@051244@@A114448@0302400`@Q1444@@09124402400`@Q1484
@P0412401P@R1488@PQ200000@848@0312848@@Q00<48@0400048@@Q248P1242248021cWE[ENmekg
F]HYBPQ236<524861245248XOol025JdDY=FeDib9BT@Pa2448<536<334<00`Q32488@P05248336<8
48@25:D36<H011cW6<HHaQBU0Q240PaS010<@`PR2288@Pa3368@Ha23=HaJeFmJHaMNmF<GIaMW>0iS
5`03H_MS5V<G009S5P=O5P9RmP08G]EJe6<FG]EVmVLG@NhY1`XU1`048@LPib3W8>L28>H;8>L58>H2
8>L38>H<7<H012367<HLaQc60abU00<LaQBT46<00PaR00@@Ha2348<<H`8<HP0336<@Pa23008<H`<8
@P<48P032288@PQ300<8@P84@P0314448@@Q00H48@041440@PA216<326<01PA212808@0Q12408@84
8@0312848@PP00840007220<@AB38>DU1bTX8>H00QRT00@La23U7<DLa10<@@8@H@03220@HRe900=1
kP08?Ldi[Cg=?LhaJb3W6:DLaQMoo`005Goo0PaS00<8H`Q224806P@Q2@@R00@4@P000008@P8<P`04
38@@Y1cW48@324800`@Q00048@0824831242244324801@Q1248<Ha235:@00QBU00THYAcV8@LHaABT
<H]NmVMHE]@00Ukf0Uke0e[e00AJeEkfG_INmP9Nm@03F]EJe5[D009NmP=RmP04G_INmEkfF]D3F]H0
35kFG_INmUkfG_MNmU[EDYA6<CW=:DXPi`8@P`8<HP032444@@@P0084800900048@Q236@@Q0aT24<8
@PA200848@<08@<48@808@h48@808@<48@031488@@Q100<8@@<8@P042448@PQ22482244010PQ124<
H`Q20P@Q0`Q27`@Q0PQ200<HaUJeF]H00U:D00<U:@Q236<00`aS0`Q220aS0Q24:7oo0UJd00AFeDib
<H/LiP8DY@D@Q08@I08<I0`<H`L@Q08DY@@HaP8DY@@@Q00;46<<@`aS48@DQ12358@HaDibJcU_FP02
H_H00fLhIcMW5`0?IcP01fLgIcQW=fLgHcMW=f<g00=W=`06HaM[>6;fIaM_>4H?2bD700@Q1b3W8>LP
i`8PiP/Pi`DPiP8Pi`<PiP`LaP048<HLaQc67<H37:D02ac66<DHYAB448<@H`aR348@P`aS36800`aS
10Q21@@R00<8@PQ324800PQ20PA200<4@@@Q12401P@Q00/4@@A214<8H`QT26<8@`A21244@P@R0084
8@840@848@0=220<80a0564HXb3U:@H]9bTW8>DHXaR27:<00Qc400<HXaB258801QB2211Q00D<@A1R
344DPbe90091kP07APlmcCV/>JdmcC5[8>H00QRU5goo000EOol01PQS2688@PA214448@808AL48@P4
8P0:1248@`000008@PaS26<<HaBT6<H248@26<H010aS248<H`aS20Q210a20`aR21RU00PHaAcU:FU2
3U:BF]AJmEkf15ke0e[e00UJeF<GH_INmUkEG_IRmVLGIcP01EkE01=JeE[DE[ANme[GE[E>M4YB@Q0m
kcW>9BTQ21S648@<H`Q32484@@0812402`@R12448PQ236<8@`@R0048@P@Q02400P@Q0P0Q00@48@0Q
02408@l48@808@<48@0414448@PQ2243120210000`a224488@0522400`@00000000S124224801b48
G_MS65[FG_Le[ABU00<<H`@8@P8<H`P@Q2Qoo`=F]005CW8ikRDY6<HHa@0248@348DE48@=36<04Q24
46<<@a1T58DDQ1247<HYBEJDIaQW5ekfIaMW=ekfG]ERmP9Rm`eS5`QNmP04HaINmFLFF[@2G]D00cV/
7<DU1`099@L012478>LPib3W0R3V2b3W1B3V0R3W0b3V31c600@PaQc67<HLaP<LY@037<DHaAS5008H
Y@055:@DQ1245:@@Y00348@00a2336<8@P0224800`@R12448@03128010Q32488@PQ20PA200<4@@@Q
12401P@Q00P4@@A226<8H`aT26<8@P@R10@Q0P0000L400@1220881107:<Ti@03:@H012CU7:<LXabS
0b3400<LXaRR6:<01aRS21BS00H@PQRS588DXbU8=J/2>J`023g=>J`i[CV]<F/PiQRU7<DGOol001Eo
o`<4@P0314448@0Q00808@P4@@l48@T48P0@24848@@Q268<HPQR5:DU:Be[:DXaS3g_>LdQ21245:D5
36<00a2348@@Q0086:D041B45:@HY1RU7<HLiR3W9@PYB36;BU1S5VLgF_EJe5kf1eke0ekf00IS5ekf
G_IJeEJdDY<3IcP2HaL2G_H04E[F<H`YJbDZ7>PDYPaT14848@QS14808@0000448PA224800P@R1PQ2
0`Q300X<H`aT36@48P0014848@0Q1488@P848@0324848@@Q00D48@0302448@@Q00d48@<8@@043448
@@a1344234803@PP120880PP224<HQB358@DY1S67>LDY@Q20080000324848@@Q01/48@<8@P088@QF
]E[FE[ENmcg_7>L<H`H@Q08DY@<@Q0055:DHaQS66<HLi`0XOol025:DE[ABTdicBU4e[2488@L46<H0
11RV5:HDYQBV4QS60QBU112410aS112400XDQA245:DHaQRU6<H]JTH@H_MW>09W5`04JeUW>6;fIaL4
HaL2IaL2IaP8IcP3HaL00f<gHaMS5`02IaL00f<FG_E[=`02H_H00ekE>J`U1`0:9@L012478>LPib3W
0R3V2b3W1B3V0R3W0b3V31c600@PaQc67<HLaP<LY@0358@DY1BT008DY0035:DHYAS5008@Q00548<@
Q12T48@<H`022487128010Q32488@PQ20PA200<4@@@Q12401`@Q0PQS00@<H`aT36<8@P<48@0H1204
00@0100480PQ344HPQbR9>@Y1Rd6:@DTa22S688LXR2S8<<Pa2338:<LXac31ac421c3010Ha1cU6:<H
Xbe8=H/eRSF;?Ldi[3W=?LdaJb3W6:DLaQMoo`005Goo1`0Q00<0800Q02401@0Q00<48@A112403@@Q
20@R00D48@aS368@Q1BT008@Q00::DU245[FE[AJeV<HCW<YBA2438<35:D00aS56<HLi`028@L29@P6
9@L03ac68>LY:35[@Ni>DUZdG]INmV<GHaIJe5KDG_IS5P03F]D015[eG_ENmUlF0V<F00iO5f<HIcQS
5eJd@Pl]JQd748@@Pa1S3688@@@P0P0000<48P0R12800`A200X4@`A21484@P@R1488@`A212808@P4
8P800@071288@`aT36@8@`@Q22800P0100D4@PPR02440@Q200848@848P848@0310400@@Q00P48@03
12048@@P00<48@09244@Ha2358<HY1c58>HPibD7008PiP079@LY:2eZ>Ja1kTH@BU400U:D00DmkaS6
000000aS01d48@<8@P08?NmS65[FE[ES65kgDYA240<Q20067>LQ22489BTYBRe[0S6<00DicSg_@Q16
<DYB02Qoo`08D[AF]EJdE[AJeDIA<H`aR`8U:@039BXU:BDY00<U:@039BXU:BDY00dU:@DQ20DLi`<H
aP<DY@0:8>PPib3X9@TQ22TY@Q1S5fLhIaP2G_H01F<GG]EJeF/hH_H00V;g3F<G00=S5UlFHaH01F<F
00QNmU[DIaMS5V;EEY<aJR3V2RD700@Q1b3W8>LPi`8PiP/Pi`DPiP8Pi`<PiP`LaP048<HLaQc67<H3
7:D021RU5:@DQ0aR2488@@Q2368324401`Q23688HPQ112448P@Q00@48P848@0424<8@PQ224821480
0`A112448@0712400`QS36<<H`0236<01PQ2124480@Q120400888003344@HQAR008Xi@06:>@Ti2C4
9<<P`b2S0R3300LPXabR784LPAbR8:<LX`077<<:6:<01AB26:@aJT7]?Nd00Sg=00LicCg=?LdaJb3W
7<HPiP0GOol001Eoo`D08@050444@@A20000800202401@111444@@A136<00P@Q00D8@P@Q1248@P@Q
0088@PH48@@48P0312448PQ200<<H`8@Q00?58@HiS6;AS1F]EJdF]INmTib;FXDYA235:DHaAS600<L
iP036>HHaRDX008Y:0039@PU1b3W008Pi`0;9@PY:C5[>Je6459cG]ES5fLgHaINmP02F]D015kfHaMW
=ekf0elF0f<G00mNmUkgGaMJeTjC@Q0a[2DY6<D@P`aS2484@@@Q12000P@Q00h48P121280@P@R0484
8P121280@P@R04848P122P@R00P40@@R128@I1S736@00@@120@Q0P@R1`@Q1@@P00D88@Q11248@@Q2
008<HP062488@@PQ48<HY1c60R3V00<PibTX;DX00Re:00haJS6;>Ja1kdXaCW9J]E:DF]I:DPaS2480
00Q240@Q200Q0P@Q00T8@P@Q12448@Q236=:DUJeG_L00e[F00MF]DYB;F/YBRDY:DX]J`05<H`00cF]
>Lhmk`03?NlXOol2DY@3E[@01U:CAS4mkbe[:D/YBP@U:P03:BXYBRU:00HYBP039BTYBRU:00DYBP@U
:@HQ20HLi`@Q2004:DXicU9cG_L2H_L6H_H8HaL2IcP2IaP3IaL2HaL016<gHaMO5UlF0V<G00ES5V;f
F[A_FEZd009Ne@03:BPU1bTX008U:0<U208U1`<U20dU1`<Pi`DPiPDPi`<PiP8LaP087<DLaR3V8>HL
aQRU8>LPaP<LY@8LaP047<DHYAB4368434800`Q21244@@042446124412800`Q32488@P0514820242
02001P0Q1244@PQ224<<H`8@Q00B46<8@P@P100880@P100880a1568HY235;@H]1BT5:>@T`b331b2R
0abR21bS21RS00HDPQS36:<La35Y>L`2>J`3?Ld01CV/<FXY:23V6<D05goo000EOol2024202001000
0200800P0`A20PA100<08@@Q02400`0000@48@001248@PP48@88@P0>46@HYQcW7<LDYA243688@PaR
46<@PaB48@M23`9NmP07E]EJeE[FCW<aS1S648<00QcV00@Lib478@PU:08YB@0A8>LU22TY<F/eS3W=
@Nm644iBEYANeV;gIaMNmUZeEYAJe@04G_H04e[EE[AF]6LhHaMNmUJdDY=:DD8?>LhYJRe[:DXLia24
248080000088@P0314848@@Q00848@84@P0=04848P121280@P@R04848P121280@P@R04802P@R00P<
I0Q324<<I1BV24<000PR2`@Q00<40@0000000P0000<48@@P12400PQ10PaR00L<H`Q1248<Ha245:@D
Y@026:D042e9<H/i[Cg>@Ni1kdX`CU5J]5ZeG]IRmVLHJcQ[>F]I0VLi00=_Ndic12400P0000<<H`@Q
12403P@Q200Q0P@Q00P8@P@Q1248@PaS48A:DUJe0f<H00][FVLiG_MNme[FDYA:DTHa@Q0mkcW>008e
[@06<H`YBR486<HDYA24:7oo0UJd00EB]5JdE[AF]4ic009:DP05AS96<D8@?O0mc`02>Ll013F^=Jde
[CF]136<0cF]1C6<0SF]1S6<0be[1BU:00PQ22TY<F`mkdicF]IW66/i26<G0f;f1F;g16<G0fLG00=W
=elFGaH00elF00]S5fLGIaMW5e[DJeQNeF;fF[@Y:2D700@Y:0049BPU22D89@P29BP39@P;9@L28@L3
8>L38>H48>L48>H02R3W7<HLaR3V8>LPiQc66:DPaQc60QbU0Qc600HLaARU7<HHYAB446<448<338<0
0`aS368<HP04248612801PQ32484@PA214448@84@@D48@041448@PQ236@246<00`aS3488@@023442
10002@PP468HPac49>HU1RCU:>@Ti0029<<00b338:<PXP058:837:887:<86:<01QBR6<<DXQS3<FTm
k@8mc08i[08mc@8i[003=H/aJWoo01Ioo`005Goo00<8@PA214801@A200<48@0Q02400P0P00<08@@Q
12400P@Q00D8@PaS12448@aS00P8@P0336<@I12400<DQ@8@Q00:58@HaQRU6<DPibe:?LiBTf<GG_H2
E[@01E[fF]E:DCF/;FX00b470RDX018YBBeZ<H]23dH`BU5>LU:CE[ANeUkgIaQRmekfF]IJeEkFH_L2
HaL026<hIcQW>FLhG_IFeE:d;FX2:FX2;FX02bU99BPQ1b4Y9BTQ212U14848@@R14400P0Q0`@Q0144
@@A214848PA21284@P@R14848PA21284@P@R14848PA200/48P0724888PaT5:H<@`@Q36<00`@Q1@PQ
00L400@Q2248@Pa236<@H`0348<04ABT6<DLaQcV8>LQ1beZ<H/e[3W=?LhmkT7^@NmBLeJdG]H00V;g
00=S5fLhJeT00f/i00AW>6LHHaMRm`9NmP07HaQW>DHa00048@00248070@Q0PQ200T<Ha24HaQ[FVLi
E[E6<Cg_<H`00RU:00LU:B486<HDYA2436<8@P08124XOol01UJeE[ABU5:DE[AFe@9Je@09BU=:DTXb
AS524D7`?O0mkcW?00@icP<e[@HaS08]J`<aS0L]J`@YBP8]J`08>JhmcdHaDYANmf<HG_MJe@9NePIN
e@ES5`9W5`03IaQS5f<G00MS5`03HaIO5UlF009S5P0:HaMW5fLGF[AW5ekeH_EBLRD7:@L;:BP29BP3
9@P;9@L28@L78>L38>H00ac68>LPiP047<H00ac56:DLaP027:D27<H01AbU6:DDQ1c66:D011B400<D
Y1B45:@00QBT00@@Q12336<<HP<8@PH48P88@P0314848@@Q00<48@84@P0614448@A11488@PQS0Q24
00h@H`a224888@a1348880a1588La2CU9@HY1RT522330b2R1AbR21bS21RR00HHXac3588HXc5Y?N`2
?L`3?Ld00cV/=J/eR`02<FXGOol001Eoo`848@030240800Q00D48@@000848@0736<@Q1S65:D8@PaS
48@020aS00@@HaB558D@I08<H`0<48@HYAc69BPLiR47>JaBLU[EF[AFTe[E0U:C00=JeEkfF]D00U:C
1EJd0U[E00AJmUJeF]ENeP=NmP0:H_MS5ekgHaMS66;gEYA23bU:7>H236<00`Q212400003000040@P
124<HaS69BPU:BU9:DXUBRU:9BTDY@A21248@PQS0P0Q00<48@@R14800`A260@R00h000@R248@Q1S6
36<000Q146<@PaB45:@HYAS50acV00`Q1bTY;FXe[3g^AQ16<5:CE[AJeEkFH_H3HaL015[EG]ENmUkf
0f;f00QRmeJeF]IJeUkFF]INeUkg0V<H00MS5f;gH_MS66LhJcU[FP03IcT01D8@124<H`@Q000070@Q
00@8@PaS48@@Q0800003124000@Q0088@P<48@H8@PH48@88@RQoo`9:D@96D@05BU5>LTicDY=F]@02
E[H2F[H3E[H5F]H6G_L2HaP5IcT<HaP2IcT026<HH_QRn6<HIaUW66;gG]H4IaP4IaL2HaL00fLGIaQW
>002IcP016/hIcQW66LG0f<G00=RmekfHaL00UlF00QS5UlFG_ENmEkfIcQJeF<F0V;f00=:<2D7;BP0
0bTY2RTX0RDX00<U22D79@L02bD70R470b3W0b3V21c600<LaARU6:D00ac600DPaQc66:DDQ11S008D
Q0T@P`0738<<H`QR2488@@Q212800P@Q00@40@@R1284@P88@P0314848@@Q00<08@091484@@@Q1244
@PQ226<<Ha1T008@Q00=46<<@P`Q224<8AB37:@PiBD6:@HY1BCT8<<00b2S00PP`b2S8<<PXb338:<L
XR2S1QbR1abS21RR00HL`ac4484DXReX?N`2?L`01Sg]?L`eZc5Z:BPU1`8PiQMoo`005Goo00<8@PPR
12401@@Q00<8@PPQ12400P@Q00L88PQ236<DYAS68@PLi`0236<00aBU48@<H`0436<448@011BU6<HL
aacW0R3W00`Q1b3W8@LaJTXaG_ES5U[DDY9Je5JdD[<3E[@01EKDG_EJeE[EG_D00ekf00INmE[EG_IN
melGHaL2GaL03F<GHaQW>6<HG_MF]DIA<H`LiPaS48@<I0Q300<48@@8@P0348@LibDZ008U:@099BXL
j2497@P<Q00Q00000@0Q00848PD4@QT48P<8@P0I48@Ha@aS120<HQB45:@HaAcV9@LY:2U9;DTY:2e9
<FXi[47^BS1>DE9bF]ENeEkfH_H016<G16LG00aS5f;fH_INmUkgF]MJeUJfE[EFeU[GG_L2HaP01elH
G_MNmekgF_MJee[F009Nm`04?Nl000aS248M12401@Q236<<H`aS12400PQ200<48@0000000P0020@Q
00@8@P@Q12448@@002Qoo`03>LdicSW^00<mkP8mk`05>Lhiccg_?O11l003@Q06AS45BU8014icDYAF
]EJe0e[F2UJe15[F00ARmf;hG_MNe`9JeP03G_MS5ekf00QNmP9RmP=S5`9W5`=S5`AW5`04HaMW=f<G
HcL2JeP2IcL02V/hIaMNeEkEG_ENeDH?:BPaJBU90bTY2BTX0RDX00<U22D79@L02bD70R470R3W0b3V
31c6123600PLYAR446<<@@a2368@H`aS10aR0PQR00<<HPQR24800PQ10`@Q0`0100H48@@R2488@PA2
144812401PA12488H`b348@@I08@H`8<@P03448@HQB3008TiP069@HY1BCU9>@P`abR0b340b330R2S
0abS00<LXQbS7:804AbR00HHXQRS6<<DPARR<FP2?N`01Sg<>J`eZc6:;DTY:08U1`038@Ioogoo01Eo
o`005Goo00<88PPQ22400`@Q0PPQ01048@PQ348@HaRU7>LU22TY<H`e[CW>:DX@Q0aS48@<H`<@Q0<D
Y@8HaP0@58DDYARU6:DHaR3W9@PYBC5[?Le>DEZdE[ABTeJCF]D2E[<02E:cDY=BTe:CE]ANmU:cE[AF
e002F]D00e[DE[AF]002F_H015KECY=6DCh?0SW^00<Q:1SV26800P0P00<4@@QR26<01@@R00`48@@1
00448P@Q36@Lj2DY8@TPj2495:H26>L00a2524<4@P07148412803@@Q12848@@R12448P@Q12848@@R
12448P@Q00T48P051248@PQ1124@Q0039BP04C6;;FXaRSF;>L`mkD8>ARm:<5JcF[AJe5kEG_ERmV<F
HaL00Ukf1V;f1ekE00AJeF<HGaQNn09Jm`06G_QS6F<iGaQS6FLj0VMJ00AS>F<IG_QW>@9[FP05AS40
0000124@Q00712400`A112448@0>1244248336<00`Q200048@04124524821243000312400`Q236<<
H`0248@XOol2000312000`0P000000021246128824831243248236<248@=36<00a2434<@H`0248@2
46<00aB46:D@P`0748<26<D27<D00ac67>HLiP027>H01B3V8@LU1bDX:BP00RU900DYJBU9<HXmkD8>
008mk@03@Pi>LDia009:D004BS0eRbD7;BP4:BT7:BP29BP39@P;9@L28@L38>L38>H<7<H00b3V7<HL
aP027:D01QRU58@@HP`Q348<HP8@H`04368<@PQ22484244524802P@Q10400@0112488PQ32484@PA1
10@Q00L4@@A21484@PQ2268<H`0348@01a1S348<8@a258<PaRT7008U1P039>DTi2CT00<P``8Ti0<P
a0038<<PXabS00LLXa0LXP066:8DPQRS588HXRe80SW;00Lmc3V[>J/eRc5Z;DTYB002:BPGOol001Eo
o`84000?22488Pa346@DQ1BU8>LU22TY<F/i[Cg_AQ16<Dic009F]@06?NlHaQ246<HDYAS60acW01HQ
22DY9BTYBRe::DXY:BDY:BT]JcV]@Nm>LUJCF]ENeEJCCU5BLU[DE[=B/`9BT`9>TP05CW9:DEkeG_EJ
m@02F]D00eKDE[AF]002<J`012UZ7BPDY@QR0P0P00<8@PA114400PQR00D4HP0P00048PPR00@8@`0?
22848P@R128<I249:D/U2B499BX8@`b436@8@`@R0084@P031284@P@R00<08P848P0314848P@Q00d4
8@L48P@48@03368U:48?009:D@07DY=Je5kDG_ERmF<FIaL00VLg0f<F00=RmEkeG_D00Uke0Ukf00=N
mEkEG]D01UkE00INmEkfH_IS5V<GF]L4E]L3E]H2E]L01e[gGaQS>FMJJga_O6]J009S6005AS448@@Q
00048@0724891488248336<348@00`aS2488@P03248312400`Q200048@04124010Q236<8@PQ21PaS
:7oo00@000@P12448@8480848@0624848P@R12400@@12P@Q20Q20PaS3`Q200<<@Pa334<00Pa20PQ2
0Pa21`a110a21@aR00<@HQ2358<00aBT00DHaAS48BLeZcW]008e[007?LdaJSV/=H/aJSF::BP00RD7
00<Y:BTX:BP01BTX0RDX0bD82bD70R470b3W1B3V1ac600LPiQc67<DHYAB46:DLY@056:D01AR446<@
@Pa136800Q2300@<H`a22488@P@8@@0;2488@@Q2244<H`Q322848@@112448P0224800`A21444@@02
1482248536<010b448@DYA240aB400@HQ235:@L]:08Ti@8Pa0048<<T`bCS9>@58<@00ac48<@L``08
7:<?7:800aRR584H``025:801BD5:DLY9be8;FT00Re800<Y:2DW9@H00R3V5goo000EOol02Ac67>HU
22e:=H`mkTH@BS5FU004E[@3EY@01e9cE[EJeT8@8@PLibDY008U:08U:@08:DX]Jc6<=JdicDH`CU9F
U0=Je@=J]003DY=>LU:C009F]09BT`0=F]EF]5:CCW9:DD8?=J`UBABT48<<HPQ112000`0000D8HPQS
26<8HPA20084@@031484@@0P008000061444@PA20248@PPR10@R00D88PQ324<48PaT008Ha`0648D8
@`Q324<8H`Q30P@R00D4@PQ212848P0Q00<00@0302448PQ200l48@L48P848@07248@PacV>LeJeEkf
E[@01E[D0e[C00=Je6;eG_D01Uke0Ukf00UNeE[EF]EJeEkEG_ENeE[EG]D00Ukf0V<G00=S>6LiIcX0
0VMJ01=W>UlIF_MFeU:EAS8aSAd848D8H`QT38@8@P0036<HaP005:D<H`0A248836<348@25:D01Q24
34<48@PR248<@`8@Q0055:DHaQcW8@TU:@02:DX032U;;F`e[SW??Nm244XbCWAF]E[FG]MNmbQoo`04
1204@@Q1144212401@Q236<<H`Q222800P@R00<4@PQ324<00P@Q00@48PQ22488@P8<H`0:12848@@R
14448PA12484@PaS268324800`A22488@P0924801`@Q00440@PQ2488@@@Q00@88@@8@@<8@PT8@@04
22448@@Q1242120021239BP]JRDX9@LYB247<FX2:BP00be9:BPY:009:BP39@P=9@L38>L78>H87<H0
1Qc56:@@Ha1R46<DP`<DQ00768@HYART58@@H`PQ36800Q2300D<H`Q12448@@A100@8@@<48@045:D@
Q0Q3128212401P@R2484@PA21284@P88@P0624<8HaBU4:@@Q0b4112400P@HaRT8>HU1bT79@HTiR3U
1B3400@ThbCT9>@Pa0LLa0HLX`8HX`lLXP056:8DPAc46:8@H@026:<01AB26:<DPQB35:<01ART5goo
000EOol021cV9BP]JSF/?Ni23dY@CW43E[@2F]@2E[@01UJcDY=B]5:C@PlaR`8U:0<YB@0?:FX]JS6;
>LdmkT8?AS1>LEJcE]AF]5JcE[AJe5Jc00IBT`09DW=FeDicAS4mkcF]<H/U:B47008<H`0324848@@Q
00848@052488@a2448@8@`04128200400`0Q12448P0312800`@Q12848P02228212802`@Q1288@a25
5:HDYA2436<8@PQ1224010@P0PPQ00T8@@@Q244000Q1368000Q112402P@R0PA200D48P@Q02448P@1
00800@0312448P@Q00<48@056>I23e[EE]ABT`02E[<00eKCF]=Jm003G_D015kfF]EJeEke0f<G0Ukf
00EJeEKDE[AFe5[E009Jm@05F]ES5ekfF_INmP02HaL05EkfF]EO65[GE[EBU4jDCW=:DdYB?NlecR4Y
5:D@Q0Q3248@Q0Q21248@P025:D00`aS248@Q00824800`aR2488@@0224400`Q234<<H`0236<234<3
36@04A1T5:HDYABU58D@Q0aT34<8@a1T48@DQARV7<LQ22D99BX00Re/00XaSCF^>Llml3ga@Q5:E4id
CWEBU@9F]P9JebQooa048PP4@P0@12848@@R1488@PA212808@Q314848PA22484@P@R124?14891440
10A214448@A20PQ200<4@P@Q12401`@Q00L88@@P5:@YBBe9:BPY:@09:BP00bT8:BPY:002:BP00bT8
:@LU1`02:@P3:@L79@L29>L<8>H28<H37<H27<D28>H01ART34888A1258@01ABU00<DQ12448@00`aS
00D<HPQ22488@PQ10088@P0324448@@Q00848@04248<H`Q2248412400`@R24<8@`0224<236@0111T
48@@QA250aBU00P@YA2448@DPQbT9@HY9bD60R340R3U0b34123T00HPiB347:<LXac37<@28<@47:<4
6:<00abS7:8LX`056:88688012346:<DPQR20QRS00PDPaB26:@HY1BT5:<DY1RT0QS55goo000EOol0
248>ARm:DDibCY9BTUJcE[@3D[<00e:CDY9BTP02DY801EJcE[AF]4ib@Rl00Sg^00Ln3T8?@Rm6<4YA
CW9>TP02DY<00e:BE[=Je002F_D03E[EG_ENmFLhGaMFeDjCAS4mkcF]<H`Q1aS6008@Q08<H`031240
00Q20088@P<48@88@P04128<I0aT24<4128324<00`PR12848P021285124200402@0000448@Q32488
8P@Q0040000324401@a1364@HQ1R48<00Q1R00HHY1BT8>HQ1`a13685148312831485128324<03`PR
12848P@R248<Ha24:DU6<5JdE]EF]5[EF]AJd`02E]<2E[<2E]@3G_H3G_L2F]H00fMIIeQS>002GaL0
3UlFF_IFeDjCBW52<3h>>NhikCF/;H/LiaS65:D448@236<03Q2424848@Q2124000@Q248000@Q48@D
Y@aS1244248536<010aR46<@PaB40QBT00@DYAB55:DDY@@DYP0D6:LHYPa346@HYR48:DXaK36==Hdi
[SW>?Lm1l4HaBU9>DdidDYEBUP9F]P03E[MJee[G00IJe`03E[MF]UJf02Qooa048PP4@P<48P071488
@PA212808@Q3248010A200<48P@Q14807PA200<48@A214801@A200@48@PQ100HY08]B@03:BPY:BTX
00PY:003:@PY:2TX008Y:003:@PY1bT700@U1`@Ti`PU1`PPiP<PaPHLa@088<HPiQRT468<@A1R58<D
Y0<DY@@@Q08<H`T8@P<48@<8@PD48@88@P0622<8@`a436@@IA250QB500<HYQBV5:D00QBU00PDY1BU
5:@aJBTV8>@Pa2CU0bT6014TiB3T8<@Pi2CU8>DL`aRR7:<HXaRR6:<LXac37:<HXac400<L``@LX`03
7<<LXabS00<LX`8HX`LHXP<HX`8LX`<HX`046:@DPaB348<258<35:@GOol001Eoo`04D[=F/eJcE[<2
D[<2E[<5CW82DY801U:CBU5>LTjBDY=BTP9BT`04D[=:LDibDY<2E[@01e:CCY9>LUKDE[=BTe:B00=B
T`0;CY<e[36;:DTQ21cV5:@<H`Q136<8@P0212432486124324801@aS48DDQ@aT24800P@R00<40@@Q
124010@Q00<48P@Q24801`Q201000@@Q12848@@R2488@`aS48<DPaBT6<DLiB3V8@HQ1`8eR`06?Ldi
cD8>>J`@P`Q10`A20`@R0P0R0PA20P@R0P0R0P@R00<00@@R12800`@R00L8@PaS36<LicW=BU9BT`02
E[@00e:cF]AJe002E[<01EJdF]ENmV<GIcP00VLi00=W>6<HHaP00V<H00DicSG=<J`]RbUZ008UB@04
8BPHiQBT38<3268314400`@Q00000004000010@Q248000000PQ20P@Q00H<H`Q2248HaQcW6<H248@0
0`aS48@@Q00348@00aBU5:@@P`0248<01QB45:@HYARU6<HDY@<HYP0:5:HDQA2546DY:S5[>Ji64DiC
DW@2DY@3G]L2G_L016;gH_QRn6<H1f<I0e[G0ekh0U[G:7oo40@R20A20`@R00L4@PQ324848P0Q26<8
@`0514800`@R1484@P0M14800`@Q1484@P05148020@Q224401BT:DT]BBTX:DT9:BP2:@P2:BP2:@P5
:@L99@L00bCW8>HPiP098>H;7<D021bU68@DPa1R48<@H`aS48@436<010Q236<<H`Q20`@Q0`Q21`@Q
0P000`@Q00P8@PaS36<<@`a446@DQABV0aRV00XLaQS66:DDYARU6<DLaR3V:BLU1@8Pi0089@DU1R3U
7:<La1c37<@Ti@8]9`069>DHXaRR6:8HPQRS0QbS00<HXaR27<<00Qc32QbS2aRS00dDPQRS7:<HXaB2
568HPaRT58<HXaRT7<DLi@028>H00b46Oomoo`0EOol001Eoo`ABTP04CY9BTU:BDY<6E[<3D[<2DY<0
1TjBCW9:DDH`@RmBTP=BT`07CW96D48??NhM1QS448<00`aR00@8@@@P2488@@848@88@P848@88@P84
8@<8@PD48@0524848@@Q1248@P0236<01@Q200000001000010@Q0`@R01H48@0012048@Q1368@PaBT
5:DLib489BT]JS6<=Jdmkd8@CW9BLUJCF[AJe@=Ne@08F]AF]5kEF[AJeDX`5:@480<8@`0314<4@PA2
0084@P88H`0524<4@PA21484@`0224<00`aT48D@Q00236@01ABU6<HU:D8?F_H00VLh00US5ekfF]E6
D48>=J/UB1cV5<@00QBT00D8HPaR24848@0000800@03000<H`QR0084@@848@80800814408@000000
80@Q14448@88@P<48@<8@P8DY@03248000@Q00<48@0424848@Q26<H28@P00acW6<HLi`027>L38@P2
9BT04bU9:BPU22479@PY:Be[<H`e[Cg?AQ5BM5ZfH_QW6FLjH_QS66LI009W>@07IaQS66;gH_QRmf;h
H_L015kg25[G00=JmekgG_L00Ukh0ekg:7oo40@R20A20`@R00T4@PQ324<4@P@Q36@8H`A212800`A2
00<48PA214807@A200<48@A214801@A200P48@Q1120DY2TY;DTY:2U92BTX1BT80RT700@U1bT7:@LY
1`<U1`8Tia0PiP`La@077:DHY1B346<<@PQ236<010Q200<48@aS248010@Q0PQ220@Q00@000@Q1248
@P8<H`<@Q00358DHYQbV008La`@LaP8La@0<7<HPiRD79@LLa2CU:@HU1R3T7:<DPQ1Q0QR200TLXbTV
=HXiZc5Y:BHPiB347<<011bS00@HXabS7:<LX`XHX`XHXP04688HPaRS6:<258802aRS7<DPiB3V9@HY
9be9<FXeRSF;>J/05goo000EOol01E:cDY=BTe:CE[<00UJd00=Fe5:BDY<00U:C00A>TTiaBU16<0A>
LP04CY=>LTYbBU42CW8024YA@PlmkSF/<H/]JQC448<424400`@P00048@031246248912400`Q21244
8@0212402@aS48@@P`Q21248@@Q236<<HP042482244020A1000000@Q368DY1SV8@L29BP032U9<H/e
[3W>?Pm6<4XaDY=FU5JdF[AJ]@9J]00:E[ANeEZeG_IJeEkfCW8LaPQ136<526<224<926<05@aT48@@
I0aT46@@QABU;F]6<E[EE[A>LTYAAU523cg^=J`YBAcV48<8@P02244010aR48@@Q0Q20P@Q00@48P01
14848@808@@4@P0336<8H`QS0088H`042484@P@R1485124224801@aS48@8@P0012400PQ200D<Ha24
48@@Q1cW008YBP049BTLiacW7>L28@P49BT49BP03bU9;FXaS3F<AQ1:<DicE[INmf<IIcU[>VLIIaQS
6002H_L00ekgG]MNeP02G]H2G_L2H_L2HaP00f<GG_MNm`02G_L2G_H02E[FG_MNmekfF]IF]E:DDY=>
L`0XOol@1288148312802@A224<8@`A2128<Q0QS14848P0314800`@R1484@P0G14800`A11244@P02
24800`A212448@07124020Q1120DQ2TY:DTY:2e9:BT8:BP5:@P00bD89@LU1`029@L29>L00b3W8>HP
iP0<8>H27>H37<H77<D011S57<DHaAS50Qc500<HaAB446<01@aS1PQ21`@Q20Q200<<Ha2448@00aBU
0Qc60R370R3W00<PaQc68<H00b3V00`TiRD69@HU1RTW:BHTiAc48>DU1RCU7<@26:<02b3T;DPmc4H>
?L`eRRe8:BHPi1RS6:800aRS0ac35ARS0Qc400DHXaB27<@Y9c5Y008aB@04=FTiRSV[?L`3@L`GOol0
01Eoo`04E[=BTe:CDY<2E[<01E:cDY=>TU:BD[<00eJd01UF/e:cCY=>LTYbBU56DDH`@PlmkReZ:DTU
:1d76<DDY1233688HPQ11208@@aR36<8@P0612400`@R12400@0;2485124011245:@@P`Q10P0010@P
0144@@Q1368@Pa244:@LiR479BP]JC6/>Le23d8_BW9>TU:d00MF]00=F[AF]5JdE[AFU5JCEYABTeJd
DY=F]4H`6<D00PQ21`Q300@4@PQ324<8H`8<H`0826<<H`Q334<<I1256:HLi`8Q20066<HU:BDY6<H<
P`aS0Q2300<<HPQ224400P@Q00d8@PaS48@48@aS36@48@0010448@0012408@0200401P0Q12848P@R
00408@<48P0302400@0000@8@P848@04248<H`Q27>L28@P01Be[<H`e[CW>@Q000Sg_00E6<DYBBU96
<D8@00<e[@8icP<mk`09BU5>LUJdF]ENmUkgG_INeVLI009W>@9W6@9Rn004G_MS66;gH_L3G_H00ekg
H_MW6002HaL016;gG_MNeU[F0e[E00AF]EJdDY=BT`9>LPA:D@96<0923bQooa048PP4@P<48P081488
H`QS2484@Pb436<4@P848Q`4@P0314448@A20088@P0314848@@Q00L48@08244881B4:BPY:BTX;DTY
:@PY:0039@PY22T8008Y20<U1`8Y20069@PU1bCW9>LPib3V0R3W1R3V0Qc62Qc50QS50QRU0QRT00HH
YAc57<DHaART58@748@00`aS12448@042482124:36<00a246<HHaP027>L00ac69>PTi`039>L07b3W
9>LPibT79@LY1bD79@HPiR357<@PaAc46:<PiCV[BRhmc2TW:BHU1RTW=FTmc4H>@NdmZcF9;DLPiARS
008DPP036:8HXac400<La0@L``<La0037<<LXaRS008HX`LLX`036<@HXaRT008HX`049>HeRSg<>J/6
?J/00cfZ>JYoo`0FOol001Eoo`9BT`08DY9BTe:cDY=>TTiaE[AF/`9BT`9BTP9BT`08BU56<3g^<H/Q
21C548<<HP88@@031244800000<000848@0:244<Ha2448@<H`@R24888P@R248424<00`0100000003
0002124224831243248010aR48<DY1230PaR01L<P`aR7>HLiR479BP]JS6;=J`ec4H`BU1:LDjBDY=F
/eKDF]ABTe:cE[AF/e:C00=>TP03DY=BU5:D009BT`9BU009EYAF]EJdF]EBU5JdBU4LiQ24008<Q0<@
Q0<@Q@0448@DYAC66<L27>L01aS76<HLj1cW6<LLj2DY00<YBP8<H`0336848@00008000041208@PQ2
248212402P0000400@Q248DDYPaT24<<H`aT0PQ20P@R00<48@@R14801P@R0`Q300<<H`@Q124010@Q
00@8@PaS:DY6<@9BU004F]INmekgHaP7IcT5HaP3IcT016]IHaMW66Lh0V/i00AW>6LHHaMNm`9Rm`03
HaQW6FLi009[>@AW600:HaQS5f<GHaMJeU[EE[EFU59cCU82BU42BU001TH`ARm23d8>?Nhmk@8ic@8m
k@@mkRQooa048PP4@P<48P082488H`QS24<4@Q2536@8@P848Q/4@P042444@@@Q144224800`A11244
8@07124020a1220DQ2TX:BTY:2e9:DT8:BP69@P29@L00bD89@LTi`028>L00b3V8<HLaP087<H00ac5
6<DHa@036<D26:D46<D46:D00aBT6:@HY@036:D25:@65:D248@324821243248336<448@236<00a24
5:DLi`048@P2:@P29>L00bCV9@LY1`03:@L00bT69@HTi@028>D03R347<@U1RTW=HY63U9aAPhaJCF:
<HXaJCF:>J/2?L`01CV[<HT]Ab3U6:<00QBR00@HXQRS6<<H`aHHX`0:6:@PiRD79@L]BCf/@Ndmc4G]
@Nd2@L`0146[?J/mZcf[5goo000EOol015KDE[AF]5[D0U[E00]F]5:C?Nhec2eZ8@LDa123388<HPA1
0088@@09124480@P2448@P0012048@Q100@8@P0;12048@aR48<@Q0aS128000@Q10400@0512842482
1243248412402`Q236<<HacV:DPe[3g]@Pm:LE:CD[<00UJd00AFe5[DF]EJe@9Jm@9Fe0=Je007E]AF
/eJcCW5>LU:BCY800Tib00=BTU:CCY<00dic00aBTe:DE[AF]5[FF]ES5ekfHaQF]C6;9DT27>L48@P2
9BT012DZ:DX]K36/0SF]018aSC6<9BXLiaBU48@<I0aS124000@Q00048@Q12488@@@Q248212400`@R
2488@P0224801PPR124@QABV36@8@`8<I00424848P@R1043128010PR1288@`Q30P@R00@00@@R1288
@`88@P8<H`08248<Ha245:E:DV<HKg]W>@=S6003IcUNmf<H00QS60AW>@9[FP04MiacNf/iH_L2F]D0
2U[FG]IBTe9cCU96<47_?LhicCV]0Sg^0T8?00A6448?@Pm1k`A23`04AQ163dH@ARl3APl00dH>@Pm2
3P02@Ph2ARl01TH?APi23T8>?NhmkBQooa048PP4@P<48P082488H`QS24<4@Q2536@8@`848Q/4@P05
2444@@@Q1448@P02244912400`a1220DQ003:BP00be9:DTY:007:BP79@P01RCW7:DHYARU6:@HQ08D
Q00358<HYARU00<HY@036:@DY1BT00<Ha@DHY@<Ha@DHY@0458@DY1RU6:D35:@00aRU5:DDY@035:D3
48@00`aS24848@02124224800`aS248<H`0236<248@336<011245:DLib480RDY00@U:2T8:@LTi`8T
iP06:@LY:2dX9@HTiRCU0R3U00@TiBD6:@I1k@9>D00;?NdeRSV[?L`ic3g<>J/eRS5Y<HXeRP02>J/0
1C5Y;DPU1Qc47<<00aRS61B200<U1c5Z?L`00SV/00I1kTH>@Ne:3dX>APh2ANd00dH=BPe:3P0GOol0
01Eoo`03E[ABTe:C009BT`08CW96<3g^<H/YJR476<D@P`<<HP88@P032444@@@Q00848@0414448@@Q
12432444124010Q248@@Q0aS0PQ200@88PaT128000848P0310848PQ200<8@PL48@@8@P0748<@XbeY
@Pm2;d8?BU000U:B0UJc00=F]5[DF]D00U[D00AFe5keF]EFe0=F]003D[=BTdia009>LP03CY9BTU:B
009BTP9BT`09DYABTe:DDY=BU5:CDYABTdic009:D@05@Q0e[2DY7>LQ20059BT00bU9:DX]J`02<H`0
335[;FXYBRU:8@PHaABU368<H`Q20008@PP48@0:24<8@P@Q00448@PR12848@Q336@348@031S76<H<
@`PR12800@@124<<I0a424<<@`88@`0512800@@11288@`02248336<00`Q248@HaP03G_L5HaP5G_L5
HaP045kgHaQW>F<HG_MF]EkgHaMS65kFDY=>LU:CF]EBLdYA0TH`00A23cW==J`mc@91kP=23`05APm6
44H?AS16;`05AS05ARl00dH?APi23P09@PhXOolH128040A20244@Pb4004M212U5:DHa`aT12808@@Q
02448@Q21`@R1@@Q00@4@@A21484@PD48@041444@PQ2144212401PQ1368<H`Q2120<@P@8@P<8@@06
348@HQB47<DPiRD70bTX0Re900@HY35Z9@LQ1`HU20079@LTj2D77<HHYAB446<00Pa22Q1S21230Q24
0QB40QBT0QBU1QB40QBT00<DQ1BU5:D00QBU0a240`@Q0PQ230aS00<@Q1S68@P00R4800@U:BD8:BPT
i`8TiP0<9>LTiRT7;BP]B2D67<@LXbCU;BLeJCF90TX_00Y63SV/=H/iZcg]@Nhmc47]>J`aRP8iZ`0:
=H/mc3W;<FTY9bD68>DLa1c37>@47<@011c36<<H`aS30aRS00<DXaB358<00QB200DHXaBS588DPQ22
00<@HP0<8>He[47^@Pm:<4H??L`i[47=APm:;dX>0TH>00=5kD7]Ool05Woo000EOol02dHa?Nhe[2U9
8@PHa@aS120<H`aR24800`Q10PaR0PQ13P@Q00H8@PaR48<DYA24248300001@Q336<8@a2536@00P@R
20@Q00<8@P@Q12400P@Q00T8@Q246<H]RTH_D[=BTTiaDY800UJc00IBTe:BDY9B/eJcE]@3F]@3E[@0
15KDF]AFe5Jd1E:C00]>TTibCW9>LdibAU5243W><J`]JbUZ008DY@084:@<P`b348<8HP@P7>HLi`DQ
20079@PLiacW7>LHaQBU48@00Q1S00P48@00124480@Q36848@aS20@Q00@0000112848P@8@P8DY@05
=Je6<Cg_AS4mk`0236<234<010Q212800@010`0000<48PQ324<00PQ300T<@acW6<HDYA24248<HacW
;F/00ekg36<H019W>F<HG_MNme[FDYA242e[7>L<@QB48@Pi[DYACW96<3g^AQ03AS0024H?@Pm63dX`
@Pm23T8?APl>ARl6ARh8@PhXOolH12802`@Q0248@Q2U5:Hn43g`@Q4ecQd824<00PA200<48PA236<0
2`A21PQ210A20`Q200P48@Q1244<@QBT9BPYBBTY1RDX0RD800<Q1bD79@P00RTX00LY:BTX:BPPiRD7
8@LLa@02:BP2;DT39@P00b489>PPi`038>L011c668D@H`a210PQ0108@@PQ24488@Q12248@@PQ1248
8@@Q22448@PQ12488@88@@<8@P03348<HQ1S008@H`<@P`P@Q08<H`<48@88@P<<H`D8@P<<H`06248<
Ha246<HQ22U:0RDY00@HY1B368<U1`8aB@0=:@LPiAR37:@Y1SV:ANe:;TG]?L`eRSF[=HX00ReY00Le
RSg<?Ndmc3g]>L`eZ`03?L`0247]?N`eZReX:DLY9bDV9@H4:BL00bDW:BHU9P029BH29BL00bD79@HU
1P038@H04b3V8>DLiAc57<@Ha1c46<@Q1SF/APm6<4X`@Phi[3F;APm:<4H_00=1kP03APi1kWoo01Io
o`005Goo00D@Q0aR244480A10088@@04124480@P020212001@@Q2448@@Q124803P@Q0P0000D8@A23
48<8@PaR00<@Q006124000000040000110@Q10Q200<000@Q24800`aS00X@Q1S6>Ne:D5:BCW5:DDib
CY9>L@9F/`07E[AJe5[EF]AF]5:CF_D01U[E011F]5[EE[A>TdY@?Nhe[2f;:FXQ21cW6<HDY@b42484
8@808@848@0600008@Q226<8HPQ20`a200@8@@PQ248<@P<8@@09224400@01248@@aS000@Q0aR00@0
00P48@0D00448PQ224848P@Q1288@Q245:A6<EkgCW9NmUJd48@000PR34<<I08<@`0646@DQA1T46@<
I0a30PPR00X<@`aS1248@PaS48@DYB48>Li>L`9Nm`ES60UNm`AS600DG_MBU3g_<H`Piac68>LYBSW=
AQ16<4H@APm:DDiaAS0i[36;>La23PA6;`04AS1:<4X`BU08ARl6APh2ARl5APh3@PhXOolH128040Q3
2488@`b48BUFeU[GF_M>LbDZ14848PQ312808@A21`@R00@48@A21444@@D4@P0314448@@Q00848@84
@P0324888@Q10084800358<]JSV/008eS0<eR`@aR`<aJ`8aJP0;;DX]BBU9<H/aJbe::BTHYB3V8>LL
aP028@P00b3X8@PPj0038>L01AcW6<HDQ0aS22800`@Q00P88PQ22288@PPR24888PQ230@Q00<88@Q2
24801@Q200D<@`aS36<<H`Q200@<H`<8@P<48@<8@P8<H`@8@PD<H`88@P0836<DYAS65:D@Q1RU7:DP
iP8Y:00:8>HHY1B27<@U1SEZ@Ne>D4X_@Nd2>J/01CW<>J`eRc6:=J/00SW<0Sg]0cg=0Sg]00=1kSV[
<FT00bU700<U9RDW:DL022U70RU80bTX0bDW0R4600@PiQcU7>DLi@8La@0;8>HeRTH?BU5:<48?>Lde
[48@AS124002?Nl00d8@@PlmkP0GOol001Eoo`0624448000000480A120Q10P@Q0`Q20P@Q1PQ20`@Q
0188@PQ15:@DXaS59BP]JcF/?Nm6DDic@PlLi`Q224<@Q11T48D8248236<02A245:DDYAS69BTaS48?
BU5:L@02BU42CW8014YaDY=F/eKD0U[E00EBTdI@?NhLiQS5008DY00448@@P`aR24851200100P0000
00A11`@Q0PQ200L4@P@Q248<Q12436<00002100300004@@0124@PaB46<DPibDX;DXaRcF/BU4mkU:C
>Lh@P`aS48<00`@Q10@R0PPR00<<H`Q212800`@Q00L8@PaS8@Pe[5[FIcQF]002HaL01CF]58DDYARV
6:D00QBU00<HaQc77>L00acW0Qc700XPj2488@PYBSF]BU9BU5[FHaQ[FP9Nm`eS6005IcUNmekgHaQW
>@02JeX01VLiHaQW>F;gDW<mcP8]BP0<?Li:DDYABU5>LDH?9BP@PQcU>La6;dH^2DH_00E6;TH_ARi6
3dH>0096;`]63P=23RQooaP48P<8H`0=24<]K5lHHaQNn5KF:D/4@PQ34:D<I0@R148020Q21@A20`Q2
0PA20`A100X4@PQ2248<HQ2346<DY3F/G]E[F@AW5`ES5`AW5`0<HaMRmf;fH_INeEkfF[ABLR3W:BPU
1acV1R3W0QcW00LDYA2436<8@PPR22488P092488124N248236<548@436<00`Q21248@P0224801P@Q
1004011S8>HU1`8La@04;DU1kTiACU02BRl2APh03T7]?La23T8?@PhmcCW<>Ldic3V/@PhicCg=?Nd2
>L`013W=>L`aRBU80bDV00<U1RDV:BL022DV0bDW0RD7124600@PiQcU7>DLa@8Ha@0;7<DLiBe8@Ni:
DDH`AQ12<3g_?Pm24003@S400d8b?Q4ec`0GOol001Eoo`032444@@@Q00<48@848004000480@Q1444
24400`Q212848P0212400`@R2488@P02128312403`@R2488@PQ1264DXbDX>La23dIACW9B]48@7>L4
8@0224820006248236<021BU48@8@PQ236<Lic6<BU42DY<024jCBW9:DDibBW9:DE:CCY<3CW802TYA
?Nhe[1BT48@<H`aR24848@@P0`0000@48@Q1248<HP8<H`032484@PA200L4@P808@0H1488H`Q20200
00@022088@Q1368@PaBT48<HYB3W:DTaJcF/?Li1kdYBAS1JeCW=0P0000@4800012448@@48P888P04
248000001242248030aR48@LiTYAG_IF]5:CE[=>TTYA7<HHY@8DQ0066:DLaR3W8@PPibDY0Re:00@Y
BRD88>LLi`8]J`03>Li:DU[F00=JeP=Nm`ES60ENm`AS609Nm`03F]INmekg009Nm`0?JcU_FV/iEY@i
cBe:;FXi[4X`@Pm:<4H_8@H001B30096;`03ARi6;dH^00E6;`03ARi6;dH^0096;P963P05BRm:<4X_
BRm63`05APh2@Nh4@NdXOolI12801PA224<8Hch@Je]WFP9S>@07=Lh@YA245<H@Y@b448@040aS1PQS
0PaS00P8@@a1344HY3g=G_IW>5[E0V<F3F;f00URmekfJcQW5eZd8>HQ1bD78>L00QcW1Qc700<<H`a3
24800`PR0PQ220@R30@Q1P@R0PA24`Q200<<Ha2448@00a240`aS20Q2014400a26:@HY11R58<]BDH_
BS163d7]?L`ic3g<@Ne23SW<008mk@8ic@8mk@05>L`icC5Z=J/mk@02=J/013W<=J/eZReX0bU70RDW
12U700<Y9bDW9BL00bDW00DU:2DW9BLU9bD700<Q1`8Q1P037>HLiAcU008Li@0@8@HU1cg<BU1644H`
BU92<Ch@?S4n4CHA=O4f4C7`:JlGOol001Eoo`80000312048@Q100<8@@8480`48@<48P<48@031288
@PQ3008<HP045:@YBD8_E[<4F]D01DYA9BP8@PaR48@010aS0a241QBU01DLibDY;F/icTHaAS123cW>
=J`aRbeZ:DXUBAS64:@<HPQ2368<H`aR24400PaS00<8@`Q224<00`Q200<<I0aS36<00PQ200<48@01
00000P@Q1P0Q0PQS0144@P@Q26<@YABU4:@HaAc68@LU:2U9<F/e[3W=AS1:DE9c009FU0AF]005E]ES
>3W=24448@022480100112448@@Q10@R00<8@P@Q24800Q230PQ200h@PacVDY=S5U[DIcMO5EJcIcQ2
3cg>=J`eS3V]0Sg>00XmcDH@AQ1644H`BS5BLeZeG_IS609JeP03G_MS66<H009W>@9Nm`IS60ANm`AS
60IW>@=S600?IcU[>FLhG]IBTdH`@Ni>DDH_BU1:;bDW000DXdY@00E:C`A:D0A:C`A6;`05APm63TH>
@Ni1k@02?Ld3>J`2>J/3=H/XOolH128030@Q128<Ha24CWA[Ff<HHaUWFTHa8@P@Q@<<Q00348D<I0aT
00D<I00336<<Q0b4008<Q08<P`P<H`8<P`056<DHY1cV<FY>LP02IaL00eZdHaIRmP08H_H03ekfG]IN
eUkFG_IRmU:CG]IJ]3g^58<@HaB358@HY@036:H01aRU5:DDYABU36<<@`a200888P0322488PPR0104
8PP48@848P84@PH8@P<48@h8@PD<H`041248@PQ2248312400`PR36<8@@0412002`a158<DPaS48@L]
JCF[?Ne23TH_?Nd00T7^00lmkCg^@Pi23Sg=;FXQ1ReY?LdaRcF;?Ndi[3FZ;FT00bU80RTW00<YAbU8
:DP01RU70RTX00@U:2DW9BLU9`8U1`048@LQ1R467>H47>D042TX9@Hi[4YA@Pm6<4IB>NlacS7?;JlQ
KAe<7FdQKAe]5goo000EOol01PQ2368<HPQ21244808000<8@P0324448@@Q00<48@@48P<8@P88@`0E
2488@`aS48@@QABU6<@U9cg]DY9Je5JdE[=Je5JdCW8]JQ24368<Ha23008Ha@PHaP057>LU:C6<>Lhe
[@02;F/01QcW6<HDYA2436<8@P88@@0848<8@P@Q124<HPb336<8@P<0000900448PQ222848P000044
8@@R0088@P88@`<4@P88@P<8H`0B0244@P@Q0244@QC6:F/icTXaCU9BLeJDE[AJ]EkFG_INeUkf0V;g
00YNmUkFG]INeUJdG_EJeBDX0000808000848@848P@8@`0=36@<HaBU6<HDY0aS6<DYBDibG_IO5U[d
HaH00UlE015[F6]IIcQRme[EEYA>LTYAAS0aJReZ;DX]JSF<APmFTekf00AS6004G_MJeU[FG_L5HaP3
G_L3IcT5HaP00ekgHaQS6005IcT046LHH_QNmUkgH_MNmUJdDW9:DDH`BU123RU8488PiCg/2D8=00=1
kCg]?Nd00cg/00<mc3V[>J/00SF;00@eRS5Z<FXaJP<]B@05;DPY:2TX:BPY9`0XOolH12803@Q3148@
QAC6F]MWFU[GHaQW>U:e>NlU:QSW008DaPXDYPDDY@<@Y@8@Y00348@@Y12U008DY@08244<HR3V?LeF
TekfH_IS5`ENmP9Nm@05G]ERmV;fG]INe@02F]D2G]D026;fIcQF]2e96:D@HQB358@348@346@236@2
36<2248010@R12448@@Q40Q21@A21`@R00<4@PQ224800PQ210@Q2`Q20`@Q1PQ20P@Q0`Q20P@Q00@8
8@00000480@8@@08120<HQS59BL]JC6[=J`ic0@ic@0>?Ni23d8??NhYBABT:DTmkC6;=J]23SW<<HXY
J08YA`03:DPUAbE700DYA`@UA`049BLU:2DX9BL58@L012467>HLiQcU0QS500DLaBTX7<DeRdYA0092
4006@S4YS1dZ9FdUSR5]0QU=00<MKQf?Ool05Woo000EOol00`0012448@02124224800`aS12448@03
1243248424<436<448@05ABU6<HLiacWBU5F/fLgJgUS5e[DF_ES=elFIeUNmdYA>LhYJR489BPLi`02
6<H00aBU48@<H`0236<01Q2424800@@Q24848@80000324848@@Q00@48@0524848@@P124<HP0248@0
1`Q200048@@Q2248@PaS00<@Q0@8@`0424848P@R124212800`@Q12848P0312802P0124<8H`@R24<Q
:DYBHcQF]E[E0UkF00EJeEZeF[EJ]F;g00AS5`0:IcQ[>F]IIcQ[FE[f9BT<Pa2T244324800`Q334<<
H`0336@01`aS48<DYAS65:@HaCF/009F]00O=L`U9aC4240<PAS45:<Q1RTX<F/i[3W=?Li1kdH@CW9B
LTiBAQ0eS2D758<<@P@P5:De[4icF]INmf<HKgX00VLi00YW>6<HG_MNmU[FF]E>LdibBU9:D@96<@96
<008CW9:LTYAAS12448?@Q16<0=6400=@Pm1kcg^?NhmkCW=@Ni23SV/:DPU9be8<HX022eY0bU800<Y
AbTW9BL00RDW00@Y:2TW:BLY9`HU1`039@HPiR3V008Pi@037<Eoogoo02IooaP48P0@26<4@QBU7@QW
>VmkHaU_W6]JJe]O64Yc>Nla[BU[9BX89DX00b4Y8BPQ20038@P47@P37@L02ad88@PQ23W=?Ni>LV<F
IaMNeEZdH_H01FLG0f<G00=W5f;fH_H00ekE00QNmV;fG]ENeDH?468DP`PP0Pa11`a21@Q200@88PQ2
2488@PP48Q<48@<48P84@PH48@88@P0336<8@PQ200P8@P0=12848@@Q100000@P000400Q258@HYABT
48<00R4700TPiaS546<480PP368<H@a124000P@P01H880a1364PiR479BPYBCF;?Ni23d7^;DTHY2U9
?NhaRcF;@Phic36:;FPYB08]J08YJ003;FTYB2U700@YA`8UA`8Y:0<U:0DU1`038@LPiR3V008LiP0=
8>HU1aB3<FU>DDH`@Q0n425:4<PMKBgb<Q@00RXD0RHE5goo000EOol2128824801P@Q1288@PQ21284
8@H<H`0738@@Q12448DDYABV6<H00acW00i2<4ibF]ENme[fF]IJmUkgF_IFeDic?Nl]Jb480QSV0QBU
00H@YA2436@<H`QS24<2148010@R12448@@Q0P0Q00<4@P@R12801@@Q0108HPQ2244@PaS5368480b3
120@PP@P364DXa237<HLi`<48@<48P0322848P@R00P48P0936D<I000124YBU:CHaMF]5[F00=NmP03
GaMNme[F009S5`03G_IJmU[E009F]006DYABTdic@S0]JaBU0PQ200<<P`Q236<00PaS01/<Pa245:DH
aQ245:@HY1BT7<DYBD8>DY=F/cW=;FTQ1PaQ5:<U1acU9@LaJSg=@Ni23dY@DW800U:C00mBLTibAS0i
cBU97>DDQ0Q16<He[4YBE[AJeEkgIcP00ekf0U[E00QJe5JdE[ABTTjBCW5:D4H`0dH_0TY@00I:<4H_
ARm2;dH?@Pl2APl00d7^?Nhmc@03>Ld02Sg=>Lde[36;<F/aJRe::DT]BBU80RTX00XYB2e9;DT]BBTW
9BLY9bDW:BLU9`8Y9`8Y:003:BLU1bD7008U1`079@HU9bD79@LPiQcU7<D00QRT:7oo4@@Q00D4@@Q2
2488@PA100<48@0=36<@Q2U:DYAW>F<HF]IO66<HG_M>U3W_;F/00bU[00DQ:BU[<H`YBRDY008YJ`@U
BP059DTU:BDY9BTUB@028BT02B4X8BTYBRf;<Ha23dibF]ENm@02F]D00ekfHaMW=`02IaL3HaL3IaL0
3F;eH_IRmE[DH_IS5UZcIaINeDH>8>D8@0a000D@HP03364<@@Q10088@@046:D000Q236<224800`01
1284@P07148212801@@Q02408@@Q12802@@Q00<000@Q12400P@Q00<000@Q24800`@Q1@Q20PaS0PQ2
00@48@Q2248<H`84@P848P<48@0>120880PQ444DPabT7<@LY1R3:@LTiR356:@DHP8@@@<<@@H@@@04
6:@DXaS46:@2>L`01Cg^?NdU9bD7;DT00SF;00Di[3g==J/aRc6:00@]J@06;DTYB2U8:DPYBBe90RU8
0RDW00<U1bDW9BP00RDX00DU9bD79@LU:2D7008PiP0D7>HPiQcV8>HY:2D78>I63diB?Nm24Bf=16HU
T2Wc8ODR5ahH7QTEn1Moo`005Goo0P@R2`@Q0P@R00@48A2448@DY@8HaP8Hi`076>HLiacW7>LHaQC6
5:D00Q2400h<Q1S68BTYJbf<<H`e[CG>9DTU:B486<H<Q0Q20PA200D8@PQ32488@PA200<48PP8@P03
1284@PQ20088@P081484@@@Q00048000144Ha@8Q1`0:8BL]JCW;=JXmk47]?Ne6;cV/2443248524<3
248222<224<03`@S24@8@`@R5:De[5:CF_IS>6<HF_IBTdYBAU56<002?Pl01SW^=J`YJR475<D@P`8<
HP8<H`063688HPaS48@DYA2T0QBU0QC500<HaQcV7>L00RU801T]JSF/@PmBTf<FJeUS5e:CDW96;be9
:DPeZbeY@Pi:<4ibDY9F]5[DE[ABLTH`BS1>D@02CW4024Y@APm23SW=?Li23dH`BS45BU4014X`ARm2
3d8>0T7^00=63d8>@Ph00T8>00=63TH_ARl00Sg/00<mc3W<>J/00SF[00DeZS6:<FXaJS5Y008]J@04
;FXaJRU9;DT3;DX00be9:BTY:@05;DT00bTX9@LPiP05:BP01RDW9@LU1aS56<@Ha@DHY08<@@03368@
HQ1R00<@HRQoo`082488@@Q22448@PQ12488@@<48@062448@PQ12488@@001P@Q0PQ200PDY124368<
H`Q100048@Q30Pb400h<H`A202408@A25:D<Q12U6>L@YA245:D@YAC60QBU0Q2U00@@Q0b438@<H`88
H`092488H`aS38@@Y0Q1368@Pa1R008<HP0348<DPaRT00<HY0076<DLaAcV7>HY9be8@Nd00Ti@00IB
LEJcEY9:;di@BS02@Nd2BRl00d7]APi63@02@Nd01Sg]?LdmcCW=7>H88@8<H`88@P0300448PA200L4
@P848P848@848P84@P0324<8@PQ200D8@P031248@PQ200d8@P8<H`88@P051248@PQ236<4@P021280
0`0Q12448@0222403@a2468HPb349>HXiBC47:<TiBC58<DLY1bS00<LP`<HP`8LP`<LX`086:@DPaS4
7<@mkD7]APi1kP8PiP0>;DTeRcF;>Ja1kCW=>J`eRc5Z;FTYBBTX9BLQ1`8Q1P038>HLiQcV00<LiP03
8>HQ1bD700DU1`03:BPU1bD700DPiP0@9>HU1ac5?LeBLTH@AS4ed0AV8G0YmBHG8SXNFaiM6U`GOol0
01Eoo`P88@052448@PQ222448@0212004`@Q5:DHaAcW8@PU:24X8@LLiad77>LLiQS65:@<P`Q21448
@@Q20088HP0:2484@@@Q02048@A12444@@@Q12041243128314831243128214800`@Q12848P022480
4`A212448@A148<<Ha2T<H]:LTjBBW5>LE:ADY9Ne5ZdG]ENmCW=00888@88@P0424<88PPR12822483
12802`@S24<8A0a422<48`aT6<HU:Be[<H`00RDX00HQ21S548@<H`Q2020224421443124030@P2488
@PaS5:DQ22U9:DXYBB4X9BTYB@<YBP0>;FX]JbeZ;FXeRd8>DY9NmF;fG_IW5ekeIcMRmP96;`04EY=B
TSW=>J`2=H/02CW<?Nhic2eZ>L`icD7^APm6<002BS002DH`BS1:<4X`BU5>DDYAARm1kP02ARl014H?
@Pi1kSg^0T7^00HmcCW<>J/eRS5Y;FT2;DP8<FT2<HX00c5Z;FT]B@03:DT042D89BPU:2D88@LU22TY
;DXU22478>HLiAc67<DHYART2PaR111R00X@Ha1R8>LQ1bD79BPY:Be9;DX]JRQoo`P8@P0812848@@R
12448P@Q12848@<<H`<8@P0324<<H`Q2008HaP0536<8@P@Q124@Q002024414801PQ226<<Q0A238@D
Y@<<Q00436<@YA2U48D238@00`aS26<8H`0426<030Q32488H`QR36<<@@PQ12088@Q1348<HPD@P`0<
58<DY1BT340DXcF[DW5>LDX`DW5BTTi@0U9a00E>D59aDY9>D47]00=:;`03BRi63dH>00923P079BP<
HQ2436<4@PQ200402@A210@R0PA200<8@`QS36@02PaS0Q2400<<H`Q224801PaS0PQ20PaS10Q200D<
H`aT26<4@`@R00808@0<1248@Pa258@LY235:@H]1bT6:>DPa2C50R350b340R350QbS1QbT00@La1RS
7<@La@91kP0FAPhmcBD79@LaJSV/=H/iZcg=>L`i[3F[<HX]JBU9:DPU9bD79BLQ1acV7<D26<D011cU
7>HHY1S40Qc500@PiB3V8>HQ1PPPiP0@8<DY1ac5=H]BLTXa@Q0n4@R76Dh^5RiI:U/VOB9m8WhGOol0
01Eoo`8880@88@8<@@888@8<@@<88@0434448@Q1368238<010aR24448@@Q10A100@480000008@@84
8@04244<@PaR348324400`Q2348<@P0334800`Q21488@P0524801P@R12448P@Q12848@D48P84@P88
@P88@@0638<@Pad7@RmJmE[f0U[D00YJde[DHaIJ]5kfH_HYB@@P2248@@88@P0322848P@Q0088@P<4
8P0922<8A0Q436@88`Q358DHaQ240088@P086<HQ22U::FXYBRE97@PDa@D8@P072444@PA1120080@P
24400PaS00D8HP@Q5<DHaQd7008Q20038BPU:2DY008YB@0C;FXic48?BS163cg]@PhmcDH_@Ph]BC6:
ARm:<5:BBU0mkCF[?Nd00TY@0dH_00m:;dX`BS1:<4X_BS1:D4X`APlmkCV/>J/aJRTX:DP01BTX1BU8
1Be80RD600<Q1R3U8>D00QcU00TLa1BS5:<@PPaQ3448@0PP12000PaR00h8@@@P100<HQcV:DU1kSV]
<F/YBBe:<H/i[Cg>0Tib00=BLe:CEY@00UZe00=JeEJdE[@01UJd14ib0e9c00=BTgooOol09Woo00/8
@`Q224<8@PQ32488@`Q224<8@PQ300D8@P071288@PQ224888PQ224<00PaS00TDY@aS1248@`Q21244
8PQS248010A200H48@0Q12408@Q238@214800`QS1244@P041483128614801`@R124<H`PQ10088@aR
008@H`0648<<@Pa22488@@PQ0`Q100P8811R=HYFTU:BBRm:D59a0TiA00=:;d8>APh00TX_14H>00e2
3D7]@NdmkCg=:DT<Ha2436<48PQ21248@P0814800`@Q12848P0214800`Q326<<H`0836<448@011BU
48@<H`Q220aS1PQ200d<H`aT38@8H`A212848@Q246<DPac68>DTiP02:@H00bSU9<DPa0038<D00b34
7:@LY0027:@568<278<00aRS7<DHY0027<D0448>@Ni1kSV/=HX]JCF;>J`eRcF[>J`]JRDW8@LPiQcV
0QcU00HLaAS46<@DY1B348823680111R488@HQ1R0QB300HHXaRT6:@Ha1RT6<@77<D03bdX8<DY:4iA
BU4mcd8b4<TE;C8f=Y/^NbZM8WdRWP0GOol001Eoo`D<@@05340<80`P1008000322000`a0344<@@04
12000`0P00000002000212000`A02448@@0224401@aR24488@Q146<00Q2300H@HPa2244<@Pa13482
24400`PQ12448@06124524800`Q124848@0224800`@R12448@02248236804@aS5:@aRe:cF_EF]5[D
GaENe5[DG_ABTUZdF]@U:0Q124800`a200<8@PPR12801@Q200h8@`a436@8A0Q348DLj1cW36<48@Q2
48@HaR480RDY00@Q21S648@@Q08<H`88@P848@030008@PaR008<H`@<HP0636<@Q1S57>HLib470RDX
00@]JS6:=J/ic@8mk@08?Ldic4Y@@Pm:DDH`<HXeZ`=:D006ARlmkCV[>La6;di@0Ti`00E>D4Y@BU1>
D4i`009>L@9>D004APheRc5Y=HX2=H/00c5Y;DT]B@05;DP012TX:BLY9bTW0RD60R3U0bD600HPiAcU
7<@La1RS5:<648805a23468@Pa1S36<DQ23W<Ha23dH@?Nhe[36;=H`icT8?AS1:<DYABU9>LTicDY<0
0U:D00=NeU[FF]H00U[E0UZe00IF]EJdE[AF]5JDDY@3DY<XOol836@348@00a1T36@<I00236@010@R
24<<I1240Q250aBV00dHaa2424<@Q0aT12400@QS2484@PQ22688H`02248010QS248@Q1240PA200<8
H`@Q12801@@R0PA20`@R0PA20`@R00T48@0000048@Q222448@PQ34800PQ21@PQ00H<@@aQ:DQ:D59a
BS02CU001dX`CU5>DDX`ARm:;dX`00A:;`0=ARi63TH>@Pi1kRDX368@H`aR1248@P@Q24<020A200P4
8@@R1284@PQ226<<H`aT20aS112400@DYA2436<48@@8@P<<H`0348@8@PQ200@8@P0436<<Q0aS26<2
248010aS48@HYAc60RD700<TiRCU9>D00b340R3500HPa1c47:@LXaRS68<97:@011RT7<DLaD8>0T7^
0Sg=0SF;00li[3F[>J/eRRDW9@LQ1QcU6<DHa1RT5:<@Pa2246800PaR10aQ00@@HA1R488DP`<DX`8D
P`0G6:@LaB3U7>DLaAcU8>DLa2TW8<DPiTH?CU8mkd8b7B/E339G?[`bW3:n9YhZ_`0GOol001Eoo`0;
9@HPiR3U7<DLY1RS68<DPQR3588@H@0244401Pa0320880aQ2448@0<480031408@0A00084@0@4800=
220<HPa1200400P022040000348<@@PQ32400Pa100D<8@PQ2248@@PQ00848@0312048@@P00P48@03
22448@@Q00848@0?2448@PQ25:@HaB47?NiJe5:cBU5BTTY@BTm6;TH_008mk@03@PhLi@aR008<@P@8
@P0424448@@Q1242248324<02A1U48DHab3X6<H<H`Q236<<I00348@01A1T48@@Q0aS10400P@Q00<4
8PPR24800PQ2024000@P2448@@@Q1208@PaS5:@HaAcW8@PU:BU9;F/aRc5Z=J/icCg]@Ni23TH?AS12
3Sg]BS16;c5Z<HY63dH_BU000Tia0TY@00E>L59aCW1:CdX_00=6;`=:C`08APi><4X`@LdeRcF:<DTY
9`8U1`059>HPiAc57<@LY0046:@00aRS58<DPP0246423400111Q588DPaRT0Qc400lQ1R479BLUB2U9
;FXaRc6/@Pm244H`AS5:DDibEY@00U[F1EJe00=J]EJeE[D01eJe0U:D00IBM4icCW=>LdiCBU84CW<0
14iCBU9:DTYB:7oo212500<DYQB548D0112500D@Q1255:DDYQBU008@Q@8DYP087>PYBbe/:D/]K2e[
:D/aS08U:@0>8BTU:BE99DXUBBDY8@PQ:BE:7@P<H`Q236<8@P@8@`@8H`041488@`Q324<426<020aS
348<Ha2446<88@Q246<35:D00aBT5:DDY@026:D011B2344LaCF:0cV[00/eRS5Y>La:;diaCU1:;d8>
@Ne:;dX^00963P0<@Pi1kT7^?NhU20Q236<8@P@Q24848@Q320A200<48@@R12800PA200@8@`QS36<<
I0L<H`D@Q00336<8@PQ200D8@P8<H`0348@8@PQ200@8@P0436<@Q0Q2248236<011BT6<DPibD70bD6
00PTiR358<@Pa2CU7:@La2340R3500<Pa1c47:@011bT0QbS0QRS00@HY1BS7<DLa@8mc@03@NdmcCV/
008aJP0==H/aJS5Z;DTPiRD78>HHaART5:<@PPaQ34400PaQ0PaR00<@HQ2248800Q2200<DPaRT7<D0
0Qc500LLa1RT7<@PiRD79BLU1`028>H04B466:@LaAc57:@i[59b@Q16DbV>3<Xb=T;M>]djobZn<]l0
5goo000EOol2=FT0135Y<DP]9bTW0RT600@Y9bCU8<@Pa08Ti@078<@HXaS35:<DXQ2246400`aQ00<8
@0A012000`@P00<880Q032000P`Q00<<@A1256800QAS00@DHQ11324<8@@@@P033448@@Q200D8@@84
800I2248@@Q1248<@PaR348<HQ1S48@DQ12448<@PQRT8@LYBCF[@PhmkCF/>L`aRSW;<HT00S6:00/]
BC5Z8@HDY1B348<@H`aR36<@Ha23008<HP0348<@Q12500<@Q@075:HHYaS75:H@Q0Q212400PQ20Pa3
00l48PPR24<<H`Q346@<I0a324<88P@Q104000PQ36800Q230`aR0Q2300hDY1S57>HQ1bDX:DT]JS6;
=J/icCg]@Ni23dH_0TY@00Y:<5JCCU4aJS6:BU5BTTH^BTm>L0A:C`04ARiBTE:ACW45CW0034X_CU1:
3cV[<DTY9ac4444DHQ1Q444<@@<<8007220DPaRT7<DU1be8<FX00cF;00Pi[3g=@Ni:;diADW9FTU:B
0U:C00EF]5[DF_ENmUlG009Je@9JeP04F]EF]E:DDY@4DYD015JEDYEBM4ic15:E00ABU4idCWA>M0IB
U@9BU09>M003DWA>U59d00=BU2Qoo`097<PLaac87<LLb1c77<PLaac800DHa`036:LDYQBV008DYP8@
Q@065:HLb249>Lm6<TXc0T8A00<ml3g@@Q400d8@00<n3cg_?Nh00SW^00Pmkch?@Pl]J`aS1244@@0P
0PQ200@4@P@R12848P848@T48P0712488@Q2124000aS8>P00b4800XPj2488@PQ22D8:BPU1Re8<HXa
J@8aRP07:BPU1Re8>J]63di@CU400di@00E:CdX_BRm6;dH?00923`089@P<@Q1S36<48@Q21248@PP4
@P@48P041488@`QS26<936<348@236<424821242248236<624801PaS48@<H`aS48@DY08Ha@8La@06
6:@LaB3U9>HPiB340R3U00<LXabT7<@0123500<La1RS6:<00aRS0aR30QRT00@LaAB3<FXY:0<]B@04
:BP]BC5Z9BL29@L00ac55:<DP`024880212358<@Pa225:<@P`aR3442240040Q1344DPaRT8>DU1bTW
9BLU1R3U9@LYB35Y;FTY:2D60R3V010La1B37<DHY35YCW96<D8b<M04Z2hD?]`f_3[o:Yd^_aMoo`00
5Goo0SEY135X0S58010]9bD59@DaB3f[APe5kD7/@Ndmk3W<=J/aRReY;FPYB08U9`8U9P0A9BLYB2eY
<HXaJC59;BPY1b356:@DPaAR468<@@PP200<80033243224524401Pa2368@Ha235:@HY0<Ha@0=7>HU
22TY:DTU:2477>HYB3g]@Nhi[3W<?L`00SF[00haRSg]=J/ic3g]=HXi[3F/9@LQ1acV7<DHaAc60acV
00<M1R479BP00RDY0R490QBV00<DQ@aT24<00`aS00@<@PaT46@<@`88@P0322800@PR00@88P848P04
124480PP348236802`a12448@Ac57>HPib479BPYBC5Z=H/00Sg]00=1kT8>APl00dH_00A:D4H_BU0e
Z`8@HP04<HY23TY@CW03BTl2CW06BTl3CW001eJACU0mZbe8>H]>DEkD00EN]004G[ENeF;FH]H6F[@2
EY<015ZDE[AJU5Jd0eZd00IF]5KEE]AF]5:cDY<3CY<01EJeD[EBU4jDDY@00e:E00QF]U:FDYE>UE:E
D[IF]U:f25:E14id00a>MDjECWE>UE:ECYEBUDjEDYE>UE:ECYDXOol::D/01RT[9BXU:RDZ9@XU2@<U
:P0N:D/eST8ADYENef/kKgaW>f<IKea_O6/kJeYW>F]IJeY[FFLiIcQW>FMIHaQW>6<HAU4Q21245:@@
PaRV0QBV0Q2500<<Q0aT36<00`aT1PaS00`<@a1S48@<Ha24:DY:<F/iIcUW6FLHHaP2H_P00f;gG_EN
e002H_H01ekDH_IW5U[DH_EJ/dia00A:D004CU1:;dX_BRh2APh02T8>@Ni1kRDX368@Q0aS1488@P01
2@A210@R0PA200<8@`QS36<020aS0Q2400D<H`Q22488@PaS00<8@P848@88@P0336<8@PQ200@8@P04
36<@Q1BT5:@36<D02aBT48<@HPa158<La2CV9>DPiB348<D00QbT11c40QbT0ac40abT0QRS00HLaAc4
7<D@HR3V6:<26:@29@L2;DT011c55:<HY1BT0R4600/U1bU8<HXi[3g=?Ndi[36::DPQ1QS500<Ha00P
588HY246:BP]BBe8:BLU1be8<FTeRS6::DPQ1R3U7>DPiQB28>DHY2TWCU56<3g`>O44QbWc>[XbVcKN
8SXVO1Moo`005Goo0SEX0S5X01/aB357;DL]AbdV:BH]9S5X?JY63DX^CRm63TH^APhmk3W;=JXaRBeX
<HTU1RU7<HT]B3F:>L/00Re800@iJSEZ:@LTiP8Y1`038<DLY1A1008<8004444<80`P444222000`PQ
244<@@0334401`@P240<@A1R6:@PiR47008PiP0<8@LU:2TX:BPU1ac558<]JCW<?NdiZcF[0Sg<00@e
ZSV[>J/iZ`<eZ`07=H/aRRe99BPQ1QcV8>H00R47124600XQ1bDX9BTQ21S748D<I0a324888P<8@P8@
I00622448@aS34840@PR0P@100P48@PQ22888PPQ10488@Q110aR00h@HQB358<LiBD78@LU1beY=H/e
[3W<?Le23TH_0TX`00]6<4H_ARm23U:B<HX<@A228@M6;dia009:C`03CW1:CdY?009:C`05DY5>L4H^
ARi:C`02CW0024iaCU1>D4X?8>DaJV;eFY<3F[@4F[D00eZDF[AJ]@03F[D035ZdE[AFU5JdF[AF]5Zd
E[AJ]5JdF[AF]0AB]0AB]@UBU@07CYIBUTjFDYI>UU:FCYH024jE0die0TjE00=>UU:FCYH025:F:7oo
00<iccW>>Ll00SV^0cF^1C6=00/eSCF^=Jdi[SW??O164DidE[INn6<I00M[F`03JeYW>6Lh00IW>00F
IaQW>6<GBU4]BQBU48@DYABV5:DDQA2446@<H`a324<@Q0aT36<8@`a336<234<011B5348<@Q240Q1S
00L]BU:DH_MS66LiIaQNm`02IcT035JDG]EFTUkEKeQ[=f;eG_ENeFLFG]ABL@9:<004CU1:D4X_CU03
BRl01TH_APm23Sg^9BP8@P8<H`04248<H`@R2486148212800`0Q12448P0214800`Q224<8@`082483
36<2248336<3248636<010Q212448@Q20`aS00H@PaBT6<DHaART5:<26:@011B26:@PiBD70RTW00<T
iQc47<@01ac40aRT1AbT00@HY11R6:@La@8DP`037<@LaBTX008]B@0=:BPU1QcU8>DPiRU9;DT]JS6:
=H/eZcF/>J`00SF[00<aJRDX8>H00acU0Qc400<PiBD6:BL00bTW0c5Y01D]B2U8:BLU1R466:@Ha1RS
7<DHY4X`AS5243XA5@XICS9G=YXZNQhH9W/05goo000EOol2<DL2;DL02RdV:BHY9RT5<FPmZTX=DW1J
TEZa0UJA0UJb0UJB00QBTE9aCW5BLDi`ARi>L5:A0TH>01U6;cg<@Ne>;dh`@L`iJSV:>H/eJBCV8<@L
Y2CU:>HTiRCU9>HLaART58<@PPaR3448@@02240234402`aQ58<LaAc56<@U9b3V6<DDPa2246800PaQ
00LaJCW<?NdibcV[?N`mk@03>L/2>L`01cV/=J/eZcF[>L`eZc5Z008]J@0;;FX]JBUY=J/YB1cV6<@D
Y12436<88P0224<00`Q222848P0324801a246:D@H`@Q104000@000<@H`0336<<@PPQ00<88@042208
@@Q1344424403AcV9@LY:2D79BL]BC6;=H/icCg=?Ni23TH?00=6;`08CW563dib<FX8@@Q0364U1`A:
C`03CU1>L4ia00=>L005DY5F/U:BDY5:D002BRl01dY@@PhLaCF;G_EBLUJd00=FU0IFU@04EYAFUEJD
EYD3EY@025JEEYAFUEJDEYEFU5JEDYD6CY@2CYD3D[H6DYH7DYL8D[L4E[P4E]P8E[PXOol5Je/5Ke/5
Kg/2Kg`00fmkJe][F`02Je/2Kg/@JeX026LiKgY_NUkf@Q0YBAcV6<D88>L27>L26<H35:D061RU348@
PaB448<Picg^G_IcNfLhIaQW>6LHHaMW>6;gBU4HY1c4>J]J/f;fH_ERmP9Rm@03F[ABLDi@00=>D003
BRm>D4X_00=:;`05APm23Sg^9BP8@P0236<010Q236<48PQ21PA21@@R0`A240Q20PaS0`Q21PaS00@8
@P@Q1248@P<<H`0648<PiS5Z=J`eRc5Z0Re900PPiRD7;DPaJSF:<FTY9b3U211R1aAR00DDPQRT468D
Pac4008DP`047<DPiSF;>J`2?Ld2>J`01cg=?NdicCg=?Ne1kT8>00963`07ARm23Sg^>L`]JRTX9BP0
0RDW0bD600DU9bD69@HQ1R3U00@Y9`8U1P0B8@HPiAc47<@HXac56:A63dYA@S0n4Ae<4>/^5BXh8SPN
5b8i5goo000EOol2=HT03cEX<FPaAbe7;BHY9S5X=JU1bd7/ANa63DX^CTmBL@02BTl04e9aCW1:;dX_
CW1Ne5ZcF]=BLCV[:BLU1Qc4;DPiRSf[<DPTiRCU008Y1P08<DT]B358=HXmZcV:=FXaJ@8eRP04<FX]
JBe8:DP2:BP00ac57>DLa0026:@27<D01aS4488@HPaQ344<@0PP00800005=JXmk47]?L/ib`02?N`0
0cW;>L`ic006>L`00cV[=J/eR`02=J/2>J`2=J/0124V488<H@Q10P@Q00<48PPR24801PQ200<88AB4
58@00Q1S00<88@@02240100000D400P1224<@Q1R008@H@@@HP03464La1cU008PiP049@L]JCV/>L`2
ARl014H`BS1:D4Y@0TYA00U>DD8>BU0eZaS55:<@PQBSDY800UJb00E>LDi`CW1>D4H^00923@03APi2
3T8=00<mk008>J`mkCF;488eRekfBU5FU0=BU0EFU@EBU@0:D[EBUEJeE[IF]EJfE[EF]UJeE[H9D[H3
D[L5D[P8E[P;E]T2F]T3F_T8E]TXOol2HaP00f<IIcUW>@0;IcT2Kg/016]KJeY[FVLj0VLi1fLj00=W
>F<GHaL01V<G00QNmVLHJcQS5e:C?NhaJbU90acV0R3W0b470acV00<LaQS56:D00QS500TLaR3W8@LU
23F<CW9S5f/iHaL00Ukf00URmekfHaMJeD8?468DXcF:EY<00f;e0UkD00=F/e9aCU000TiA00A>D4X_
CU1:C`=:;`05APm23Sg^9@P8@P0236<010Q226<48PQ21PA20P@R20A200<48P@Q12401@@Q1PQ20PaS
0`Q210aS1@Q20PaS018@Q1236<DU9cF:>J`eRc5Z<FTaRReY<FTeRSV/?L`eRbTX8>D@6:<031S458<H
Y1S458<HY2D7:BPeRcV/?Ldmk@8mc@03@Ne23Sg]00<mk@0<?LdicCW<>La23d8>>L`]JRTX:DPY:2DW
12TW00DU1R457>@La23U00HQ1@0A8>DLiB3U6<@La1RT?La:D4Ha@S4][`B79O<UmAgf7QLJ5`0GOol0
01Eoo`8mb`03>JXeZCF9008aJ003;FL]J2e7008]A`05;FPeRCg;@Ne1k002>J/02d7]@Phic3V[?L`Y
B2eY=HXiZcF:=J/00cV[00E1k4G]?L/iRSV[008mZ`07>J/iRSV:>J/mZcVZ=FT00Re800LaJCF;?La1
kD8>APm:;`02EY803DiaBRm63TH>@PhmkCg=>L`iZcF;=HXaJBe8008Y9`8]B005:BHU1BDU9@DLi003
>L`00cg<?Ldmc002>L`01CF;=J/eZcW;>L`00cg]00PYAaBR1408@0Q11448@PaS0PQ210Q30PQ200@H
YB3W8>HPi`8]B@039@LPibTY008U2007:BP]BBe::BTY:2478>H011c500XHY1B3468@HQB36:@U1cF;
@Ni:<0A23`923P0=@NhmkSW=<H/e[36:8@LLiART368@HB3U:DP00RDW00L]B2eY:DLaJBeY;DPYB002
;DP2:DP02247;FTU:0Q1<HaNmTYAE[D2DY@2DYD2EYH2E[H3E[L4E]L00e[HE]MFe`06E]L4E]P8E]T4
E]X8F_X8E]T015:hD[UB^EJi35KI:7oo14YB00A>LTicCW=>L`9>LPI>L`04BU9>LTicDY<4DY@ADY<3
E[@015:CCU9:DDH`14YA00A:D4X`BS16<0A:D@=:<006BU1>DDH?AS1FTe[D0U:C00AJeEJdDY=F/`9F
]006F]EF]4H_?Ndmc4X`0UZc00eF/eZcEY=FTe:BDW5>LE9aCW5>D4Y@CU1:C`03BRl02dH_@Pi1kRD8
244<H`aR2488H`@Q24801PA20P@R10A20`@R3@@Q0PQ20PaS0`Q20PaS1`Q200/<Ha2448@@Pcg]?L`i
c3F:<FXaRSV[008mc08iZ`05?Le1kCV[:DPPiP0<9@H58>H02ART7<DLaART8>HaJSF[@Ni23P02APl5
@Nh2@Ph02T7^?NhmkCg]?LdmkD7^>L`]JBDW0RDX00<U1bTW:BL00RTW00DU9RD68>DLi23U008Q1@DU
1P038@DQ1Qc4008La00;<FU:DDYA@S8j<P268M8Qm1ge8SPImP0GOol001Eoo`0A?L/ibcVZ=JXaRC5X
;FP]AbD58@DU1Be7=HXibcV[=JXiZ`02=HX2?Ld00cF;<FTaJ@02<FT00be9<FTiZ`03?L`3>J/2>JX2
>J/023F:>J/iZSF9<FPaJC5X;DL29BH01C5X?La6;Ti@EY400UZc00AFTUJbEY9>D0=:;`04APiBLDH>
<FX29@H00bTW<FTiZP02;DP00be7:BHU1@029@D011cT>L`ic3W<0cg=0SW<0cg/0SW<0SW;00@ebb45
4:48H08<H@0314448@Q20088@P@8@`88@P0F58@PiR367:DU1bdY;DTaJRTX9>LPiRTX=H/i[2e99@L]
:2TW9@HPiR3U7<D27<@021RT58<DPQRT9@LaJSg=APh2?Nd053g^?NdmcCW<=J/aRcF[<FX]JC5Z9BPP
iQc5364@HR46<FT]JBU8;DP2;FT012DW8@HPiR460RDW00dPiAS47@HQ:248368aS5kgBW=JeU:EDYIF
]P02E[L00eJhF[QF^002E]P00eKIE_UJn@03F_T8E]T00e[iF_YJnP09F_X4F_/8E]X8D]T7D[T00e;I
E]UFf@06E]TXOol3BU401DYbCW9>LTicCY<025:C0Tib0Tic00=>TdicCW802Dib00=BTe:BDY801E:B
00EFTe:CDY=FTeJc00=J]09BTP04DW5>LDiaCU06BU002di@CW5>DDi@DY9BLUJcH_INmE:BCW400U:B
00]>LE:BDY9>LE:BE[=>LEJBBU1>DE9b009>D003DY9BLE9b00ABL@05CW5>D4i@CU1>C`03BRl02dH_
@Pi1kRD8244<H`aR1488@`@Q24801PA20P@R0`A20`@R00<48@0Q12401`@Q00<000@Q12400P@Q0PQ2
00<<H`Q224801PQ20P@Q00<8@PaS36<00Q2400@DQ4X_@Pdmc08iZ`<mc008@Ndic3V/?LdmkCF::DPU
9`PY9`8U9`8U1`@U1P099@LLiB3V8>HLaBTX?La1kT8>00A63`=23P03@Ni23T8>00E23P05=J/mkSg^
<H/YB002:DT00bDW:BLY9`02:BL01RDV9@HQ1B3U8@DU1@@U1P8Q1@0@8@HU9ac47>DLa23VBS1:DD8a
@U<4Yaf@9O@QmBHh6OHGOol001Eoo`04?N`ibcW;=JX2<HT3;FP02BDV8@DYAcFZ?Na23Cg/CU1:<002
BRl014H??LdeRbe90RTX014U1Re8APmBLDiADW5>L4Y?BRi6;TX_BTm6;T7]?L/iZS69008]B00<<FP]
AbTV;DPeRT7]BRm>D59`DW5FTU9a0eJB011BTEJBF[9FTTi@@NdiZc5Y<HTmbdH>CTm1kD7/?N`mj`91
k004?N/mbcg<?Ld4?Nd023g<>L`mkCg/>L/aRRU89BH28@H01QS35<8@XPb12648@@848@848P042288
@PQ224<224800aRT=H]63P02?Ld02cg<?Le63diABRm1kTH>BRm1kS5Z9@H011RS00`HY23U:BL]BBTX
8>DDPaRS7<DU1RTX;DT4;FT00be9:DPU:0039BL07B3V9BLLiART8@HDXa226<@Q1RD78>HLiAcV8@HU
:23V6:@DXaS48>HU1bDW;FXUBBf;6>H]S5[GDYD00eKG0UKH15[I00=FfEKiE_T00UKi0eKj2UKI25KJ
1UKK25KJ00aFfeKJE]]FfUKKE]YFfeKJE]]FfUKKE_X4F_/025KkE_YFneKjE_]FnUKkE_XXOol2BU40
1TYaCW9>LTjBDY9BT`9>TP9BTPABT`AF]09B/`9BT`QJe@]F]09J]003E[AFTe:B00QF/`0GCU1:CdH_
BU1BLE:BCW5:D3g]DW5F/TY?ARmBTEJBCW1F/e:AE[=F/Ti@CW5F/`02DY801Ti@DW5BTTi@DW5FTPIB
L@03CW5>D4i@009>D0=:;`0:ARm23d7^9@P8@@aR24848PQ3124714821282148312800`@Q02408@0=
124224800`aS2488@P0624800`@Q2488@P0236<01a245:DHaC5Y=HXiZd7]00963P08?NdiZcF:<FTa
JSV[=J/YB08Q1PPU1`8U9`8U1`<U1P0:8@HPiQcU8>HLaAc4:DPmcD7^@Nd2@Nh00dH>APm63`02APl0
34H_APm23Sg]>L`eZc6:;FXU:3W<@PheZ`8YB003:DTU:2U7008YA`05:BLU9RD58>DLi0038@D00bD5
8@DQ1@028>D042469BLLiB3U7<@DPdH_BU4n43hb4@X=32HD8O@R=aWe5goo000EOol063h=?Ndmk3W<
=L/eZS6Z<HXibc69:DLUAbeY=JXibcW<APm:<4H?@Le1kTH?@NheR`91kP8eR`0HCU1>DD7^APiBLDi_
CTm:Cdi?BTm:;TH^@Pa1k3W;<HTeRCFZ<HTYAbD6;DLaJCF90c5Y00<eRSF9>L/00d7]00=63TX_ARh0
0cV[00/ibd7]APi:;di?APe1k3g/@Na63DH<009230A1k@8mk@8mk005>L`ibcFZ;FTYA`039BH02245
9DHQ1A222408@@aR2482228020Q224<<@`aT48@DQ35ZCU02F[<2G]@2EY<02VLFG]ABLTX_?Ld]B1RT
340<@A1R0QB300THY23V<FXmcC5Z9@HHXaRT7<D00R3V00@U1b3V7>HLi@8Ha@0<7>DLiR467<DQ1QS4
8@HDY1BS;FTYB1BS0PQ101HDY23V8@HU1bU98@LU1bDX:BPYBC6;?Ne6<3h?:H/ikbU[;HaFeUKGD[IJ
f0=Jf@AJfQ1FnPIFfP9Ff`9Jn`IJo0QFn`0;F_aK75[lFaaJo5/LF_aK75[lF_]Jo005Fa`8F_/XOol0
14iaCW9>LTjB0U:B0U:C0e:B1E:C0e:B00E>TU:BDY=F/eJd00QBTPaF]004EY=BTe9bCW43EY84E[80
85JcCW16;d8=ARi>L5:ABTm23DY?F[=Je4iaCW1JdekDDY5J/e:AEY9F/TiaDY5F/U9aEY9BLUJcF[=B
LUJBE[<5DW400diaCU5>D003CU04BRl02DH?@NhQ1`Q13688@P@R24848@071488128?124224800`aS
2488@P07248336<248@01AS67>HY9c5Y>J/00d7]00Y63TX_:BLY9beY>J/eRbDW8>DQ1P`U9`0>9@LU
1R468@HPiQc58>HLaART;DQ1kD7^BS1:;`=63`91kP8mc@0?>Ldi[36;;FTY:2478@HDXc6:@Phi[2U8
9BPY:2DW00<YA`06:BLU9RD58>DLi23U0R450bD50R45010PiBDW8>DPiAc434163dH`@S4j4B5]08PU
m1gD8QHMmQMoo`005Goo00DmkCg/?N`ic3G;008eZP03<JXLi1cT008M1@0F7>@DX`aQ240000a1364<
@ART;DTeRRTX58<LaART9@M63e9aBS1BLTi@CTl2CW0024i?BTm:Cdi`BRm:;T8=?L/2>L/02CFZ;DLY
9RU7;DPYAbDV9@HY9`02;DP01SF:?L`mc3g<@Ne23P91k@0:>L`eRS5Y<HTiZcg/@Pe:;dH=@Nd4APd0
0d8=@Pi23P02@Ph0148=?NdmkCg/0d7]00dmk3W;>La23DH^=JXmk36Z5:<480A03684@@03248040aS
48@DYAS67>HHY1S3220001RS:DP]B2TX9@LU:2U80Re900@YB2TX9BLPiP8U1`0D7>DHa23U;FTmcC5Z
9@LHa23V:BP]BC5Z=H/icCF/<H/]JS5Z=J`mkP923`05BU0mkT8?=H/aRP02DY<01TH`:DTDY1S58>HH
Y0<@P`05:DU:DEkfHaMNmP02F]D024H`;H]2<36]:F]B]U[hD[L2F_T2E_X015[jF]YJfUKJ0e/K0UKk
0eKj25/K2E/L1e/M00=O7ElLGa`01ElL25/L0UKk00AJne[lF_aJo09K70QFnbQoo`9:D003BU5:LDia
00=>L@ABTP04DY=BTU:CDY82E[<01E:CDY9BTU:cE[<02EKD25Jc00QF]5JcEY=BTU:CEY=J]5kE25Jb
00QF/di`ARi:CeJBE[9>D48=0TY?00M>LEJbF[=BTDi`DY5F/P02CW001eJbDY5F/UJbCU1FTU9a009B
TP04CU1BLEJBCW43DW401DiaCU5>D4i@CU400Ti@0dX_00]6;d8?@NlQ1`Q13688@P@R24848@@R00H4
@P/48P0=12448P@Q12848@@R12448P@Q12848@A224800PQ31PQ200@8@@@Q36<<H`<@P`045:@LiRD7
9@H2:BH03B3U7<@PiCF:APlU1bTX=J]23Sg];FTU9bU800XU9`8U1`<Q1P8PiP058>DPiQc57<@]B@02
@Nh0248??Nhi[3F;;DTU:23V6<D226800`aR388<P`0348<020QQ;FU6;cg=:DPY9bU7:BL5:BH00bD6
9@DQ1@028@D00bD59@HU9P039BH00acU9BHPi@028>D02`@0APm6<4YB>Q4]d015:O@Mdb7e8QL05goo
000EOol04T7]@Pe23Cg/?L/ibc69:DLQ11d47@DQ1Qd55<@@PPaR240<HP8<H@0:6<@]JC6:;FTPiR3U
9@LaJT7^CU02DW48CU002DY?ARi23Cg/?L`ibcF:<HTY9P02;DL4;DP01beY=HXeZcg]ARm:D4H_0092
3P07ARlaZReY<HT]J36:?Nd01dH>00=23T8=APh00T8=147]01@mk47]@Ne1kCg/?L`mk47]@PdU9TY?
:DL4@1RS488001BS6:@8@@aR0Q23020LiRD848<D``b0000@XQC49FT]Rc7<9DT]JcF]=J`]JcF/?Lha
JbTX:DP]BBTX7<DHY2TX>LdaRRTX8@LU:3F<0Sg>02Xi[D8?@PlmkSg>?Ni1kdH@AS1FU4ib@NmBTcF<
:BUNmUJdDY<YB@aR58@LiQRU46<@PaBT7<HmkTibG_IJeF<GE[A>LRDW?Nhe[BU[D[EO6U;HE_T4E_X0
15KkF_]Fne[k1eLK25/L00=O75lMFa`05E/L1eLL1e/L2U[l:7oo00IBTTiaBU1:D4iaDY43DY800e:A
DY9BTP03DY802EJBEY=F/UJCE[9FTeJbEY=F/P08DY8025JcE[9F/eJbE[=F/UJcE[88EY800e:BCW5B
T@02E[82DY402EZcDY9>L4Y?BU1BTUJbCW56;`02DY402EJAE[5F/UJbF[9F/UJADY5FT@05DY4015JB
DY9BTU:B159b159a14ia00A:D4iaCW5:D0=6<007?NhU:@aR124<H`Q312400P@R0`A300<4@PA31480
1@A200<08P0Q02400P0Q2`0R00<08@0R12800PA301408@A22688HPaR48<<H`Q2244@PQBS58<@PQRS
8>DU1bD500<U1P0F8>DTiSF;APlLaBdY>Je1cSV<;DTY:2T7:DPY:2DX9BLU:2DW9@LQ1QcV8@L29BP0
12D78>HPiR460R3V01lPiART7<DY:3V/APlmcBTX:DTQ21SV7>LDY0b318<4PPc52:<8P`bT268<X`b3
7@I23Sg/:DH]ARTU;DHYA`04:BL01RDV8@DPi23U8@DU1@@U1P<Q1@0>8>DU1R3556<U1diAAS0n3cXA
08DA;BXE:QLQmQMoo`005Goo0d7]00Pmk3g;>L/eRBe76<<Li24V0RU801<UB2DX8BPQ9bDX9BLQ1bU9
>L`mkCF[=HXeRcg<APi>D59ACU1:;P09CU002DX_APi1kD7/?L`iZcF9<FLaJ002=HT2<HT0136:=HXe
Zc6:0ReY00H]RSF/?Pi6<3g];HT2:FP012E7;FTmkDH^0TH_1DH?14H>00=63D8=@Pd01D7]00Tmk3g<
?La1k48=:DM6;SF:5:<00R4501/HXbTW7>DHa1cU8>HLiB467>D<H@A03:0<P3W/@Tm6LD9A?S5>]DIc
AU=:M4jDEYE>M48@=J`00SF[010aRRU89BL]JCW<?LhmkT7_AS5BLeJdF[EF]EkfG]IJe@9J]@0CF]IN
mV;gCW9FU59cF]DaJacVEYAJ]EkfAQ0Q20aR224<@Q1S48@00Pa200hQ1c6<E[ABU5ZeE[ABLRDW?Nde
[BU[D[IO6U;i0UKj0ULK00=Jne/KFa/02E/K25/L0U/M3E/L00=G75/LFa`01U/L25LL1e/L2EKl:7oo
00E1kCg]?N`mkD7]00923@04@Ne23T8>@Ph3APh2ARh@ARl@BTl01TY@CU1>LEJbE[=FTP=BTP08CW5>
L4iaE[9F/e:BCW1BT@9FT@EF/PEFT@=BT@=FTP9BTP03DW5BLU9a00EBL@=>L@04BU1>LDiaBU02AS00
2T8??NhQ20Q2124<H`a31248@PQ30PA32PA200D0@@0Q02408PA200T4@`848P<4@`0324<8H`QS008<
P`094:@DaABT368Ha122364@PQc4008U1P04:@HLa1c48<@28>D02BT7?JaBDAbU:BPiS47^@Lhm[@02
>H`01S5Z;DPU9b478@HPiP8Li@038>HLiQS5008HY08Ha@8La@098@HU1R3V8>HY:3W=BS0Q1`aR008D
Y00448@HaQBU4:D21:@206803@1S0684H`A238<M1T8>?N`YARe6:BD]ARU700@Y9`039BHQ1B3T008Q
1@039@DU1RD6008U1P0A8@HQ1B458>HU1R3656<Tidh`ARln3ch@4>PA2bWd:QHQeP0GOol001Eoo`0<
@Ne63DH=@N`mk3g[=JXaJ2DV;FPeZSW<13W]00`ec3W==L`aZcF/?NhmkCF[?Ne1kTH?CU02DW400di@
BRm>D007CW002U9`CU1:;dH>@Pdmk3W;>JXaJ35W0S5X00T]J2e8:DPYB2TX8BLLiQC44:<00Q2300/@
XbUY;FPik4I?@Ri23TH_ARi:;dH_00A:;`963`=6;P=63P03APe23D7]00=1k@07?N`mc3g/@Nd]J48=
>L/00RDV00`YAbU8<HXaRSg=?NhmkCg^=J`YBB474:826>@00ch>AW5:T`02BY@064Id?Q8n4TYeDYI>
UDieDW@mkSW<>J`e[36;;FXaRcV/?Li6<59cF[EJeE[FG_IRm`9J]@03E[EF]5Jd009F]00QE[E>LeJe
E[ENmSW=:BUBTeJdEYAF]DH`9@P@PaRU7>HHaAc646<@Pb47E[EF]5JDF]EBLRTX?LdicBE:D[IK6EKi
009K6`AK7003GaaK75/L00mK7003GceK7E/M01EK70QG711K72Qoo`06>J/eZcF[>L`mc3g=0SW<13g<
0Sg=4Sg]247]23g]00Dic48=ARm:D5:A009F/P9BTP08DY5BTUJbE[=JdeZcE[9FTPIF/PAFTPEFT@AF
TP04DY9BTE:BDY48DW400di@CW5>L@02BU002TX`@PlicB4734848@aS24848@PQ0P@R00@4@P@R1284
8P848@H08@80800302408P0R00T08P848P<4@P0U38<@Q12T5:DHiQd77>HDY11R240<@1RT8>DLa1B2
464HXaRR6:<LXac4:@Lmc59A;BTeJSf/@Ni1cSf]>H`eRcV[<HXYB2DW8@H00QcU00<LaAS45:<00Q1R
00hDPaS46<@HY1RS8>DU9bD68>HU1c6;@PlQ1`aR0a2400XDaA2438@0H`S70480I0R52:HM2@8<Q@08
7>M23cg^;DP]AbTV;DLYA`@Y9`039BHU1B3U008Q1@039@DU1RD6008U1P0A8@HQ1B458@HTiR3658<T
idH?ARln3Sh`9H`8bBGB:OHMe@0GOol001Eoo`07APi6;TH>APe23D8<?L/00SFY00<mk4H_ATl00TI@
0TYA00Y>Te:CCY=:LDibDY9>LDX`@Pi6;`=:;`03CU1BLE9a00Q>L00;DW5>L4Y?BRi63T7]?L`mbc5X
;DLYAP02:BH01BD68@DLiAS47>D011cV00HHaABT364Da36ZATl2ARl00dY?@Pi:<008BRl3ARh3APh0
1dH=@Ne23D8=@Ndmk3g<00<mk005BTm>L47]<HXib`02@Ph01c5YAPi23cg]ARlmcBeY008aRP09;HTQ
9SW]BW9>]5/HFaUG6EKi009JnP06BWH]Sbf?BU@icCV/0cW<00PeZcV/?Ne1kTXaEYAJ]EJd0eJD15Jd
0UJD029BU5:CF[EFU4ibF]EBLdHaF]EBTdYAF]EJ]Cg_;FXaRcV]=J`mcRTY5:@PiekfF]IFU5kEDW8Y
B3g=>LhU:E:fFaUFn@9K6`=K709O7003GcaK75/L00iK70=O?@03FaeK75/L02YK72Qoo`06<FX]JBe9
;FTaJS6:135Z3S6:1cF;4CF:00HaRCg/ARi6;dY?DY42E[<00eJBE[9F/`05F]<2F[8015ZcF[9J/UJb
0UJB0UJb0eJB00=FTEJBEY801EJB00=FTEJBDY400U:A1U9a00=>L59aDW400Ti@00]:<48>>J`U1a1R
348@H`a122088@@Q00@8@P031484@@A100@48@D4800312448P@R00D48P0500408@@R1488@P0224<0
1@Q24:@HaAcV6>H00QS500PHa1BS7<DU9cg=DW5>D3V[0Re800TPiAc36:<HXabS9>HeRTH>?L`00cf/
00`i[3V;=FXaBB467>DHa1BR488@H@aQ240336401a226<@LiB3V8@H]B35Y008iZ`8eRP04?Le:<2eZ
5:@26<H02ABU6<H@Q0b53<M:]eLJKmmgo`02Kkl02SG@38HHj3g`?Nl]JRe9:BL]B2U712TW00<Y9RD6
8>D00R451BD600<U1B458@D00R4600`PiQR48<HmcDX`@Pln<37`1:LMT2We8MDGOol001Eoo`04APi6
;TH>APd2@Pd01Sg[=JXeZCh<ARi23P8ik@8mkP0@@Pm2<48`@Pm2<4H`@PlmkSg]BS1>LDY@BRm>D4ia
DW0:CW0024i@BRm63T8=@Ne1k3VZ<FP2;DL01be8;FPYAbDW8@HU9b47008LiP068BPU:B4X7@HQ9c6[
0Sg]00=6;e:BDY802DX_0dH^0dH>00I63D8=APi63T8=@N`2?L`06cg/@Pe6;Ti`ARheZcg/BRm23S6:
APm23SW<@PhmcCF;?NdYB2DW7@HecDjDC[EK6EKiFc]OG@02Heh03dZH9FlUKdjG>Ldic3g]@NhmkCW<
?Ni6<59bDY=J]@02F]D00eZeE[EF]@04F]D2F[D08UJdEYAJeE:CCU9F]E[EF[ENeU9cE[AJ]EJDAS0i
cCV]@Pm>DTHa<H/LaR3WG]IJ]E:CF]EBLReY>Ldmkb48D]IJnE/J0U/K15/L0UlL25/K25/L15lm00EK
7E/LFaaK75Kl02MK72Qoo`06<H/]JBTX9BLU1bDW0RDX22U822TX42e922eY00@YAcFZARi:C`9>L09B
T@08E[9Jde[CF]=F/eJbE[=Jd`EJ/`9F/P03EY9F/UJb009F/PAFTP03E[9FTUJB009FTP03EY5FTUJA
00ABT@ABL@03DW1BLE9a009>D004BU11kCF;7<D234401A1R344880a122401`Q100<88@Q124400PQ1
00@88@@Q12448@P8@P0412048@Q236<448@03QS58BLYBBDX7>HHaAcV8@HLiBTX?La:D4X_>J/3<FT0
32e79@DPi1c48>D]AcV:>J/eRS5Y<DTaJP8eJP04<FXHa1S36<<26:<031BR488<H@aP364@HA225:<Q
1BeX=JXmk08mc091k@0K?L`mkDH?:DT@PaBU6<DDYAS64:DDa`AVEa]WWfoOLmmc_fnO:Fh@QaS8?M11
l35/;DXY22e800HY9`049@HQ1B459@D69@H00b459BHQ1P028>H02aR47<HeRdY@AS0n<3Xa2:LE;BWD
9OD05goo000EOol3APh2@N`02T8<?N/ibSFZ@Pdn3Bf97@HHiASV0QS50QS600THiQcV7>HLiQcU8@He
ZdY@CW400di@00=:Cdi`CW002Di`00Y>CdX^APi63TH=?L/eRBe7;FPeRP8ib`8eZ`07>NdmkSW=>Lhn
3cg_>Ld00SW<0Sg]00@eZcW<@Phmk@9:D0M:;`03BRi6;TH^00A63P05APe63TH>APe1k@03?L`02CW;
?Na6;TH^?Na23DY@ARl]J@02=J/0435Z<HXaRc6;=J/aJRU89BPaS4IC?S9>]dZGAYQ:^DZI0U;K00/e
m2fcD[Ticcg=?NdmkSg]>Le23TYA00=F]005F[EJeEkFF]IJe@04E[@2EY@2DY<00eJDE[AF]002E[@3
EY@035ZeDY=BLe9cBS4icCV]?Li243F/:DXYB@=J]@09F]EBLS5Z>Le23ad8E]MFn5/J009K6`IK70QK
6`QK70EO?@9K7@03FaaFneKl00MK70MK?1QK72Qoo`04=H`]JRD87>H26<D27<D@6<D@5:@758<01AB2
5:8Q1C69ARh015:A00AF/U[CF]=Jd`AF/P=J/`05F]=J/eZcE[=F/P02F[<015JcE[9F/eJb0UJB15Jb
0eJB0eJA1E:A159a00IBL59@CTm1cC5Y568220001@a02208811134001@PP0`@P1@PP0`@P20@000H8
80Q1468DQ1BT6:@35:@02B47;FX]JReY<H/mkDH_DW9:D002APh2BRl02T7]?L`mc3F9;DLY9RD69@DY
9Re70RTW00@U1RD7:BL]:08]B@8YB00^;FP]JC69;FT]B2U76:<DXQ22364@PAcT<HU1kD8=>L/iZcg/
@Ndmc3g=@Pl]JQ245:DHaQBU5<H@QAC77B]K?6MnE_Y>^5;JD[TM31276:Pid47a<F`]BbD9;DT4:BL0
1BU7:BLU9R459@D00bD60RDV0RD6010Q1B4V8@HPiR3W6:@LYC5ZBS1:DD8`?S4E2PcZ9M8]mAMoo`00
5Goo00=63TX^APh00dH=00M233g;?N]6;T8=9DL@PP03244238<00`b448@@P`0248<01Q2S364YB4H_
CW5>L09BL@03CU1BL59`00IBL005CW1BL59aCW1:C`02BRl01TY?APdiZReX;DLeZP8mk003?La23TYA
009BT`0<D[ANmekgE[E>TTiaDY=BTTYaDY9F/dia1Di@0di?00E:CdX_BRm:;dX^00=6;P963P03ARi6
3T7]008mc00;>La6;Ti`CW5BLE:AE[9F/eJbDW5BTP02F]@075JdG_ERmU[DE[A>LTHa@S5>UChBE_UF
ne/LFci>fe;mFclnF2fcBWPn43g=>L`mkD7^APm:DE:B1EJd0eZe0UkF00AJeU[EF]EJe@9J]@03DY=J
]E[E00=FU00JDW=J]E:CDY=F]5kFF[E:DCg^>Li:<DH@BU523eZeF]ERmeJdDW8aRSW=@Q0HieKGE_QK
6P9K6`AK709O711K70IO?@9K7@03E_]Fo5/L00EK70QK?@QK7003FaeK75/L00eK72Qoo`03>Lhe[2e[
00DYB@8U:@HU:0PU20PLi`PLiPLHa@066<@YAacT9BHmk4i`0U:A15Jb15[C00IF/eZcF[=J]5ZcF[@7
F[<3E[<6E[83E[44EY44DY43EW42DW001di?@L`aB1bT564DHQR3008DHP0368<DPQB200HDPP03488@
HQ1R00@@HP8<HPP<@@0@468DPaRT7<DPiR3U7<DLa1RT7>HU9bDX;DTeZd8>ARl2BS00248>>L`mc4H>
@NdeRCVZ<FT2;DL01RTV9BHU1BTV9@HY9P8]B0@]B@<aRP08=JXeZcFZ=HXaRBDW8@DH``8DXP047>@Y
AcF:?L`2=JX07Cg<?Ndmc47^CU4icAS67>HLiaS65:H@Q1C75>Tj<e;IBYM6ET8e;Hl<Ia275:Pid47a
=Hd]BRD8;DT012TW00DYAbTW9BHU1RD5008U1PDU9P058@DU9R468>HPi`026:D02BTX@Pi:LDI@?S0Y
S@c89I0]d`0GOol001Eoo`03BRm>CdX_009:;P0:BTi6;D8<>L]2;Ch=:DP@Xa235:@25:D34:D00a24
48<@Q0025:@01c6;CU5>LDi@CW5BLDi`00QBL00=CW1BLE:ADW5>D4i?CU1>L4i?@N`aJ2eX=JX00Sg/
00Xmc4H>?Nh]JQBT248<I12536@Da@8@P`044:<HaCF[CU03CW42CW04CU02CTl2BTl3BRl02dX^APi6
;TH^APi1kCg<?L/ibd8=BTl00TH_0Tia00Y:D4i`@PhmkDibF]ABTe[EH_IBLP9J]00NF]IF]U[H?Q9B
^E;JB[YG7E;lE_eOGd9i<OEBfTIB?Ndic3g^BU5BTe[EG_IJeEkEG_INeU[EF[EJeEkF0U[E0UZe00=F
]EZeF[D00eZe00IF]59cF[ENmUJDF]D3F[D05EJdF[EJeE[FF]EFU5JdIaQF]5[EE[ERmdibDW8eRcW<
AS0HieKGE_QO>`02Fa/2Fc`01ElLGcaO?5llGa`01e/l25/L1Ulm0U/M0UKk1U/L25/m25/L0U/M3U/L
:7oo00ES66<GG_MNmf;g00=S60=W>@9W>1]S60QW>005HaDmk2U8>La>L002DW401eJcE[9F/UJbE[=J
e5kD009Jd`03F[=J]5Zd009Je0EJ]0=J/`=F/`9J/PEF/P03E[5FTEJA00=FT@=BT@=FL@9BL@05CTm1
c358>HX]B002<DP2:@H00bTW9@H]B003;DL01BdW:BLY9bTX8>D0123V01<PiB368<DU1bD69@LU1RD7
9@HU1bD68>HU1RTX;DP]BBe8:BLU1`028>D02AS458<HXacU8>DLa@PP8>DaRP02<FT043F[=HXY9be8
9BHU1RTV:DLY9RD59BDY9S5X>J]1kDH>147^00<mkCg=?N`00Sg]00Dmk3g<<FTYAbDV008Q1@069BDQ
1B448>@L`b3T0RDV00LU1ReY@Nhe[1S56<HLi`026<L01A256>P@Y`R63:L00P140Q2W00THbA275:Li
[d8@=H`]BRD8;DT012TW0RU700<U9RD69@H00RD61BDV00DQ1BDV8@HPiR3W008HY@099BPmkDY`AU0n
;cX@3:LUKbgB01Moo`005Goo00=BLDi`CTl00dX^01M23D7/?N]2;DY?:DP@PQ2S388DY12U6<L@Y@QS
36<@Q12T6<D@XbeZ@Pi:D4ia009:C`03F[=BLE9a00UBL@03DW1>L4i`009>L007CU163SF9<FPibcg/
>L/00Sg/00i:DBU936<8@a266<P<I12448<@Xa2348923dY@0Tia0Ti`0di@0Ti?0Ti@00=>CdY?BTl0
0dX_00E6;TH>APi6;T8=008mc007?Na:CdY?BTm:D4i@CW000Tia021>DCg]CW5J]5JdF]EF/e[DF]EJ
]EkGG_QBUTIDBYIK6e/LD_aG7E/ND]a2F3hgAWM:DSg]>La:<5JCE[AJ]5kf0UkE00ANeU[FF]IJe@AJ
ePAJe@QJ]@9F]@QF]0EJ]@=Je@09EY<aRSF/CW<DaU[hE]QK6U/k00=K?0AO70QK6`AK7004FcaO?5ll
Gc`8Gcd3Fa`00e/MGceO?@02Gcd:Fcd2Fc`BFa`00eKlE_]oo`0WOol4F]H3F]L015[gG_MNmekg0ekh
00=S65lHG_P03Ukh2Ekg00IS5elGHaMO5f<GGaL2HaL01fLg?NdLi3W;ARiBTDY?00UBTPIFT`9FTP9F
T`04DY9BLU9bDY82EY<2EY44DY42DW48CW0035IaDW5BD4i@CRm:3T7<?J/iZcF:<DP]9`@Y1P03>HXe
RC5Y00@aJ@0=;DPeJQB368<HXaR47<DHQ1bT;DPU1RCV:BL00Re80RTW00d]:2e8<DTaJC59;DPY9bT7
:BLU1R3U7<@Pi@029@H02R3U7>DU1SF:8>DY9dH><FXY9be80RTW0RU701XY9RTU:BHY9S69BTliZdX`
@PlmcCg>>L`mkCg=?Ne1kSV[=J]23SFZ8@HQ1BDV9BDQ1BDU0R44014Pi2DV8>@Q1BD69BM63d8?48@Q
224948DHb1S75<L@YPbU00<<Q@0;4:H@YaC75:HHYRU:@Pm1kRe99@L]J@06:BL01BTV9BHPiB459@D0
0RD60bDV0R4U0R460QcV00XPib47?Ne2;dI`AW4ikad95>X]/1Moo`005Goo00=BLDi@BRl00dX^00i6
3D8<=JXmk4H^9DLDXaC448<@Y0Q348DHaaC70Q2U00XDYABT6<De[4YADY9F/TiaBTm>L0aBL@0MDW1>
L4i`CW1BL4X_>J/aRCg;?N/ibd7/@Pi:DCF/=Je24CW@;Dd@QQ2T4:<DY12S48=6;diaDW5>L@03CW00
14i@CTm>Cdi?0di@0dY?0TX_00E:;TH>ARi6;T8=008mc005?Na:CdY?BTm:D002CW03CW402Cg]DW9J
e5ZdG]EF]5[EG_INeP02G]L054jE?Q8j4dIfBYQ6MdJHB[U6VChf@UM>V4IA>L`eZdH`F[ANmEkEG_H2
G]D2G]H00e[FF]EJeP03F]H5F]D8F[D00eJeE[AF]006E[@4F[D4F]D025JC<HXe[4ic5<IJn5KHFaX@
Gc`5Fa`00e/lGcaO?008Gcd2Fa`00e/MGceO?@02Gcd=Fcd00e/lFaaK700AFa`XOol<F]L00e[gG_MN
m`0QG_L025[E<FT8@2D6:DPeZbeY=J/8<HX;=H/2<H/3=H/2=HX2=HT<<HT032e8<DTaBC59<FTiRdG]
BRmBD4h_BRm63P=5k@04APe1k47<?L/3?J/013V[>H/]B0a10Q1100H<@A1R324@HRdX8>D26:<47<@0
2R3U9>DTiRD69>HPiB358<@U1RCU0R3T018PiBD69@HQ1S5Y<HXic2TW;DU:;cg==J/aRReY:BPU9RD6
8@D28@@011cS:DM:Ccg=0TiA00e>DU9cCU9:DDH?AS1:D3g]<HXibcF[8@HQ1@029BH02R459BDQ1244
8><U9B3T8@DU1RDW0T8?00HDYB488@T@QQS86<L25<H00aC54<D@Y@024:D25:H25:D01RU9@Pi1kReY
9BH]B0HY9`04:BHU9RD69@H69BH28BD03R468@LLiacW8@LU:3W<ARm:L4I`>NhM20b66>XGOol001Eo
o`03DW5>D4i@00=>C`08BTi6;Sg/ARi:CbeY6<@Hi@8@Y00>6>P@YQ2V4:H8Ha2U5<H8@Q2T=Ja:D4ia
DY9B/P9>L19BL@0?APdmbd7/?N/mbd8=BTm6;beZ<Ha24CW@<HlQ2QBV00@DY003BU1BLU:B009>L@03
DW1>L4i`009>K`03CW1>D4i@009>D005CTm:CdY?BTm:;`03ARh014H=?L`mc3g/0dY?00=>D4i`CW00
0dia00M1kE:BF]AJe5keF[ANe@02H_H01f;gG_MBUChB=O0ilRf`008YS`0?;K4]/2f@<M52<dic@Phm
kDiAG_ES5ekfG]ENeUkE009NePAJeP03G]IJeU[F00IJe@MJ]@QF]@AJ]@AJe@07EY<aRSV/CY<DaUKg
E]P00U/k0e/l15lL3U/L0U/l25lm00=K7ElmGcd015lm3E/m00IK?5/LFaaK75lmFad>Fa`XOol2E]H3
E]L3F]L4E]LDF]L8F_L7F]L02E[FIcPeR`aR9BLU1bU99@L]B@08;FX6<FX012e:;FXaJS5Z12e:0S5Z
0beY1Be81beY00T]BCEZ=H/eJRTX9>HY:3f/CS000TX_00=:3TH>APh00TH>0TH=00=1k3g<?L/00Sg<
0SV[00`]B@a1344<@@`Q34888A1R>J`]:1c46:<37<@00b358>DTiP049@H05bT7:@HPa2348>@U1BTV
;BL]Abe8>J/mbcg];FTaJTH>>L`aRS6;;FXY:2468>D00QcT00LLhb3T<HUF/TH_BU564002AQ405Cg_
>LdaJbe:;FXU:2TX>L`eZbDV8@DU9bDV8@DU9R458@@Pi2DU8>@U1@029@H02T7^@PlLaQcX8@TDYQS7
6:LDYQC50aC411C50QBT00HU:48=@PhaJBDU:DL2:BL2:DL3:BL012DV9@HU1RD60bDV00HU1RDV8BDQ
9B4V8BL28@P02RDY:DTeZdH^BU16Cch?<H`U:RE;5goo000EOol3DW406e9`DY1BT5:@DW0mjd8]BTlY
B12S5:@@Pa2U6<L@YcG?F]MO6F<jD[DQ:A2T>Le>LDY@BW1BTP03DY47DW45DY44DW4045JBCU1:;TX^
@P`mbd8<BRm6;b4848DDYaBX8@`U2aS60aBU00@DaDYaDY=FT`9BL@IBL0=>L0=>D003CTm:CdX_0096
;P05BRi63Cg<?L`mk002BTl00dY@CW1>L002CW408U9aDW923U:BG]EJeEkfF[ANmF;fG]ENmV;gF]I>
M4IC@U=>]dZFCYI>]djfCYIF]elHF]EBLTiaF[AS5V<GG_IJeEkf1EkF0U[F0ekF00=JeU[EF]D01E[E
3eZe1U[E00QF/cF;>LeBTaC6E]MFf5lk25ll25/L0U/l1Ull3elm2E/m0U/l15/L0ULL00=K7E/LFa`0
0U/L00=Fo5KkE_/00eKk1E/L:7oo0eJg0eKG1E[G1E[H45[h25[G25[g00QS62eZ368YBB47:BTQ1bDX
22471B3W0b3V00<Pib3V8>H00Qc600@PiR3W8>HPiP8Pi@<Li@/La@078>HTib3V8>H]BD7^DW801DH>
00E63D7]@Ndmk3g;008iZP<iZ`0==H/aJQ1R448@HPa2448<@QRU<FXU1QB246400aB200<DXaRS6:<0
0QRS01LLa23U9@HU1R348>@Y1C57=FPeJCV:?J/iRSg<@NdiZcF[?L`aJRD76:DDY123008<H@0O464<
H0Q06<<YAdia=H/U:ARV48D<@`aT48@@I11S34888AS5?Ldic2DW8@HY9bDV8@HU9R459@@Pi2DU8>@0
0RD600LQ1Sg=AQ0Q21cW8@THa`026:L01aBV4:@@Xa335:@Da1C5008Ha@095:@DXbD7?Ne63S699BHY
ARTW00@YA`8Y9`03:BHQ1B45008U1P@U9P8UAP8YB00<:DTYBRe[<H/eZdH^ATm23DH_AS52448A5goo
000EOol00e:AEY5FTP03EY42E[40248=BTm>TBeY4:<Da1BT7@L25<L02cW`F_QFeeKGAU8LiaBT?PiF
/djACW000djA00=BTE9aDW401E9a1E:A0UJA019FTU9aF[=J/UJADY1:;Cg;?N]6;dia:DT<I1267>X]
CR4;6<H25:D01AC56<E>LUJCEY800U:A00=BLE:@DW001E9`0Ti`14i@00Q:CdX_BRm:;dH>?L`mbcg/
0TY?0Ti`0Tia0U:A00=BTT8>EY<00UkE00URmU[EG_ERmEkEG_ENmUkgF]H00UKF0e:f00]FeUJfE[EF
]E[EG_IJeEkEH_IS5Ukf009Ne@9NmPENeP03F]INeUkF009NeP03F]IJeE[E00EJe@eJ]@EJe@0;F]IJ
eEZc=J/icE:C5:EFeeKHGc]SG@03Ged4Hed=Gcd3Gc`>Gcd00e/MFaaK?@07Fcd2Fa`6Ea`4Fa`9E_/0
0eKlFaaK700XOol7F_P8G_TAGaT?G_T2G_P01bU:6:DmkcV^?NlmcSg_00PicP/i[@03>J`iSCV/008i
[@Di[003=J`eRcF;00PeR`08;DXaJS5[=H`i[D7_BS1BLPA23P06@Ni1kCg<?L`mbcW;0SVZ00DiZcW<
>J`i[35Z008<@@8<@P0:34<@Hb3W9@LLiART7<@PiB3V8@H29@H38@H03RD6:BLYB2e8;BL]9S57>HTm
ZSf[?L]1kCVZ@N`3?Nd09cW<=J/YBAc67<LLaQS57<DLiAS3360Li2DWAS0U:12424<@I@a446D@I0a3
46@@Q0Q258@]JSW=9BPQ1bTX9@LQ1RDV9@HU1B3S9BDQ10029BH01B3U>Ja642U:6<L00QcX0QBW00<D
YQ2T4:<00Q2S00X@Y1BT5:DDaAS548<PiSW<APheZPLYA`<Y9`049@HU9RTW:DL2;DP2;FP042eW;HP]
RBf:;F/aS36/=L`ic4I?AThn34H_BU56<4H@5goo000EOol00e9aDY5FTP03EY42E[4014H]BTm>L2E7
0PaQ00`8@A249D`UC2f>9D`<Q@b45:H<P`QR<J`2CY8015:BDY5>L4jA25:A0UJA1UJB00IBLEkDG]AJ
de[BCTl2?N/03dY?BU0Q1`aT9B]654ih>M8HaaBU6<DHiQcWDY=F/`02DY82DY45DY03DW400e9`CW1>
L002CU002DY?BRm:;dX_APhmc3g;?Na>D003CW000diaDY5BT@02DY801T8>EY=NmEkEH_IJe@9Nm@03
G_ANmEkf009NmP9O5`04F]IJmUkfG_L2H_H2H_D01E[DG_ERmV;fG_D00UkE0ekf2ekF0U[F1U[E2eZe
15[E0U[F00]NeUkEF[@eZcg=DY<@YEKGE]QO>ell00=K?0aO?0AO?@AO?0QO?@9K7005FaeO?ElmGceK
7@02Fa`7Fc`3Fa`5Ea`4Fa`00eKlE_]Fn`07E_/2E_`XOol2GaX>HaXHHcX8HaT01VLI<F`YBekgF[IS
609W6@U[>Q1[>@E[>0YW6008JcUW66;gG]IJ]E9cBS523`91kP06?NhmkCg=>L`i[3F[0SW;0SFZ01<i
ZcW<>J`e[2eZ24488@aS348<HaB5:BTU:2DW;FTic3g]@Ne23P02ARl00dH>@Pi1kP02@Nd03D8>@Pe1
bcV9>FQ1ZTG/@L/mbd7<>J]1k3V[008mk@06?La63cg^?O12447`0Sg^00U23SF[:DLYAbU8BU4YBQRV
9@X00T7b01A:<be/46D<I1RV58DHYBU:?LhY:BD7:BPU9b469BLU9RDU8@<U9BD40RDV01PLiCF;AS0a
S1RV7>PQ2ABW5:PDYQC55:@@Xa2348@DY1BU6<DHaQ246<De[48?=J/8:DL2:BL052eX<FPaJCF9=HXe
ZSVZ=JXeZCG:=J/e[36/=JdecCW]<JY2;TH^ARd2CU000dH?@Nmoo`0FOol001Eoo`04DW5FTEJBE[82
EY4045JaF]8mjch<@PhU9aBS6<@@Pa2414<Db24[7@T<QPQT0Pb400LLicG<AS1:LE:bDY9>T009DY45
EY83E[805EJBG]ANe5[CG]=BL48<?Na:Cd8>6<D<I2D[?O=:Ecgb6<LDaASV7@LU:002E[@00eJBDY9B
TP03EY43DY02DY43DW43CW0024i@BRm:;dX_APhmc3g;?N`4CW000e9aDY5BTP02DY804D8>DY=NeEkE
H_IJeEkeG_ARmF<EHaINmEkfGaIO5e[EF_D00Uke0V;e0V;d00=Nm5keG_H00eke1Ekf2ekF0e[F1E[E
0UZe35[E00aJeUkFG]INeEZd>J`mkE:C4:EBeUKHHe`8Fa/8Fa`3Gc`00e/lFaaK700>Fa`2Fad:Fa`3
Fcd00e/lFaaK700BFa`XOol00elJHaYS6P08HaX2Ha/BHc/9HcX7GaT02F<IG_PY:RTZH_QJ]V<IIcYW
6@08HaP00fLIIaQW6007IaP016KhH_QRn6Kh0fLH0VLG3F;g00QS66;hG_QNmekGE[E>LdHa0TYA0TH`
00M6;d8>@Pi23Sg/>L/iZ`04=J/2<H/2248030aT34<<I1BV;F/LiRDW=J]23TH_@Pm6;`9:D018AU16
<4H_ARm2;dH?APi:3CfY>FPmZTG/@L/mZcg;>J]1kCV[APi6;cg]BU56<4HbBS=6<D7_@Pm6;cW<:FPQ
9R46@PlU:AB59B]6<d7cDWHeSQ1U34@DQQ246:H]Jcg^:DTU1bTX9BLQ1bDW9BHU9B439BDU12TV9BHL
a35ZAS0i[ABV7>PU2Q265:LDYQS50QBT00d@Q1BU6<HLj2497>P@Q1RU<H]23cV/;DTYB002:DL2;DL2
:DL2:BL2>J/00cW;?L/mc002?L`01CW;>N/ijcW<=L`00SF]00XecSW^<HXmk48<ARe>CdX_@Ni63aMo
o`005Goo00]FTUJbF[=J/UJbE[5JdU[CBTm>L5KC009:D00=F]ABTTibCYAF]U:EBWABUE:eD[AF]4YA
CY800Tia00AB/U:ACW1F/PQBT@AFTPAF/P06F[=NmEkCF[=Nde:@0T8<00m:;dH_9BPLab3Y6<PLbABW
6<HHaAcV8BLYBE[EF]@00eJB15JA00AFT5:@DY5BT@=BL@05DW1>L4i`CU1:C`02BRl014H>?L`mbcg/
0di`00m>LE9aDY5BTE:BDW523U:BG]EJeEkfF]ANmEkDHaD00VLf00AS5UlFHaIS5`=S5P9Rm@9W5@09
H_EW5f<GH_INmV<FHaMRmUkE00ANmPYNePAJePAJe@9J]@]Je@9JeP=NeP08F[@i[3g^DY<@YE:fE]QS
G11O?09K70IK6`QK709Fn`iK70AO?@03FceK?5/l00=K7@UO7@03FaeK75/L009K72Qoo`9Jn@9JnP9N
nP9O6P05Ga]O6UlKGa]S6`03Hc/?Ha/016<JGaYO6ElJ35lI00UNnF<H:BXY:V;hEYENef;hG]L026;h
1f;g00ANmf;gH_MRe`9NeP07G_MRmf;gH_INmV;fG_H035kF00=JeU[GF]H00U[F00=F]59cCW800TH`
0T8?148>00=2;T8=?Nd00cW<0SF/00/aR`Q1244<H`Q234<@QBU:8@LYJCW]0096;`03?Pi23TI@0092
3`03@Rm6;dH_00=6;`06APheRC57>JU5k4G[0T7;010mbdX_@PiBTe:D@S5:Lchb?S=2E3XB=Nlikd8_
>NdYJ@8YB009CW4]JaBV8>Te[bD/8>THZ1B6008Lb00L46@@Q2e;?NlYBBD8:DPU9b479BLU9RDU8@<U
9BD4:BHU9QS4;FY6<3g>5:DLibDZ48HDYaBV58D248@02aBT6<HQ22e;<F`Pj1245:@aJd7^>J`00Re9
00@YB2U7;DP]B08YA`8Y9`Dmk08mc005>L/mjcg/>N`ic002=Jd2>Ld023W<?Pdmk3W;?N`iZcV;@NhG
Ool001Eoo`0;EY9F/UZcF[9F/UJaF]9JddY?CW1Fd`02BU003E[DDY9>LTjDE[IBUDYdDYEB]E:dE[A:
DDjB009>L@04D[9BTDi`E[88DY44EY84E[801UZcG_ENdeZcG]=BT092300?BRm6;bDX7<LPjAS87<TD
YaS66<DLiR4W:DUJeE[D00=FTPAFT@04EY1BT5:ADY43DW401E9`CW1>L4i@BTl00TX_00A63Sg<?L/m
k0=>L00?CW5BLE:ADY5BTU9a@PiBTUkEF]ENmU[DG_ENe6<E009W=P04HaIO5V<FHaL3HaH2H_D2IaD0
2F;eIaMS5f;fG_IS5V<GH_INe@04G_H:G]H4F]H4F]D2F[D;F]D2F]H3G]H025Zd>J`mkU:C4:EB]UKH
He`@Gc`2Fa`6Fa/8Fa`2E_/>Fa`4Gcd00e/mFcaK?003Fad9Gad00e/MFaaK7002Fa`XOol2F_T2F_X2
G_X2GaX01ElKGaYO6elKHa/00f<k3f<K00AS6UlJGaUO6PaO6@09G_US62TZ:BYRn5JEG]MRn5kG00QR
n0MRm`04G_MRmf;gH]L2G]H01ekgH_MRmf;fG_IRmUkf00aNeP03F]IJee[F009JeP03E[ABLdib0096
<0923`A23P03@Ri23Cg]00<ic08e[00;<H/8@@Q136<8@Pa348DYBR47:FTik@02ARl00ch>@Pi6D002
@Pl00d8_ARm6;`03ARl01TH>=HTaAcVYANa5j`91b`0@?L]:;d8>DY=BU48aBW<n<Shc@U@j4SG_>Nm2
;cW]:FT2:DP02Dia;F/DYR3Y=JlU;23Y6:PDQP027<P0711T48@]Bcg_:DTU22U89BLQ1bDW9BHU9B43
9BDU12TV9BHHa2eZAS0mcQBU7>LU:Q265:LDYQB50Q2400/DY1S68@P]Bc5/8>P@Q1BT<F]1kSV/008]
B@04:DPYAbe8;DP2:DL2:BL5?N`2?L`01CW;?N/mk3W/>L`00SF]0SW=00Pic3h=?N`ibcg/>J/iRd7^
5goo000EOol2EY82E[82F[801e[BF]=>L4i`DW5BTEJB00=F/P03EY=BTeJC009BT`=BTP=BL@ABT@03
DY9FTEJA00UFTP9F/P05F[9J/eZcF[=Jd`02G]@025ZbCU123CW;@Pdmc3F:;DT2:BP02Re9;DXU1bDW
;DPeRSg]BRmBTEZc0UJb0UJB0UJA15:A00ABLE9`DW1BL09>L003CU1:;Ti@0096;P05@N`eRDH^CTm>
D002DW0025:AEY5FTUJBDY56;diaG_D2G]D015kfG_ENmEke1Ukf2V<F16;f1ekf2ekF45[F25kF00YJ
e48?=JaF]1BUBWAO6ElJHc]O>`AO?09O>`03GcaOG5mL00EOG09K6`AK>`9K6`QK?0aK70AK6`AO?0AO
70AO7@AK7@9Fo09Jo09Jo@9K7BQoo`=K6`05Ga]O>elkGcaO>`0@Gc`8He`015lJGcYO6UlJ0U[i25lI
0UlH00ENn2D8<HaF]E[F009NePUNm`aNmQINeP9JeP9NmP07E[A:DDYABU1:<4H_APl0148>00Y1kSg]
?NdmkCg=>L`i[36;48848088@@0;5:@U:23W9BP]JCF[?Ni63dH_@Pm23P03ARl3APl2@Pl00d8_<HXa
J@02?L/02d7:AN]1bSg:CTmF]3haAYHf=3Hf;SD00RXe020Z=3Ie<S4]cSG]9DPUAbDW@Rle[1S66<LM
2AcY7<PHYaBV6<LDYQ1T6:HY:D7_;FXQ1RDW:DPU9bD69BHU1BDT0RDU0RDV0RDW00@mkSF;7>HDY08L
i`0348D@Q1RU008HY@0=6<HLaR47;DXaRac548<DPbTX?L`mkC6::BL022U800@aJCg<@Ne1k@Hmc0Lm
c@Lmc1Moo`005Goo00AF/EJbE[9F/P9J/P03F]9JdeJA009FT@EF/PMFTP03EY5BLE9a00=BT@9FT@03
EY9FTEJB00UFTP9F/PAJ/`08F]=Ne5kdG]AJ/U:ACW1F/PAFTP06F[=NdekDG]AJdeZc0UZb00=J/e[C
G]@00eJb0UJB00=FTE:ADY400U:A00ABT59`DW1BL09>L003CVm:;Ti?0096;P05@N`eRDX^CVmBK`02
DW02EY42EY800e:ABRmBL@02G_D00ekDG_ENm@04G_H4H_H:HaL016;gH_IRmV;f1ekf00=NeUkEG]D0
25kF45[F25kF00UJe48?=JaF]1BVBWAO6ElJHa/00UlK1Ulk25/k00MO>ellGcaO?5lkGcaK>`08Gc`7
Ged00elmGcaO?002Gc`00elLGcaO7002Ga`00e/KFaaK6`02Fa/2F_/01ElMFaeK7E/MF_d00e[l0UKl
00=Jo5KlF_`00e[l:7oo25ll1emM00=OG6=MHe`01V=L1f=M00MSG5lJGcYO>UlJFaUJn@06GaT3GaP0
1V;hG_LU236;E[AJeP9NeP03G_MNmUkf01=NmP9NeQ1Ne@=NeP9Je@05G]INmUJDBU56<002APl2@Ph0
5cg^?NdmkCg=>L`e[3F[=J`eZcF;<HXYB0aQ120<@@aR6<DU9acV;FXeRcW=@Ph00dH_00=23dH_ARl0
0TH_0dH?01U23d8`;H/]RSW;?LY1bTGZ@LY5k48=>NhQBc7c:O@^=bHG8SLN=QWc8Q<Z4C8@?W8ac002
9DL0548>=J`HaAcW7@PLj1c86:HDYQS65:H@Q1RU9BQ1kReZ8@HU9bU89BL29BH49BD02RDV:DLYAbU8
CU123Re97>HQ223W0QRU0Q1S0aB400LHY1c58>HPiQS47<@]B002?L`00c69:BL]B007;DP01CF:?La1
kT7]?L`00Sg=00<mc3g=?Ld023g=1Sg<5goo000EOol3E[83F[82F]82F[801e[BF[9J/UZbE[9F/EJb
00MFTPEBT@=FT@MFTP03E[9FTUJB009F/P05F[9J/eZcF[=Nd`04G]@3G_@2F[<00ekCG]ANm003G]@0
1F;eG_ANdeZcE[800eJB0eJb0eJB0UJA0e:A00ABT59`DW1BL09>L009BRi>KdX^ARi1k3F9BRi>Ke9_
009BL09FT@9FTP03DY5:;e9a009Nm@03G]ANmEke00ANmP=RmP03H_MS5f<G00QS5`04H_MRmV;fH_H7
G_H00ekFG]ENe@08G]H@F]H8G]H02U[DAPle[5Jd5:I:LekiGaYS6elK1Ulk25/k0U/K15/k0U/K0ell
00=K?5/LFa/00U/K25/L0U/K00=K75/KFa`015/L00=K6e/LFa/00e[k00=Fne/LFa`015/L0U[l00=J
neKkF_/00U[l0e/L:7oo0emM3F=M26=m26Mm00IO>eljGcYO6U/IF_T8GaT2HaP026;g9@PaReJdG]IN
mUkFH_LFG_H:G]H7G]D3G]H01e[EF[EJeUkFEYA:DDY@009:<096;`05APm23T8>@Pi1kP04?Nd03SW=
>L`eRb467>DU9bU8<HXeZbeY>L`mkD8>APl3AS05ARl3APl07d8?@S0]Rbf:>L/mbd7:AN]1bT7/@Phi
kad[:M4Q/R7D5K@Ae1We5M<MlbGa;Q0j<2589DPUAch>>LdHaAcW008Lj00>7<PHYQRV6:HDYA246:DU
23g^<FXU1bDW:DPU9`<U9P<U9@<U9P099BLic3F;8@LDY1RU5:@@HaB4008HY@DLaP098>HaJRe8:DPe
Rd7]?L`aJBTW00P]B007=HXmc47^@Ndmc3g=?Nd033g=1Cg<5goo000EOol2E[84F[82F]84F]<00e[B
F[9F/P04E[85EY84DY44EY45EY86E[801EZbF[=J/eZcF]<00UkD0ekC0UkD1Ekd00ANe5[CF[9FTP9J
/`9J/P9J/`9Jd`04F[=J/UJbE[83EY801EJADY5BTE:ADY00159`00=>L4Y>CW000TX^00A1k3F9BRiB
K`9BL003EW1FTEJA00=FTP05BTmBLEkeG_ENe002G_D2G_H3H_H2H_L;HaL016;gH_IRmV;f1ekf00=N
eUkEG]D025kF45[F25kF00UJe4H_>LeF]ABVBU=NnF<JHc/00V<l3Ell25/K00=O?5/lFa`00e/K00QG
6eKkE_]FnUKkE_YFneKj1UKk00=Jo5/KFa`02U/L3e/K:7oo26=M1f=n00=SOFMnIgd01VMm1fMn00UW
OElkGc]O>elJGaUK6ElIGaX01UlI0V<H00QRmbDX<HaF]EkFG_INeV;g1ekg6Ekf1ekE0ekF00YJeEZe
F]EJeEJDBU56<4H_APm23`923P05@NhmkT8>?Nhmk@02?Ld01SW=>L`e[4H_@Ni23P96;`04AS16;d8>
APl3ARl4AS06ARl01DH?@Pm2;c6;<HX00Sg;01a1bTG[@LXmbd8?@U8Y[c8D:ODbFBik>_i3GclM>]Xf
MSYd?U<QJRE99DPmkCg^6<DQ21cW7>PLa`<HYP065:DDQ1RU8>LmkS6:0RDW00@YAbDW9BHU9P8YAP<U
9@079BHU1RD6APm6<47^>Ld00Sg^00@mcTH@AQ1640=:<00;AS163dH?@NhmcCg<?Ne1kCg<<HTY9`08
;DT01CV[?Le1kT7]?Ld00T7]00<mcCg]?Nd01cg]0cg=13g<5goo000EOol6F[82F]83F[8015[BF[9J
/UZb1EJb25JB15JA15JB1EJb00AJ/UZcF[=J/`IJd`=Nd`9Jd`ANe0=Nm003H_ANm5kD009Ne004G]=J
dekCG]<3F[<00eZbE[9F/P02EY82EY42DY401e:@DW1BL59`CW1:Cdi`009:;P03@P`eRDX^00=BL008
EW5FTEJBEY9F/UJBBTmBTP9Nm@04G]ANmEkeG_H3H_H2H_L<HaL016;gH_IRmV;f1ekf00=NeUkEG]D0
25kF45[F25kF00QJe4H_>LeF]ABVBU=NnF<J0V<k15ll00=O>ellGc`02ell00IO?EllGcaO?6=MHcd3
Gcd00ellGaaK700<Fa`015/MFceO?Elm1e/L00AG75/KEaYK6PEG6P05FaYG6U/JEaYK6P03EaXXOol2
Ged>Hed8Hgd8Igd3Gc/01ElJGaUK6ElIGaX01UlI0V<H00ES5bDX<HaJ]EkF009NmP03H_MNmekg00EN
maUNmPMNe@04G]IJeUkFF]H2F[D00e[EE[A>LP02BU42BU001dX`ARm6;dH_APm23T7^008mkP0;?Ndm
cCW<@Ni:D59bCW9>DDX`AS1:D@02BU000dX`AS16;`0:ARl06D8?AS0aRc6:?L/mjd7[AN/mbcW;?Nhj
4BF?=ULfND;n@am7Gd^O@cljfc9f=UA2M2f]008UB@0A>Le23aS69@THab3X7<LHaQRV6:DDYAB46:DL
aCg=<H/YB0049BL29BH2:DH3:DL00bU8;DPeZ`03?Nh01D8?@NlmkTH`@Nl00T7^0Sg^0T7^00<mkD8>
@Nh00T7^00A1kCg]=JX]J0PeR`03>La1kD7^008mk@91k@03?LdmkCg]00Pmk@<mc@<mc1Moo`005Goo
25Zb0UJb1UZb1EJb25JB0eJA0eJB1EJb15Zc0U[C0UkC0UZc00ANdekDG_ANm09Ne004F]=J/eZcF[82
F[<00ekCG]AJd`03F[<015ZbE[9FTUJB15Zc00AJ/UJbE[9F/P9FT@9BT@07DY1BL59`DW1>L4Y?CW00
0TX^00=23CFYBRh00e9`00QFLEJAEY9F/UZbE[9:D5:B0Uke00=Ne5keG_D00f;f00=Rmf<GHaL036<G
00ARmf;fH_IRmPMNmP03G]INeEkE00QNeQ1JePQNeP0:F]A6<3g^F]DDYTYCG_US>f<KGa/6Gc/;Gc`2
Gcd3Gc`5Gcd00ellGaaO7008Gcd2Fa`3Fad015/mFaeK?E/L0eLL00AFo5LLE_aFn`EFnP=Bn@EFnP=B
nBQoo`AOG@aSG@QSO@QWO@04Gc]S>elkGcX3GaT00elJGaUO6@05HaT01V<HHaLU:3F<F[ENeP9NmPYR
m`URmPiNmPMNe@05G]IJeEkFG]IJ]@02F]D015ZeDY=:DDYA0TY@00=:<4H`ARl00TH_00=23d8>@Nh0
0T7^00/mkCW==H]6<4iaBS1:D4H_@Pm>DDYA009:D003AS16;dH_0096;`96<0I6;`0TAS0aRc6:?L`m
jd7[@N`mk3g]>Plf42F_>WP^=agf2E81DPVD4K<R5BGc9O4b4BE[9DXUBCF/AS0HaRTY6:HPj1c77<HH
YQBU0aBT00@HYCg==H/YB08U9`07:BLYAbU79BHYAReX=JT00SW;0SW<00`mkDX`BS16<4YAAQ11kdH`
BS163d8?@Nh2APl0148>@NhiZcg=0cg]00=1kCg<>J/0247]00<mc47]@Nh00Sg]00=1kT7]?Ld033g]
0cg=00<mc7ooOol05Goo000EOol5F]86F[82F]84F[85E[87EY82EY400e:AEY9FTP05E[8015ZbF[=J
/eZc0U[C00=NdekDG]@00UkC15kD0Ukd0V<E00=RmEkdG_@00ekD00ANdekDG]ANe0=Nm003G]AJde[C
00=J/`=F/P=FT@9BT@06DY1BL59`DW1:Cdi`0TX^00=23CFYBRh00e9`00QFLEJAEY9F/UZbE[9>D5:B
0Uke00=NeEkeG_D00V;f0V;g3V<G00ARmf;fH_IRmPMNmP03G]INeEkE00QNeQ1JePQNeP07F]A:<3g^
F]DDYTICG_T00V<k0V<l1Ull1elm0ell0Ulm0ell25lL25lm1E/M00IK75/MEaaK7E/LFad5Ea`00eLK
EaYG6P02EaX3E_X4EaX2E_X2D_XXOol2Ged>Hed8Hgd8Igd01ElkHc]S>eljGaX00UlI00=O6UlIGaT0
1V<I00MS5bDX=HaJ]EkFG_MNmP0:H_L:H_H=G_H7G]D015kFF[ENeUkF0U[E00ANeU[EE[A6<096;`96
3`06@Pm23T8>APm23T7^0Sg^00`mkCg=>L`ic4iaCU56;diABU16;dibBU42BU02BS06AS06ARl00cF;
<HXmc003@N`073g/?Phn<3iC9K0b=R7D4I<140Uc1E89DB8E;SD^4cHb9HdUJbE9<Ja:<AS6:BXHYB3X
7>HLaQRU1ABT00<icCF[;DT00RDW0RU700LY9bU7;FPeZSg/@Pe63P02@Ph0247^AS163d7^APm1kSg=
@Pl5?Ld01Sg<=J/aRSF:?La1k@8mk@03@Pi63T7]00Q63P08?Ne1kT7^?Ne1kD8>@Nhmc@U1k@<mk@@m
cAMoo`005Goo0e[C0e[B0UZb1E[C0UZb00=F/UZbF[8015Jb0UJB0UJb0eJB0UJA00=BTEJBEY8015Jb
0UZb0eZc0U[C00INdekDG]ARmEkdG]@4F]<00ekDF]=Jd`0;G]@2F]<00eZcF]=Jd`03F[<00eZbE[9F
/P03EY42DY401U:@DW1BL59`BTm>L09:;P03@PdeZTX^009BL004EW1FTEJAEY82F[800eJbCU1BTP02
G_D00ekEG_ENm@02H_H00f;gHaMS5`0=HaL016;gH_IRmV;f1ekf00=NeUkEG]D025kF45[F25kF00QJ
e4X`?NiJeABUAU=NnF<k1FMM0f=m2f=M0V=N0f=M0f<m1F=M1f<m00=O?EmNGch00eln25/m0e/M15/l
15/L0U/l0e/L0eLK:7oo26=M1f=n00=SOFMnIgd01VMm1fMn00IWOElkHc]S>eljGaX2GaT00elJGaUO
6@06HaT01f<H9BTeS5ZeG]INmekf00YRm`YRmPeNmPMNe@06G]IJ]EkFG]IJeE[F0Ukf00=JeF;fH_H0
0Ukf15ke00=JeE[DE[@00eJc00IBTe:BAS1F]4iaARl2DY800dX`CW5:D005BU02BS03AS05ARl08dH`
=H/eRSg<?Na1k48<?N`ec3h`?U<MKR7B9OE2oU>OFoljoQge9ODYm2GA=Q8]cRE[9DXaS4YA7<D]BQRU
9>PLiQc66<D011BT00@DXcW<=J/]J@8U9`<YA`04;FPaRCW;@Pd2ARh02T8>?NdmkD8>?NdicD8>@Pm1
kTX`0dH>0TH?00Q1kSV/<HXiZd7]APi1kT7]0dH>247^00Q1kD8>@NhmkD7]@Pi1kSg=2T7]0cg]0cg=
5goo000EOol:F]86F[83E[85EY89EY43EY83E[8015ZbF[=J/eZc0U[C00=NdekDG]@01EkD0ekd45kD
00ANde[CF]=Jd`=J/`9J/P05E[9F/EJADY5BT003DW001di?DW1:;TX^@PdeRDX^009BL004EW1FTEJB
EY82E[800eZcCU1BT@03G_D015lFG_ENmUkf0f;f00=Rmf<GHaL026<G0f;f3Ekf0ekF0U[F0e[E45kF
1e[F0U[E00I6<3g^DY@Pj48aG_P2Hc/00f<lHeaSG@02Hed2He`5Hed2Ied00fMNHeeSG@0:Hed4Hcd0
0f=MHceS?@04Hcd3Gcd015lnGceO?Elm1U/m0e/M00AK75/mFaeK7@QK70EG72Qoo`QSG@MSOP03HgeW
OVMm00IWO@9SO@=WO@9WOP06IgeO>f=KHe]O>UlI0UlJ0elI1V<I00AS61c6@NmF]09NeP03H_MS66;g
00IRm`03HaMRmf;f015RmPYNmP04G]INeEkFG]H3F]H2G]H2G_H2IaL2HaL4HaH025keIaMNmTibAS1>
DE:BCW82DW82CW83CW400diABU5:D@03BU02BS000dH`BS1:<002AS03ARl01DH?@PleZc5Z>J/00T7/
01lmc3g]>NhekSXa9M0YlagC>[];GdLo?_hV5R7C:O<]lSHB9HdUJbUZ<H`e[2e:8>HLaB3W6<DLaAS5
58<DY0026<D01ABS>LdicBeY9BL00RU800PU9bU79BHaJCg/ARi6;dH^1d8>147^0TH>0d7]00@mc3V[
<HXmc0963P04@Ni23T7^@Nd8@Ph2@Nh@@Nd3?Nd3?LdGOol001Eoo`YJdPIJ/P=F/PEFTPUFT@=FTP=F
/P04F[9J/eZcF[<2F]<00ekCG]ANe005G]@3G_@@G]@015kCF]=Jde[C0eZc0UZb00EF/UJaEY5BTE:@
00=BL00;CTmBL4X^BRi233F9BRiBKe9`EW1FT@02EY82E[800eZcCU1BT@03G_D015lFG_ENmUkf0f;f
00=Rmf<GHaL026<G0f;f3Ekf0ekF0U[F0e[E45kF1e[F0U[E00Y6<3g^DY@Pj48aF_QS>elJGa]O>`=O
?003Gc]O?6<l00=S?A5SG@=S?09SG@ES?003GcaO?Elm00QO?@03FaeK75/L00=K70UK7@9K7003F_aF
o5Kl009Fo2Qoo`QSG@MSOP03HgeWOVMm00IWO@04HgeWOFMmIgd3Igh01VMmGc]SFf=KGcYO6@9O6P=O
6@IS6@04HaPLaT7_E[@2G]H00f;gHaMRm`06H_L00f<GH_MRmP0BH_H9G_H5G]H2F]H2G]H4G_H6G_D0
25[EG_EF/dH??Ne6;diaCW82DW82CW83CW400diABU5:D@03BU02BS000dH`BS1:<002AS03ARl2APl0
6SF[<FXiZd7]@N`mc3g]@Plj3chb:JlYlQfA:QDZ5RHE;SLUdbWd<S@f4cXb;JdQ:BU:=J`2@Nh2?Ld0
147^ARm23cg^0cg]00hicCW<=J/eZbU88@HY9bDW8@HU9bU7<HTmk4H^14H_248>00=23DH>APh00T7]
00M23Cg/>J/aJCW<@Pi63P03@Ph00d7]@Pi23P06@Ph2@Nh@@Nd3?Nd3?LdGOol001Eoo`YJdPIJ/P=F
/PEFTPUFT@=FTP=F/P04F[9J/eZcF[<2F]<00ekCG]ANe005G]@;G_@9G]@00ekCF]=Jd`03F[<2F[80
1EJbE[5FTE:ADY000e9`00Y:Cdi`BRi:;T8<=HU:;U9_DW1FL09FT@=FTP03F[=>D5:A00=Nm@04GaIN
mEkfG_H3H_H00f;gHaMS5`08HaL3H_H<G_H4G]H2F]H3F]D@G]H7F]H03E[EG]E:<3g^DY@Pj48aF_QS
>ekjGaYO6elk009O?09O>`IS?09S?@QSG@ESG0=S?09SG0IS?003GcaO?Elm00=O?@MO70AK70=K7@=K
70QJo003E_aoogoo02Ioo`QSG@MSOP03HgeWOVMm00YWO@AWOP05Gc]SFf=LGcYO6@02GaX00elIGaYO
6P06HaT01f<H7<I1keJdG_INeV;g00US5a5Rm`=RmPYNmPANeP9JeP9NeP9NmP=Je@IJe006G_EF]4Y@
@Pm:D59b0U:B0U9b00=>LTiaCW400Tia00=>DDYABU400dY@14X`0TH`0dH_0TH?01/i[36:>Ja1kD7/
?L`mkCh>>Phn<2V=<O8YlRhD8K8MTBWc:M8b4cHC<O0el2f<9DTYJCF[@Ph00dX_00A:<4Y@@Pi1kP96
3`8mk@0<@Phic3g]=J/aJSF[<HX]JC6:=HXibd8=1TH_0TH?00=63T8>@Ph00T8>00=23DH>APd00d8=
00Dmk3V[<FTibd7]00923P963P]1kQ11k@<mk@<mcAMoo`005Goo2U[B1UZb0eJb1EJB2EJA0eJB0eJb
00AJ/UZcF[=J/`9Jd`03G]=Ne5kD00ENe0]Nm0YNe003G]=Jde[C009J/`9J/P05E[9F/EJADY5BT003
DW0024Y?CW1:;TX^@N`eRDX^CVl2DW02EY43EY800eZcCU1BT@03G_D015lFG_ENmUkf0f;f00=Rmf<G
HaL026<G0f;f2Ukf0UkF00ANeEkFG]INeP9JeP=JeAMJeP08F]ENeDX`@PmBU1cX@Q5Jn0=S>`03HcaS
G6=L00QSG09WG003IeeWG6ML00UWG0YSG09S>`9S?09S?@9S?0=O?0iO70=K709Jo0EJnbQoo`ISG@9S
OQ1WOP9WO@IWOP04Gc]SG6=LGcX3GaX00elIHaYS6P06HaT01f<H7<I1keZeG_INeV;g01YS5`9Rm`=R
mPYNmP=NeP9JeP9NeP03G_INeEkE009Je@AJe008E[=JeEkeE[ABTeJCDY=BLP9BTP03DW9>LTib00=>
L@9>D@04BU5:D4Y@BU04BS02AS03ARl024H?AQ0i[36:>La1kD7/?L`2?Nd01SW^>PlUJc7`=Q8nM@8]
lP07=Q<]dCGa<O0][CG^;J/00RUY00<aRCV[@Nd014H>0SW<00a63TH_?Ne1kDX`ARm:D4H>@Pi6;d8>
?L`3@Ph4ARl2ARh5ARl2APl014H^@Pe6;DH]0T8=00I63D7/>J/aJCV[@Nd2@Ph00dH>APm23P0:@Nh@
@Nd3?Nd3?LdGOol001Eoo`YJdPIJ/P=F/PEFTPUFT@=FTP=F/P04F[9J/eZcF[<2F]<00ekCG]ANe005
G]@;G_@;G]@2F]<3F[<01UZbE[9F/EJADY5BT0=BL00<BTm>L4X^ARi1k3F9BRi>Ce9_DW1FLEJA0eJB
00=J/di@DY400eke00AO5UkeG_INmP=RmP03H_MS5f<G00QS5`=RmPUNmP9NeP9Ne@=NeP9JeP=JeAMJ
eP09F]ENmDY@@PmBU1cX@Q5Jf6<k009WG006IeeSGF=MHeeSOFMm4FML1FMK0V=K0fMK0f=K0V<k2F<l
0f<L2elK1Ekj15[j:7oo0V=M0f=n4fMn00=WOFMnIgh01FMn00AO>f=LHeaO>`=O6P03GaUS6V<J00IS
6@07HaPLaT8?F[ERmekfH_L06f<G0V;g0f;f2Ekf0ekF0U[F0ekF15kE00QJeE[DF]AJe5:BE[AJe5Zd
0UJc00=BTTibDY800U:B00=BLTibCW400Tia0diA00=:DDY@BU000TY@0TX`0TH`0dH_01Y63dH`>Jde
RcW<@Ne1k3g<?N`mkD8?AU4a[3X@>Q52Dc7a>Q8n4C6^>Nlj3cG>?PlikBf90ReY00<eRCg/BRh00Ti?
00E6;SW<?La:Cdi`0096;`0:CW5:;dY@ARm:<4iaAPlmkDH_BS0>ARl014H^APe6;DH]0dH=00E1k3W;
<FTiZd7]00923P03APi63d8>00Y1kQ11k@<mk@<mcAMoo`005Goo2U[B1UZb0eJb1EJB2EJA0eJB0eJb
00AJ/UZcF[=J/`9Jd`03G]=Ne5kD00ENe1=Nm0=Ne003G]=Jde[C009J/`06F[9F/UJaEY5BTE:@0U9`
00a>L4Y?CW1:;TH^@N`eRDH^CTmBKe9`EW42EY42EY800eZcCU1BT@03G_D015lFG_ENmUkf0f;f00=R
mf<GHaL026<G0f;f25kf00=NeUkEG]D00UkE0ekF0U[F4e[E1e[F00UJeEkeBU123e:D7>Q24E[HHc/0
0VML0V=L00=S?6=LHe`00V=L0fMK00AWG6MKIeaWG0USF`=SFPAS>P03HeYS>V<j00ES>P03Hc]S6f<K
00QS6`03Ga]O6UlJ009NnPUNn@MJn2Qoo`=SG@=SOQQWOP9WWP08Gc]WG6MLGc]O6UljHcYO6@9S>P9S
6PAS6@06HaPLaT8?F]ERmekf7V<G00=Rmf;fH_H00f;f1ekf0ekF00AJeU[EG]INe@=Je@IJe005F[AF
/eJCDY=FT`02E[<3DY800e9bCW9>LP03CW42CU400dYABU1:D002BU02BS02AS03ARl024H?AS0icCF;
?La1kT7]?L`2?N`03dH^DY92<4Yb@S56DcX@?Q1243W>@Pm2<3W]@Phic002>L/01cFZ>JXmbdX^CTm:
;dH_00923@0=BTm:D4H_ARi:CdH_BTm6;dY@CW523Sg]BS000TH_00=63TH?ARl00dY@1TH_0TH^00=6
3DH]ARd00TH=00I6;D7/>L/aJCW;@Nd2@Ph2APh00d7^@Ne1k@06@Nd2@Nh@@Nd3?Nd3?LdGOol001Eo
o`YJdPIJ/P=F/PEFTPUFT@=FTP=F/P04F[9J/eZcF[<2F]<00ekCG]ANe005G]@3G_@8H_@8G_@4G]@3
F]<01eZcF[9F/UJaEY5BTE:@009BL003CW1:Cdi_0096;P07@N`aRDH^CTmBCe9`EW000UJA0UJB00=J
/di@DY400eke00AO5UkeG_INmP=RmP03H_MS5f<G00QS5`=RmPMNmP9NeP=Ne@04F]ENeUkFG]H2F]HC
F]D7F]H02E[EG_E:D48?DY@Lj48AF]QS>`02Ie`016<lGc]O>e/k0Ulk46<j0V<i0Uli35lI00=O6Ukj
G_X01ekj0eki0U[i00EJn5[GF_MJme[G00MJePEFeRQoo`QSG@MSOP03HgeWOVMm00IWO@EWOP9WWP09
JiiO>fMLIeaO>elJGcYS>UlI00AS>P=S>@07IaUS61c6@PmJeF;gG_L00V<G1f<H5F<G0V;g1F;f1ekf
0UkF00=JeU[EG]H00UkE0e[E15[D00=NmE[DE[@00eJc00=F]5ZdDY800e:B00=BLTibCW800dia0TiA
00A:DDY@BU1:D09:<096<0=6;`08APm:<CW==H`icD7^@Ndmc0<mk00<CW16;e:B@S16DD8@@Nm63cg=
APm1kC6:0SW;00Q23DH]@P`mjd7[APe6;D8<1Ti`00m:D4Y?BTm:D4H_BU1>LD8>?Ne:D4H_@Pm23T8?
ARl00TY@00A:<4H_ARm6;`E6;P03ARe:;DX]00963@07ARe23Cg;<FTibd8>APh00d8>00=1kT7]@Nd0
1T7]0T7^447]0cg]0cg=5goo000EOol02eZcF]9J/e[BF[=JdUZcF]9J/e[BF[<01EZb15Jb15JB00YF
TE:AEY5BTEJADY5FTE:AEY5BTP9FTPAF/P=J/`=Jd`MNe0=Nm0QRm0QNm0ANe0=Jd`07F[=J/UJbEY9F
TE:ADY000U9`00=>L4Y>CU000TH^00E1k369ARi>Cdi_009BL0=FT@04EY9J/di@DY43G_D00f;fG_EN
mP04G_H;HaL3H_H7G_H015kFG]ENeEkE0U[E0ekF0U[F4e[E1e[F00iJeEkfBU123e:D7>Q24E[HHaYW
G6=LHcaO>e/K0e/J00=K6ElIGaT04ElI00AK6E/HFaQK609K6@=K60=Jn0AJn@UJf@9Jf003E]QFeeKF
00AFeP05E[IF]EJfE[EF]P05D[DXOol2Gc`3GedCHed5Igh016NNJii[WUlk0VML00ES>elJGcYS>UlJ
009S>P0<HaYS>V<jHcUS6FLIHaPLaT8@F]IS5ekg0V<G0f<H6V<G00=Rmf;fH_H00f;f1ekf0UkF00EJ
eU[EF]ENeEkf00=Nm@ANe@9F/`07E[AJeE[EE[ABTe:BDY<00e:B00=BLTibCW800dia0TiA00A:DDY@
BU1:D09:<096<0=6;`0LAPm:<3W==H/icD7^@Ndmc47/APdibd7]>J]23SF[>Ldic3g<@NdiZcg<=JX]
B3g/ARi234X^BTh2ARd2CTh02DX^ARi:CdY?ARi:;dY?BRm23@02BTl024H_BU1>D3g]?La:D4X_ARl2
@Ph3ARl00dH>ARm6;P04ARh00dH>ARi6;@02BRh2ARd01DH^@Pdmbc69?L`00TH>00=1kT8>@Nh02D7]
0T7^0d7]00<mkD7]@Nd02T7]0cg]0cg=5goo000EOol3F]<4F[<01EZbF[=J/eZcF[800eJb00MFTUJb
E[9FTU:BEY9BTP0:DY400eJBDY9FTP06E[800eJcF[=J/`04F]<2G]@4G_@<H_@4G_@3G]@2G_@3G]@2
F]<04eZcF[9F/UJADY5BLE9`CW1BLDY?CU1:;TX_@NdaRD8=BTi>CU9_00=BL009DY5FTUJBCU1BLUkE
H_INmU[E009NmP08G_ENmUkfG_IO5V<FHaMNmP9O5P9S5P9O5P9NmP=Rm`INmPENeQ1Je@EJ]@9Je@9J
eP=J]@=JeP9NeP08F[E>LTH@CW<YBcW?F_UO6P9S?004Gc]K>eLJEaX2EaT00e/IF_UK6@03FaT02ElI
FaUO6E/IGaUK6ElIFaUO6@07FaX2FaT7FaX00e/IF_UJn@09E_T2E]T00eKHE]UFf002E]P00e;HD]MB
f003D]L2E]P3D]P00e;GD]QBe`0XOol2Gc`3Ged5Hed2Ged5Hed7He`00f=MIeeWO@02Igh01V]nJii[
WUlkHeaWG0AS>`04HcYS>f<jIc/2IcX02F<jHaYS6F;h6:E>LekgG]IS600OHaL00f;gH_IRmP02HaL0
16;gH_IRmV;f2Ukf0ekE1E[E00=Je5ZdF[@00UJd0UJC15:C0U9b0Tib0dia0TiA00A:DDY@BU1:D09:
<096<0=6;`963`03?LdeZcV/008mk@Dmk003?L`mk3g<00<mc0<ib`03>J/eZSg;00963@963P96;P=:
;P09BRm6;Ti?ARmBLDi`=HXaRT8=00=:C`05CU123Cg<ARi63P02@Pd014H^BRm63TH>14X_00=6;TX^
ARh00dH^1DH>00Y23T7]<FTic48>APi23TH>@Pi1k@Y1kP03@NdmkD7]00<mk@Q1k@8mk@<mc@<mc1Mo
o`005Goo0e[C2EZc1EJb0UJB0e:B2U:A0U:B0UJB1EJb0UJc00=J/e[CF]<00U[C0UkD15kd36;d1Ekd
0UkD0Ukd0ekD0U[C01=J/eZbE[9FTU:ADW5BL4i`DW1:;di@ARi:;T7]<HU23DY>CTi>K`02DVl02U9`
DY5FTEJBDW5BLUkEIaMRmUkF1Ukf0elF45kf1EkF0e[E15kF15[E3EZe0e[E15[F15kF00]NeE9bAS1B
LbU;>LmJn5lJHcaO?5lk00EK>`=O>`eS>`03Gc]O?5lk00QO>`03Fc]K6e/K009K6`9K>`QK6`AK6PAG
6PaFnP9FnBQoo`04GcaOGEmMGed6Hed2Ged5Hed7He`01F<lHeaSG6=MIed00VMm00EWOUlkHeaWG6<l
00IS>`9W>`09IcYS>V<JHaUS61RUCW=NmekF009S61iS5`9Rm`04H_IS5f<GH_L3H_H:G_H3G]D6F]D0
1UZeF[AF]5JdEYAFT`ABT`04DW=BLTibCW83CW42CU4014YABU1:D4Y@0TX`0TH`0dH_0TH?00<mc3F[
>J`00Sg]1Cg/00<mc3g[?L/00cg;0cW;00<iZcFZ?L`014H>0TH^00a:;TX_BRm:;dH>BRm63TY?APhU
1R3U@Nd3BRl014Y?@Ndibd8=0SW;00<mk4H>BRl00TH^14X_0TX^0dH^0116;dH?APi63TH?APi23T7]
<FTic48>APi23TH>@Phmk@Y1kP03@NdmkCg]00<mk@Q1k@8mk@<mc@<mc1Moo`005Goo0e[C25Zc00=J
/UJbE[8015JB0e:B2e:A0e:B00=FTUJbE[800eJb0UJc00=J/e[CF]<00U[C0UkD15kd0V;d2F;e0V;d
1Ekd00=Ne5kdG_@00ekD0U[C00IJ/eJbE[9FTU:ADW43CW002TX_CU16;TH^@NdaJD8=BTi>CTi_0U9_
00YBL5:@DY5FTTiaDW9NeF;gG_INe@UNmP03G_ENmUkf009O5PQNmP9NePENe@aJe@MJ]003F[EF]EZe
00iJ]@09G]EBTTH`DW<YBcG?F_QO6V<k009O?0=OG09OO0ESG0=WG11SG09OG0=O?09O>`]O?09O>a1K
6`04FaYFnUKjE_XXOol4GedDHed2Hc`016=LHeeWGFMM0VMm00AO>f=LIeaS?0IS>`9W>`0;IcYS>VLj
HaUS61RUCW=NmekGIaQS6009HaL@IaL6HaL2H_L2HaL016;gH_IRmV;f2Ukf0ekE1U[E00IJ]EZdE[AF
]5JDEY<4DY<0159cDW9>LTib0dia0TiA00A:DDY@BU1:D09:<096<0=6;`963`03?L`eZcV/008mk@Dm
k003?L`mjcg;00<mb`<ib`03>J/eZSg<00A63P96;P0=BRi:;dX_CU1:;di@ARi>D48=7<@DPT7]BRl0
0TY?00A>Cd7]>J]1k@8iZ`05?Na:;TY?BRm:;P04BRl2BRh3ARh044H_APm63TH>APm63T8>@NdaJCV/
@Pi63T8>APi23Sg]2T7^00=1kCg]?Nd00cg]247]0Sg]0cg=0cg<5goo000EOol3F]<8F[<2E[84EY83
DY8=DY43DY82EY83E[82E[<00eZcF]=Jd`02F]<2G]@4G_@2H_@;H_D00f;dG_ANm002G_@00ekDG_AN
m003G]@2F]<01UZbE[9FTUJADY5BL@=>L009BRm>CdH>ARi1k35Y@Pa:;DY>00=>K`0;CW1BL5:ADY5>
D4iAF[ARmUkEF[ENeP04G_H4G_D00ekfGaIO5P04GaH00ekfG_ENmP02G]H3G]D00e[EG]EJe@08F]D0
15ZeF[AJ]5Zd35Jd0UJe35Ze00UJeDibAQ1>LbU:=LmJf5lJHc/00Ull0emL00=OOF=mHe`05F=L0UmL
16=L00=OG5llGc`025ll1E/L2e/K15Kk1EKj:7oo0UmM5V=M0fMM00=WOFMnJgh00V]n00AO>fMLIeeS
?0IS>`=W>`9W>P08IaUS61RVCW=RmekgIaQS60US5a1W5`YS5`04H_MRmV;fH_H:G_H3G]D6F]D01UZe
F[AF]5JdEYAFT`ABT`04DW=BLTibCW83CW42CU4014YABU1:D4Y@0TX`0TH`0dH_0TH?00<mc3F[>J`0
0Sg]1Cg/00<mc3g[?L/00cg;0cW;00<iZcFZ?L`014H>0TH^019:;TX_BRm>L4Y?CW1:Ce9aARhLi1B1
@Pe:Cdi?CU1>L4H>?L`2APh01T8=APi:Cdi@BRm:;PA:;`9:;P=6;P0;ARm63dH>APi63dH>@Pi1kBeY
>J]1kP02@Ph00dH>@Phmk@0:@Nh00d7]?Ndmk@03?Nd8@Nd2?Nd3?Ld3?L`GOol001Eoo`=Jd`MJ/`03
F[9F/UJb00AFTP9BTPmBT@=BTP9FTP9F/P9F/`03F[=Jde[C009Jd`9Ne0ANm09Rm0aRm@05H_ANm5kd
G_ANe002G_@3G]@2F]<2E[801EJBDY5BLE9`CW000Ti@00Y:;TY?APi63Sg/<FU1k4X]BTi>C`=>K`0;
DW1BLEJBCU1>DEZdG_ENeE[EG_ENmP0:G_D2G_H4G_D4G]D8F]D2F]@00eZdF]AJe005F[@=E[@2E[D2
F[D8F]D02eJdCU523dib:DXecU[hGaYS>elkGc`00U/l0U]L00AOG5lkGc]O>a1SG0=OG09O?0=OG0MO
?09K?0]K70=K6`9G6`YFn`9FnRQoo`03GeeSGF=M00]SG@03HgiWOF=M00MSG@03IeeWOFMn009[OP04
Jii[Wf^OGc/2Ied016=LHc]S?6Lk0f<k0fLk0fLj00IS61RVCW=Rn5kgIaP2HaP8HaL@IaL:HaL016;g
H_IRmV;f2Ukf0ekE1U[E00IJ]EZdE[AF]5JDEY<4DY<0159cDW9>LTib0dia0TiA00A:DDY@BU1:D09:
<096<0=6;`963`03?L`eZcV/008mk@Dmk003?L`mjcg;00<mb`<ib`03>J/eZSg<00A63P96;P0DBRi:
;dX_BRm6;TY?ARi>D4H=7>@DPT7]BRm:Cdi@DW16;T7]BRm>D09:;`9:C`03BRi:;di?00=:;`9:;P=6
;P0;ARm63dH>APi63dH>@Pi1kBe9>J]1k@02@Ph00dH>@Pi1k@0:@Nh00d7]?Ndmk@03?Nd8@Nd2?Nd3
?Ld3?L`GOol001Eoo`=Jd`IJ/`03F[9F/UJb00=FTP9BTPMBT@QBL@ABT@=BTP05EY9F/UJcE[=J/`04
F]<2G]@4G_@2H_@=H_D2H_@015kdG]ANm5kd0ekD0U[C0UJb00=FTU:ADW400Ti`0Ti@00Y6;TY?APi6
3Sg<;FQ1k4H]BTi>CP9>C`08CVm>L59aEY9>D4iaF[ARm@9Ne@03G_INmEke00INm@03F]EJmEke009N
m@9Jm@03F]ENmEkE00ANe@EJe@03F]AJ]5Zd009J]0=Je@9Je0=J]0QFT`]F]09J]@=Je@08F[A>DD8?
CW8YBSG>F]QO6P9O>`IK>`AO?003HcaSG6=L00USG0=SG@=SG09OG0AO?0=O>`03GcaO?Elm00=O?@EK
7@]K70IFo0EFnbQoo`iSG@03HgiWOV=M00YWG@0<IgeWOV]nJgi[WV<kIeeWOF=LHc]SG6Lk0V<k1FLk
0VLj00ES6ARVDW=Rn5kg009W6003HaQW66LH00IW5a1W609W5`QS5`04H_MRmV;fH_H:G_H3G]D6F]D0
1UZeF[AF]5JdEYAFT`ABT`04DW=BLTibCW83CW42CU4014YABU1:D4Y@0TX`0TH`0dH_0TH?00<mc3F[
>J`00Sg]1Cg/00<mc3g[?L/00cg;0cW;00<iZcFZ?L`014H>0TH^00e:;TX_BRm:CdX_CU16;Ti?APhU
9R45@Ne:;P02BRl034i@APdmk4X_BTm6;TH>ARi:;TH^BRm>D0=:;`9:;P=6;P0;ARm63dH>APi63dH>
@Pi1kBe8=J]1k@02@Nh2@Ph00d7]@Ni1kP08@Nh00d7]?Ndmk@03?Nd8@Nd2?Nd3?Ld3?L`GOol001Eo
o`=Jd`EJ/`04F[9F/UJbE[83EY89DY48CW44DY44DY8015JbE[=F/eZc15[C0UkD15kd0V;d3V;e0V;d
00=Ne5kdG_@00ekD0U[C00IF/UJBEY9BTE9aCW03CU002TH^BRm63DH>?L`]J3g/ARe:;Ti>0di?00=>
L59aDY400Ti@00AFTekDF[AJ]09Ne@03F_ENeEke015Nm@=Ne@AJe0AJ]0AF]0AF/`QFT`=FU0EF]004
EYAF]5JdF[@2F]D02ekFG]ENeE:BAS1BLbU:=LiFf5[iGa/015/K00=G>e/kFc/00elk1Ell26=L0V=M
0emM0emL0Ull0e/l0U/k00AK?5/mFceK?@QK7@=K70EG70EFo003EaaFo5Kl00EFo2Qoo`iSG@03HgiW
OV=M00MWG@05HeeWGFMMIgeWOP03Jgh01F<lIeeWOF=LHc/00VML00=S>fLkIc/016Lk0VLj00ES6ARV
DW=Rn5kg00EW60IW5a1W>0=W5`MS5`04H_MRmV;fH_H:G_H3G]D6F]D01UZeF[AF]5JdEYAFT`ABT`04
DW=BLTibCW83CW42CU4014YABU1:D4Y@0TX`0TH`0dH_0TH?00<mc3F[>J`00Sg]1Cg/00<mc3g[?L/0
0cg;0cW;00<iZcFZ?L`014H>0TH^00e:;TX_BRm:CdX_CW1:;di`CU0iZSg;APi:C`03BRl0147]?La:
;dX^0TH>00E6;TX_ARi:;Ti?00=:;`9:;P=6;P0;ARm63dH>APi63dH>@Pi1kBe8=J]1k@02@Nh2@Ph0
0d7]@Ni1kP08@Nh00d7]?Ndmk@03?Nd8@Nd2?Nd3?Ld3?L`GOol001Eoo`=Jd`EJ/`04F[9F/UJbE[83
EY89DY48CW45DY43DY8015JbE[=F/eZc15[C0UkD15kd0V;d3V;e0V;d00=Ne5kdG_@00ekD0U[C00IF
/UJBEY9BTE9aCW02CU002di?APi:;dH=APhmc2eX?Na6;DX^BTl00di?00Y>L59`CW16;TH_DW5F/eJB
EY=J]09Je003G]ANmEke009Nm@03H_ES5V<F00IS5PMNm@04G]EJe5[DF]@3F[@2E[@2DY<6DY88DY<2
EY<2EY@4E[@04EkEG]INmV;fHaMW5fLhIcMS5UJcBU1BTbU:=LiFee[iGaX00U/K00=G6e/KFc/00U/l
1U/K00=K75/KGc`01ell00AOGEmLGcaOG0MO?09K?003Fc]K?5/l00EK7@05EaaG7ELLEaeG700;E_`0
0e;kD_aBn`06E_`00e;lD_]oo`0WOol>Hed00f=nIgiSG@09Ied016MmIgi[OV]n0V^N00ES?6MMIgeS
G6<k009WG003Hc]W>fLk00AW>`9W>P05HaTHYU9cH_QNm`05IaP6IaL@IcP3IaL7HaL016;gH_IRmV;f
2Ukf0ekE1U[E00IJ]EZdE[AF]5JDEY<4DY<0159cDW9>LTib0dia0TiA00A:DDY@BU1:D09:<096<0=6
;`963`03?L`eZcV/008mk@Dmk003?L`mjcg;00<mb`<ib`03>J/eZSg<00A63P96;P0:BRi:;dX_APe6
3TY?ARi>D59aAPh2CU001U9aCU1:CdY?@Ndmk09:;`07APi6;TY?BTm6;TH>BRh00dX_0TX^0dH^00]6
;dH?APi63TH?APi23T7];DPeRd7]0091kP923P03@Ne1kT7^00Q1kP03@NdmkCg]00<mk@Q1k@8mk@<m
c@<mc1Moo`005Goo0UkD00=Nde[CF]<00eZc00AJ/UJbE[9F/P=FTPIBT@9BL@03CW5>L4i`00I>L003
CW5BLE:A00=BT@9BTP=F/P03E[=J/e[C009Jd`9Ne0ANm0ARm0aRm@9Rm0ANm00:G]ANde[CF[=J/UJb
EY9BTE9aCW02CU000dY?APi:;`02@Pd02CW;:DLmbdH^BRi:CTi?CU1>L002DW001e9aBRm23TH>CU1B
LE9b00=BL@9BT@ABTPQF/`9Je0=F/`03F[AJe5kE00QF/`03DY=FTeJC00MF/`03EY=BTe:B009BTPUB
LP09DY=F/eZdG]ERmV<FHaMS5U[D009BTP06CW4YBRe/F_QJnElK0Ull15/l00=KG5LKFa/01U/K00QO
?EllGceO?5lmGcaO?Ell1emM00=OG5llGc`01U/l00=K?E/MFah01e/M15LM00EFoEKlE_eFo5Km00MF
o0ABo003D]aBfgoo02Mooa5SG@mWG@05Ga]S?6=LHcaSG002Ie`3Hc/4Ic/2IcX025kh6:EBM6;hG_MW
66<HIaP2HaL4IaL2IcL@IcP3IaL:HaL00f;gH_IRmP08G_H3G]D5F]D2F[@2E[@00eJDEY=BT`04DY<0
0e9cDW9>LP02CW82CU42BU43BU03BS02AS03ARl2APl00cg<=H/iZ`07?L`6?L/4>J/013VZ?L]23DH=
0dH>0dH^00A:;TX_BRm:;`A:C`0:BRm:CdX_CU16;TY?BRlibdX^ARh3APh014X^BRm:;TH^0TX^14H^
0dH>00=63dH>APh014H>00T]BCF:?Ne63T8>@Ni1kD8>@Nd05cg]0Sg=1Sg<5goo000EOol2G]@00ekC
F]=Jd`03F[<3E[83EY800eJADY5BT@03DY40159aCW5>LDia24i`0Tia00ABLE:ADY5BT@9BTP=F/P03
E[=J/e[C009Jd`9Ne0ANm0ARm0aRm@9Rm0=Nm09Ne003F]=J/eZc009FTP04DY5BLDi`CU02BTl00dX_
APi:;P02@Pd023W;:DLibdH=APi:;TX_CTl3CU000e9aBTm63P02@Nd00d8>@Ndmk@03@Nd00d8=@Pi2
3P02@Ph8?Nd01d7^@Pi23TH?BS1>LE:B00=FT`9BT`ABTP9Je@=Ne@=Nm@AF/`05EY=BTe:BDY9>L@07
CW82CU45CW802TiaDY5>D4iaBU0UBBU[E]MJnElJ0e/K15/l0Ull00=O?EllGcd02Ulm00AOGEllFcaO
?0EK?003GcaK?5/l00EK?003FceK7U/N009K7@04EaeK7ELMFad5Ead00eKmEaeFo@02E_d2E_`015;l
E_aBo5Kl1E;l00=Bg5;lOol09goo26=M1f=n00=WOFMMIed01VMM26Mm00=O6f<lHe`00V<k0VML0f<k
16Lk0VLj00QNn1RUDWARn5kgIaQS66LH0V<G16LG0VLg46Lh0fLG2V<G00=Rmf;fH_H025kf0ekE1E[E
0UZd0UJd00=FU5JCDY<015:C00=BLe9bCW800Tib0TiA0TYA0dY@0dX`0TH`0dH_0TH?00<mc3F;>J/0
1cg<1Sg;13V[00@iZSg;@Pe63@=63P=6;P9:;P9:;`A:C`08BRm:CdX^CU16;TY?BRlib`96;P=63P05
BRi:;dX^ARi:;P05ARh:APh02Be9=HXmkDH>@Pi1kT7]@Pi1k@0G?Nd2?Ld6?L`GOol001Eoo`04G]AN
de[CF]<4F[<3E[82EY800eJADY5BT@02DY42DW43CW49CW03CW45DY401EJBE[9F/UJbE[<00e[C0UkD
15kd16;d36;e0V;d0Ukd0ekD00UJdeZcF[=FTU:ADW5>L4i@BTl00dX_00e23DH^@Ne1kCV[:DLibd8=
APe63TX^BRm:C`02CTl00eJADY5BL@0=DW47CW06CW42DY801EJcDW9BLU9bDW4014ia0Ti@0TiA2Dia
00=>D4Y@BU402dYA0TY@00E:<4H_ARm>D4X_009:D005:DTYJeKGE]QO6P02Fa/2Fa`7Fc`00elmGcaO
?@02Gcd02UmMGceOGElmGeeO?EmMFceKGE/m3E/l00=K7E/mFad02ULM0eLL00=Fo5LLE_`02U;l0e;k
:7oo26=M2FMn1fMm26Mn00=O6f<lHe`00V<k0VML0f<k16Lk0VLj00QNn1RUDWARn5kgIaQS66LH0V<G
16LG0VLg46Lh0fLG2V<G00=Rmf;fH_H025kf0ekE1E[E0UZd0UJd00=FU5JCDY<00e:C00=BLe9bCW80
0dib00=>DDYABU400dY@0dX`0TH`0dH_0dH?00<mc3F;>J/01Sg<1Cg;00<ibcg;>J/00cV[00DiZSg;
@Pe23DH=00=63P=6;P04BRi:;dX_BRl2BTl2BRl01dY?BRi>D4H^BTm:;cW;0096;P=63P03ARi:;dH^
00I6;PY63P0:@Ph]BCF:?Ne63T8>@Ni1kD8>@NdG?Nd2?Ld6?L`GOol001Eoo`9Nd`9Jd`AJ/`05E[9F
TUJBEY9FT@03DY40159aCW5>LDia3Ti`0Tia15:A00EFTUJbE[9F/UJc00=Jd`9Ne0ANm0ARm0aRm@9R
m0ANe004F]=J/eZbE[82DY401E9aCW1>D4Y?BRl00TX^00]23DH>@Ne1kCV[:BLiZd7]@Pe63TH^009:
;`9:C`08ARi:;di@DW5>L59aDY5F/PMFTPUF/P04F[=F/e:BDY83CW400diACW5>L@05CW400diABU1:
D006BU08ARl8BS02BU46CU402Di`BTm>LDia:DX]JeKGE]QO6`02Gc`00e/lFceK?@02Fcd4Fa`015/m
FcaK?E/l25lm15mM15]M1e/l00=G?5LMEad01ELM25LL25;l25;k00=>fgooOol09Woo26=M2FMn1fMm
26Mn00MO>f<lHcaO>f<kHeaW>`03Hc/4Ic/2IcX025kh6:EBM6;hG_MW66<HIaP2HaL4IaL2IcL@IcP3
IaL:HaL00f;gH_IRmP08G_H3G]D5F]D2F[@2E[@00eJDEY=BT`03DY<00e9cDW9>LP03CW83BU42BU03
BS03AS02ARl4APl00cg<=H/iZ`06?L`3?L/3>L/00cg;>J/iZ`02>J/00cVZ?L]23@02@Pd00dH=APi6
3P04ARh00dX^BRm:;`04BRl01dY?ARi>CdH^BTm:;cV[0096;P=63P04ARi:;TH^APh4ARh9APh3@Ph0
2Be9=HXmkDH>@Pi1kT7]@Pi1k@0G?Nd2?Ld6?L`GOol001Eoo`=Jd`=J/`9J/P=FTP03EY5BTE:A009B
L@9>L@I>L0Q>D0A>L006CW5BLE:ADY5BTUJB0UJb00AF/eZcF]=Jd`9Ne0ANm0ARm0aRm@9Rm0=Ne00;
G]=JdeZcE[9FTUJADY5BLDi`CU1:C`02BRl00dH^@Ne63P02?N`01cFZ:BHiZT7]@Pe63TH^009:;`9:
C`08BRm>D59`CW1:CdX^BTm>D0=BL0EBL@Q>L0I>L@03DW5BTDia009>L@=>L09>D0Q>L0=:C`9:;`=6
;`Y:<0=:D005BU5>DDi`CW1:C`02CW401BUZ;F]FeeKHGa/00Ull25/m1Elm25/m0emM0e]M0e/m1E/l
0eLl0ULM2eLL1E;l2e;k0TkK:7oo26=M1f=n00=SGFMnIgd01VMm26Mn00MS>f=LHeaO>f<kHeaW>`03
Hc/4Ic/2IcX025kh6:EBM6;hG_MW66<HIaP2HaL4IaL2IcL@IcP3IaL:HaL00f;gH_IRmP08G_H3G]D5
F]D2F[@2E[@015JDEY=BTe:C0U9c00=BLTibCW800Tib00=>LDYABU400dY@00=:<4H`AS000TH`0dH_
00M63d8?@Pm63cg<=H/iZ`06?L`2?L/2>L/00cW:>L/mb`04>J/00cVZ?L]23@03@Pd3APh4ARh7BRl0
1dH^BTm63TY?BRliZdH^00963P03APe63TH^0096;P04APi6;TH^ARh9APh4@Ph02Be9=HXmkDH>@Pi1
kT7]@Pi1k@0G?Nd2?Ld6?L`GOol001Eoo`=Jd`=J/`05F[9F/UJBEY9FT@02DY43DW48CW08BU05CW00
0diaDW5BL@02DY83E[800eJcF]=Jd`02G]@4G_@4H_@<H_D2H_@3G]@00e[CF[=F/P02EY82DY400e9a
CW1>D002BRl014H^APi1k48=0Sg<00<eZRDV=JX00T7]00=23DH>ARh00dX_00QBL5:AEY9FTU9aCW1B
L5:A15JA15JB25:A00=BLE:ADY801E:B00A>LDi`CW1>L09>D09:D0Q6;`=:C`E:;`Q6<09:D003BS16
<4H`009:<00;BTm>CdX^CW1:D2U9:DYB]U:gGaYK6`03Fa`2Fc`8Fcd00elmFceK?@09Fcd9Fc`4Ec`;
Ea`00eLKDa]C6`0=D_/00e;jC_Y>nP02C]XXOol@Hed00fMnIgeWO@05Igd8Igh00f=LIeeSG002Hc/2
Ie`3Hc/4Ic/2IcX025kh6:EBM6;hG_MW66<HIaP2HaL4IaL2IcL@IcP3IaL:HaL00f;gH_IRmP08G_H3
G]D5F]D2F[@2E[@01EJDEY=BTe:CDW<00U9b14ib00=>DDYABU000TY@0TX`0dH`0dH_0TH?00I23d8>
APlmc3F;>J/5?L`2?L/3>L/00cW:>L/mb`04>J/00cVZ?L]23@03@Pd014H=APi63TH>0dH^00=:;TX_
BRl014X_00=6;TY?APh00TX_00HiZdH>APi63T8=APh3ARh00dH>ARi63P09APh3@Ph2@Nh02Be9=HXm
kDH>@Pi1kT7]@Pi1k@0G?Nd2?Ld6?L`GOol001Eoo`9Jd`=J/`03F[9F/UJb009FT@9BT@=BL@03CW5>
L4i`00=>L0=>D0Q:C`9>D0=>L0=>L@9BTP06EY9F/UJbE[=J/e[C0UkD15kd16;d36;e0V;d0ekD00EJ
deZcE[9FTU:A009BL@05CW1>D4Y?BRm6;P02APh033g/@Pdmc3g<=HXU1SF:?L`mkD7]@Pi63P=6;P03
APi6;TX^009:C`03CTm>L59`009>D0=>L0]BL003CU1>L4i@009:D004BTm6;dH_CU07BU000di@BU1:
D005BU08ARh8ARl01TYABU1:D4X`AS1:<09:D00:BTi6;DY?ARlU:2U:D[IB]elJFa/3Fa`3Fcd00eLM
FaeK7@05Fcd7Gch00elmFceK?@03Fc`3Ec`2Fc`5Ec`6Ea`01ELKEaaG6eLLEa/01E<K1U;k00EBnU;k
D_YBne;j00E>nP03C]Yoogoo02Ioo`QSG@MSOP03IgeWGFMM00IWG@QWO@03IeeWOFML009S>`9WG0=S
>`AW>`9W>P08G_PHYE9dH_QNmfLHHaQW609S5`AW5`9W=a1W>0=W5`YS5`03H_MRmV;f00QNmP=Ne@EJ
e@9J]09F]004EYAFTe:CDY<2DW84CW800diBCU5:D@03BU000dX`AS16<005ARl024H?@Pm23d8>APlm
c3F;>J/4?L`2?L/4>L/2>LX00cg;>J/iZ`02>J/013VZ?L]23D7]0d8=14H>0TH^00=:;TX_BRl014X_
00I6;TY?APi:;dX^>J/2APh01DH=@Pe63DH>ARh034H>0d8>0d7^00T]BCF:?Ne63T8>@Ni1kD8>@Nd0
5cg]0Sg=1Sg<5goo000EOol2F]<3F[<015ZbE[9F/UJA0e:A0e9a1Di`0Ti@2dY@00=>D4i`CW000Ti`
0Tia00=BTE:BEY800UJb00=F/eZcF]<00UkD15kd16;d36;e0V;d0UkD00INde[CF[=F/UJADY42CW00
2Di@BTm:;dH^APi63DH>?Na23@02?L`00cF:9@HeRP02?L`00cg]@Ne23@03APh4BTl014i?CU1>L4i`
1e9`00=BLE9`DW001E9`0di`1Dia00A>L4Y@BTm:D0=:C`06BRm:CdH_ARi6;dH^0dH>00I23TH>APi6
3TH^APh3ARh8APl00dX`AS16;`02ARl03DH`BU1:D4X^APe:;dH_9BPYBUKFE]QO6elk009O?004GceK
?E/mFcd3Gch=Geh01elmGeeO?E/mGceK?5/m00EK?003FaaG75/L00]G7003Ea]FneKk00=Bn`9Fn`QB
n`03D_YBfU;J00=BfRQoo`QSG0QWO@QWG0UWG@9WO@03HcaS>fML009WG0=S>`=W>`9W>P0;G_PHYE9d
H_QNefLHHaQW66<HHaMW6003IaL00fLgIcQW>00?IcP3IaP00f<GIaMS5`06HaL4H_L8G_H3G]D5F]D2
F[@2E[@015JDEY=BTe:C0U9b14ib00=>DTiABU400dY@00=:<4H`AS001DH_00Q63d8?@Pm23TH??L`e
RcV[13g<0Sg;0cW;0cW:00<mbcV[>J/00SV[00@iZSg;@Pe1k@=23@E63P03ARi:;TX_00=:;`08BRi:
;dH^BTm63TX_BRhiZ`963P05APe23DH=APi6;P08APh014H=APi63TH>0d8>0d7^014]BCF:?Ne63T8>
@Ni1kD7^@NdmkD7]?Ne1kCg]@NdmkD7]00lmk@<mc@03?L`mcCg<008mc1Moo`005Goo0U[C0UZc0UJb
15JB00AFTE:ADW5BL@9>L09>D0A:D09:C`03ARm:;dX_00=:C`A:D09>D0A>L006DW5BTE:ADY9FTUJb
0UZc0ekD0Ukd0f;e26;d1F;e0Ukd0ekD00AJdeZcE[9FTP9BT@9>L005CU1:CdX^APi63@02@Pd01cg/
@Ndibcg;=JXU1S5Y008mk003@Ne23DH>00=63PA:;`9:C`9>C`E>L0=BL0a>L0E>D0M:C`03BRm6;TH^
00U6;PA63PQ63`06BRm6;dX_ARm:;dH_0TX_00e:CdX^ARi6;beY:DU>Le:fF_QJnE[jFa]Jn`05F_`0
15/LGaaO7ElM2Ulm00=S?EllGcd00ell1elL00=K6elLFa`025/L1eKl0U[l1E[K0UKK0e[K1EKK:7oo
7fLj00=S>fMmHe`015lk00AS>elkHc]S>`9S>P9S>`05HcYS6EJf6<MBU002G_L00fLHH_MS6005HaL3
IaLEIaP00f<GIaMS5`08H_L4G_H3G]H00e[EG]INeP04F]D2F[D3E[@2EY@3DY<5CW8014iBBU5:DDY@
14X`0TH`00=6;dH?APl00dH?0T8?00E1kTH>?L`eRSV[008mc0@mb`03>L/ibSW:00<ibP<iZ`8eZP04
>J/mc47]@Nd3@Pd4APh3ARh2BRh3BRl03TX^BTm6;TH^BTm63Cg<APe63TH=@Pe63DH>ARh8APh014H=
APi63TH>0d8>0d7^00HaRRe8@Ne1kSg=APh3@Nd03Cg]@NdmkD7]?Ne1kCg]@NdmkD7]?Ne1kCg]00A1
k@8mk@Tmc@<mc1Moo`005Goo00EJdeZcF[=J/UJb00=FTP9BT@9BL@03DW1>L4i@00=>D0A:D003BS1:
;dH_0096;`04BRm:<4X`BU02BTl014i?CU1>D4i@0di`0U9a00IBTEJAEY9F/UZbF[<2F]<01UkCG]AN
e5kdH_ARm@aRm09Nm09Ne006G]=JdeZcE[9FTU:A0U9a0Ti@00A:CdX_APi63@=1k@07?La1kCV[>L/e
RRD6;FP00Sg<00<mk47]@Pd00TH=00E63TH^ARi6;TX^00A:;`03CTm>D4i@015>D003CTm:CdY?009:
C`M:;`E6;P=63P=6;Pe63PQ6;`09BRm6;TH^ARlYBBE8CW=B]E:F009B]`03D[QB^E:i009B^P=F^PAB
^P08D[UF^UKJE[YFfUJjE]YF^P9FfP03E]UF^EJi00UB^@03D[QB^Dji00QFf`QB^PIF^P9FVPEF^`=F
^RQooamS6@03GaUWOEmL00IO>`03Hc]O>elj00=S>`05HcYS6EJf6<MBM002G_L00fLHG_MS6005HaL3
IaLFIaP2I_P8H_L016;fG_INmUkf0ekF00=JeEkFG]H00e[E0eZe0eJd0UJD0e:C1Dib00=>DTYABU40
1TX`00=6<4H?APl01DH?00I23d7^APhibcF:>J/2?L`00cW;?L/mb`02>L/5>LX3>J/01SFZ=HXiZSg<
@Na1k@=23@A63PA6;P06BRi:;dX_BRm6;TY?0TH^00Y:Cd8=?La63DH>APe23DH=APi6;PQ63P03APe6
3TH>00=23PA1kP06<HX]B47]@NhmcDH>4d7]0Sg]2cg=0Sg<5goo000EOol3F[<01EJbEY9FTUJBEY40
0U9a00IBL4i`CU1>D4i?BTl5BU000dX_ARm6;`05ARl3BRl3BTl3CU02CW00159`DW5BLE:A0UJB0UJb
0eZc00AJdekCG]ANe0iNm003G]ANde[C009J/`07E[9FTU:ADW5>L4i@BTl00TX_00A6;TH=@Ne1k@8m
k007>L/mk3FZ>J/eRB45;DP00SW;00<mc3g/@Nd00d7]00A63DH>APi63P96;P9:;P=:;a5:C`I:;`03
BRi6;TH^00M6;QA63PQ6;`07ARi63T8>APhYB2DXBU800U:E00A>UTjGDYQ>^@=>V@03D[YB^E:I00AB
V@0=CYUB^U:iD[YB^E:jD[UB^U:iDYUBV5:IDYP034jH24IG24IH14YG0TIG0THg0TIG1THg:7oo25ki
1f<I4ElI00=SOEmLGc`01Elk00=S>elkGcX00f<k00YS>UlIE[HHaU9dG]MNmfLHG_MS60IS5`9W5aAW
60=W5`QRm`ENmP9Ne@MJe@=J]09F]003EYAFTe:C00=BT`E>LP03CU5:DDYA00A:<003BRm6;dH?00E6
3`0<APi23T7^@Ni63SW;=HXeZSg;?L`ibcg;0SW;1CW:00TiZSV[>J/iZcFZ=HXiZSg<@N`00T7]0T8=
00A63DH>APi63PA6;P9:;P9:;`09ARi:;dH>ARi:Cd8=?La23DH>00=23@03APi6;TH>00I63P963@03
@Pe23T8>00923P=1kP07@NdaRRe8@Ne1kSg=APh02T7]2Sg]2cg=0Sg<00<ic7ooOol05Goo000EOol0
0eZcF[9F/P02EY800eJADY5BT@02DW42CW02CU02BTl3BU000dX`ARm6;`0:ARl2BRl2BTl014i?CU1>
D4i@0Ti`0U9a00EBTEJBEY9F/UZb009J/`9Jd`=Ne0QNm0=Rm09Nm009G]AJde[CF[9F/UJBDY5BLDi`
009>D09:;`0@ARi63T8=@Ne1k3g/?L`ibcg<=JXiZS698>D]B3V[>L/2?L`013g/@Ne1kD7]0T8=00A6
3DH>APi63P96;PM:;`03BTm:;dX_00e:;`9:;PE6;P963P03ARi63TH>00U63P963@923@Q23PY63P09
@Pi63bU99BQ:DTjDCWE>MTjG009>V0A>V@9BV@9B^P9F^P03E]]F^UJj00IF^PYB^@=BV@03CYQ>VDjI
00Q>V@96E`92E`92=`92=P925PE25@03?QDmmCge008mm@@mm2QooamS>P05Hc]SGEmLGc]K>`04Gc/0
1F<kGc]O>UljHc/00V<j00AO6EJf6<IBM09Nm`04HaQNmf<GH_L8HaL?HaP2IaP3IaL8H_L2H_H4G_H0
0ekFG]EJe@06F]D2F[@2E[@00eJDEY=FT`04DY<00e9cCW9>LP02CW800diBBU5:D@05BS000dX_APm6
3`05APl02TH>@Ni1kT7^APhibcF:=JXibcg;0cW;13W:00<iZSW:>JX00SV[00HiZSFZ=HXeZSg;?N`3
@Nd2@Pd4APh5ARh2BRh02DH^BRm63TH>BTm23Cg<@Pe63P03@Pd3APh00dH=APi63P02APh014H=@Pe2
3D8=0T8>0d7^0d7]00HaRRe8@Ne1kSg=APh:@Nd8?Nd<?Ld013g<>L`ic3V/5goo000EOol2E[82EY80
0eJADY5BL@03DW42CW02CU03BTl00dX`BRm6;`04ARl2APh2APl4ARl4BRl2BTl01Di?CU1>D4i@CW00
0U9a00ABTEJBEY9J/P9J/`9Jd`]Ne0=Rm@9Nm003G]AJdeZc009F/P07EY9BTE9aCW1>D4i?BRl00TH^
00A63T8=@Ne1k08mk00<>L/mc3FZ>JXaRB3U;DPiZcW;?L/mc3g/0d7]0T8=00A63DH>APi63P=6;P9:
;Q=:;`A:;PE6;PI63P963@03@Pe63TH>00963@A23@03@Ne1kT7^00E1kPY63P05@Pi63bU99BU:D`02
CWD2BWH00digBWQ:N002BWP3CYT01E:JD[YB^U:jE[X025:j24jI14jH0dih00=:N4jICYT01TjI1DIG
00A2ET8f@SI2=Pa25@<n5BQooa5WG0mSG004HeeOG5llFc/6Gc/2GcX2Hc/02elJGaUF]QS6DWANeekg
HaQNmf<GH_L026<G3f<H00AW66LGIaMW5`QRm`=RmP=NmP03G_ENeEkE00AJe@03F]AJ]5Zd00AF]005
EY=BTe:CDY=BTP03DW83CW8014iaCU5:DDY@14X`00=:;dH_APl01DH?00=63T8>@Nh00T7^00A63SW;
=HXeZPDib`<ibPDiZP07>J/iZSF:=HXeZSW;?N`00d7]0T8=00=63DH>APh00TH>1DH^00=:;TH^BRl0
0TH>00Q:;d8=?L]23DH=@Pe1kD8=0dH>00E23DH>APi63TH=00A23@04@Pi1kT7^@Nh4@Nd01S6:;DQ1
kD7^?Le63PY1k@Pmk@/mc@03?L`ic3W<008i[1Moo`005Goo0eJB00=FTE:ADW400e9a00EBL4i`CU1>
D4i?009:C`03BRm6;dH_0096;`03APm63TH>00A23P03APi63dH?00=6;P03BRi:;dX_00=:C`=>D007
CW1BLE:ADY5FTEJbF[800UZc00=JdekCG]@02EkD00IRm5kdG_ANm5kDF]<2F[<2EY8015:ADW5>L4i@
0TY?00A6;TH>APi23@91k@8mk00<?L`iZcg<=HXeZS698>D]B3VZ>J/ibcg<0Sg/0T7/0T7]0T8=00A6
3DH>APi63PE6;P=:;P]:;`03BRi6;TH^00M6;PI63P03APe23D8=00923@03APe23D8=00=23@Y1k@Q2
3P0<APi23T8?APlYBRDYBU=>MEJhE]QFfEKJ15KK45:j1djI00ABVDjICYQ>V@A>N003BWQ6EdIG0096
E`03@UI2=T8f00M2=P03?SDn5D8E00=25@@n5@8mm@Hmm2QooamSG09SG@03GeaO?5/k00MO>`0=GcYS
>f<jGaYO6EJe6<IBLekFG_IS5ekfHaL00V;g00=S5f<FHaL00V<F4F<G0fLG1V;g00=RmV;gH_H00V;f
00ANeUkfG_INm@9Ne@AJe@=J]0=F]09F/`=BT`03DY9BLU9b00E>LP03CW5>DDYA00A:<09:;`03ARm6
3dH?00=63`963P08@Pi1kT7^@Ne23SV[=HXeZPDib`8ibP<iZP05>JTiZSVZ>J/eZP02=HX00cFZ>L/m
k004@Nd2@Pd00dH=APi63P03APh4ARh01dH>BRm63TH>BRm1kCW;00=23@03@Ne23DH>00963P04@Pe6
3TH=APd5@Pd00d7]@Ni1kP05@Nd01S6:;DQ1kD7^?Le63PY1kA4mc@8mc003>L`i[3V/008i[1Moo`00
5Goo0UJB00EFTE:ADW5BLE9`009>L09>D004CTm:CdX_BRl5ARl00dH?APi23P08@Ph01DH>ARi6;TH^
BRh00dX_0TY?00E>Cdi@CW1BL59a009BT@9FTP04E[9J/UZcF[<2F]<8G]<3G]@01EkCF[=J/UJbEY80
0U:A00MBLDi`CU1:CdX_BRi63P02@Pd00d7]@N`mk002?L`033g;>J/ibcF9=HXaJAcT:DLeRSFZ>J/i
b`@mc091k0=1k@=23@963@I63P]6;PY63P963@04@Pe63DH=APd9@Pd<@Nd:@Nh02T7_@PlY:RD9AS9:
E5[IF_UJnU[k15[l15KK0eJk00=F^UKKE]/01UKK0U:j0UJj00AF^eKKE]]Ff`UB^P03D[U>^DjI009>
V@9>V096E`03AUI2ET9F00M2=PA2=@8n50Dmm003>OAoogoo02Ioo`QSG0QO?003HeeOGEmM00eOG@04
HeeO?5/lFa/3Gc/01ElKGc]O>elJGcX00V<k00EO6UlIE[DHYE9c009NeP03HaMNmV<G00=Rm`03HaIS
5f<F009S5Q1S5`9W5`03H_MS5f;g009Rm`IRmP03G_INeUkF009Nm@9Ne@04F]EJe5[DF]@3F[@00eJd
E[=F/`02E[<4DY80159bCW9>LTib14ia00=>DDY@BU000TX`0TX_00=6;dH?APl01DH>00=23T7^@Nh0
0T7]00A23SV[<HTeRP8ib`04>J/ibcW:>LX4>JX2>JT2>JX01cFZ=HXeRSFZ>L/mk47/00=1k@=23@03
APe63TH>00963PA6;P09APi:;dH>APi:;d7]>L]1kD8=00=1k@04APe63TH=@Pd2APd5@Pd2@Nd00d7^
@Ne1k@04@Nd01S6:;DQ1kD7^?Le63PY1k@lmc@<mc08ic0@i[1Moo`005Goo0UJB0U:A0U9a0Ti`0Ti@
0TY?00A:;dX^ARi6;PA6;`03APi23T8>00U23P04APi6;TH^ARh4BRl2BTl2CU001Di`DW5BLE:AEY40
0UJB0UJb0eZc25kC0e[C00=J/eJbEY800U:A0U9a00I>L4i@BTm:;dH^APh3@Nd04Cg/?L`mc3g;>L/i
ZcFZ>J/aJCF9;FPLa2TW=HTeRSFZ>J/00cW;00<mbcg<?L`00Sg/00=1k47]@Nd0147]1D8=2dH>00=6
3D8=@Pd00T8=00=63D8=@Pd00d8=0T7]00=63D8=@Pd00d8=0T7]0d8=3D7]247^00e1kCg>@Ni1kbTY
8@U6<TYDCWE:MTigCYM:V003BWP2DYT2D[X2E[X2E]/025[LF]]Jg5[KF]aJfe[LF]/4E]/2F]/00e[L
F]]Ff`04E]/01EJjE[]B^U:jD]X00U:j00EB^DjiCYU>VE:j009B^@03C[U>VDjI00=>V0A>N0=:N0A:
M`A:EbQoo`QOG@QO?A1OG@05HeeO?5/lFa]K7002Gc`01ElKGcaO>elKGc/00V<k00EO6UlIE[DHYE9c
009NeP03HaMNmV<G00=RmPES5Q1S5`9W5`04HaMRmf;gH_L7H_H00ekfG]INm@02G_D2G]D015[EF]AJ
e5[D0UZd0UJd0eJc00=FTe:BDY800U:B00=BLTibCW801Dia00A:DDY@BS1:<0=:;`03ARm63dH?00E6
3P03@Pi1kT7^0091k@04@PdiZc69=HX2>L/2>J/2>LX4>JX2>JT2>JX01cFZ=HXeRSFZ>L/mk47/00=1
k@=23@03APe63TH>00=63P=6;P09APi:;dH>APi:;d7]>L]1kD8=00=1k@04APe63TH=@Pd2APd4@Pd3
@Nd00d7^@Ne1k@04@Nd01S6:;DQ1kD7^?Le63PY1k@hmc@@mc003>L`i[3V/00<i[1Moo`005Goo0UJB
00UFTE:ADW5BLE9`CW1>D4i?BTl00TX_0TH^0TH>3d8>00=63TH^ARh00dH^0TX^0TX_00I:Cdi@CU1>
L59`DW42DY4015JAEY9F/UZb1EZc0e[C1EZc0UJb0eJB0Ti`00A>D4Y?BRm6;P963P03?L`mk3g/008m
c003>L/iZcV[00<eRP0:<HT]J2TW9@HPiC5Y<HTeRSFZ>JX3>J/6?L`2?N`@@Pd8APh3APd=@Pd2@N`4
?N`2?L`8?Nd8@Nd2@Nh01Cg>@Nl]BR3X@O000Tie00E:MDYfBWM:MdYh009:V09>V09>V@03DYUB^E:j
00AB^P9F^P03E]YFfeKJ009B^PIF^P08D[YB^E:jD[UB^U:iD[YB^@QB^PQ>^@I>V09:N0I:M`96EbQo
o`mO?@03GeeKGE]M00IKG@UOG@03GcaK75/K009K6`03Ga]K6elk00EO6`0;GaYNnE:D6<I:DEkFG_IN
eUkfG]INmP03H_H5HaH7HaL8HaH2IaL2HaL4H_H3G_H5G]D00e[EF]AJe003F]@2F[@6E[<2EY<2DY80
1E9bCW5>LDiaCU400TYA14Y@0TX`00E6<4X_BRm:;dH_00A63PU1k@04>L/eRS69=JX2>J/00cVZ>LXi
bP04>JX2>JT3=JX02CF:=HTeRSV[>L/mc3g/@Na1k@04@Pd4APh4ARh02DH=ARi23DH=BRm1kCW;@Ne2
3@03@Nd014H=APi63D8=0TH=148=0d7]00=1kT7]@Nd0147]010aJBTX?LdmkCW<APi1kT8>@Ni1kD7^
@PhmcCV/?La1kPPmc0Hmc@@mc003>L`i[3V/00<i[1Moo`005Goo0U:A0U9a0Ti`0Ti@00E:CdX_BRm:
;TH^00963PE23P91kPA1k@91kPA23PM63P05ARi:;dX_BRm:C`02CU02CW000e9aDY5BT@02EY800eJb
F[9J/`04F[<015[CF[=J/eZc0UZb00=F/UJBEY800U:A00IBLDi@CU1:CdX_ARh2APh01DH=@Pe23D7]
?N`013g<0SFZ00HeRS69;FPY9b458>@2<FT00cF9=HXiZP04>J/3>L/013g;?L`mc3g<23g/448=1T7]
2T7/0T7]0T7/13g/23g<23g=00Y63d7^?Li1kbe[8@U244YdDYI>UP9>U`A>V0Q:M`Q6EP04CYQ>N4Yh
BWP2BWL2BUL2CWP2BWP6BWL6AWL01DIGAUI6EdIFAUL00dIF14Yg0dIG00A6ETIGAUI6E`E6ERQoo`mO
G@UKG@UOG@05GcaK75/KFa]K7002Fa/6Ga/01ElJG_UBU1c6CU800ekf00=S5ekfG_H00Ukf00=RmF;f
H_H00V<F0Ukf16;f0V<F2f;f0Ukf0ekE0f;f00=NmUkEG]D00UkE0eke00=NeE[EF]@00U[D0UJc00=F
Te:CDY801e:B00=BLTiaCW400dia00=>DDYABU000dY@0TH_1TH>0TH_1TH>00U1kCW;=JXeRSV[?L`m
bcV[>LX01CVZ0SVY0cFZ00DeRSF9=HXiZcW;008mc003?Na1kD8=00=23@E63P=6;P09@Pe6;T8=@Pe:
;d7]>L]1kD8=00=1k@05APe63TH=@Pe63@05@Pd:@Nd02C5Z:DPmcCg]?La63T7^APi23P02@Nh01D8>
?LdiZcW<@Nd023g<1Sg=0cg<0SW<1CV/5goo000EOol2DW000di`CU1>D003BTl00dX^ARi6;P02APh3
@Pd2@Nd<?Nd2@Nd5@Pd01DH=APi63TH^BRh00TX_00A:Cdi?CU1>D09>L09BL@9BT@04EY5FTUJBEY84
E[83EY8015JADY5BLDi`0Ti@00I>CdY?BRm6;TH>@Pd3@Nd01Sg<>L/iZcF:=HTaR@8eR@8eRP06<HTa
J2U79@HLi1c30ReX00@aJCF9=HXeZP8iZ`06>JXiZcV[>J/ibcg;2Sg<23g/247/13g/33g<0cg/3Cg<
23W<00Q1kCg==J`icBU98@Pmkd8b0TjE0TjF14jG1TjH0TjG0e:h00IBV4jHCYQ>UdjHBUH2BUL7AUH0
1dHf@SE2=D8e@QDn5D8f00I2=@04?SE2=D8e@SD2?SD00chd?Q@n5005@SD2?SD00chd@UI2E@06@SDX
Ool?Fcd@Fed2Ged00ellFaaK6`04Fa/6Ga/02UlJG_UBU1c6BU5NeUkfG]IRmUkf1Eke0f;e00ANmV;f
H_IRmPaS5PERmP03H_ENmEke00=RmP06G_ENeEkEG]EJeEkE0e[D00AJ/eJcE[=F/`9Je004F[=F/eJc
EY84DY801U9bCW5>LDiaCU5>D0E:D004BS1:;dX_@Ph7@Pd9?L`01SV[=HXeZSW;?L`ib`HiZP8iZ@09
=JTeZSFZ=JXeRS69=HXiZSW;008mc003?Na1kD7]00=23@03APe63TH>00E63P09@Pe6;T8=@Pe:;T7]
>L]1kD8=00=1k@03@Pe63T8=00I23@Y1k@08?NdaRRe8?Ne1kCg<APm1kP963P07@Ni23T7^?LdiZcV/
@Nd023g<1Cg=0Sg<0cW<1SV/5goo000EOol01Di`CU1>D4i?BTl00dX_00A6;TH>APi63P=23@91k@lm
k@91k@E23@04APe6;TH^BRh2BRl3BTl014i?CU1>D4i@0Ti`00=BL59aDW4015:A1E9a00E>L4i@BTm:
;dX^0096;P03APi23D7]00@mk08mc004>L/iZcVZ=JX2=HX2<FT032eX;DLU9R3U7<@HXbU7;DP]J35Y
<HTeR@8eRP<eZP8iZ`8ib`03?L/mc3g<01/mc003?L/ibcW;00dib`<iZ`Pic0Ti[00:>L`e[3V/9BPL
icW>@S5:DdYDBW@2BWD014YfBYI:UU:g15:H0djH24jG00=>V5:HD[P00U:i0UKI00QFfU:iD[UB^5:H
CYQ>Udig0TYg00=6MdIfAUH01DIF00=2ET9E@UD0148e23hD0SXD0cXC0cWc:7oo00mK?E/lFceK?5/m
FcaK?E/lGceK?ElmFceO?E/mGcd00U/m00IKGE/mFeeK?E]MFcd9Fed015mMFceK75/K0U/L0U/K00=O
75lKFa/00elK00YO6UkiCW<HYDH`F[AJeEZdG]EJe@QNm@ES5P]S5`MW5`04IaIRmV;fH_D2G]D01EkD
F[AJ]5JcEY<00U:B00IBLDiaCW5>DDY@BS02ARl014H>@Pi23T7^13W<00<iZcF[=J/013F[00<eRS6:
<HX00S6:3C5Y0beX00@eZSF:=HXeRP8iZ`03>JXeRSVZ00<iZP04>JTeZCFY=JT2=JX2=HX01369=HXi
ZSW;0Sg<00Hmk47]@Ne1kD8=@Nd2@Pd2APd4APh02D8=APi23D8=ARi1kCV[@Ne23@03@Nd0148=APe2
3D7]148=2D7]0cg]00LaRRe8@Ne1kCg<APm1kP02APh2@Ph01D7^?L`eZcV[?Ld023g<13g=00<mc3W<
>L`02CV/5goo000EOol2CU001Ti?BTm:;dX_BRi6;P=63P04APe23D8=@Pd2@Nd??Nd00d7]@Pe23@03
@Pd2APd2ARh00dX^BRm:;`02BRl00dY?CTm>D003CU03CW05DW402E9`CW1>D59aDW1>L4i@BTm:;`02
ARh01T8=@Ndmk3g<?L/ib`8mb`@iZ`03=JXeRS5Y00<aJ@0:;FP]B2TW9@HQ1B3U:DL]Abe8;FP2<FT2
<HT013F9=HXeRSF:0SFZ00<iZSV[>J/01cV[23g<23W;0Sg<00<mbcW;>L/03CW;1SV[23W<23V[00Te
Zcg=>L`ic2DX8@LmkTHaAU800TIC00E:M4YeBYI>UTjg00A:M@04BWI>UTjFCYH4CYL4D[L3BWH3CYL0
0e:HD[QB^003D[P015:HCYM>UdjG14jH00A>UdZGBYM:U`9:MPA6MP96EP92E@=2=@03?SDn=3hd008j
4`<il`8el`03=O9oogoo02Ioo`QK?00FGceO?5lmGcaO?EllGceO?5/mFcaK?E/lFceK?5/mFcaOGE]M
GeeKGEmMFed3Ged00e/mFaaK6`04Fa/00elKFa]K6`03Ga/01EkjG_U>LaBTAPl00eJd00EJeE[DG]EN
e5kE00ANm004G_ERmV;fH_H=HaH016LGIaIW5VLF16<F0Uke0UkE00EJe5ZdF[AJ]5JB009BTP03DW5>
LDi`009:D0=6;`923P03@PdmkCg]008mk005?L`ic3W<>L/iZ`05=J/013FZ=HXaRS6:13690cF90cF:
00<eRC69<HT00c690cF:00DeZSV[>J/eZSF:00<iZP03>JTeZCFY008eZ@0<=HXeZSF:=HTaRCF9=JXi
bcg;?L`mk47/147]148=0TH=0TH>00M23DH>@Ne23DH^@N`iZ`03@Nd00d7/@Ne23@02@Pd0147]@Pe2
3D8=2D7]13g]00TeRRe8@Ne1kCg<APi1kD8>APh00d7^00@mc3F[>J/mc@Pmc0<mc@03?L`ic3W<00Xi
[1Moo`005Goo0dY?00=:;dX^ARh00TH>0TH=0d8=0d7]43g]0d7]1D8=0dH>14H^00=:;Ti?CU001Di@
1Ti`00=>D4i?BTl00Ti@00A>CdY?BRm6;P963P8mk08mc004>L/iZcV[>J/5=HX00c69<FT]J003=HT2
<HT00c5Y<FP]J002<FT2<HT01CF9=HXeRCF9<HT00SF91CF:43FZ23V[0SW;9SV[018aRSV[=H/aRb46
6>De[3W>@Q0n4D8a@U96DdIdBWA:UDYeBYD3CYH00djfD[MB]`06AU@2BWD4CYH=BWH7BWL8AUH2AWH3
AUH2@UH6@UD3@SDXOol8Fc`8Gc`?Fc`2Gcd00e/mFaaK6`02Fa`2Fa/015lKFa]K6e/K0UlK00ENnU[i
CW<HY4H@00=F]003G]EJe5[D00=Je005G]ANm5kdG_ANe002G]D=G_D4G]D6G]@00e[DF[AJ]002F[<3
E[<01UJbDY9BTU:ADW5>L@=BTP03DY5>LDia00=>L005CU1:D4Y@BTm:;`05ARl00dH^APi23P02@Ph8
@Nd3?L/5>L/3>J/3>L/2>J/3>JX5=JT3=HX3<HT00cFZ>J/ib`02?L`00cg/@Ne1k@04@Nd5@Pd00dH=
@Ne63P02@Nd00dH^?N`iZ`03@Nd00cg/@Ne23@02@Pd00d7]@Pe1k@09@Nd3?Nd2?Ld01S6:;DPmkCg]
>La23P91k@08@Pi1kD7^@Ndmc3F[>J/mc@Pmc004?Ldmc3g<>L`<>J`GOol001Eoo`9:;`96;P963P92
3@I1k@04@N`mkCg/?Nd2?Ld00cg<>L`ic004>L`013g<?LdmcCg]0Sg/0T7/1D7]1D8=0dH=0dH^0TX^
1TX_00Q:;TH^APi63TH=APi63D8=0T7]0Sg/00<mc3W;?L/00Sg<00LmbcV[=JXeRSW;>J/eZP03=HX0
1CFZ>J/eRSF:=JX00SV[0SW;00<mbcV[>L/013W;23V[2SVZ23F:2SVZ13FZ2SF:0SFZ3SF:23F;0S5Y
00PY9bDW6<@DXbU98BP]JbV;0Rf<00@][Bf^<JhacP<j4@8n4@<n4PE:M@=:U@A6E092=092<`8n4P06
?Q=2<d8c@SA6E49D0cXC00Dn4chD?Q@n53hd00<n508n=003@SA2=D8e00E2E@=2=@E2E@=2=BQoo`QK
6`MO?0UK?0QO?004GceK?E/LEa/2Fa`2Fa/015lKFa]Jne/K0UlK00INnU[iCW<DY4H?EY<2E[<00e[E
F]AJe006F]@00ekDF]AJe002F]@015[EG]ENeEkE2U[D25Zd0UZc1EJc0UJb15:B00=BTDi`CW000dY@
0TY?00E:;dH_ARm6;TH>00923P=23@03@NdmkCg]008mk@8mk003?L`mbcW;008ib`<iZ`<mb`Tib`<i
Z`04>L/iZSVZ=JX5=JT3=HX01S69<FTaRCFZ>J/ib`8mc003?Na1kD7]00I1k@A23@0>@Ne63T7]@Ne6
;Sg/>J]1k47]@N`mk47/@Ne23@a1k@<mk@<mc@08<FXYB3g=?Ldi[47^?Ldmk@A1k@04?L`eZcV[?Nd:
?L`2>L`;>J`00cV[Oomoo`0EOol001Eoo`05ARi63TH>APi23@03@Nd8?N`00cg<>L`ic00=>L`2?L`5
?N`3@N`B@Nd01Cg/?L`mc3g<>L/00cV[0SFZ0SF:00<iZcW;?L`00Sg<00HiZcFZ=HXY9bD68>D27<@0
0acU9@LY9`02<HX013F;>J/mc3g]147]00=1kT7]@Nd00Sg]00@mk47]@Ne1k@8mk@0K?N`mcCg<?L`i
c3g<>L`mc3W<?L`ic3g<>L`mc3W<?L`ic3g<>L`iZcF[>J/eZcV[=J/iZcF[00DeRP03<HXeRS6:00Pa
R@<aJ@03;FTaJBeY008]J0PaJPPeRP08>J/aJR468>HHY1BT8@LDY@<Da@<DaP8Da`@DaP035:H@aQ2V
00D@YP044:D<Y@b538D44:L011BW4<LDYa370QSX00LHjAd98@XQ:R4[9D/a[`03<K04=M44>O87?Q<0
0cXB>Q<j4P02>Q82=O46=M4XOol8Fa`@Fc`7Gc`2Gcd00e/mFaaG6`04Fa/015lKFa]Jne/J0UlK00IJ
nU[iCU8DPd7_DY82DY<2F[@8F]@00ekDF]ENe@02G]D00ekeG]ENm@08F]@00ekEG]ANe005G]@4E[<4
EY<00e9aDY5BL@04CW4014i`CU1>L4i@14Y@00A:CdY@BTm:;`96;`04ARi63T8>APh2@Ph3@Pd3@Nd2
@N`2?N`013g<?L/mbcW;0cV[13VZ0cW;00<iZcFZ=JX013VZ00<eZSFY=JT00cFY0cF:00TaRC5Y<HTe
ZSV[>L/mbcg<?N`02D7]0d8=00Q1kDH>@Ne1kDH^?N`iZd7/0T7]00@mk47]@Ne23@a1k@<mk@<mc@0F
<FXYB3g<?L`iZd7]?L`mcD7]?Ne1kCg]?L`eZcV/?NdmcCg<?Ldmc3g=?L`2?Ld013g<>L`ic3W<2CV/
00<e[3V[=J/05goo000EOol3APh00dH=@Pi1k@05@Nd01D7/?Ndmc3g<?N`043W;0cg;0Sg<23g/0d7/
0T8>1D7]0cg]13g<0SW<00@mcCg<>J`iZ`@eR`0?=J/iZcV[=H/aJS5Y<FXeRRe9:DTY:BDX:BTYBBeZ
008aR`<aJ`0@=H`e[3F/=J`aJcF/>LdmcCg>?LdmkT7_@PlmkSg>?Ld2?Nh013g>>LdmkCg=0SW<00<m
cCg]?Ld02CW<00Pi[3F/>J`e[3V/=J`i[3F/0SF[0cF;00@aRc6:<HXaRP8eRP07<HXaJC6:=JXeZc6:
<HT00ReY0S6:00<]JBe8<FX00S5Z00<aJC5Z<FT00S5Y00<aBC5Y<FT01C5Y00D]BBU99@LPiQS5008H
Y0036:DDY1BT008HY@<Ha@<Da@066<DDaAC55<DDYA2T11BU00@DY12T48@@Q08Da@<DY@<@Y0046<HH
iQcW7>L28@P01B4X8BTYBbU;:D`00RU/0be/0S6=00haSS6^=Jhe[SF_=Llid3G_>M0ekcW@=Nlid3G_
1SG?00<ed3G?Ool09goo0eLl1E/l25LL25/l0e/L0U/l0e/m00=K?5/LE_/00UKk0U[k00eFnU/KF_YJ
nU/JGa]O6U[jF]Q6<ARTAPm>LP03EY<2F[@4F[<00e[CF]AJe008F]@01UkDF]ANe5[DG]AJe09Ne004
F]AJde[CF]<7F[<2E[84EY82DY42DW43CW000di@BU1>D003BTl2BRl2ARh3APh3@Pd3@Nd013g]?N`m
k3g/0Sg<00<mjcg;?L/013g;13W;00<ibSVZ>JX00cVZ13FZ0SFY0cFZ0SFY13F900PaRC5Y<FTaJCF9
=JXiZcg;0cg<0cg/00=1k47]@Nd00T7]148=00M1kDH>@Ne1kDH^?N`iZ`03@Nd00cg<?Ne1k@02@Nd0
0cg]@Ne1k@06@Nd8?Nd02CF;:BPic3g]>La1kCW<?Le1kP02?Nd01Sg^?Lde[3V/>Ldmc@8ic@/ic0Di
[003=J`i[3F/008eZaMoo`005Goo14H>147]23g<23W;23FZ13W;13g;13W;0cg;00<mc3V[>J`00SV/
13V[0SF;13F[0SV[0SF;1SV/00<U9be9=H/00SV/01@mcDH?BU5S5fLhJeY_FV]JIcQNme[EDYA>LdXa
@Q0mkSV]=H`aJcF]0SV]00<eS2eZ:BT00RDX0R3W00@Q22TY;F/aS08eS008>J`icCg]?NhmkCW=>J`e
Z`Pic0Pi[0<e[0DeZ`8ic003=J/aRS6:00<aRP08=J`aRReY;FTaJSF:=J/i[0<eR`8eJPPaJP08<FTa
BS5:;DTY:2D88>LPiP<LaP<HY@8HY0065:@DQ1B46<DDaABU0aBT00DDYABT6<DHaASV00<LiP037@LQ
1aS500<Ha@046<HHaAS66<D25:@00aBU5:@Ha@036<D248D258D45:D25:H00aRV6<HHaP036<L47@P2
8@T28BT4:F/4;F`XOol6Ea`2Ec`8Ea`2Fcd01U/MFceK7E/mFaeK?@=K7007FceO?E/mGceK?E/LEa`0
0eKk00AK6e[kE_YK6`9JnP09FaYO6UlJF_YJf4Ha6:E23diB00=FT`=J]0IJ/a1Je09Jd`QJ/`=F/P=F
TP=BT@03DW5BL4i`00A>D0=:C`=:;`96;P=63P=23@=1k@03@N`mk3g/00<mc0Lmb`<ib`03>LXiZSVZ
00<iZPDeZP8eZ@<eZP03=JTeRCF9008eR@03=HXaRC5Y008aJ@03=HTeZSVZ008mb`<mc0<mk0E1k@=2
3@07@Ne63T7]@Ne6;Sg/>J/00T7]00<mkCg=?Nd00d7]00<mcD7]@Nd01T7]23g]010eRRTX>L`mcCW<
@Ndmc3g]?LdicCg=?NdicCF/>J`mc@<ic@/ic0Di[0<e[08eZaMoo`005Goo1D7]00@mkCg<?L`mc08i
c0DiZa0eZP<iZ`8iZP<eZP<eRP03=JXiZSV[008iZ`03=HXeRcF;008eR`<eZ`05=H/eZcV[>J/i[003
?L`00cg]@Ni63`02APl01T7^?NdmcDX`EY=W=`AcNP06Mi]g_7NlNkekgWoN0gon021ogW_MNkek_G_M
OmikgW_MLiacVfmJIaQJeE:CCU9:<EJdDY=:DD8?>LdaJbTY8@LDY1cU9@LYB2eY<HXi[3g]53W<13V/
00@ic3V/=J/eZ`@i[008<HXaRcF/>LdmcCW<<HX]B@Di[006=H/eS3F;=H`eRcF<1CF;00He[3F<<H/]
JRU99BP29@P2:BT012DX9@PQ1b470R3W00<LiQS66<D00QBU00@DY1BU5<D<P`8<H`D<HP8@P`8<P`@<
H`<Ha@045<DDYABT5:@25:D35:H<5:D338@01A254:D@YA2U5:H0212U:7oo3eLL00=K75lmGcd01Ulm
00=O7E/MGad01Elm00=K75KkE_/00eKk0UKj15[j00QO6U[jF_UJf4HA6:A1kdiB0U:C00=FTeZcF[<0
1eZc25Zd25[D1EZc0eZb0eJb0eJB0UJA00EBTE9aDW5BLDi`00=>D0=:C`=:;`9:;PA63P04APe23D8=
@Pd3@Nd2?N`3?L`5?L/3>L/2>LX6>JX5=JX2=JT00cF9=JTeZ@07=HT01c69<FTaJC5Y<HTeRSVZ008i
b`03?L/mc3g<00<mk003@Na1kD7]00I1k@0;APi1kD7]APhmk3V[?Na1kCg]?Ldmk@03@Nd00cg=?Ndm
k@06?Nd8?Ld023F::BLi[3g=>La1kCg<?Nd3>L`01Cg=>Lde[3V/?Nd00SW=2cW<1CV/0cF/0cF[5goo
000EOol5?L`:>J/00cF[=HXeRP06=HX8=JX3=HX00cF9<HTaR@02<HT00c5Y<HTaR@02=HX00cFZ>JXi
Z`03>J/00cV/>L`mc002?L`013W<?L`mc3g=0T7]0T7^0Sg=00Y1kSg=>J`aJRTX8>H]BDH?IaMk_0Ao
oPioo`03OoiogWoo00Moo`0@NkekgGoNOoioogonOmikgGonOoe_NUkEBS0mkCW=?Nd8>J`A>L`00cF[
=H/i[002>Ld01CW<>Le1kSg=>J`00SF/00<icCg]?Nh043V]0SF]00<icSg>?Nl00cg_00<mcSW>>Lh0
1CF]00@mkSW>>LhicP@e[@04?NlmkSW>>Lh5>Ld2=Jd2<H`3;F/28@P27>L26<H00aS55:DDY@025:D3
48D248@236@236<010a324<8@`Q310aT10b42125:7oo1ELL0eKk1eLL3E/L0UlL0UlM0UKk0UKj00AF
neKjE_YFnPIJnP06F]UFf4HA58A1kTiA0U9b0UJC0UJc65Zc0UZb1EJb0eJB00AFTE:ADY5BT@9BL@04
DW1>L4i@CU02CTl01DY?BRm:;dX_BRh00dH^0dH>00=63D8=@Pd00d7]00=1k3g/?N`00cg<13g;1CW;
1SVZ1SFZ00<eZCF9=HT01cF913690c5Y00<aRCF:=JX00cW;00@mbcg<?L`mc0<mk091k0E1k@09APe1
kD7]APhmk3VZ?Na1kCg]008mc@91k@03?NdmcCg]00Lmk@Pmc@0@=HXY9cV[?L`ic47]?L`mkCg=>L`i
cCg]>Lde[3V/?Ld7>L`00cV/>L`ic002>L`3>J`5=J`4=J/GOol001Eoo`04?L`ic3W<>J`7>J/3=J/0
0cF;=HXeRP07=JX:<HT5<FT00beX<HTaR@02=HX00cFZ>J/iZ`02>J/2>L`01Cg<?LdmkCg]@Nd01Cg<
1cg=00PeRbe99@HLaBDW>JaBLV;f16LG00AS5f/iLi]ogP9oo`07Omik_GoNNmikgG_NOoh00goo00=o
oWoNOmh00WoN00EkgW_MNmeogWon00Ioo`08LgY[FEkeBU4e[2e9:DT]JAPi[003?Lde[3F/008ic@06
=H`aRcF/<F/aRcF/0SW=00<i[CF/=J`013g>13g_0cW>0Sg>0cg_0SW?0Sg_00@iccW>=Jde[@Dmk`05
?O0n448@>Lhic`04?Nl00cW?>LhicP05>Lh2>Ll2=Jh013F]<HdaS2e/0Re[0RU:00HU:RDY8@TQ21cX
7>L36<L01AS66:HDYQBV5:D00Q2500@@Q11T36@<I08<H`<<Q00336@<H`QS0088H`P@QBQoo`EBfP03
D[Y>^Dji00QBfPaFfPAFf`04E_]BfU;JD_X3E_X015;IE_YFnUKj0e[j00IJfEKH@Q0DQ47^CU43DW82
EY<3E[<DF[<4E[87EY800eJADY5BT@02DW42DW0014i`CU1>D4i?0TY?0dX_00=:;TH^ARh00dH>00=6
3D8=@Pd0147]0cg/0cg<00<mbcW;>L/013W;0SW:1CVZ1cFZ00<eZCF9=HT01SF91C690S5Y00DaJ35Y
<HTeRSFZ008iZ`8ib`04?L/mc3g<?L`4?N`2@N`3@Nd03d8=@Na1kDH>?L`eZSg/@NdmcCg<?LdmkD7]
?Ndmc008?Nd8?Ld02C6:9BLiZcg<>Ja1kCg<?Ne1kP02?Nd01Cg^?Lde[3V/?Ld01SW<0SV/0cW<0cV/
1CF/1CF[5goo000EOol2?L`00cW<>J`i[003>J/4=H/3=HX00c6:<FTaJ@06<FT8;FT3<HT5<FT3=HX0
0cFZ>J/iZ`02>J/01SF[>J/iZcV[>J`ic0Xmc00=?Le1kT7^@Ni1kCg<=H/eRRe8;DTaJReY:BP00bD7
00HY:BeZ=Ja1kdXaCW83DW<01U:CF[ERmfmJMkaogP]oo`0>Nme_NUkFCU923cg>7<DQ1bU9<HXeZcW=
@Pi6;`Pi[0Pe[08eZ`<e[0<i[005>Lde[3V]?NlmkP02>Jd02D7_>LdmcSg_?NhicCF<<F/]J`04:DX4
;F/4=Jd013F^>LhicSW>0SW_00Hml3h@?Q0n43g`>Nl2=Jh2=Lh4>Ll2=Jd00cF^>Lhic`03>Ll4?Nl0
1Cg?>LlicSF^>Ll01SW>00Di[SF=<HdaSC6<008]K08]J`04<HdaS36<<F`2;F`2;F/3:D/00bU:9BXU
:P029BT01R487@PLj1cW6>LHa`8DaPD@Q@8@Q00338Aoogoo02Ioo`=:V09:N0=:M`Y:N006CWQ:N4ih
BWQ>N4Yh1djH00=>VE;JD]X00U;J0UKj00EFfU;IE_YFnUKi00=JnP06E]UF]d7`58@mkTXa0e9b1EJC
0eJc2EZc25Jc25JB0UJA0U:A159a0Ti`0Ti@0TY?0TX_0TX^0TH^14H>0d8=0d7]0T7/0Sg/0cg<1SW;
00<ibSVZ>JX00cVZ1CFZ0SFY00<eZSFY=JT01SF91C690S6800PaRC5Y<FT]J35Y<HTeRSFZ0cV[0SW;
00<mbcg<?L`00Sg<1Cg/0T7/00U23Cg/@Na63Sg<=JXmk3g]?Ld00Sg<00@mkD7]?Ldmc0Pmc@Pmc009
<FXU9cV[?L`i[47]?L`mkD7^008mkP05@NhmcCF/=J`ic@04>L`4>J`013W<>J`i[3V/1CF/1cF[5goo
000EOol2>J`3=J/3=H/5<HX3<FX8;FT8<HX8=HX00cF[>J/iZ`05>J/2=J/4>J/2>J`8?L`2=H/00cV[
>J`i[004>J`2=H/02C6:=H/iZcV/?Ldi[CF;;FXY:0029@P022DX:BTU22D79BPYBBeZ=H/2=J`2<F/0
1S6;>Le644ibDY=FT`<aR`08;FXY:BD78@LU1c5Z<H/eZ`8i[003=J/eRc6:00Pe[0Pi[08eZ`8e[0@i
[00C=JdeS3W=?Nli[Be[<F/mcSW><H/U21RU58@LiReZ>Lhe[SF]=Jh01CF]21S700PDaaSW8@TUBbf=
=Lhil3h@0ShA00I24D8a@Q4n43W`>Ll2AS800d8A?O0ml003?O02>Ll2?O00147`?O0mccW?0cF^0SV^
00<icSW?>Lh01CW?00<icSW?>Lh013F^1SF]0S6=0S6<0Re/00HaSC6<;H`]K2e[:F/2:D/00bU:9DXU
:P059BXXOol2BWP3BWL00dYGAUM6E`0:BWL01DYGBWM:EdYgBUL01DYg0TYh00A>N4YhD]Y>f@9BfP9F
nP03D]YBfEKj009Ff@0=E_YJnU[iE]UF]d7`58<mcTX`CU5>LU9bEY800UJC00=FTUJCEY802eJc1eJC
1EJB0UJA1E:A0e9a0Ti`0di@00=>CdY?BRl00TX_0dH^0dH>1D8=0T7]00=1k3g/?N`013g<00DmbcW;
>L/ibcV[008ibPDiZP@eZP04=JTeRCF9=HT2=JT6=HT4<HT03368<FPaJ35X<HTaJC5X;FPaJ35Y=HXe
ZP@iZ`8ib`8mb`@mc0@mk00:@Na23Cg/@Na63Sg<=JXmc3g]?Ld2?L`2?Nd00cg=?L`mc@07?Ld8?L`0
1c5Y9@LiZcg<>Ja1kCg<008mk@07?LdmkCg]?Lde[3V/?Ld013W<0cV/00<e[3V/>J`00SV/0cF/23F[
00<eRgooOol05Goo000EOol4<HX3<FX00beY<FXaJP02<FX4;FT00cF[=JXeZP05=JX8=J/7>J/00cW<
>J/iZ`06>J/2>J`3>L`3?L`013V[>J`i[3V/0SW<0Sg<0cg=00@mc3W<>L`mc08mc@03?L`i[3V/008m
c@05>J`e[3F/>Jdmc@02?Nh023g=>Jde[3W=>J`e[3V/>Ld2?Ld02CW=@NhmcCF/=H`e[3F<<H/aJP04
>Ld3=J`00cW==J`eZ`02=J/013W<>LdicCW<23F/23W<0cF/0SV/0SW<00dicCW>=Jdi[CF]:BTDYAB4
7>M:DUZeJeYk_@02Ool00goNNmioo`04Ool3Nol5Ool2Nol02G_OOomkogNnKiaWFelIF_QJe`02D[H0
2UKFE[IB]DYdAU=2<RU;8@THaa250`Q300H<I1BV7<LU:Re/=Jh3>Ll3?O05>Ll4=Jh4>Ll4>Lh013V^
=Jhe[SF^0SW>00<i[SF^=Jh00cF]0S6=0S6<12e/00<aK2f<;F`00be/0Re[:7oo0TjH0Tih00A:N4Yg
BWM:Ea1:M`I>N09>V004D[U>^E;ID]X2E_X2D]T015KjE]UFfEKi0U[i00IFfEJg@O0DPcg=BS02CU40
159bDY9FTeJC1EJB2EJc1eJC15JB00=FTE:ADY4015:A0e9a00=BL4i`CW000di@0TY?0TX_00=:;TH^
ARh00dH>00=63D8=@Pd00T8=0d7]00=1k3g/?N`013g<0cW;0SV[1cVZ0cFZ00<eZCF9=HT00SF90SFY
1SF90c6900<aR35X<FP00S5X00TaRC5Y<FP]J35X<FTeRSFZ>JX00cV[0cW;00<mbcg<?L`00cg<13g/
00Q23Cg/?Na63Sg<=JXmc3g]0cg<00@mcCg]?Ldmc0Pmc@Pmc009<FTU1cF[?L`i[47]?L`mkCW=008i
c005?NdicCF/>J`mk@03>L`3>J`2=J`3>J`3=J`8=J/2=H/GOol001Eoo`03=H/aRReZ00<]J@0:<FXa
RS5Z;FT]BBeY<FXaRS6;<HX3=J/013F;<HXaRSF;1SF[0cF;0SV[0SV/13V[0Sg<0SV/0SW<00<i[3V[
>J`083V/3cF/00<i[3F/=J`00SF/0SF[00@eRcV/>J`i[1De[0Pi[0Pe[006@NlmcSF]<F`]Jbe;0Re[
00EJeV<HKg]g_GoN00Yoo`03Nomoogoo009oo`9ko`=oo`05NomggVnMJgaWF`02HcX035lIHcUS>V<j
GaUJme:eCW@ml3F=:D/U2@8U:P0:8@TLj1cX8@TU:RTZ:D/]K3F^?O0;>Ll2>Jh3=Jh2>Jh8=Jh4=Jd2
=Hd5<Hd7<H`0135/;F`aK2e/:7oo24Yg2dYG2DYg0Tih0TjH1U;J0U;I00=FfEKjE_T00UKI00]JnEKI
DYI1kaB4@Ni:<4iADW9FTU:B00=BLP=BTQ=FTP03EY5BTE:A00=BT@=BL@03DW1>L4i`00=>D09:C`=:
;`03BRi6;TH^00A63P03APe23D8=00=1k@03@N`mk3g/00<mc08mb`Dib`03>J/iZSVZ00<iZPLeZP03
=JTeRCF900HeR@LaR@03<HPaJ35X008aJ006;FP]B2e8;DPaJC690SF:0SFZ0SV[0SW;00<mbcg<?L`0
0Sg<13g/00Lmbd7]?L`ibd7]?L`eZP03?L`01SW<?L`mcCg]?Ldmc08mc@/mc0<ic00;<FTU1cV[?L`i
Zcg=>J/ic3F;=J/e[004>L`013V/>L`ic3W<0cV/1CF/1CF[13F/13F[5goo000EOol2:DT00beY;FX]
JP03;FT2;FX01c6:<H/eZcF[<H/aJSF/008iZ`<eZ`08>J`ic36:=H/eZcV[>L`mc@8mk@05=J/eRcF:
=H/iZ`03>J`013F[>J/iZcW<0cg<00<ic3V/>J`07cV/5CF/0SF[1SF/0SV/43F/23V/2CF/00Pi[Cg_
AS5BU5kgJeYcNgoN1Woo00=ogWooOol037oo00AkggONNomko`]oo`07NomggW>nLiecW6mlKg/00f]K
00U[FV<IHaUNn4id?O0eSC6==Hd01cW?00DicSW?>LhiccV^00@e[P03>Jhe[SF^00He[PDe[@8eS@@a
S@LaS08aK0<]K2Qoo`QB^@9BV@=B^@QF^PEFfP=F^P=FfP04D]Y>fTkID]T2D]X3D]T2E]T02U;IE]QF
fEJhDYHmkaB3?Li644iA1E9b1E9a00=BTUJBEY801UJB25:B0U:A1U9a0di`0di@0Ti?0dX_00=:;TH^
ARh01DH>00=63D8=@Pd0147]0cg/0cg<1CW;0cV[13VZ1cFZ00<eZCF9=HT01SF91c6900<aR35X<FP0
0c5X00H]J2e8;DP]B35X<HT2=HX2=JX00cVZ>J/ib`02>L/5?L`3?N`01cg;@Ndmc3W;@Ndmc3FZ00<m
c007>L`mc3g=?NdmcCg<?Ld02cg<13W<00PaJRDW>J/mc3V/@Ndmc3g]0SW<0cW=0SW<00@i[3W<>L`i
c0<i[0De[0DeZ`<e[0DeZaMoo`005Goo136;0SF/13W=0SW<0SW=00<ic3F/=J/01cF[0Sg]00PmcCW<
=J`eZc6;<HY1kSg=13V/00XeZcF:>J`i[3W<?L`ic3V[=H/eRQ0iZa0i[1<e[0PeZ`03=J`i[3V/008i
c10e[10i[00=<H/aS3F<=J`i[CW=?LhmkV<HJcUcVg^mOmh037oo0W_N47oo0g_o2goo00Mk_W>MKga[
Ff<HDYA64@05>Ll5>Lh2>Jh;=Jh6=Jd2=Hd2<Hd00cF=<HdaS@03<H`8<F`00be/Oomoo`0VOol>E[X3
E]X3E]/015[KE]]JfeKK0U[k00=JfeKKE]/00eKK0U;J00A>fE;JD]YBfP=Bf@9Ff@0>D]QFf5KIE[QB
USg?46<mcDH?BS1>DDiaCU5>L@MBL@mBLPEBL@04DW1>L4i`CW04CU001Ti?BTm:CdY?BRm:;P96;PE6
3P03APe23D8=00A1k@<mk0<mc08mb`@ib`<iZ`<iZPDeZP<eZ@PeR@DaR@<aR0HaJ08]J006;DP]Abe8
;FPaJC690SF:0SFZ0SV[0SW;00<mbcg<?L`01Cg<00Libd7]?L`ibd7/?L`eZP02?L`01CW<>J`ic3g<
?Ld02Cg<00<ic3g<?L`00Sg<0cW<00Ti[2e98>HaJSF;<HXi[3F[>L`00SW=23W<0cV/1CF/3CF[00<e
RgooOol05Goo000EOol05ABT48<<HPaR488HaB47:DTQ9acV4:<<HPaQ388@XaBT;FXaJS6:=J/ic003
?Nd2<HX013F;=J/eZcV/0SW<0c6:00<eRSF;>J/00SV/00HiZcV/>J`i[3F[=H/2=HX@>J/@>J`@=J/0
0cF/=J/eZ`08=J/00cF/>J`ic002>L`@=J`@>J`2@Nh013g^?LhicCV]0SF/00HY:2U9;FXaJc6;<FX2
;FX012DX9@PPiac611RU00PQ223W9@PaS4YBHaQgW7_N0goo00=kog_ONml00W_O0goo00=kogooOol0
0Woo1W_O0goo00MF]RU;6<HQ2C6==JdaS00:>Lh3=Jh3=Jd5=Jh7=Jd00cF=<HdaS@03<Hd3<H`7<F`2
;F`2;F/XOol9CYP3CYT4DYT5D[T6D[X2D[T2D[X2D]X014kIC[U>fE;J0U;I00iB^E;IE]UFfE;IE]QF
fEJhDYHmcQ1S?Le63dX`0diA0dia1E9a259b2U9a00=BL4i`CW000di`0di@00=>CdY?BTl00TX_0TX^
0TH^14H>0T8=0d7]13g/0cg<00<mbcW;>L/00SW;1SV[00<iZSFZ=JX00SFZ0SFY23F91S690S68235X
0beX00L]B2e7:DLYAbe8;FPaJ@03=HX013FZ>JXiZcV[0cW;0Sg;13g<00hibd7]?L`ibcg/?L/eZSW;
?L`ic3V/>L`mc3g=1cg<0cW<0Sg<0cW<0cV/00TeRRTW>J/mc3V[?L`iZcW<>J`00SF/0SV/0cW<13V/
0cF/23F[00<eRcF[=J/00SF[13F;5goo000EOol03b4X8@LLiQcV8@LYJSF/>Nhe[2eZ8BPHiQS56>HM
1`038@L00bDW:DP]JP03<HX01D7^?NhmkCg]>Ld00SW<00Li[3g=?Ne1kSg=>J`eZ`02>J`2=H/01SV/
>J/eRcV[>L`mcA0iZa0i[1`eZ`04>J`ic3W<>L`@=J`@>J`2<H/00cF;=J`e[003=J`033F[=H/eRc6;
<FX]JBU89BPaJReZ:DTU:0@Q1`099@PPib3W:DTmcU9cG_IW66/i00=W>@04JeU_Ng>LMkd>Ool027_M
Li][FDHa8@P@Q1cW<H/6>Lh5>Ld7=Jd4=Jh7=Jd00cF=<HdaS@03<Hd2<H`9<F`012e[;D/]Bbe;:7oo
00Q:EdIGBUM6EdYGAUM:EdIG14Yg1dYh2DZH00U>V4jiC[UB^TjiB[Q:V4ZhC[T00Tjh00A>V5:hD]UB
f09B^009E]QB]die?Ll@Hcg=APm:<4YA009>D@=>L@EBL@QBLPUBL@E>L0A>D003CTm:CdY?00=:;`04
BRi6;TH^ARh3APh014H=@Ne1kD7]0Sg/1Sg<00<mbcW;>L/01cV[0SVZ0cFZ0SFY23F91S690S68235X
12eX0Re800PYAbTW:BLYAbe8;FPaRCF90SF:00@eZSVZ>J/iZ`@ib`8mb`8mc009>L]1kCg<>J/mk3W;
=JXibcg<008i[005>L`mc3g<?L`ic004?L`4>L`013g<>L`ic3W<13V/00H]JBD6=J/ic3F[>L`2=HX3
>J`5>L`3>J`3=J`8=J/2=H/2=J/3=H/3<H/GOol001Eoo`0CGaMS5fLhJeU_NW>KLkag_7>lLi]_NV]j
JeUWF6<hHaM6;d8>?Nd00SW<01@eRbeY9BPHa1c58@HU9be9<HXeZcW<<FXeRcV/>L`i[3V[=J/iZcV/
0Sg=00Dic3F[=H/i[3W<010iZ`li[003=J`eZcF[01DeZ`03=J`eZcF[008eZ`8i[08ic10e[0Pi[0Pi
c091kP03?NhmkCg=008ic006>J`eRcF;=J/i[3g=0cg]00Di[3F;=H/eRcE[00<eR`03?Lhi[3F<008e
R`03<H/aBRU9008U:08U20059BP]BS5[=Ha>DP05CW8044iBBU5F]5JdG_IS>6LhG_I:DCW>7>HU:36;
>LdmkSW>23W=0cG=13F]0SF/0SF]0SF^1SF]0SF=1C6=00<aS35/<F`01S5/0Re[1Be;:7oo248e0d8f
00=2ET8f@UH00TIF2d9F0TIg14ZH00A6V4JGBYM:V09:U`03BWM:Udjh00=>U`07D[M>UTYD?Lh@HcW=
@Nl00TX`00=:D4X`CU400diA00A>D4iaCW5>L@QBL@M>D@I>D0=>C`9:C`=:;`=6;PA63P04APe23D8=
@Pd3?N`3?L`013g;>L/mbcg;0SW;1cV[00<iZSFZ=JX00SFZ00<eRSF9=HT01SF91C690c68235X1BeX
0ReW00<]B2e7:BL00RTW00<YAbe8;DP00S6900@eRCF:=JXeZP@iZ`Dib`0=?L/ibd7/?L/iZcg/>L/e
RSW;>L`i[3V[>J`00cg<00@ic3g<?L`mc0<ic08i[0<ic0<i[08iZ`09;FTU1SF;>J`eZcW<=HXeZcV/
008ic006>Ldic3W<=J`eZcV/0cF/23F[1cF;0c6;0S6:5goo000EOol00gNlMmeooP04Ool00gonOomo
o`03Ool04gonNmeg_7onNmegVg=jKeUW5e[EDY=BLTYA@Ple[2U98>HHY123008U1`08:BPeRcg=@Nhm
cCV/<FXe[08mc@04=J`aRc5Z=HXO>J/G=J/2=J`2=J/4=J`2>J`@=J`8>J`8>L`2<HX013F;=J/eZcV/
0SW<00A23Sg]?Ldmc08mk@03>L`i[47^00E1kP05ANi1kSV<>J`m[002?Ld01Sf/>J`iS3V]>J`i[@<i
[005>Jdi[2TX:BPY:@02:BP01RDX9@PU22U9;FXaR`8e[00;;H/U:1cV<H/icCg_?Nhe[CF/>LdmkP05
>Ld2=Ld013F/=Jde[3F]1CF/00<e[CF^=Jd013F]0cF=1S6=00<aS35/<F`01C5/22e;:7oo2D8f00=2
ET8f@UH00T9F00=6ET9F@UH0149F00U2MdIg@WM2Ed9gAWM2MdIgAYP00TZH00M:^4ZHBYQ:V4jHC[Q>
V002BYL00djhCYM>U`02CYL01djFBU@i[Q1R>Ja1kTH?00I:<09:D0]>D0Q:D003BTm:;dX_00E:;`=6
;P=63PE23@91k@04@N`mk3g/?N`3?L`00cg;>L/ib`04>L/3>J/2=JX3>JX5=JX5=HT7<HT00c68<FPa
J006<FP7;FP01beW;DL]Abe7;DPYAbTW008Y9P03:BLYAbe800<aR@8eRP8eZP03>JXiZcV[008iZ`Di
b`0;@N`mbcV[?N`ibcF:>L/ic3V/>J/i[003?L`00cW<?L`mc003>L`3>J`2>L`3>J`4>J/03Be8>J/i
Zc6:=J/aRSF:;FTaRSF[>J`ic3V/008eZ`@e[0PeZ`<eR`DaR`@aRQMoo`007goo0Won1Woo00=ooWoo
Ool00Woo2Gon00ik_FmjIaMNmE[ECW4i[2D76:@Q1c5Z=J/i[3F[0SV/01liZcF[>J/eZcV[=J/iZcF[
>J/eZcV[=J/iZcF[>J/eZcV[=J/iZcF[>J/eZcV[=J/iZcF[>J/eZcV[=J/iZ`0E=J/3=J`4>J`2=J`0
0cF[=J`e[00@=J`8>J`8>L`2?Ld4>L`02SW=?Ldic3V/=J/i[3W<?NdmcCW<1Sg=00<m[CV/?Ld01Sg=
00e1kSV]>LdmcSg^@NhmcSg=>Je23d7_@NhmkP03@Nh04D7_?NhmkSW>>Lde[CW=?Ni23cW>>Lde[CW=
>LhmkSW==J`01CW=00HecCF]=J`e[CF/=Jd5=J`6=Jd01CF==JdeSCF]=Hd00S6=1C6<1S5/00<]Jbe;
;D/01Be;:7oo44ZH0TZI34ji0U;J0U;I00=>^E:iD]T00U;I00iB^4jgD[QB^4jGD[MB^5:GCWDi[@a2
>J`mkT8?0dH?00=6;dX_BRl01DX_00M:<4X_BS1:;dX`BRm:<009BRl5ARh4APh00dH=@Pe23@06@Nd0
0d7/?N`mk006?L`00cg;>L/ib`02>J/2>L/3>J/013VZ=JXeZSVZ1CFZ0SF:13F91c6900<aR35X<FP0
1S5X1beX00<]Ibe7;DL00be700PYAbTW9BHU9RTW:DL]Ac5Y0S690SF:0SFZ00<iZSV[>J/00cV[0cW;
00TiZcg/>L/iZcg/>L/eRSV[>L`00cV[0cg<00<iZcg<?L`00cW<0cV[0SW<0cV/0cV[010Y9aBS7<DH
Y0aQ488<HA227>HQ1bU9<HXe[3V/=J`eZ`<e[0LeZ`DeR`04<H/eRc6;<H/5<HXGOol001]oo`9ooP04
OomooW_NOmh:Ool2Ooh00g_NOomoo`02Ool03g_nNmikgWonMi][FFLhIaQJeDH@=H/U22TY;FXeR`02
>J`2=J`6=J/01CF/=J/eRcF[=H/01CF[00<iZcFZ=JX00cFZ00DeRS6:>L`ic3V[00<eZ`04=H/aRcF;
=H/:=J/4=H/2=J/013F/=J/e[3F[0SF/00LaRcF[>J`ic3W=>L`i[009=J`8>J`8=J`2>J`00cV]>L`i
c@03>Ld8>L`8>LdA?Ld053W=?LdicCg=>LdmcCW=?LhmkSg>?NhmcSg^?LhmkSg>>LhmcSW=>Lh7>Ld3
>Jd03CF]>Jde[CV]=Jdi[CF]>Jde[CV]=Jdi[CF]00@i[@8e[@8e[0<eS004<H`eS36<=H`5<H`6<F/2
;F/6;DX2:DXXOol00d9G@UI2E`04AUL3AWL00dIhAWM:N002BWP00dZHBWQ:N002BWP4BYP3BYT2CYT3
C[T4CYL2DYL015:gDYM>UU:G0U:g00aBUdjFBWE>M3F<6:@aJT7^>Ja5kdH?@Lh3APl014X?BRm:;dX`
3TX_00=6;TH_APh00TX^0dH^00=63DH>APd00TH=0d8=00=1k47]@Nd00T7]0T7/00<mk3g<?L`013g;
1CW;0cVZ1CFZ0cF92C69135Y1C5X12eX12eW22e70bU700@Y9RU7;DLY9`8U1P03:BL]J35Y008aJ@05
<HTeRSFZ=JXiZP02=JX2>J/3>L/02SV[?L`iZcV[?L`mbcVZ=JXiZcW;0cV[00<ibcg<>L/02CV[01Dm
c3F:>J/ic3F:=H/mc3V/:DPDPaBS7<D<@@Q146<<@A237>HYBC6;<J/00S6;00@eRcF[=J/eZ`DiZ`8e
Z`TeR`03<H/eRS6:008aRQMoo`005Goo00=ogWonOol02goo00=k_GNlOol027oo00=koWOMNmh017oo
0Won0goo00MooWNlLg]F]4ib@NleS002;FX00cF<>Lde[005=J`2>J`8=J/02SW;=JXeZSFZ=J/iZcF[
=JXeRSFZ2CF[0SF/0cV/0SF;00<aRc6:<HX00S5Z00T]JReY;FX]JS5Z<H/eRcF[=J`00SV/0SW<00Hi
[3F/=J/eRcg>>Lh4>Jd00cF/=H/i[007>J`==J`3>J`X>Ld8?Nh3?Lh00cW>>Ldic@06>Ld4>Jd00cF/
=Jdi[@03>Jd2>Ld8>Jd3=J`8=H`00c6<<H/aR`02<H/6<F/2;F/6;DX2:DXXOol2>Q@6?Q@5>O<3>Q@3
>O<9>Q@4?Q@00chB?Q4n4P02?Q83@Q82AS<2AU@02dICAS=2<T8A<F/HY35Z@Nhi[4H?BS0014G_1DH?
3DH>1dH=148=147/1Sg/00<mc3g;?L/00cW;0SV[1CVZ00@eZSF:=HXeRPLeR@DaR@03<FTaRC69008a
R@<aJ@HaJ0<]J08]I`P]A`8YA`@YAP049BHY9bTW9BH28@D00bTW;DPaJ002<FT00c69=HXeRP02=JX0
0cF:=JXiZP05>J/01Cg<>J/iZcg<>L/00SFZ0cV[00<iZSV[>L/00SW;2CV[01Pmc3F:>J/ic3F;>J/i
[3F:6:<HY2D7<FXU1aB334888@Q14:@M1bUY<H/eZcF/>J`2=J/6>J/00cF[=H/eR`08=H/00cF:<HXa
JP02<FXGOol001Moo`9ooPAoo`06MkekgWonOmik_GoN3Goo00EooW_NNmeggGNm009oo`08Ooi_NUZd
@PlaRbe9<H/aJP<]JP03<H/e[3V/008e[0heZ`8eZP8aR@04<HXeZSFZ=JX2<HX2=J/013F/=J/eZcF;
0SF[13F;0S6;0c6:00H]JReY;DTYBBU8;DT7:DT3;FX2<FX2<H/02CF;=J`eS36<=H`i[CW=>Jde[00@
>J`4=J`4>J`X>Ld:?Lh2>Lh4>Ld2>Lh5>Ld>>Jd6=J`7=H`2<H`4<H/5<F/2;F/00beZ;DX]BP04;DX2
:DXXOol8=M44?Q<2>Q<2>Q82?S@>@S@00d8c@S96<`05AS<00dICBUA:E002BW@01TYDAU=:DbTY58<Y
:08eR`03?Le1cSg=00Q1kP03APi63DH=00E63@Q1k@Q1k08mc0Lmb`<ib`@iZ`03>JXeZSFZ00<eZP<e
RP8eR@PaR@/aJ@DaJ0D]J0<]A`LYA`03:DHY9RTV00<Y9P<U9P058@DPi23U9BHYA`02;FP2<FT01369
=HXeRSFZ0SF:00<eZSV[>J/00cV[00dmbcV[>J/mbcW;=JXeRSVZ>J/iZSFZ>JXiZ`02>L/9>J/03Sg<
=HXeZcW<>J/i[3F[:DP@HBD7>J`mcCF<7<H222401@@P248DY247;FX00cF/1cF[2CF;0SF:0S6:135Z
5goo000EOol012488>LLiQS50aRU00DHaBU9AQ1[>Gon00Yoo`9ooP0;NmioogooJgY6<BU97>LM1a23
7<HU:002;FX01S5Z=H/i[Be9<FXe[08ic@03=J`aJbe900<eZ`DeR`<eZ`DeR`06=JXaRBeX;FPaRCF:
0SFZ1CF[00<aRc6:;FX01BeY0Re900<YBBeY;FT00ReY00@]BBU9:DPYB08]B@DYB@04:DP]BBU9:DP2
:BP022U9;DT]JRDX9BTY:Be[=J`3>Ld@>J``>Ld8?Ld2>Lh5>Ld013V]?LhicSW>1CW=0Sg>0SW=00@i
[CF]=J`e[08ic@8i[@8e[08eS0<e[0DeS08aS0DaR`DaJ`04;F/]JReZ;FX6;DX2:DXXOol37@X57@T3
6>T56>P34:LA5<L46<L00aBV5<LDa`056<L00bTY6:@Y:002<FX00cf]>J`i[005?Ld00d7>@Ni1k@0;
@Nd00cg/?Ndmc002?L`2?N`5?L`4?L/00cW;>J/iZ`07>J/00cVZ=JXeZP04=JX4=HX00cF9<HTaR@03
<HT4<FT2<FP9;FP3;DP00beX;DP]B005;DP5:DL00bU6:BHY9P06:BH49BH01bD68>DLi23T9@HY9be8
008]J003<FTaRCF900@eRP03=JXiZSV[00<iZ`03>L/iZSV[008ib`8eRP03=JXiZcFZ008eZP04>J/i
bcV[>JX8>J/02cg<=HXeZcW<>J`ic3F:8>HLaCF;@Nh00Sg=00<U1`a134400PQ100<<PaSV:DT00S6;
00<aRSF;=H/00SF;0cF:23F;00<eRS6:<FX01S5Z5goo000EOol012e::DTU223W11cV00PLaSF<EYA[
FG=kKgYcNg>L0Won0goo01MooWOMMkaNmVMIJeYJeCW=8@LHaAcV6<DLiRD7:DT]JS5Z<H/eRcg^>Ldi
[3F;008aR`8eR`@eZ`8eR`8aR`8eR`8aR`@aRP05=HXaRC5Y<FTaRP03=JX2<HX01CF;<H/aRS5Z;FX0
0ReY0Re90RU90bU80bU91Be900HY:2U9:DT]BBeZ<FX3<H/01BeZ;DTY:BDX:BP00RU900DYBRe:<F/e
S3V]00<icA0i[0Lic@03?LdicCW=02Hic@Pmc@03>LhicCW=00<ic@8i[@03>LhicCW=00<ic@8i[@@i
c@Pi[@8e[08eS0<e[0DeS003<H`aRc6;00<aR`DaJ`03;F/]JReZ008]JPH]BP8YBRQoo`@DaP8DY@8@
Y@8Li`HHi`<DaP<HaP8Hi`8DaP<HaP<Hi`@Ha`@Hi`036<LHiaSW00DLj0089@PLaBe9<FXaRcg=>J`m
cP<i[0<i[@8ic@Pmc0@ic004>J`iZcV/>J/2>L/7>J/5=JX==HX5<HT8<FT3;FPB;DP3:DL00be7:DLY
A`03:DL5:BL5:BH00bTW:BHU1P038>D00bD6:BL]B002;DP012eX<FTaRC690SF90SF:00HeZSVZ>JXi
ZSFZ>J/2=JX02CW;>J/eRSF9=JXiZSFZ=HXeZP03>J/00cFZ>J/iZ`06>J/00cW<=HXeZ`02>J/013W<
<FXHY2TX0Sg=00di[3g=;DXDP`a22488@@aR5:@U9beZ<HX]JP02=H/6=HX6=H/2=HX8<FXGOol001Eo
o`03;F/]JRe:00DYB@8U20068@LLaQRU8>L]Jcg>0Tib0U:C00aBLdibBS56<23W8@LQ22DX9BTYBBe:
;FX3=H/01cF/>J`i[3F/=H/aJReZ008]B@04;FXaRcV/>Ld2=J`3=J/3=H/4<HX02C5Z;FX]JReY;FP]
B2U8;DP]J002;FT2;DP3;DT3;FT2;FX5;FT2;DT3:DP2:DT00be9;FT]B@0::DT03BTY:DT]BS5[=H`e
[48?AS5:<DH`?NlicCV]00Xi[0Li[@<i[08i[B/ic@Pmc@@ic@@i[@<ic@Di[@8e[08i[@04>LdmcSg>
?Nh3>Jd3=J`2=H`3=J`5=H`4<H/5<F/2;F/5;FX6;DX2:DXXOol25<D65:D00a2338<<P`0338<236<0
11244:@@Y12T11BT0a240a2T0QBT112U1aBU00dDYQC65<HDaQS66:DDQ23W8@LY:3F;;DXi[003=H/3
=H`2=J`00cV/>J/iZ`05>J/4=J/3=H/2=HX00cFZ=HXeRP06=HX0136:<HTaRS694S5Y1BeX0be812eX
5Re81Be71RU70bTW00<YAbTW:BH00bD600PU9RTW:DL]Abe8;FPaJ35Y0c6900<eRCF:=JX013FZ00<i
ZcFZ=JX00SV[00@eRS69=HXeZP<eRP04>JXiZcVZ=JX9>J/05CF:>J/iZcF[>J`]JABS:BPiZcW=>J`m
kSV/8>L<@PQ11448@A237@HYB@02<HX2=H/6=HX4=H/2=HX2<HX6<FX2<FTGOol001Eoo`@aR`8eS08e
[0<aR`05<FX]BRTY9BPU1`087>H02S6;;FXY:BU9<F/e[3F<<F/]JS5Z1S6:00Ti[3W<>LdicCW<=J/a
JReY=J/00SF;00@aRc6:<HXaRP<aJP8]JP8]J@8]B@09:DPYAbU7:DP]J2U8:BPU9bDX008U9`8U1`03
9BPY:2U800<YB0DYB@8Y:08YB0`YB@0?;DX]JS5[=J`mcT8?BS5>DU9cE[AJ]E9c@Pli[CF/00Ti[003
>L`icCW=00Dic@<i[003>JdicCW=03Hic@Ti[@8e[@04=J`i[CV]>Jd2>Ld00cW>?LhmcP0;=J`5=H`4
<H/4<F/2;F/5;FX7;DX2:DXXOol648<248@35:D25<D36<D448<448@00a2T5:@DY0055:@65:D25<D5
5:D00aC55<HHa@027<H01RDX8>LY:C5[:BTeR`@eS0@e[0Pi[003=J`eZcF[00<eZ`8eR`<eZ`03=JXe
RcF:00DeRPdaRP04=HXaRS6:<HXH<FT4;FT4<FT3;FT00beX<FP]J004;FP8;DP2;DL2;DP4:DL2:BL2
:DL00be7;DP]J003<FT2<HT2=HX4=JX02CV[=HXeRSV[>JXeRC69=HXeZP03=HX013FZ>JXeZSF:23VZ
0SF:0SV[00HeRSF[;DTDXbU8=HX2?Ld02cW=?Ld]BPa2124480A1368HaBDX;FT00c6:1SF:13F;00<e
RS6:<HX01C5Z00@aJBeY;FT]JAMoo`005Goo0bU900<]BReZ;FX00ReZ00PaRc5Z;FXaJcF;=J`eRc5[
0SF/00/eRc6;=H/e[3W=?Ld]JS6;>J`icCV/00<e[008=J/e[3V/=J`aRc6:<H/eZ`PaRP8aJP03;FX]
JBeY008]B@03:DT]JReZ008]J@8]B@05:DTYB2eY;FTaR@03<HX01BeY:DPY:2DW8@L00acV00@PiR47
8@LQ1P@Q1`8U1`8YB0<Y:0@U:00=:BT]BS6;=JdmcT7_@Pm644H`AS5:DDiBDW<00UJD00E>DUJDF]EB
Td8?008e[003>Ldi[3V/00Hi[003>L`icCW=00Tic@@mcC<ic@Pi[@03=Jde[3F/008e[007?NhmcSg>
>LhicCV]=Jd033F/1CF<0c6;1C5[0Re[12eZ22e:0RU::7oo0b471B4800@U:BTY:DTYB@XYBP8]BP/a
S003<J`e[3F/008e[@03>LdecCF]00@e[@09>Lde[3V]?NheS3W=@NheS3g^00@i[@@ic@Pmc@@ic@04
>Jdi[3V]>J`2>L`8>J`6=J/00cF;=J/eZ`05=J/3>J/3=J/==HX2<HX3<FT3<HX5<FT3<HX9<FT2<FP6
;FP4;DP00c5X;FP]J002;FP012e8:DLY9bTW0RU700<]B2eX<FP00c5Y00DaRCF9=HXeRSFZ008eRP05
>J/eRSF:>J/iZP02<HT3=HX01SF9=HXeZSVZ=JXeRPPiZP0A<HXeRSV[=J/aJSF;;DTDXc6:=H]1kSg=
<H/i[C5[3688@@0214401@aR5:@M1RU8;FT00S6:1SF:0cF;0SF:00<aRS5Z<FX00c5Z00<aJBeY;FT0
0Re95goo000EOol2:DT4;DT2;FT00beZ<FXaJP03<FX2<HX>=H/2=J/8=H/3<H/2<HX01C5Z;FT]JC5Z
;FX01ReY00<]BBU9:DP01BU800D]JBU8:DP]JC6:008eZ`07=H/]JBe9:DTU:2478>L00acV00<Pib47
8@L00R4700HU1bDX:BPQ1bDX:BT28@L02RU9:BPY:Be:<H`e[3W>@Nm2448?0TXa00Y6<DXaDY=:DDiB
F]EF]5:DE[ANmP<ic@03>Jdic3W<00Lic10ic@05?LdmkSg>?LdmkP02@Nh3?Nh00cg>?Ldmc@02?Ld>
>Ld00cV]>J`ic@0?>Ld3?Lh2>Ld3>Jd2=Jd013F/=Jdi[CV]0SW=0Sg>00@icCV]>Jde[08eS08e[@@e
[0DeS08aS0<aR`HaJ`8]J`<aJ`8]JP<]BP8]JP8]BP04:DTY:BTY:BTXOol2:DX2:D/4;D/=<F`3<H`4
=Hd4=Jd00d7_>Lhe[003=J`023F]>LdmkSF]<H`a[3F]=Ld2>Jd2>Ld3>Lh2>Ld00cV]>Lhic@02>Lh<
?Lh8>Ld3?Ld2>Ld5>L`6>J`023g<<FU23SF:>J/aJCW<=H/2>J`7>J/3=J/6=H/?=HX3<HX3<FX0135Y
<HTaRC693C5Y22eX0bU70be80ReX0c5Y0S6900@eRCF:=HXiZ`8eZP04>J/iZS69<HT2=HX01CF9<HTe
RCF:=JX02cF:0SF[00DeRSF;<HXY9aS400@aJP05?LdmcRe958@48@03244011237@HYBBeZ0S5Z0S6:
0cF:00<aJSF:=HX00S6:2c5Z00<aJGooOol05Goo000EOol2:DT5;DT012eY;FX]JReZ1C5Z236;43F;
00@aRS6;<H/aR`8aRP0:<FX]JRD78@LPiQcU6<DHa1RT5:@37>D27>H38>H021cU7<@Ha246:DPaJS6:
;FX2=H/6<H/02bU9:BPU:2477>HLaQcV8>HU21c58@L00RU900@aJSF/<H/icP8mcP05?Nm244HaBS56
<@03BS4014iBEYABLdic0UJe00=BU5JdG_H00cW=00<i[CW<>L`01cW<3cW=0Sg^0cW=00<i[CF/=H/0
0cg=1CW=13g=0SW=00<i[CV/>Ld00cW=00@mcSg^@Ni23`PmcA0ic@8e[@8i[@04>LdicSg>?Nh3>Ld2
>Jd2=J`00cF<=Jde[004=J`5=H`00c6<<H/aR`02<H/6<F/2;F/00c5[;F/]J`02;FX3;DX2;FX2;DX0
12U9:BTY:BTY:7oo0SF=3CF>00@e[SF>=HheSP<e[P8i[P<e[P8i[P8i[`04>JheSCW=?Lh3?Nh03Sg_
?NhicCg^@Pm1kcW>>JdicCg^>LdicSg>?Nh4?Nl2?Nh6?Nl@?Nh00d7^?NhmkP04?Nh013g]?LdicCg=
1CW=00PmcC5Y>J`aJCg=?La63Sg<0SV/2CV[0cF[13F;3SF:0SF;1SF:00@aRS69<HTaR@`aJ@P]J0P]
B006<FPaJC5Y<FTaRCF90SF:00<eZSF:=HX00SFZ0S5Y00LaRCF:<HTaRCF9=HXeZP0;=HX023F[=HXe
RSF;<HXY9aS4:DP2>J`01Re9<FXicC5[6<D48084@@05244@PQcV:DP]J@03<FX01C6:=HXeRS6:<FX0
0c6:2S5Z0c5Y5goo000EOol3:DT3;DT3;FT3;FX<<FX00cF:=H/eR`06=H/7=HX2<HX00cF:=H/eRP03
<HX01Re9:DPU:2D78@HLiP8Li@03364<HQ2200<@PP03468<HQS4008DX`057<DYB36:=J/aR`02=H`3
=J`00cF]>Jdi[@03>Jd00cF/<H/]JP02;FX02BTY7>HQ1beZ=H`i[CW==H`mcP02>Lh00cg?@Q16<@02
AS43BU802E:DEYAF]E:DEYEF]E:DE[ANm`03>Ld00cV/>L`ic007>L`?>Ld023g>>LdicCg=@Ni23d7^
?Nh2>Ld023g=?LhmkSg^@Ni1kcF/>J`8>Ld013V/=J`e[3V/0SW=23g>23g=13W=13V]00<mcSW>>Ld0
0SW=00<icSg>?Lh01CV]00<e[CF/=J`01CF/1CF<0S6<136;1C5[0Re[22eZ00H]BReZ;DX]BRU::DT3
:BTXOol3=Hh3=Jh6=Jl:>Jl2>Ll6>Jl2>Ll01CF<?Li1kcg>>Jd00Sg>0SV]00<icSg>?Lh00SW>00<m
cSg^?Nl00Sg_0d8@00=1l48@?Nl00cg_00a1kcg_@O123d7_?Pm1kch?@Nln3d7_?Pl8?Nl9?Nh00cW^
>Lhic@02>Ld02SF]=J`mcCW<@Ndi[3g=<HXeRbe91CV/0cV[0cV/0cV[0SF[1SF;0SF:3CF;0cF:0c6:
5c5Y00HaJ2eX;DP]AbU7:BL2;FP0135X<FTaRC690cF:00/aJC69=HXeRS5Y;FPaJCF:<HTaJC6900<e
RP03=HTeRSF:00XeRP0E=H/aRRTW6<@Y:3V[=H/PiRTY@NheS1RU1204@@A0144<PQcV:DP]BBeY008a
JP<aRP03<FTaJS6:00/aJP04<FT]JBeY;DTGOol001Eoo`04:DPYBBU9:DT4;DT4;FT3;FX9<FX2<HX2
=HX4=H/00cF:<HXaRP07<HX00cF:=J/eZ`03=J/013V/=J`eZcF[0SF;0SF[010icCg=?NdmkCW=>J`e
Zc6:9BLLiAc58@H]JSW<>Ldic0DeS08aS006<H/]BS5[=H`i[CF]0SF<00haS3F<:BT]BSF/=H`aJbe[
:BT]BRU:;D/e[D7`0dHa0TiB00Y:DUJDBU9J]EJeEYEJ]EJDE[ERm`<ic@03>J`ic3W<00Lic0lic@03
?NhmcCW=008ic@03=J`eS3F/00Pic@03?LhmcCW=008ic@04?LdmcSg^@Nl2@Nh5?Nh8?Lh8?Ld2?Lh0
0cW>>Ldi[@02>Jd01CF]@Pm1kcg^?Lh00SV]0SF/13F]13V]13F/13F<0S6<1C6;1C5[00@]JbeZ;FX]
JP@]BP@]JP<]BP8YB@<Y:BQoo`<aS@<aSP03=HhaSSF>00@e[PLe[`Ti[`<ic`0@>Ji1kcg_=J`eSCg>
?Nli[DH@?LheS36<>JdmcSW>=H`3<H`3;F/::DX8;F/8:DX2;FX7:FX2:DX00bU99DTU:0029BP021S4
;DTeRcW<?LdaRSg<?Nd5>J`3>J/5>J`3>J/00cF[=H/eR`0==H/013F:<HXaRS6:135Z00@eRS6:<HXa
RQLaJ@03;FP]B2e8008YA`8]B003;FPaJ35Y008aR@09=HXeRC5Y<FTeRSF9<FP]J35Y008aR@03<FTa
RCF:008eRP03<HTeRSF:00XeRP0>=H/aRRTW7<@aJS5Y8@LLiSF<CU4mcABT12048@848004368HiBDX
:DT2;FT00c5Y<FXaJ@03<FT9<FX2<FT00beY;DT]B@02;DTGOol001Eoo`@YB004:DT]BBe9;DT8;FT;
<FX6=HX9<HX00cF:=J/eZ`08=J/013F/>J`ic3V/0cW<00<i[3F[<HX00S5Z00LYB2DW:DPaRcW<>Ldi
[002>Ld3>Jd01SF/=H`aS2eZ<F/aS0<eS007=Jdi[CV];DXaRcW=<F/00RD800PQ22D89@PYBSW>AS5:
<TYB0diC00Y6<E9d?LmFUEZfE[EJ]EJDF[ERm`<ic@03>J`ic3W<00Lic14ic@07?Ni1kcg^>LdmkTH?
@Nh00Sg^00<mcCW=>J`00SF/0T8?00@mkSg=>Ldmc@8mkP03>J`icCW=00@mkP03?LhmcCg=00HmcA0i
c@06@Nlmkcg>>Lde[CF/0SF<13F/00@e[CV]>Jdi[@<e[0DeS003<H`aRc6;00<aR`DaJ`03;F/]JReZ
008]JPL]BP03;FX]BRU:00<YB@<Y:BQoo`@aS@04=Hde[CF]=Jd2<Hd013F==Jde[CF]3cF^01<ecSW>
>Lhi[Sg>>Lhi[Cg>AQ11l3V]=H`e[CF=<H`eS3V]=HdaJ`02<H`012f<;F`]Jbe[0RU:00<UBRU::DX0
1BU:22e[4c6<00<]Rbe[;FX00ReZ00PaJT7^;DTeRcg==J/mcCg]1SV/0SV[1cV/00<iZcF;=H/03SF;
00<eRS6:<HX01C5Z0SF:0c6:2S5Z00<aJC69<HT01S690S5Y00<aJ2eX;FP00ReX12e800@]J35X<FTa
J@8aR@8aJ@06=HXeRC5Y;FPaJC690c5Y00<aRCF:<HT02C6900<aRSF:=HX00SF:00daRRTW7<@eRbTX
8>HYBD7_CU4i[B3W12048@02120010aR6<DU9bU80ReY1S5Y1C5Z0S5Y0beY1Re95goo000EOol5:DP2
:DT3;DT6;FT=<FX3=HX:<HX00cF:=JXeZ`04=J/2=H/3<H/2=H/2=J/013F/>J`i[3V/0SF[00Ti[3F;
<HXaRSF[>J`icCV/>Jd00SW=0SW>01LicCV]=Jdmkcg>>Lde[3F<=J`icCg^<H`Y:Be[>Jd]JR479@PU
:BD89@T]Bcg?00964@0>AS5>DdYBCU=6<Dic;D]BM5[FF[EJeUJdF[ERm`<ic@03>J`ic3W<00Lic0li
c@05?NhicCg=@NhmcP02=J`02Cg^=J`e[3V/>LdmcCg^@Ni1k`03=J`01cV]>LdmkSg^@NhmcCg>00<m
kP03?LdicCW=00Pmc@Pic@8i[@07>LdicSg>?Nhmkd7_>Ld00SV]00De[CF/=J`e[CV]00He[08e[@03
=J`eS3F<00DeS0@aR`DaJ`8]J`D]JPP]BP@YB@@Y:BQoo`HaS08a[08a[@03=Jda[CF]00He[@8ec@03
=LhicSG>00Le[@04=Jhe[CV^>Jh2?Ll01cW>=Hd]Jd7`F[I_Ng=l009_F`06Mieg_G_NNmikgg_o0Woo
00=kog_ONmh01W_N00=kgg_NNmh01W_N5Woo00AkoWonMi]cNP8aJP04?Ldi[3F[<FX6>J`2>J/5>J`0
0cV[=J/eZ`02=J/E=H/5=HX3<HX8<FX9<FT012eX<FPaJ35X135Y12e80beX00PaJ369;FPaJCF9<HTa
J2eX0c5Y00HaJ35Y<HTeRC69<FT8<HT0635Y=HXeRS6:=HXaRRTW7<@U1b3V9BPaJSV/=H`]BRDX1204
@@A0120<HQS59BLYB08]B@03;FTaJC5Y00<aJ@<aJP03<FT]JBeY00X]BAMoo`005Goo1RU80RU912e9
12eY235Y1c5Z2c6:00HeRSFZ=JXeZSF:<HX2>J`00cF/=J/eZ`03=J/0136:<H/aRcF;13F[0SW<0SV/
00@e[3V/>Jdic@8e[009>JdicCW>>Jde[CF/<H`e[CW>008mcP08>Lhi[CV]=JdY:Be:=JdaJ`8U:08U
:@0=9@T]BcV^>Lhi[Sg_BU96<DiCBS9BLb48CU<00e[F00=F]EZeH_L00SW=00<i[CV/>L`023W<3cW=
00e23cF/<H/i[3W=<H/]BBeZ6:DHaAc57>HQ1`029BP012TX>JdmcD7^0T8?00DmkSW==J`mkSg>00<i
c@03?LhmkT7_00PmcPPmc@@mcP@mkP05>Jde[CF/=J`e[@03>Jd8=J`7=H`00c6<<H/aR`02<H/4<F/2
;F/5;FX00be:;FX]JP03;DX2:DX5:DT4:BTXOol6;H/00c6;;H/a[007<J`2=J`00cF]=Ldec@03=Ld0
1CF/<J`e[3F/=Jd00SG=00/e[CW>>Jhi[Sg_>JhaK3F=?Lm>DfLI009k_P03Mkioggoo035oo`05Ooio
gBeZ<FXmc@03@Nh;>J`2=J`3=H/00cV/=J`e[00D=H/00cF:=H/eRP02=HX4<HX8<FX@<FT8;DP00c5X
;DP]J002<FT01ReX;DPaJC5Y<FP]J08aJ@8aR@XaJ@<aRP0D=HXaRRTW7<@LaBD7:DT]BBU9:BTU21cV
1248@@A1140<HQSU9BLYB08]B@03;FTaJC5Y00HaJ@03;FT]BBe900X]BAMoo`005Goo1RU800@]BBU9
;DTYB@<]B@04;FT]BBeY;FT7;DT7<FX;<HX3=HX3<HX2=J/3=H/00cF[=J`e[002>J`00cF/=J/eZ`03
=J/0236;=H/e[3F/=H/aRcF<=J`2>Jd2>Ld02cW>>JdeS3F<:DTe[DYBF[EJeUJDBS400T7_00X]BRU:
=JdaS2DY9@PQ22TZ9BT]BP8eS@0?<F`mcdiBAQ1>LdYBDY@PidiBF]IJ]E[EE[AJeF<G008ic@03>Jdi
[3W<00Lic10ic@08:BTLiRDX@PmS5fmkMkakg@=oo`03OmikgGNl009cV`0@F[EJeE[FF[E>LSg^;FXU
212346<@PaB46<HU:36;=Jd@?Nh02dH@@Q123cg_?LhicSV]=JdicSW=>Jd00SF]00<e[3F]=Jd00SF]
13F/00LeS3F/=H`e[3F<<H`eS003<H`3<H/5<F/2;F/4;FX2;DX3;FX2;DX5:DT00bTY:DTY:@03:BTX
Ool2<H/00c6<<J/a[003<J`3;H/3<H/00c6<<J/a[005<J`4=J`3=L`3=Ld013W>=Hdi[Sg_0SV^00=>
Df/jOol00Woo0WoO0Woo00=g_GooOol01Woo0g_o9Goo0Won00I1kSg=>J`aJSF;?Ld9>J`2=J/5=H/2
>J/00cF[=H/eR`0;=H/00cF:<HXaRP05<FX2=H/3=HX3<HX8<FX8<FT00c69<FTaJ@05<FT9;DP012U7
;DPaJC5Y0Re800@]J35Y<FT]J08aJ@03<HTaJC5Y00TaJ@<aRP05=HXaRRTW7<@U1`02;DT01RD7:BPe
RbTY58<88@<8@@04368LiBDX:DP3;DT01ReY<FTaJC5X;FTaJ@<]J@T]B@<]B1Moo`005Goo0bTX0bU8
00@]B2U8;DPYB0/]B@03;FTaJC5Y008aJ@`aJP8aRP03=HXaRSF:00heR`07=J/eRcF[=H/eZcF;=J/0
13F/00DeRcF<=J`e[3F<008ic@0F>JdicCg>=J`]BRU9>Je:DUJeF[EBU4iBBU8mcRe:;FXi[Be[8@PU
22DY8@P2:DX04SF^=HdYBSg_BU9>Ld8@CW9242U9@Q1S5dibF[EJeEZdCW4mkP8e[003?Ldic3W<00Hi
c004=Lde[CF]=Ld2>Ld2>Lh03SW=?Ni23d8??Nhe[C6;;F/Q22U:>LiBU6]JMkd6Ool037_NMkecW7>L
IcUW>6<HHaMNmU:C@PlaS08Q20039BPU:BU:008]J`06<H/]Jc6;<H`e[CV]1CW>00<mcSg_?Nl00cg_
00]6<D8@>Lhe[CF<=JdicSg^=JdicCW>008e[@05<H`e[CF]>Lde[@03=J`00cF]=J`aS004=J`2<H/2
;FX0236;<H`eS3F/=H`aRbe[;DX2;FX3;F/3<F/00be:;DT]BP08:DT2:BT39BPXOol01Re[<F/aJc6;
<H`aR``aS003=H`e[3F/00Xe[08e[@07>LhmccW>>Ji64EkGLg/06Woo00=kggooOol077oo00MooSV]
@NhaJcF<APleS005>J`00cF/=H`eS002>J/3=J/8=H/3=HX8<HX8=HX8<HX@<FT8;FT2<FT3;FT<;DP7
;FT8<FT01c5Z<HXaJS5Y<HXaJRTX008Li@03:BPaJBeY008aJ@088@H@HPPP244880@P364La@8U1`@]
B0@]J08]J@<]B@04;DP]BBe8;DT4;DP3:DPGOol001Eoo`DY:0<YB08]B0/]B@8]J@<aJ@haJP8eRQDe
R`07=J/e[3F/=J`eS36;;FX00S5[00`aRcF/=J`eS3F/>Lde[2eZ:DTeS48@CU82CW<01dibCW<icBTY
:DTeS2e:008Pi`0I8>PU2BU;:D/icSF^;D/mcTH`=J`]JS6<<H/YBDYAG_IBTTiaDW9>LDH_>LdeZcF/
>Ld023W<0SW^13W>00lmkSg_=Lde[C6<;F/YJRe[<J`ecEJeF_MW>G>LNmh047oo00=kgW>LJeX00W>L
00I_Vf]JG_MBU4Ha?Nl3>Lh013F]<H`]JbU:0bDY00@]Jc6<>Lhmk`92408icP<mk`8icP04=JdaS36<
=Jd5>Lh2=Jd013G==J`e[36/0SF/00@]JRe[<H/aS0@e[008<H/]Jbe::BTYBBe:<F/eS0D]J`<]JP03
;DX]BBe900PYB@03:BTY:2DX008U:2Qoo`PaK0DaS0PeS0<e[08eS0De[008=Jdi[CV^=JdeSCW>CW=_
FcMoo`9og`04MiacNcV/@Nh2=H/00cg><FXi[003>J`4=H`013V[=J/eZcF[1CF;1cF:236:23F:236:
6C5Y0beY12e92Re80Re90beY2S5Y00<aJS5Y<FT00S5Z018YB23V8>DY9be8:DP]B2e99@HDP`PQ3448
8@PP488PiRTX:DP5;DP3;FP012e8;DT]BBe922e812U85goo000EOol8:BP00bU8;DP]B00;;DT3;FT2
<FT=<FX2=HXE=H/01SF[=J`e[3F/=H/aJ`<]JP0X<FXaRc5Z;DX]JS5Z;FXYBBD8:DTaJcF<=Jdi[Cg>
@Nli[BDY:BTeS36;:DTY:BD8:DX]JbU:=JdaS2D8;DX]Jc5[;FXY:B47:DTmkTH?>J`2@Ph01D7^?Ldi
[3F[=J`02CW<00DaRcF/>LdicCF]008a[00:=J`icSF/;F/]JSF/BU5O5fnKNmhMOol00g_NMke_N`02
Kg/016]JIcUNmeJe0Tic00a:DTHa>Lh]JbDY6<HDYAS68@PU:Be[<H`3=Jd0148@>Lhe[C6<13F]00@a
S3F]>Lde[@<aR`04=J`icCW=>Ld2=J`0136;;F/]JSF/0SF<00DaRc5[;FX]BRU900<aJ`03;F/]JReZ
008]JP03;DX]BBU900LYB@03:BTY:2DX00<U:2Qoo`03;F/aJc5[00PaK0DaS0HeS08e[0<eS0@e[008
=JdicSW>?Lm1l4XbG]IcO1Uoo`03Nmmoogoo009oo`03Nomoogoo00AcW@9cW003KiacO6ml00M_O005
HaURnF;iG_QNf002F[L02EZfCW=BLc5Z?Ldi[3F/@NheR`04>J`013F/=H`eS3F;13F[0cF;23F:00<a
RSF:=HX01SF:236:435Z435Y12eY0be912e80RU80RTX00<Y9bU8:DP00Re800<]BBeY<FT0335Y00T]
BC5Y<FX]B2D76:<PiBDW:BL00RTX00<LiA1Q22000PPQ00D8@A228>DU9bTW00D]B005;DL]Ibe8;DP]
B@08;DP3:DP3:BPGOol001Eoo`TY:08YB003;DP]BBe900/]B@8]J@03<FTaJS5Z00XaJP8eRQDeR`08
=J/eRcF/=J`eS36;<FX]JP@aJP<]JP04;DTYBBeZ;F/3<F/01S6;=J`icCF/9@PY:@8e[00H<H`aJbU:
<F`eS2e;=JdeS2TY;F/]BSW=@Nl]JR3W;DTaJRDW8>HicCW<=J`eZcF/0SV/00<e[3V/>J`01CV/00de
[3G=>NhmkcW><H/U:Ad77>MB]5kgKg]koP0NOol2Nol:Ool4Nmh7Ool017_NLia_NfLi0f<H00A:DSW>
8@P@Q08<H`8@Q003;F/aRc6<008e[005=JdicCW>;FX]J`02<H/0336<<J`a[36/9BPY:BU9;DX]Jc5[
;F/]JP<aJ`8]JP<]BPXYB@03:BTY:2DX00<U:2Qoo`@]J`03<F/aK35/00HaK0@aS0/eS0<e[003=Jda
Jc5/008aS004;D/U2AS658D336<246<346@836@236<336@02`b448@@Q1BV7>LQ:BDY8@TLj2499BT0
0bU;00<]Jbe/;F`00S6<235]1cF>00PeSCV/?Lh]BSV]>Ldi[47^0cV/0SF/0cF<00<eRcF[=J/00cF;
23F:0c6:23F:236:435Z435Y0ReY0be91Be800<YB2TX:BL00RTW00@U9bTW:BPY:08]B003;DT]JC5Y
00T]J@0?<FT]BBe8;DTaJBeY:BPDPQc49@HY9bU89BLHX`PP00@<@@0458<LaBD69@L2:DP00be8;DL]
B002;DL7;DP5:DP3:BP2:BLGOol001Eoo`039BLY9bTW00LY:08YB003;DP]BBe900/]B@8]J@03<FTa
JS5Z00TaJP8eRQDeR`8eZ`8e[005=H/aJReY;DTYB@02;FX0235Z<H/aRc6:<FXaRbeZ;F/2<F/01be[
<F/aRcF<<H/U22DX008aR`8aJ`0=:BTeS3V];F/i[CW>=H`mkcg>=Ha23cF<9BP00S6;00@U9bU8>L`e
[08eZ`04>J`ic3V/=J`7>J`033F/>LdicCF]<H/YBBDX8BPU:6LhKgYkgP=oo`05OoikgWooOomkgP0I
Ool9Nmh:Ool01W_NOomoog>LJeYS60=Nm`04F]I:DSF]9BT47>L022488@LM1bDX:DX]JbeZ:DT2>Ld0
13G==J`aS36;0ReZ00<i[CF<<F/00be:00DaJc6;<F/aJbe[008]JP<]BPPYB@8Y:@03:BPU:2DX00<U
:2Qoo`H]J`HaJ`8aK0@aS0/eS08e[009=Jdmkcg_@O1243g_<H`Q21RU00<Q20DU20lU:@039BXYBRe/
008e[@04<HdaS36==Jd2<H`2<Hd2=Jd2=Jh8>Jh2<Fd00c6==HdeS@02=Hh00cF]?Ldmc@03>J`0136;
>J`aJSV/0SF/1CF;00@eZcF;=H/eR`PeRP@aRPPeRPPaRQ0aJPPaJ@P]B@04;FT]BBe9;DT5;DP2:DP0
0bTX:BLY9`029BL3:BL01BTX;DP]B2e9;FT022e900D]B2eY;DTYB2e8008aJ@09;DPHY1c48>DPiR46
7>DDPPPP00<<@@04488HY23V9@L2:BL00bU8:DLYA`02;DL6;DP3:DP5:BP4:BLGOol001Eoo`8U1`8U
9`03:BLY:2TX00DY:003:DP]B2e800d]B@03;FTaJC5Y00TaJP8eRQDeR`07=J/e[3F/=J`eRbeZ:DT0
0RDX00<Y:2DX:DP00be900@]JS6;;DX]BP8]JP08<F/aRc6<=H`e[2TY:DTaJ`<]JP049BTaS3F];DX2
<F/02RU9=H`aJbeZ?Nhe[2eZ>Ldi[36:0SW<00<i[3F/>J`00SW<00<i[3F/>J`01cV/0cF/00HicDHa
E]E[FG>LOol2Ooh00g_MNkekg@0BOol00g_NOomoo`05Ool00gNmNmioo`0=Ool2Mkd2Nmh<Ool017_N
Mke_Nf]J0fLi00mS64YA@PlicSW=>LhecBeZ9BPDYAS57>HQ1bDY:DX00ReZ00<Y:Be:<F/00SF<00@a
JbeZ:DX]J`<]JP@]BPHYB@<Y:@8Y:0@U:0039@Qoogoo02Ioo`8]B`P]J`HaJ`8aR`8aS0/eS007=J`a
S35[;F/aJcF]?Lh00Sg_1SW>0Sg>23W>23g_00@icSg_@O0mk`8icP07>JhicSg_?NlmccW>>Ll00cW>
23g?014i[SW>>JhicSV^>Lhi[SW>?Ldi[3g==H/mcCF;>J`eRcF/00XeR`PeRP<aRP8aJPPaRPPaJQ0a
J@P]J@P]B0<]B@D]B0<YB003:BPY9bTW008Y9`069BLY9bTW:BLY:2U80Re822e900<YB2e9;DT00Re8
0ReY00@]B1cU6<@DPP<@HP03364<@0PP00888005488La23V9@LY:002:BL5:DL2;DP3:DP5:BP7:BLG
Ool001Eoo`@U1`049BLY9bTW:BL4:BP2:DP3;DP;;DT2;FT2<FT8<FX2=HXE=H/01cF[=H/eZcV/=J`a
Rc5Z008]J@08;DTU:2D79@LQ1QcV9@L]B@@aR`0;=H`e[3V]>J`aRbTX:DT]JRU9;DTaJ`02;DX02cF<
;DX]BRTY8>LY:BD8=H/icCV/=H/00SV/00@eRcV/=J/e[08i[0`e[08mkP08@Nm:DEkfLi]ooWooOmio
oP=oo`03OoiogW_M00Ioo`03OoiogWoo01Ioo`03Nmioogoo01=oo`03Nmig_GNm00Uoo`0EOoig_G>L
Kg][FEkgE[EBTdib@Q0icBU:7>LDY@aS6<DLiRD8;DXaJc6;008aJ`<]JP@]BP03;FXYBBU900<YB@8Y
:@<Y:0@U:0039@PU1goo02Moo`@]BP03;FX]Jbe[00D]J`@aJ`<aR`03<H`eS3F<008eS003<H`eS3F<
00DeS003@NlicSF<008]J`03<H/eS3F]00Hi[@8ic@08>JdicCV]>Ldi[CW=>Jdic@@icP04?LhicSg>
>Lh3@Q02?Nl01Sg^?LhicSg_?Nhmc`@icPTi[P<i[@0==JdiSCF==HdeS3V/<FXmcC5Z@Ndi[3g<>J/0
2SF;23F:0c6:0c5Z235Y235Z235Y42eY2Re91Re80bU81BTX1BTW0bTX22e800<Y:2e9;FT00Re80Re9
00DYB2467<@DPQ22008DPP09468@HA1Q340<HARS7>DPiBD600HY9`03:DLYB2U800<YB08Y:0PY9`<U
9aMoo`005Goo1BD70RDW00<Y9bTX:BP00bTX00<YB2e8;DP00Re82be900<]JC5Y<FT0235Z0SF:5CF;
00<eZc6:=J/01SW<00/mkC6;:DPU1ac56:@LiRU89BLQ1b3V008LiP0E8>HQ1b479BPLiR479BPQ1bTX
<FX]JRTY=H`eK3V]=H`aJcg==J`eS3V/008eR`8i[004>J/eRc6:=H/2=J`3=J/9=J`04SW<=J`aRc6;
=H/]JR476<DQ1acV5:@HaBU9BU5_FGooNmiooP=oo`03Omioogoo00=oo`03Ooioogon01Yoo`9kgRIo
o`08Omi[FE9c>JdY:BDX;DXaJ`H]BP8]JPDYB@03:BTY:2TX008Y:0@U:0039@PU1goo02Moo`D]BP<]
JP05;F/]JRe[;FX]J`03<F/3<H/2<H`3=H`2<H`6=H`00c6;<H`e[003>Jd00cF/=H`i[@06>Jd00cW=
>Jdi[@0:>Jd2>Ld013W>>LdmcSW=0cV]00<icCV]>Jd063V]00DmcC5Z?NdaJT7]008eR`03;FTeRcF;
00PeR`PeRP<aRP<aJPPaJ@PaJPPaJAP]J@8]B@H]B08Y:0HYB0PY9`P]B009:BL]BC5Y;DT]B2e9;DPY
:2TW008U1P069BLY9bD67<DHY23V0Qc400DU1RTW9BLY9be800LY9`8YB0<Y:0PY9`@U9aMoo`005Goo
1BD700<U9bTW:BL022TX0Re82be900<]JC5Y<FT03C5Z00<aRSF:=HX00SF:23F;00@eZcV[>J/eZ`8e
R`PeZ`0;>L`aRRU89BLLaA226<@YB2477>HHa@026:@01QS57>HQ1acV8>HU1`8U:003:DT]JS5[00Le
S003>H`eS3F;008eR`@iZ`03=H/eZcF[00XeZ`<e[008>Ldi[3F/<H/]JRe9:DPY:0<LiP0;8@L]BD7^
E[AW66;gIaQ_FWNLOmiooP02Ool5Omh00gonOomoo`07Ool00goNOomoo`0aOol02G_NOomoogNmOomk
_F<GAS4eS002;FX00be::DT]BP02;DX2:DX3:DT00be:;DT]B@03:DT2:BT01RTX9BPU:2DX9@PU1`8Q
1bQoo`<]BPD]JP03;F/aJc5[00HaJ`DaR`8aS08aR`@eS08aR`<eS003=J`eS3F/008e[008=Jde[3F]
=J`e[CF/=Jde[0Pi[@03>Ldi[CV]00<i[@8ic@04?NhmcSV]>J`3>Jd00cV/>Jdi[@0C>Jd00cV/=H`e
S002>J`3>J/6=J/5=H/9=HX01S5Z<FTaJSF:=H/aRPTaJ@8aRP<aJP/aJ@8]J@8aJ@8]J@03;DT]B2eY
00P]J@03;DT]B2e8008]B004;DT]JBe9;DT8;DP3:DP5:BP6:BL00bDW:BLY:00:;DP022U8:BPY:23V
8@HU1RD79BL3:BL38>D29@H00bDW:BLY9`08:BP5:BL59BL39@L39@HGOol001Eoo`DU1`8U9`03:BLY
:2TX00HY:08]B0/]B@8]J@03<FTaJS5Z00/aJP8aRP<eRPTeR`8eZ`<eR`TeZ`09;DTU9bD76<@<HA22
6<D@Pa22008<HP06468DY1S57>HQ1bD70RDX00DY:2U9;FXaRcF;008eJ``eR`03=J/eRcF;008eR`Te
Z`<e[08ic@04>L`i[3V/>J`2=J`2>J`043F;;DTU:2478@HQ1bD7:DTaRcg>AS1>LU:CEYA[FGNL47oo
00=oggoNOmh0:goo00Ag_WooOomkgP=oo`08JeY23cV]<F/]BRe[<F/]J`@]BP8YBP<YB@03;DXYBBU9
008YB@03:BTY:2TX00@U:0049@PU1b478@LXOol4;DX7;FX8<F/7<H/4=H`2<H/4=H`<=J`>>Jd2>Ld0
0cg^?Ldi[002>J`00cV]>J`i[00E>J`00cV<=H/eR`03>J/3=J/7=H/3=HX5<HX3<FX0135Y;FT]BBeY
0S5Z00<aJBeY<FT01c5Y135Z335Y0ReY0S5Y00@]JBe9;DP]B0P]J@8]B@@]B08]B@T]B0<YB0DY:0LY
9`049BLY9bTW:BP4:DP5;DP01bU8:BPY9b469@HU1bDW00@Y9`@U1P049BLY9bTW:BL8:BP4:BL49BL4
9@L49@HGOol001Eoo`HU1`8U9`PY:003:DP]B2e800/]B@8]J@haJP<aRP8eRQDeR`0:=J/]JBU8:DPU
9ac46<@LiART5:@25:<011S47>DQ1RDW1BTX00@YBC5Z=H/aJPDaJ`03=F/eJSEZ00<eJP@eRP<aRP<a
R`8eR`HeZ`8e[003=J/iZcV/00<i[004>L`mc3F;>J`3?Ld3>J`02S5[<FXaJS5Z;DTY:BTX9@PY:2e9
0S5Z00@eRd7^EY=W60Qoo`03Omioogoo02eoo`0<NmmoogooNmmcW6mKF]LmkbU::DTYBRe:0S5[00<]
JRU:;DX00Re:0RU:1RU900<Y:BTX9BP01RDX0RD70R47:7oo00@YBBe9;DT]B@8]BPH]JP<aJPDaJ`Ha
R`04<H`eS3F<<H`2<H/013F<=H/eRcF<33F/23V/00<i[CV/>J`00SV/00<i[Cg=?Ld00Sg=3CV/00<i
ZcV/>J`01SV/00DiZcV/>J`i[3V;008eR`03=HXeZcF[00<eR`LeRP<aRP<aJPHaJ@05;FT]BBe8;DP]
J@0;<FT2<FX><FT00be9;FT]J@02;FT00be9;DP]B00:;DT4;DP2;DT5;DP7:DP3:BP8:BL59BL2:BL0
0bTX:DPYB004:DP00bTX:BLY9`029@H00bD7:BLY9`02:BP00bTW9BHU9P08:BL6:BP2:BL39BL59@L6
9@HGOol001Eoo`PU1`03:BLY:2TX00HY:08YB003;DP]BBe900X]B@03<FTaJS5Z00haJP8aRP03=HXe
RcF;00TeR`03<HXeRSF:00HeRP07=J/aRReY<HXeRbeY;DP00Re90RU80RTX00<YB2e9;FT00RU900LY
B2DX9BPYB2eZ=H/]B@02;DX4<DX8<FT2<FX7<HX00cF;=J/eZ`07=J/7=H/013F[>J`i[3V/0Sg=0T7^
00DmkSg=?LdmcCW=008i[@05>J`mcT7_@Nhmc@02>J`01Sg=:@TY:BD98>PLaP8HYP057<HY:Sg?G]Ig
W@04Ool00goNOomoo`0VOol017_OOomkgdYC0bU:0SF<00<aRbe[;DX00Re:00@]JRe:;DX]BP8YBP@Y
B@03:BTY:2TX00LU:0039@PU1bD7008Q1bQoo`@YB@<]B@03;DX]JReZ00D]JP03<FXaJc5[00DaJ`Xa
R`<eR`8eS0Xe[0di[004>JdmcCg=?Ld6>J`00cV[=H/eR`03=H/2=J/00cV[>J`iZ`06>J/4>H/013F;
=HXeRSEZ0SF;1SF:0c6:0S5Z1C5Y0ReY0Re90Re800D]JBe8;DP]B2e9008aJ@03<FXaJC5Y00`aJ@X]
J@8]B@<]J@03;DT]B2e800T]B@H]B004;DT]B2e8;DP3:DP2:BP2:DP3:BP8:BL49BL01BD79@HU1RD6
9@L012TW12TX0RTW00@Q1RD69@HU9a0Y9`@Y:0<U9`<U1`PU1P8Q1QMoo`005Goo22D70RTW22TX0RU8
00<]B2e9;DT02Be90S5Y435Z0S6:00DeRSF;=H/eRcF:00HeR`TaRP04=HX]JBe8;FT2=HX4<HX00beZ
;FT]B@03;DT2:DP01RTX9BLU9bTX;FTaJP@]:@@]B@<aB@DaJ@@aJP@aRP8eR`HeZ`03>L`i[3V/008i
[0<iZ`04@NdmcCV/>J/4=H/4>J`013g=@Ni5kdH?147^00/mcCV<<DXY:3E[=F`aJbe::BTU22CX008P
j008<F]:<EkFIaQ[6FmJMiegW2Qoo`07Nmikgf<I;D/DYRDZ<Hd00S5[00H]Jbe::DTYBReZ<H/3;DX2
:DX3:DT2:BT00bTX9BPU:0029BP39@P49@L28@LXOol6:DT3;DT2;FT6;FX2;F/5<F/:<H/5=H/00cF[
=H/eR`06=H/00cF/>H`iS005>H`6>J`2?Ld00cf/>J`i[004>J`00cV[=H/eR`03=H/;>J/01SV:>H/i
RcV;>HXeRP8eJPLeRP03<HXaJC5Y00HaJ@8]J@04;DT]B2e8;DP3:DP01bTX:BLY9bTW;DP]JC5Z00`a
J@<]J@`]B@03;FT]BBe8008]B0P]B@P]B0@YB0<Y:003:BLYB2TX008Y:0PY9`@U9`039@LU1RD6008Q
1P049@HU1bDW9BL7:BL01B3U8>HU1RD69@L00bDW00<Y9bTV:BH00bDV00<U9bD69BL00bDW12DX12D7
22D60b4600<PiWooOol05Goo000EOol89@L29BL2:BL8:BP00bU8;DP]B009;DT2;FT2<FT@<FX01c6:
=HXeRSF;<FXaRSF:008eR`03=HXaRS6:00TaRP05;FT]B2eX;FTaR@02;FT5;DT2:DT3:DP02BTX9BLU
9bDW:DP]JBTX;BP]:@05;BP2<DT01358<DTaB3580S5Y135Z136:13F;13F[0cV[23V/00<mcD7]@Nh0
13g=0SV/00HiS3F;=H/eRcg==H/2<FX01CV/@Ni63dH??Jd00SV^0Sf^00di[CF<<F/eS2dZ8>PLYQAT
46<Pac5/JeYkgP0XOol036ml>LlHabTZ>Jh]K2U9;DX]JS5[;F/]JPD]BP8YBP@YB@03:BTY:2TX00@U
:0PU1bQoo`8YB0HYB@@]B@03;FT]JReZ00D]JP04;F/aJc5[<F/2<H/4<F/6<H/D=H/3>H`3>J`2?Ld2
>J`00cV[>J`i[002>J`5=H/<>J/5>HX2=HX00cEY=HXeRP06=HX8<FT01BeY;DT]B2e8:DP00RTX00@Y
9bD69@HPiP8Pi@039@HYB2eY00P]J@04<FT]JBeY;FT<;DT00be8;DT]B@02;DT2;DP00bU8;DP]B009
;DP2:DP3;DP012U8:BPY:2TX12TW0bTX22TW0bDW0RD72BD600<U1bDW:BL00RTW0RDW0R3U00<Q1RD6
9@H00RD700<U1RDV9BH00RDV12D60RDW12D700<U22D79@L022D60b46123V5goo000EOol00bD69@LU
1`069@L29BL00bTW:BPY:006:BP2:DP3;DP8;DT2;FT00c5Y<FXaJP02<FX00c5Y<FXaJP09<FX2<HX2
=HX2<FX0136:=HXeRS6:0S5Z2S6:00<aRBeY;FT00ReY00<]B2e9;DT012eY0Re900PU:2TX:BPU:2DW
:BPYB2eY0bTX1BdX0S5900@aB359<DPaB08aJ@<aJPDaRP04<H/eRcF;=H/4=J/4=H/2>J/3>J`3>J/0
1CV/>J/eRS5Y=H/00SV/00<m[Cg=?Ld00T7^00<eRcV/@Lh00TH?00=1kSF;<FX00d7_00m:4DiBCU9:
4D7??JhY2AAT204000@06:DaJf<HMkd0:7oo00IW6BDZ6<HaS3F^9BX2<F/3<H/00be[;DXY:@03;DX2
:DX5:DT00bTY:BPU:0039BP58@L39@LXOol3:BP00bU8:DTYB@02:DT5;DT2;FT6;FX3;F/2<H/4<F/6
<H/4=H/7<H/<=H/00cV<>J`i[002?Ld4>J/01Cg<>J`iZcF;=HX00cF;1CV[2cVZ0SV:2SF:235Y00H]
JBe9;DP]B2U8:BP2:BL28>D01QcU7<@La23U:BL]B@/]J@8]B@d]B0<]B@8]B003:DP]B2e800T]B08Y
B0<]B0<Y:0DY9`8Y:0PY9`<U9`<U1`XU1P039@LU9bDW00<U9`058>DPiR469@HU1`039BL012D69BDU
9BD60bDV00<U1RD79@L012D700<U22D79@L012D61R460R3V0b3U5goo000EOol29@H89@L00bDW:BLY
9`08:BP00bU8;DP]B002;DP8;DT00beY<FTaJ@03<FX2<FT;<FX00c6:=HXeRP02<FX4<HX2<FX8<HX0
12eX;FTaRC5Y0ReY00@]J2U8;FT]J@8]JP8]J@8YB0089BLY:2U8:DPY:2U8:DT]J@@Y:0@]:08aB@04
<DPaBC58<DP2<FT00c5Z<HXaRP05<HX2<H/3=H/3=J/2>J/6>J`01Sg=>J`eRcF;>J`mc08mc@03>J`m
[Cg=008mc@03?Jdi[3V/008mc@0H>J`iS3F;>Ja1kTX@?Lhi[Cf^AO1><TiBAO0i[Cf^:BTHQ@a32044
01B4:BUJeW>L9Woo00YkggooG_P]Jb49:D/]Jc5/<H`aJ`<]BP8]J`04;FX]BRe:;DX2:DX6:DT00bTY
:BPU:0029BP68@L29@LXOol4:BP00bU8:DTYB@03:DT5;DT2;FX00be:;FX]JP03;FX00be[<H/aR`04
<F/7<H/3=H/7<H/<=H/00cV<>J`i[002?Ld4>J/2?L`00cV[=H/eRP02=H/3>J/00cV/>J/iZ`08>JX3
>J/013VZ>HXeRSF:0SF[1SF:0S6:1S5Y0ReY00@]BBe8:DPY:08Y9`8Pi@067>DLa1c48>DY9c5Y2BeY
0be93Re80Re90be800<YB2e8;DP022e812U80Re800<Y:2TW:BL01BTW0RTX22TW0bDW0bD70RD600<U
1bDW9@L00RD60R460RD600XU1bDW9BLU9bD78>HQ1RD69@LU9`<Y9`039@HU9BDV00@U9P03:BLU1bD7
00@U1`039@PU1bD700<U1PDQ1P<PiP@PiAMoo`00ogooogooEWoo003oOoooOomFOol00?mooomooeIo
o`00ogooogooEWoo003oOoooOomFOol00?mooomooeIoo`00ogooogooEWoo003oOoooOomFOol00?mo
oomooeIoo`00\
\>"],
  ImageRangeCache->{{{0, 595.313}, {211.813, 0}} -> {-0.0539635, -0.0178609, 
  0.00354088, 0.00354088}, {{15.1875, 284.188}, {206.75, 
  5}} -> {-21.5777, -9.85978, 0.999266, 0.999266}, {{311.063, 580.063}, {
  206.75, 5}} -> {-317.236, -9.85978, 0.999266, 0.999266}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pedagogy", "Section"],

Cell[TextData[{
  StyleBox[
  "A typical course is organized as an alternating sequence of traditional \
and "],
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  StyleBox[
  "-based lectures and exercises. Frequently, a single class session mixes \
the two types of classroom activities. Traditional lectures are used to lay \
the theoretical foundations, while the laboratory sessions reveal \
implementation details and provide opportunities for experimentation, \
visualization and testing. The two forms of instruction complement each other \
well. Theory and implementation reinforce each other building a deeper \
understanding of the subject matter. To achieve this end, "],
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  StyleBox[
  " is used in a variety of ways. As a productivity tool, it helps students \
solve many of the problems found in standard undergraduate textbooks. The \
student benefits by spending more time formulating and understanding the \
problem than on algebraic manipulation.  There are many examples of \
\"calculator-like\" problems easily solved by "],
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  StyleBox[
  " with typically a single, simple command. Examples of algebraic evaluation \
common to many introductory undergraduate courses include:"]
}], "Text"],

Cell[TextData[StyleBox[
"\[FilledSmallSquare]  evaluation of Fourier, Laplace and z-transform \
integrals and sums"]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Sum]\+\(n = 0\)\%\[Infinity] r\^n\ 
        \[ExponentialE]\^\(\ \(-\ \[ImaginaryI]\)\ \[Omega]\ n\)\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \(E\^\(I\ \[Omega]\)\/\(E\^\(I\ \[Omega]\) - r\)\)], "Output",
  CellLabel->"Out[21]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]\_\(-\(\[Pi]\/2\)\)\%\(\[Pi]\/2\)\[ImaginaryI]\ \[Omega]\ 
          \(\[ExponentialE]\^\(\ \[ImaginaryI]\ \[Omega]\ n\)\) 
          \[DifferentialD]\[Omega]\  // ExpToTrig\)], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \(\(\[Pi]\ Cos[\(n\ \[Pi]\)\/2]\)\/n - 
      \(2\ Sin[\(n\ \[Pi]\)\/2]\)\/n\^2\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell[TextData[StyleBox[
"\[FilledSmallSquare]  partial fraction expansion of rational polynomials  \
"]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(H[z_] := \(z\^2 - z\)\/\(z\^2 - 0.9\ z + 0.81\); \n
    Factor[H[z]\/z, \ GaussianIntegers -> True]\  // Apart\)], "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \(\(\(0.5`\[InvisibleSpace]\) + 
          0.352825164504771304`\ I\)\/\(\((
            \(-0.45`\) - 0.779422863405994803`\ I)\) + 1.`\ z\) + 
      \(\(0.5`\[InvisibleSpace]\) - 
          0.352825164504771304`\ I\)\/\(\((
            \(-0.45`\) + 0.779422863405994803`\ I)\) + 1.`\ z\)\)], "Output",
  CellLabel->"Out[48]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["\[FilledSmallSquare]  "],
  StyleBox[
  "solutions to constant coefficient difference and differential equations"]
}], "Text"],

Cell[BoxData[
    \(<< SignalProcessing`\)], "Input",
  CellLabel->"In[1]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(x[n_] := KroneckerDelta[n]; \n
    ZRSolve[{\ y[n] - 0.9\ y[n - 1] + 0.81\ y[n - 2] == x[n] - x[n - 1], \ 
        y[\(-1\)] \[Equal] 0, \ y[\(-2\)] == 0}, y[n], n]\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \({{y[n] \[Rule] 
          \((\((\(0.5`\[InvisibleSpace]\) - 0.352825164504771304`\ I)\)\ 
                  \((\(0.45`\[InvisibleSpace]\) - 0.779422863405994803`\ I)
                      \)\^n + 
                \((\(0.5`\[InvisibleSpace]\) + 0.352825164504771304`\ I)\)\ 
                  \((\(0.45`\[InvisibleSpace]\) + 0.779422863405994803`\ I)
                      \)\^n)\)\ DiscreteStep[n]}}\)], "Output",
  CellLabel->"Out[21]="]
}, Open  ]],

Cell[TextData[
"\[FilledSmallSquare]  solutions of systems of (non)linear equations"], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = 
      Solve[{c0 + c1 + c2 + c3 == \@2, \n
            \t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ 
            c0 - c1 + c2 - c3 == 0, \n
            \t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ 
            \(-c1\) + 2\ c2 - 3\ c3 == 0, \n
            \t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ 
            c0\ c2 + c1\ c3 == 0}, {c0, c1, c2, c3}]\  // First\)], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \({c0 \[Rule] 1\/8\ \((\@2 - \@6)\), c1 \[Rule] 1\/8\ \((3\ \@2 - \@6)\), 
      c3 \[Rule] 1\/8\ \((\@2 + \@6)\), c2 \[Rule] 1\/8\ \((3\ \@2 + \@6)\)}
      \)], "Output",
  CellLabel->"Out[1]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " helps the student visualize and the instructor demonstrate, many \
important phenomena thus assisting in the learning process. As an example, \
consider the ease with which we can obtain the plot of the transfer function \
and frequency response of the  discrete time system ",
  Cell[BoxData[
      \(TraditionalForm\`H(z)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Here is a surface plot of ",
  Cell[BoxData[
      \(TraditionalForm\`\( | H(z) | \)\)]],
  ", the magnitude of the system transfer function."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot3D[Abs[H[z]\  /. \ z -> a + \[ImaginaryI]\ b], 
      \ {a, \(-2\), 2}, {b, \(-2\), 2}, PlotRange -> {0, 3}, 
      ViewPoint -> {1.925, \ \(-1.620\), \ 2.263}]; \)\)], "Input",
  CellLabel->"In[49]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85625 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0138654 1.01387 -0.0294601 1.01387 [
[.02577 .40163 -12 -6.82977 ]
[.02577 .40163 0 2.17023 ]
[.1155 .31218 -12 -6.98027 ]
[.1155 .31218 0 2.01973 ]
[.21302 .21497 -6 -7.15156 ]
[.21302 .21497 0 1.84844 ]
[.31941 .10894 -6 -7.34826 ]
[.31941 .10894 0 1.65174 ]
[.43591 -0.00715 -6 -7.57649 ]
[.43591 -0.00715 0 1.42351 ]
[.45536 -0.00894 0 -8.97911 ]
[.45536 -0.00894 12 .02089 ]
[.59924 .08958 0 -8.57868 ]
[.59924 .08958 12 .42132 ]
[.73245 .18081 0 -8.24397 ]
[.73245 .18081 6 .75603 ]
[.85613 .26554 0 -7.96003 ]
[.85613 .26554 6 1.03997 ]
[.97126 .34443 0 -7.71613 ]
[.97126 .34443 6 1.28387 ]
[.97126 .34443 0 -7.71613 ]
[.97126 .34443 6 1.28387 ]
[.98371 .40885 0 -7.60973 ]
[.98371 .40885 6 1.39027 ]
[.99683 .47677 0 -7.4985 ]
[.99683 .47677 6 1.5015 ]
[1.01067 .54847 0 -7.38208 ]
[1.01067 .54847 6 1.61792 ]
[ 0 0 0 0 ]
[ 1 .85625 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03702 .40745 m
.44638 0 L
s
.03702 .40745 m
.04265 .41037 L
s
[(-2)] .02577 .40163 1 .51773 Mshowa
.12659 .3183 m
.13214 .32136 L
s
[(-1)] .1155 .31218 1 .55117 Mshowa
.22394 .2214 m
.2294 .22462 L
s
[(0)] .21302 .21497 1 .58924 Mshowa
.33011 .11572 m
.33547 .11911 L
s
[(1)] .31941 .10894 1 .63295 Mshowa
.44638 0 m
.45161 .00358 L
s
[(2)] .43591 -0.00715 1 .68366 Mshowa
.125 Mabswid
.05436 .3902 m
.05773 .39196 L
s
.07198 .37266 m
.07534 .37444 L
s
.08989 .35483 m
.09323 .35663 L
s
.10809 .33672 m
.11143 .33853 L
s
.14541 .29957 m
.14873 .30142 L
s
.16454 .28052 m
.16785 .28239 L
s
.18401 .26115 m
.1873 .26304 L
s
.2038 .24145 m
.20709 .24336 L
s
.24443 .20101 m
.2477 .20296 L
s
.26528 .18025 m
.26854 .18222 L
s
.28651 .15912 m
.28975 .16111 L
s
.30812 .13762 m
.31134 .13963 L
s
.35252 .09342 m
.35571 .09548 L
s
.37533 .07072 m
.37851 .07279 L
s
.39857 .04758 m
.40174 .04968 L
s
.42225 .02402 m
.4254 .02614 L
s
.25 Mabswid
.44638 0 m
.96095 .3518 L
s
.44638 0 m
.44188 .00447 L
s
[(-2)] .45536 -0.00894 -1 .99536 Mshowa
.58985 .09809 m
.58516 .10235 L
s
[(-1)] .59924 .08958 -1 .90637 Mshowa
.72271 .18892 m
.71784 .19297 L
s
[(0)] .73245 .18081 -1 .83199 Mshowa
.84608 .27327 m
.84106 .27713 L
s
[(1)] .85613 .26554 -1 .7689 Mshowa
.96095 .3518 m
.9558 .35548 L
s
[(2)] .97126 .34443 -1 .71469 Mshowa
.125 Mabswid
.47598 .02024 m
.47326 .0229 L
s
.50512 .04016 m
.50238 .04279 L
s
.53381 .05977 m
.53104 .06238 L
s
.56205 .07908 m
.55925 .08166 L
s
.61724 .11681 m
.6144 .11934 L
s
.6442 .13525 m
.64134 .13775 L
s
.67077 .15341 m
.66788 .15589 L
s
.69693 .1713 m
.69403 .17375 L
s
.74811 .20629 m
.74517 .20869 L
s
.77314 .2234 m
.77018 .22578 L
s
.79781 .24026 m
.79483 .24262 L
s
.82212 .25688 m
.81912 .25922 L
s
.86971 .28942 m
.86668 .29171 L
s
.893 .30534 m
.88995 .30762 L
s
.91597 .32104 m
.9129 .3233 L
s
.93862 .33653 m
.93554 .33876 L
s
.25 Mabswid
.96095 .3518 m
1 .5553 L
s
.96095 .3518 m
.9558 .35548 L
s
[(0)] .97126 .34443 -1 .71469 Mshowa
.97328 .41606 m
.96807 .41966 L
s
[(1)] .98371 .40885 -1 .69105 Mshowa
.98628 .4838 m
.98101 .48731 L
s
[(2)] .99683 .47677 -1 .66633 Mshowa
1 .5553 m
.99466 .55872 L
s
[(3)] 1.01067 .54847 -1 .64046 Mshowa
.125 Mabswid
.96337 .36438 m
.96027 .36658 L
s
.96581 .3771 m
.9627 .37929 L
s
.96827 .38995 m
.96516 .39213 L
s
.97076 .40294 m
.96764 .40511 L
s
.97583 .42932 m
.97269 .43147 L
s
.9784 .44272 m
.97526 .44486 L
s
.981 .45626 m
.97785 .45839 L
s
.98362 .46996 m
.98047 .47208 L
s
.98896 .49779 m
.98579 .49988 L
s
.99168 .51193 m
.9885 .51401 L
s
.99442 .52623 m
.99123 .5283 L
s
.9972 .54069 m
.994 .54275 L
s
.25 Mabswid
.03702 .40745 m
0 .60991 L
s
0 .60991 m
.53011 .85625 L
s
.53011 .85625 m
.52766 .66147 L
s
.52766 .66147 m
.03702 .40745 L
s
.44638 0 m
.96095 .3518 L
s
.96095 .3518 m
1 .5553 L
s
1 .5553 m
.44179 .20472 L
s
.44179 .20472 m
.44638 0 L
s
.03702 .40745 m
0 .60991 L
s
0 .60991 m
.44179 .20472 L
s
.44179 .20472 m
.44638 0 L
s
.44638 0 m
.03702 .40745 L
s
.52766 .66147 m
.96095 .3518 L
s
.96095 .3518 m
1 .5553 L
s
1 .5553 m
.53011 .85625 L
s
.53011 .85625 m
.52766 .66147 L
s
0 0 m
1 0 L
1 .85625 L
0 .85625 L
closepath
clip
newpath
.5 Mabswid
.667 .718 .887 r
.49658 .70706 .52844 .72382 .55594 .70541 .52397 .68817 Metetra
.663 .717 .889 r
.52397 .68817 .55594 .70541 .58404 .68693 .55196 .66925 Metetra
.657 .716 .892 r
.55196 .66925 .58404 .68693 .61278 .66851 .58058 .65051 Metetra
.649 .717 .898 r
.58058 .65051 .61278 .66851 .64219 .65028 .6099 .63225 Metetra
.638 .72 .907 r
.6099 .63225 .64219 .65028 .67234 .63231 .63998 .61483 Metetra
.625 .729 .922 r
.63998 .61483 .67234 .63231 .70324 .61446 .6709 .59843 Metetra
.619 .748 .938 r
.6709 .59843 .70324 .61446 .73491 .59609 .7027 .5824 Metetra
.644 .779 .946 r
.7027 .5824 .73491 .59609 .76724 .57606 .73523 .56438 Metetra
.7 .804 .929 r
.73523 .56438 .76724 .57606 .80009 .55323 .76813 .54117 Metetra
.74 .797 .899 r
.76813 .54117 .80009 .55323 .83339 .52757 .80121 .51257 Metetra
.74 .769 .877 r
.80121 .51257 .83339 .52757 .86722 .50012 .83472 .48169 Metetra
.721 .742 .868 r
.83472 .48169 .86722 .50012 .90174 .47212 .86897 .45114 Metetra
.702 .724 .867 r
.86897 .45114 .90174 .47212 .9371 .44421 .90416 .42171 Metetra
.688 .715 .869 r
.90416 .42171 .9371 .44421 .97337 .41654 .94036 .39317 Metetra
.668 .716 .884 r
.46417 .6898 .49658 .70706 .52397 .68817 .49145 .67031 Metetra
.664 .713 .885 r
.49145 .67031 .52397 .68817 .55196 .66925 .51932 .65073 Metetra
.658 .711 .887 r
.51932 .65073 .55196 .66925 .58058 .65051 .54781 .63138 Metetra
.646 .709 .893 r
.54781 .63138 .58058 .65051 .6099 .63225 .57699 .61275 Metetra
.626 .708 .905 r
.57699 .61275 .6099 .63225 .63998 .61483 .60695 .59571 Metetra
.591 .713 .928 r
.60695 .59571 .63998 .61483 .6709 .59843 .63786 .58144 Metetra
.538 .731 .964 r
.63786 .58144 .6709 .59843 .7027 .5824 .6699 .57055 Metetra
.535 .791 .992 r
.6699 .57055 .7027 .5824 .73523 .56438 .70295 .55907 Metetra
.712 .88 .959 r
.70295 .55907 .73523 .56438 .76813 .54117 .73601 .53585 Metetra
.811 .853 .88 r
.73601 .53585 .76813 .54117 .80121 .51257 .76855 .49976 Metetra
.783 .783 .852 r
.76855 .49976 .80121 .51257 .83472 .48169 .80144 .46223 Metetra
.735 .734 .85 r
.80144 .46223 .83472 .48169 .86897 .45114 .83534 .42828 Metetra
.701 .71 .855 r
.83534 .42828 .86897 .45114 .90416 .42171 .87038 .39744 Metetra
.682 .703 .863 r
.87038 .39744 .90416 .42171 .94036 .39317 .90654 .36839 Metetra
.671 .714 .881 r
.43122 .67211 .46417 .6898 .49145 .67031 .45838 .65185 Metetra
.668 .71 .88 r
.45838 .65185 .49145 .67031 .51932 .65073 .48612 .63136 Metetra
.662 .706 .88 r
.48612 .63136 .51932 .65073 .54781 .63138 .51448 .61093 Metetra
.649 .699 .883 r
.51448 .61093 .54781 .63138 .57699 .61275 .54348 .59121 Metetra
.623 .692 .893 r
.54348 .59121 .57699 .61275 .60695 .59571 .57325 .57355 Metetra
.559 .682 .921 r
.57325 .57355 .60695 .59571 .63786 .58144 .60402 .56091 Metetra
.338 .638 .963 r
.60402 .56091 .63786 .58144 .6699 .57055 .63634 .55939 Metetra
.294 0 0 r
.63634 .55939 .6699 .57055 .70295 .55907 .67099 .57317 Metetra
.464 .878 .743 r
.67099 .57317 .70295 .55907 .73601 .53585 .70469 .55291 Metetra
.955 .913 .734 r
.70469 .55291 .73601 .53585 .76855 .49976 .73524 .48887 Metetra
.832 .775 .798 r
.73524 .48887 .76855 .49976 .80144 .46223 .7671 .43906 Metetra
.732 .704 .824 r
.7671 .43906 .80144 .46223 .83534 .42828 .8007 .40197 Metetra
.688 .685 .842 r
.8007 .40197 .83534 .42828 .87038 .39744 .8357 .37077 Metetra
.669 .686 .857 r
.8357 .37077 .87038 .39744 .90654 .36839 .87191 .342 Metetra
.675 .713 .877 r
.3977 .65408 .43122 .67211 .45838 .65185 .42476 .63294 Metetra
.674 .709 .874 r
.42476 .63294 .45838 .65185 .48612 .63136 .45238 .61129 Metetra
.67 .702 .871 r
.45238 .61129 .48612 .63136 .51448 .61093 .4806 .5893 Metetra
.66 .692 .868 r
.4806 .5893 .51448 .61093 .54348 .59121 .50943 .56744 Metetra
.638 .676 .87 r
.50943 .56744 .54348 .59121 .57325 .57355 .53894 .54705 Metetra
.575 .65 .887 r
.53894 .54705 .57325 .57355 .60402 .56091 .56933 .53203 Metetra
.244 .523 .914 r
.56933 .53203 .60402 .56091 .63634 .55939 .6014 .53559 Metetra
.838 .388 .15 r
.6014 .53559 .63634 .55939 .67099 .57317 .63925 .61981 Metetra
.63925 .61981 .67099 .57317 .70469 .55291 .67349 .59582 Metetra
.991 .813 .565 r
.67349 .59582 .70469 .55291 .73524 .48887 .70006 .46603 Metetra
.799 .687 .741 r
.70006 .46603 .73524 .48887 .7671 .43906 .73128 .40675 Metetra
.689 .643 .799 r
.73128 .40675 .7671 .43906 .8007 .40197 .76498 .37075 Metetra
.656 .65 .833 r
.76498 .37075 .8007 .40197 .8357 .37077 .80016 .34149 Metetra
.648 .667 .855 r
.80016 .34149 .8357 .37077 .87191 .342 .83652 .31416 Metetra
.68 .714 .874 r
.36361 .63588 .3977 .65408 .42476 .63294 .39056 .61383 Metetra
.681 .709 .869 r
.39056 .61383 .42476 .63294 .45238 .61129 .41808 .59093 Metetra
.68 .701 .863 r
.41808 .59093 .45238 .61129 .4806 .5893 .44619 .56709 Metetra
.678 .689 .853 r
.44619 .56709 .4806 .5893 .50943 .56744 .47488 .5423 Metetra
.667 .669 .842 r
.47488 .5423 .50943 .56744 .53894 .54705 .50416 .51707 Metetra
.634 .635 .834 r
.50416 .51707 .53894 .54705 .56933 .53203 .5341 .49376 Metetra
.517 .559 .838 r
.5341 .49376 .56933 .53203 .6014 .53559 .56503 .48093 Metetra
.005 .235 .744 r
.56503 .48093 .6014 .53559 .63925 .61981 .59838 .50249 Metetra
.44 .34 .645 r
.59838 .50249 .63925 .61981 .67349 .59582 .63176 .48774 Metetra
.641 .457 .62 r
.63176 .48774 .67349 .59582 .70006 .46603 .66178 .40681 Metetra
.633 .522 .71 r
.66178 .40681 .70006 .46603 .73128 .40675 .69422 .364 Metetra
.612 .575 .788 r
.69422 .364 .73128 .40675 .76498 .37075 .72844 .3355 Metetra
.61 .619 .835 r
.72844 .3355 .76498 .37075 .80016 .34149 .76394 .31059 Metetra
.622 .655 .861 r
.76394 .31059 .80016 .34149 .83652 .31416 .80049 .2856 Metetra
.684 .716 .873 r
.3289 .61768 .36361 .63588 .39056 .61383 .35575 .59485 Metetra
.687 .712 .867 r
.35575 .59485 .39056 .61383 .41808 .59093 .38318 .57086 Metetra
.691 .706 .858 r
.38318 .57086 .41808 .59093 .44619 .56709 .41121 .54537 Metetra
.696 .694 .845 r
.41121 .54537 .44619 .56709 .47488 .5423 .43983 .51781 Metetra
.698 .675 .824 r
.43983 .51781 .47488 .5423 .50416 .51707 .46901 .48751 Metetra
.691 .644 .798 r
.46901 .48751 .50416 .51707 .5341 .49376 .49869 .45448 Metetra
.635 .586 .781 r
.49869 .45448 .5341 .49376 .56503 .48093 .5289 .42515 Metetra
.487 .47 .765 r
.5289 .42515 .56503 .48093 .59838 .50249 .56012 .41116 Metetra
.488 .392 .672 r
.56012 .41116 .59838 .50249 .63176 .48774 .59204 .38892 Metetra
.547 .414 .651 r
.59204 .38892 .63176 .48774 .66178 .40681 .62393 .34949 Metetra
.579 .507 .738 r
.62393 .34949 .66178 .40681 .69422 .364 .65694 .31978 Metetra
.542 .549 .811 r
.65694 .31978 .69422 .364 .72844 .3355 .69158 .30048 Metetra
.569 .614 .858 r
.69158 .30048 .72844 .3355 .76394 .31059 .72732 .28039 Metetra
.603 .66 .879 r
.72732 .28039 .76394 .31059 .80049 .2856 .76396 .25758 Metetra
.687 .721 .875 r
.29353 .59964 .3289 .61768 .35575 .59485 .32027 .57626 Metetra
.692 .718 .869 r
.32027 .57626 .35575 .59485 .38318 .57086 .34761 .5516 Metetra
.7 .715 .861 r
.34761 .5516 .38318 .57086 .41121 .54537 .37556 .52518 Metetra
.71 .709 .847 r
.37556 .52518 .41121 .54537 .43983 .51781 .40414 .49621 Metetra
.722 .698 .826 r
.40414 .49621 .43983 .51781 .46901 .48751 .43332 .46339 Metetra
.735 .679 .796 r
.43332 .46339 .46901 .48751 .49869 .45448 .46302 .42491 Metetra
.735 .646 .76 r
.46302 .42491 .49869 .45448 .5289 .42515 .49307 .37998 Metetra
.395 .479 .828 r
.49307 .37998 .5289 .42515 .56012 .41116 .52383 .3749 Metetra
.584 .599 .833 r
.52383 .3749 .56012 .41116 .59204 .38892 .55544 .35354 Metetra
.701 .625 .769 r
.55544 .35354 .59204 .38892 .62393 .34949 .58717 .31199 Metetra
.622 .605 .812 r
.58717 .31199 .62393 .34949 .65694 .31978 .62003 .28423 Metetra
.488 .586 .879 r
.62003 .28423 .65694 .31978 .69158 .30048 .65478 .27167 Metetra
.56 .662 .905 r
.65478 .27167 .69158 .30048 .72732 .28039 .69045 .25363 Metetra
.604 .693 .905 r
.69045 .25363 .72732 .28039 .76396 .25758 .727 .2314 Metetra
.688 .725 .878 r
.25748 .5818 .29353 .59964 .32027 .57626 .28408 .55816 Metetra
.694 .726 .875 r
.28408 .55816 .32027 .57626 .34761 .5516 .31129 .53334 Metetra
.702 .727 .869 r
.31129 .53334 .34761 .5516 .37556 .52518 .33913 .50698 Metetra
.714 .729 .862 r
.33913 .50698 .37556 .52518 .40414 .49621 .36761 .47853 Metetra
.731 .734 .853 r
.36761 .47853 .40414 .49621 .43332 .46339 .39673 .44729 Metetra
.751 .747 .848 r
.39673 .44729 .43332 .46339 .46302 .42491 .42642 .4133 Metetra
.751 .8 .892 r
.42642 .4133 .46302 .42491 .49307 .37998 .45653 .38298 Metetra
.509 .903 .936 r
.45653 .38298 .49307 .37998 .52383 .3749 .48718 .36802 Metetra
.695 .873 .965 r
.48718 .36802 .52383 .3749 .55544 .35354 .51878 .34475 Metetra
.812 .82 .856 r
.51878 .34475 .55544 .35354 .58717 .31199 .55084 .30421 Metetra
.76 .863 .925 r
.55084 .30421 .58717 .31199 .62003 .28423 .58372 .27338 Metetra
.63 .845 .982 r
.58372 .27338 .62003 .28423 .65478 .27167 .61793 .25293 Metetra
.618 .769 .952 r
.61793 .25293 .65478 .27167 .69045 .25363 .65323 .23164 Metetra
.633 .745 .928 r
.65323 .23164 .69045 .25363 .727 .2314 .68953 .20758 Metetra
.687 .73 .883 r
.22068 .56411 .25748 .5818 .28408 .55816 .24712 .54045 Metetra
.692 .733 .882 r
.24712 .54045 .28408 .55816 .31129 .53334 .27415 .51589 Metetra
.699 .739 .882 r
.27415 .51589 .31129 .53334 .33913 .50698 .30182 .49032 Metetra
.707 .749 .885 r
.30182 .49032 .33913 .50698 .36761 .47853 .3301 .46375 Metetra
.717 .77 .895 r
.3301 .46375 .36761 .47853 .39673 .44729 .35899 .43668 Metetra
.716 .819 .929 r
.35899 .43668 .39673 .44729 .42642 .4133 .3884 .41149 Metetra
.542 .89 .982 r
.3884 .41149 .42642 .4133 .45653 .38298 .41818 .39678 Metetra
.484 0 0 r
.41818 .39678 .45653 .38298 .48718 .36802 .44834 .41661 Metetra
.44834 .41661 .48718 .36802 .51878 .34475 .48063 .39979 Metetra
.945 .926 .568 r
.48063 .39979 .51878 .34475 .55084 .30421 .51346 .31635 Metetra
.885 .97 .837 r
.51346 .31635 .55084 .30421 .58372 .27338 .54645 .27122 Metetra
.763 .926 .941 r
.54645 .27122 .58372 .27338 .61793 .25293 .58037 .24039 Metetra
.698 .839 .95 r
.58037 .24039 .61793 .25293 .65323 .23164 .61534 .21306 Metetra
.674 .785 .933 r
.61534 .21306 .65323 .23164 .68953 .20758 .65135 .18555 Metetra
.685 .734 .888 r
.18314 .54639 .22068 .56411 .24712 .54045 .20937 .52284 Metetra
.687 .738 .89 r
.20937 .52284 .24712 .54045 .27415 .51589 .23619 .49871 Metetra
.69 .746 .894 r
.23619 .49871 .27415 .51589 .30182 .49032 .26361 .47415 Metetra
.691 .761 .905 r
.26361 .47415 .30182 .49032 .3301 .46375 .2916 .44964 Metetra
.683 .787 .929 r
.2916 .44964 .3301 .46375 .35899 .43668 .32013 .42654 Metetra
.621 .834 .982 r
.32013 .42654 .35899 .43668 .3884 .41149 .34905 .40876 Metetra
0 .569 .737 r
.34905 .40876 .3884 .41149 .41818 .39678 .37797 .40967 Metetra
.746 .33 .261 r
.37797 .40967 .41818 .39678 .44834 .41661 .40551 .49223 Metetra
.40551 .49223 .44834 .41661 .48063 .39979 .43894 .46494 Metetra
.998 .849 .557 r
.43894 .46494 .48063 .39979 .51346 .31635 .4741 .33055 Metetra
.938 .91 .766 r
.4741 .33055 .51346 .31635 .54645 .27122 .50766 .26761 Metetra
.822 .893 .893 r
.50766 .26761 .54645 .27122 .58037 .24039 .54161 .22804 Metetra
.745 .84 .923 r
.54161 .22804 .58037 .24039 .61534 .21306 .57643 .19513 Metetra
.705 .796 .921 r
.57643 .19513 .61534 .21306 .65135 .18555 .61224 .16401 Metetra
.681 .736 .892 r
.14482 .52846 .18314 .54639 .20937 .52284 .17082 .505 Metetra
.681 .741 .896 r
.17082 .505 .20937 .52284 .23619 .49871 .1974 .48121 Metetra
.68 .748 .902 r
.1974 .48121 .23619 .49871 .26361 .47415 .22455 .45737 Metetra
.675 .761 .915 r
.22455 .45737 .26361 .47415 .2916 .44964 .25224 .43413 Metetra
.655 .779 .94 r
.25224 .43413 .2916 .44964 .32013 .42654 .28041 .41288 Metetra
.583 .799 .981 r
.28041 .41288 .32013 .42654 .34905 .40876 .30896 .39659 Metetra
.288 .719 .968 r
.30896 .39659 .34905 .40876 .37797 .40967 .33772 .39144 Metetra
0 .362 .72 r
.33772 .39144 .37797 .40967 .40551 .49223 .36694 .40167 Metetra
.457 .378 .679 r
.36694 .40167 .40551 .49223 .43894 .46494 .39921 .37715 Metetra
.638 .474 .644 r
.39921 .37715 .43894 .46494 .4741 .33055 .43351 .30812 Metetra
.795 .718 .78 r
.43351 .30812 .4741 .33055 .50766 .26761 .46742 .25349 Metetra
.79 .804 .864 r
.46742 .25349 .50766 .26761 .54161 .22804 .50155 .21159 Metetra
.747 .802 .897 r
.50155 .21159 .54161 .22804 .57643 .19513 .53636 .17549 Metetra
.716 .783 .905 r
.53636 .17549 .57643 .19513 .61224 .16401 .57206 .14164 Metetra
.677 .736 .895 r
.10574 .51014 .14482 .52846 .17082 .505 .1315 .48664 Metetra
.676 .74 .899 r
.1315 .48664 .17082 .505 .1974 .48121 .15782 .46294 Metetra
.673 .746 .905 r
.15782 .46294 .1974 .48121 .22455 .45737 .1847 .43933 Metetra
.664 .753 .916 r
.1847 .43933 .22455 .45737 .25224 .43413 .21211 .41632 Metetra
.646 .761 .933 r
.21211 .41632 .25224 .43413 .28041 .41288 .24004 .39477 Metetra
.606 .761 .953 r
.24004 .39477 .28041 .41288 .30896 .39659 .26846 .37589 Metetra
.543 .733 .963 r
.26846 .37589 .30896 .39659 .33772 .39144 .29747 .36027 Metetra
.519 .642 .91 r
.29747 .36027 .33772 .39144 .36694 .40167 .32752 .34385 Metetra
.546 .503 .759 r
.32752 .34385 .36694 .40167 .39921 .37715 .3593 .31527 Metetra
.606 .514 .723 r
.3593 .31527 .39921 .37715 .43351 .30812 .39245 .27346 Metetra
.707 .655 .796 r
.39245 .27346 .43351 .30812 .46742 .25349 .42616 .23005 Metetra
.738 .739 .852 r
.42616 .23005 .46742 .25349 .50155 .21159 .46032 .1901 Metetra
.729 .763 .88 r
.46032 .1901 .50155 .21159 .53636 .17549 .49513 .1531 Metetra
.712 .764 .893 r
.49513 .1531 .53636 .17549 .57206 .14164 .53077 .11767 Metetra
.674 .735 .896 r
.06588 .49129 .10574 .51014 .1315 .48664 .09139 .4676 Metetra
.672 .738 .9 r
.09139 .4676 .1315 .48664 .15782 .46294 .11746 .44372 Metetra
.668 .741 .905 r
.11746 .44372 .15782 .46294 .1847 .43933 .14409 .41987 Metetra
.66 .744 .912 r
.14409 .41987 .1847 .43933 .21211 .41632 .17127 .39634 Metetra
.647 .744 .92 r
.17127 .39634 .21211 .41632 .24004 .39477 .19903 .37348 Metetra
.628 .737 .925 r
.19903 .37348 .24004 .39477 .26846 .37589 .2274 .35147 Metetra
.609 .713 .918 r
.2274 .35147 .26846 .37589 .29747 .36027 .25653 .32963 Metetra
.603 .666 .883 r
.25653 .32963 .29747 .36027 .32752 .34385 .2867 .30552 Metetra
.615 .619 .831 r
.2867 .30552 .32752 .34385 .3593 .31527 .31813 .2759 Metetra
.647 .622 .811 r
.31813 .2759 .3593 .31527 .39245 .27346 .35069 .24057 Metetra
.686 .67 .829 r
.35069 .24057 .39245 .27346 .42616 .23005 .38405 .20272 Metetra
.708 .715 .855 r
.38405 .20272 .42616 .23005 .46032 .1901 .41808 .16499 Metetra
.71 .739 .874 r
.41808 .16499 .46032 .1901 .49513 .1531 .45282 .12813 Metetra
.704 .747 .885 r
.45282 .12813 .49513 .1531 .53077 .11767 .48839 .09192 Metetra
.672 .733 .896 r
.02525 .47184 .06588 .49129 .09139 .4676 .05051 .44782 Metetra
.67 .735 .899 r
.05051 .44782 .09139 .4676 .11746 .44372 .07633 .42354 Metetra
.666 .736 .902 r
.07633 .42354 .11746 .44372 .14409 .41987 .10272 .39914 Metetra
.66 .736 .906 r
.10272 .39914 .14409 .41987 .17127 .39634 .1297 .37473 Metetra
.652 .733 .909 r
.1297 .37473 .17127 .39634 .19903 .37348 .1573 .35038 Metetra
.643 .725 .908 r
.1573 .35038 .19903 .37348 .2274 .35147 .18559 .32591 Metetra
.635 .709 .9 r
.18559 .32591 .2274 .35147 .25653 .32963 .2147 .30068 Metetra
.635 .686 .881 r
.2147 .30068 .25653 .32963 .2867 .30552 .24477 .27348 Metetra
.643 .668 .859 r
.24477 .27348 .2867 .30552 .31813 .2759 .2759 .24317 Metetra
.66 .669 .848 r
.2759 .24317 .31813 .2759 .35069 .24057 .30805 .2097 Metetra
.679 .688 .852 r
.30805 .2097 .35069 .24057 .38405 .20272 .34108 .17416 Metetra
.692 .711 .863 r
.34108 .17416 .38405 .20272 .41808 .16499 .37489 .13777 Metetra
.697 .727 .874 r
.37489 .13777 .41808 .16499 .45282 .12813 .40949 .10119 Metetra
.696 .736 .882 r
.40949 .10119 .45282 .12813 .48839 .09192 .44493 .06454 Metetra
0 g
.25 Mabswid
.44638 0 m
.96095 .3518 L
s
.96095 .3518 m
1 .5553 L
s
1 .5553 m
.44179 .20472 L
s
.44179 .20472 m
.44638 0 L
s
.03702 .40745 m
0 .60991 L
s
0 .60991 m
.44179 .20472 L
s
.44179 .20472 m
.44638 0 L
s
.44638 0 m
.03702 .40745 L
s
.03702 .40745 m
.44638 0 L
s
.03702 .40745 m
.04265 .41037 L
s
[(-2)] .02577 .40163 1 .51773 Mshowa
.12659 .3183 m
.13214 .32136 L
s
[(-1)] .1155 .31218 1 .55117 Mshowa
.22394 .2214 m
.2294 .22462 L
s
[(0)] .21302 .21497 1 .58924 Mshowa
.33011 .11572 m
.33547 .11911 L
s
[(1)] .31941 .10894 1 .63295 Mshowa
.44638 0 m
.45161 .00358 L
s
[(2)] .43591 -0.00715 1 .68366 Mshowa
.125 Mabswid
.05436 .3902 m
.05773 .39196 L
s
.07198 .37266 m
.07534 .37444 L
s
.08989 .35483 m
.09323 .35663 L
s
.10809 .33672 m
.11143 .33853 L
s
.14541 .29957 m
.14873 .30142 L
s
.16454 .28052 m
.16785 .28239 L
s
.18401 .26115 m
.1873 .26304 L
s
.2038 .24145 m
.20709 .24336 L
s
.24443 .20101 m
.2477 .20296 L
s
.26528 .18025 m
.26854 .18222 L
s
.28651 .15912 m
.28975 .16111 L
s
.30812 .13762 m
.31134 .13963 L
s
.35252 .09342 m
.35571 .09548 L
s
.37533 .07072 m
.37851 .07279 L
s
.39857 .04758 m
.40174 .04968 L
s
.42225 .02402 m
.4254 .02614 L
s
.25 Mabswid
.96095 .3518 m
1 .5553 L
s
.96095 .3518 m
.9558 .35548 L
s
[(0)] .97126 .34443 -1 .71469 Mshowa
.97328 .41606 m
.96807 .41966 L
s
[(1)] .98371 .40885 -1 .69105 Mshowa
.98628 .4838 m
.98101 .48731 L
s
[(2)] .99683 .47677 -1 .66633 Mshowa
1 .5553 m
.99466 .55872 L
s
[(3)] 1.01067 .54847 -1 .64046 Mshowa
.125 Mabswid
.96337 .36438 m
.96027 .36658 L
s
.96581 .3771 m
.9627 .37929 L
s
.96827 .38995 m
.96516 .39213 L
s
.97076 .40294 m
.96764 .40511 L
s
.97583 .42932 m
.97269 .43147 L
s
.9784 .44272 m
.97526 .44486 L
s
.981 .45626 m
.97785 .45839 L
s
.98362 .46996 m
.98047 .47208 L
s
.98896 .49779 m
.98579 .49988 L
s
.99168 .51193 m
.9885 .51401 L
s
.99442 .52623 m
.99123 .5283 L
s
.9972 .54069 m
.994 .54275 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[49]:=",
  ImageSize->{280.25, 239.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H0000ka000`40O003h00Oogoo6Goo0023Ool3
002BOol008=oo`03001oogoo099oo`00M7oo0`001goo0`000goo00<007ooOol0TGoo001dOol00`00
Oomoo`0=Ool00`00Oomoo`2AOol007Eoo`03001oogoo00]oo`03001oo`00099oo`00MGoo00<007oo
Ool037oo00<007ooOol0TGoo001dOol00`00Ool0002QOol007Eoo`03001oogoo0:1oo`00ogoo6Goo
003oOolIOol007]oo`03001oogoo09Yoo`00NWoo1000VWoo001iOol00`00Ool00002Ool00`00Oomo
o`2GOol007Qoo`04001oogoo0003Ool2002GOol007Moo`05001oogooOol00005Ool00`00Oomoo`2D
Ool007Ioo`03001oogoo009oo`03001oogoo00Aoo`8009Aoo`00MGoo00<007ooOol00goo00<007oo
Ool017oo0`00Tgoo001dOol30004Ool00`00Oomoo`07Ool2002AOol007=oo`03001oogoo00Eoo`03
001oogoo00Uoo`03001oogoo08ioo`00LWoo00<007ooOol01Woo00<007ooOol02Woo00<007ooOol0
SGoo001aOol00`00Oomoo`07Ool00`00Oomoo`0;Ool2002=Ool0071oo`03001oogoo00Qoo`03001o
ogoo00aoo`8008aoo`00Kgoo00<007ooOol02Goo00<007ooOol03Woo0P00RWoo001^Ool2000;Ool0
0`00Oomoo`0@Ool00`00Oomoo`27Ool006eoo`03001oogoo00]oo`03001oogoo015oo`8008Moo`00
K7oo00<007ooOol037oo00<007ooOol04goo00<007ooOol0Q7oo001[Ool00`00Oomoo`0=Ool00`00
Oomoo`0DOol2000EOol5001ZOol006Yoo`03001oogoo00ioo`03001oogoo01Aoo`03001oo`0001Io
o`03001oogoo06Yoo`00JGoo00<007ooOol03Woo10005goo0P003Woo0`000goo00<007ooOol0JWoo
001XOol2000?Ool00`00F_`00002F_`00`00Oomoo`0FOol00`00Oomoo`0AOol00`00Oomoo`1ZOol0
06Moo`03001oogoo00ioo`04001Jo5[l0003F_`00`00Oomoo`0FOol2000AOol00`00Oomoo`1ZOol0
06Ioo`03001oogoo00ioo`05001Jo5[lF_`00004F_`2000HOol00`00Oomoo`0=Ool2001/Ool006Eo
o`03001oogoo00ioo`03001Jo5[l009Jo003001Jo5[l00AJo003001oogoo01Aoo`04001oo`00001k
Ool005Aoo`D000]oo`03001oogoo00ioo`03001Jo5[l00=Jo003001Jo5[l00EJo003001oogoo01Mo
o`03001oogoo07Qoo`00EWoo00<007ooOol02Woo00<007ooOol03Woo00<005[lF_`015[l00<005[l
F_`01U[l0P0067oo0P00N7oo001FOol00`00Oomoo`09Ool2000?Ool00`00F_aJo005F_`00`00F_aJ
o008F_`00`00Oomoo`0GOol00`00Oomoo`1eOol005Ioo`03001oogoo00Qoo`03001oogoo00ioo`03
001Jo5[l00IJo003001Jo5[l00MJo004001Jo000000HOol2001eOol005Ioo`03001oogoo00Moo`03
001oogoo00ioo`03001Jo5[l00IJo003001Jo5[l00MJo003001Jo5[l009Jo08001Eoo`04001oogoo
001dOol005Eoo`8000Qoo`03001oogoo00ioo`04001Jn`000006F_`00`00F_aJo006F_`00`00F_aJ
o005F_`2000GOol00`00Oomoo`1aOol005ioo`03001oogoo00ioo`03001Jne[k009Jn`8000AJo003
001Jo5[l00EJo003001Jo5[l00QJo08001Ioo`80075oo`00GGoo00<007ooOol03Woo00<005[kF_/0
1E[k00D005[lF_aJo00000IJo003001Jo5[l00]Jo08001Ioo`03001oogoo06ioo`00G7oo00<007oo
Ool03Woo00<005[kF_/01e[k0P0000=Jo000F_`015[l00<005[lF_`03U[l00<007ooOol057oo0P00
KWoo001KOol01000Ool000003Goo00<005[kF_/02U[k0P0015[l00<005[lF_`03U[l00@005/L0000
01Aoo`03001oo`0006eoo`00FWoo00<007ooOol03goo00<005[kF_/02e[k0`0000=Jo000F_`03e[l
00<005/LFa`00U/L00<007ooOol057oo0P00Jgoo001IOol00`00Oomoo`0?Ool00`00F_]Jn`0<F_/0
1000F_]Jn`0045[l00<005/LFa`015/L0P005Woo00<007ooOol0J7oo001HOol00`00Oomoo`0?Ool0
0`00F_]Jn`0=F_/01000F_/005[k0P003E[l00<005/LFa`01e/L0P005Goo0P00J7oo001GOol00`00
Oomoo`0?Ool00`00F_]Jn`0>F_/20004F_/00`00F_aJo009F_`00`00FaaK700:Fa`00`00Oomoo`0D
Ool00`00Oomoo`1UOol005Ioo`80011oo`03001Jne[k00mJn`03001Jne[k00AJn`8000UJo003001K
75/L00]K708001=oo`04001oo`00001UOol005Eoo`03001oogoo00moo`04001Jf`00000>F_/20008
F_/20006F_`00`00FaaK700>Fa`00`00Oomoo`0DOol00`00Oomoo`1ROol005Aoo`03001oogoo00mo
o`03001Jfe[K009Jf`8000]Jn`03001Jn`0000YJn`03001Jo5[l009Jo003001K75/L00iK7004001K
?000000EOol2001ROol005=oo`03001oogoo00moo`03001Jfe[K00EJf`03001Jne[k00QJn`03001J
n`0000]Jn`800003F_`005/L00mK7003001K?5/l009K?08001Eoo`03001oogoo05moo`00DWoo00<0
07ooOol03goo00<005[KF]/01e[K0P001e[k00@005[kF_/000eJn`03001K75/L00iK7003001K?5/l
00EK?08001=oo`<0011oo`03001oogoo04aoo`00DGoo00<007ooOol03goo00<005[KF]/02U[K0P00
15[k00D005[kF_]Jn`0000aJn`04001O7000000=Fa`00`00FcaK?008Fc`2000DOol00`00Oomoo`0<
Ool00`00Ool0001=Ool0051oo`03001oo`0000moo`03001Jfe[K00eJf`800003F_/005[k00=Jn`03
001Jne[k00UJn`03001O75lL009O708000YK7003001K?5/l00]K?08001=oo`8000aoo`03001oo`00
04eoo`00Cgoo00<007ooOol03goo00<005[KF]/045[K00<005[kF_/00e[k00<005[kF_/025[k00<0
05lLGa`01ElL0P001e/L00<005/lFc`03U/l00<007ooOol04Woo00<007ooOol02Goo00<007oo0000
CGoo001>Ool00`00Oomoo`0?Ool00`00F]]Jf`0@F]/01000F]/000000e[k00<005[kF_/01e[k00<0
05lLGa`025lL0P0015/L00<005/lFc`03U/l00@005/m000001=oo`8000Uoo`03001oo`0004eoo`00
CGoo00<007ooOol03goo00<005[KF]/045[K00<005[KF]/00U[K00@005[kF_/000QJn`03001O75lL
00]O70800003Fa`005/l00mK?003001K?E/m009K?@80015oo`<000Uoo`03001oogoo04aoo`00C7oo
00<007ooOol03goo00@005KK000000mJf`03001Jfe[K00AJf`<000QJn`03001O75lL00eO708000mK
?003001K?E/m00EK?@80019oo`03001oogoo05Eoo`00Bgoo0P0047oo00<005KKE]/00UKK00<005[K
F]/02e[K00<005[KF]/01e[K0P001U[k00<005lLGa`03ElL00<005llGc`00P002e/l0P002U/m0P00
4Goo0P00EGoo001:Ool00`00Oomoo`0?Ool00`00E]]Ff`04E]/2000:F]/00`00F]]Jf`08F]/00`00
F]/00004F_/00`00GaaO700=Ga`00`00GcaO?003Gc`20008Fc`00`00FceK?@0<Fcd2000AOol00`00
Oomoo`1BOol004Uoo`03001oogoo00moo`03001FfeKK00MFf`03001Jfe[K00MJf`03001Jfe[K00QJ
f`03001Jfe[K00800003F_/005lL00iO7003001O?5ll00IO?08000EK?003001K?E/m00eK?@04001G
?@00000@Ool2001BOol004Qoo`03001oogoo00moo`03001FfeKK00UFf`8000IJf`03001Jfe[K00UJ
f`03001Jfe[K009Jf`8000iO7003001O?5ll00UO?080009K?003001K?E/m00eK?@03001G?ELm009G
?@8000eoo`04001oogoo001AOol003Yoo`03001oogoo00Yoo`03001oogoo011oo`03001FfeKK00]F
f`03001Jfe[K009Jf`03001Jfe[K00YJf`05001Jfe[KF]/00002G_/2000;Ga`00`00GcaO?00<Gc`2
000?Fcd00`00EceG?@05Ecd2000?Ool2001?Ool003Uoo`03001oo`0000Yoo`03001oogoo011oo`03
001FfeKK00eFf`800003F]/005[K00aJf`04001Jfe[K0005G_/20008Ga`00`00GcaO?00=Gc`01000
Ged000002e/m0P002ULm0P003goo00<007ooOol0C7oo000iOol00`00Ool00008Ool3000AOol00`00
E]]Ff`0@E]/00`00F]]Jf`0<F]/00`00F]/00008G_/20005Ga`00`00GcaO?00=Gc`00`00GeeOG@02
Ged20008Fcd00`00EceG?@0<Ecd2000>Ool2001<Ool003Uoo`03001oo`0000Moo`03001oogoo015o
o`03001FfeKK011Ff`04001F^P00000;F]/01000F]/000002Ukk0P000UlL00<005llGc`03Ell00<0
05mMGed01EmM0P001E/m00<005LmEcd03eLm00<007ooOol02goo0`00Bgoo000iOol00`00Ool00006
Ool00`00Oomoo`0AOol00`00E]]Ff`0@E]/00`00E[YF^P02E[X00`00F]]Jf`07F]/00`00F]/00002
G_/00`00G_]Nn`09G_/2000?Gc`00`00GeeOG@08Ged20002Fcd00`00EceG?@0>Ecd200000e;m0000
000>Ool20019Ool003Yoo`03001oogoo00Aoo`03001oogoo015oo`04001F^`00000?E]/00`00E[YF
^P04E[X20006F]/01000F]]Jf`000ekk0P002Ekk00@006Lk000000]O?08000eOG@80011G?@03001B
oE;m00=Bo@03001oogoo00eoo`03001oogoo04Ioo`00@7oo00<007ooOol04Goo00<005JkE[/00UJk
00<005KKE]/02eKK00<005JjE[X01eJj0P000e[K00@005[KF]/000INn`8000INn`03001W>fLk009W
>`8000QO?003001OGEmM00eOG@04001KGP00000=Ecd00`00D_eBo@05D_d00`00Oomoo`0=Ool20016
Ool003moo`80019oo`03001F^eJk00AF^`8000YFf`03001F^UJj00YF^P03001Jf`00009Jf`03001N
nekk00MNn`03001Nnekk00=Nn`03001W>fLk00AW>`8000EO?003001OGEmM00aOG@8000AKGP8000UG
?@8000UBo@8000moo`03001oogoo04=oo`00?Woo00<007ooOol00P003goo00<005JkE[/01eJk00<0
05KKE]/01eKK00<005JjE[X02UJj0`0000=Jf`00G_/02Ukk0P000Ukk00<006LkIc/01fLk0P000Ull
00<005mMGed035mM00<005]NFeh01U]N0P001ULm00<005;mD_d02e;m00<007ooOol02goo00@007oo
000004=oo`00?Goo00<007ooOol04Woo00<005JkE[/025Jk0P001UKK00<005JjE[X02UJj00D005Jj
E[YF^P0000iNn`8000aW>`<000eOG@03001KGU]N00UKGP80009G?@8000mBo@8000moo`03001oogoo
041oo`00?7oo00<007ooOol04Woo00<005JkE[/02eJk00<005KKE]/00UKK00<005JjE[X02UJj00H0
05JjE[YF^P00FYT2000<G_/3000;Ic/00`00Jia[W0040007Ged2000>Feh2000CD_d00`00Oomoo`0=
Ool20010Ool003]oo`03001oogoo019oo`03001F^eJk00eF^`800003E]/005Jj00]F^P05001F^UJj
E[X00004FYT20009G_/01000Ic]W>fLk0P0026Lk00<006^LJi`01F^L10000UmM00<005]NFeh03E]N
0P0000=?7P0000003e;m0P0000=>g00000003goo00<007ooOol0?Goo000jOol2000COol00`00E[]F
^`0@E[/00`00E[YF^P0:E[X00`00E[YF^P02E[X00`00FYUJV@04FYT20006G_/00`00Ic]W>`04Ic/0
0`00Ic]W>`04Ic/00`00Jia[W00:Ji`3000=Feh20005Cah2000;D_d20005C]`00`00Oomoo`0;Ool4
000=Ool5000[Ool003Uoo`04001oogoo000AOol00`00E[]F^`0@E[/00`00DWT0000:E[X00`00E[YF
^P02E[X00`00FYUJV@07FYT20004G_/00`00Ic]W>`05Ic/20003Ic/00`00Jia[W00;Ji`00`00HkiS
_P030008Feh20009Cah20007D_d20008C]`2000?Ool00`00Oomoo`0<Ool00`00Oomoo`0[Ool003Qo
o`03001oogoo019oo`04001B^`00000?E[/01000DWUBNE9i0P001eJj00<005JjE[X00UJj00<005ZI
FYT02UZI0P0000=Nn`00Ic/02FLk00<006Lk00003F^L00<006>nHkh016>n10000U]N0P003DlN0P00
0e;m0P0034kL00<007ooOol03Goo00<007ooOol02goo00<007ooOol0:goo000gOol00`00Oomoo`0B
Ool00`00D[]B^`02D[/00`00E[]F^`0;E[/00`00DWUBN@04DWT00`00E[YF^P03E[X00`00E[YF^P02
E[X00`00FYUJV@0=FYT2000;Ic/2000<Ji`00`00HkiS_P09Hkh2000ACah3000?C]`2000>Ool2000;
Ool00`00Oomoo`0[Ool003Ioo`03001oogoo019oo`03001B^e:k00AB^`03001F^eJk00UF^`03001B
NE9i00IBN@05001F^UJjE[X00005E[X00`00FYUJV@0<FYT00`00I]QVf0020009Ic/01000Ji`00000
26^L0P002f>n0P0000=CO`0000003TlN0P0000=6_000C]`044kL00<007ooOol03Goo00<007ooOol0
27oo00<007ooOol0:goo000eOol00`00Oomoo`0BOol00`00D[]B^`06D[/20008E[/00`00DWUBN@08
DWT00`00E[X00005E[X00`00FYUJV@0=FYT00`00I]QVf002I]P30005Ic/00`00Jia[W002Ji`00`00
Jia[W004Ji`00`00HkiS_P0:Hkh00`00DgmCO`03Dgl2000:Cah20004A[`2000>C]`00`00C[`0000=
Ool01000Ool000001goo0P00;Goo000dOol00`00Ool0000BOol00`00D[]B^`09D[/00`00E[]F^`04
E[/00`00DWUBN@0:DWT00`00E[YF^P03E[X00`00FYUJV@0=FYT00`00I]QVf006I]P20002Ic/00`00
Jia[W004Ji`20003Ji`00`00HkiS_P09Hkh20008Dgl20006Cah20008A[`00`00C]a>g009C]`20003
C[`2000?Ool00`00Oomoo`0cOol003=oo`03001oogoo019oo`03001B^e:k00]B^`03001F^eJk009F
^`03001BNE9i00YBN@04001BN@000002E[X00`00FYUJV@0>FYT00`00I]QVf008I]P70004Ji`00`00
Ji`0000;Hkh00`00DgmCO`0:Dgl20002Cah2000;A[`00`00C]a>g007C]`00`00C[a>_005C[`00`00
Oomoo`0=Ool2000cOol0039oo`03001oogoo019oo`03001B^e:k00eB^`800003E[/0059i00YBN@80
00ABN@03001F^P0000mJV@03001Vf6KH00UVf003001k^7^h00Ak^0X000IS_P8000iCO`<000i6_003
001>g4kL00E>g003001>_4jl00M>_003001oogoo00ioo`03001oogoo031oo`00<Goo00<007ooOol0
4Woo00<005:kD[/045:k00<0059iDWT02E9i00<0059iDWT01E9i00<005ZIFYT03EZI00<006KHI]P0
2VKH00<007^hNkP027^h00<007?jLoX00P0000=cnP0000001@003E=o0P000SiL00<004JlA[`03DJl
0P000dkL0P002djl00<007ooOol03Goo0`00<7oo000`Ool00`00Oomoo`0BOol01000D[`000003e:k
00<004ij00002E9i00<0059iDWT01E9i00<004hG00003UZI00<006KHI]P02FKH00<007^hNkP027^h
00<007?jLoX00g?j00<007?jLoX00W?j00<006=mHgd00`0025=o0P001CiL0P003dJl00<004kL0000
3Tjl0P0037oo00D007ooOomoo`0002moo`00;goo0`004Woo00<005:lD[`00U:l00<005:kD[/02e:k
00D004ijCWY>NP0000MBN@03001BNE9i00EBN@04001>5dhGCQL2000;FYT00`00I]QVf00:I]P00`00
NkQk^008NkP00`00LoYcnP04LoX200000g?j001SO@05Hgd30003Dgl20009?U`00`00A[a6_00=A[`0
0`00C[a>_00?C[`00`00Oomoo`0>Ool2000]Ool002ioo`03001oogoo019oo`03001B_5:l00AB_003
001B^e:k00UB^`03001>NTij00=>NP03001BNE9i00=BN@03001BNE9i00IBN@03001>5dhG00=>5`03
001JVEZI00QJV@03001Vf6KH00UVf003001k^7^h00Qk^003001cnW?j00McnP03001SOF=m00QSO@<0
00`nG0030016_4Jl00Y6_0800003BW/004jl011>_003001oogoo00moo`03001oogoo02Yoo`00;Goo
00<007ooOol04Goo0P0025:l0P0025:k00<004ijCWX01Dij00D0059iDWUBN@0000QBN@03001>5dhG
00E>5`03001JVEZI00IJV@03001Vf6KH00YVf003001k^7^h00Mk^003001cnW?j00IcnP800003Hgd0
000000QSO@03001>N@0000dnG0030016_4Jl00M6_08000A:N`03001>_4jl00a>_0800003CY/00000
00moo`<002Yoo`007Woo1@002Goo00<007ooOol04Goo00<005:lD[`02U:l00<005:kD[/015:k00<0
04ijCWX01dij00<0059i0000259i00<004hGCQL01dhG00<005ZIFYT015ZI00<006KHI]P02VKH00<0
07^hNkP01g^h00<007?jLoX01W?j00<006=mHgd00f=m00<006=mHgd00f=m0P000dii00<003iL?U`0
2ciL0P001DJl0P001dYk00<004jlC[`02Tjl00<004jKCY/00djK00<007ooOol037oo00@007ooOol0
02Uoo`0087oo00<007ooOol027oo00<007ooOol04Goo00<005:lD[`035:l00<005:kD[/00U:k00<0
04ijCWX02Dij00<0059iDWT01U9i00<004hGCQL02DhG00<005ZIFYT00eZI00<006KHI]P02VKH00<0
07^hNkP01g^h00<007?jLoX01G?j00<006=mHgd01F=m0P000V=m00<004iiCWT014ii00<003iL?U`0
33iL00<004JlA[`00P002TYk0P002Djl00<004jKCY/01DjK00<007ooOol03goo0P009goo000JOol3
0003Ool00`00Oomoo`07Ool3000AOol00`00D[aB_00>D[`200000e:k001>NP0:CWX00`00CWX00006
DWT00`00CQM>5`0;CQL20002FYT00`00I]QVf00:I]P00`00NkQk^007NkP00`00LoYcnP05LoX00`00
HgeSO@08Hgd20008CWT00`00?U`nG00<?U`2000>BW/00`00C[a>_004C[`20009CY/2000AOol00`00
Oomoo`0TOol0021oo`03001oogoo00Ioo`03001oogoo015oo`04001Bg000000@D[`00`00CWY>NP09
CWX01@00CWY>NTij0000159i00<004hGCQL03ThG00<005ZI000036KH00<007^hNkP01W^h00<007?j
LoX017?j100026=m0P0000=>N@00CWT01dii0P002SiL0P0000=6>@00BW/03TYk00<004jlC[`00Tjl
00<004jKCY/02djK00<007ooOol03goo0P0097oo000POol00`00Oomoo`05Ool00`00Oomoo`0AOol0
0`00D]aBg002D]`00`00D[aB_00<D[`00`00C[`00009CWX00`00CWY>NP03CWX01@00DWUBNE9i0000
4DhG00<006KHI]P02VKH00<007^hNkP01W^h00<007?jLoX00W?j10000fMK10000f=m00<004iiCWT0
0Tii0P0024ii00<003iL?U`01CiL0P0014Hi00<004YkBW/03DYk00@004jl000000m>V`8000ioo`04
001oogoo000SOol001moo`8000Ioo`03001oogoo015oo`03001Bg5;L00ABg003001B_5:l00YB_005
001>_4jlC[`00007CWX00`00CWY>NP05CWX00`00DWT0000ACQL01000DO@000002VKH00<007^hNkP0
1W^h1@000W^b00<006MKIe/01VMK0`001dii00<004iiCWT01Tii00<003iL?U`00SiL0P001dHi00<0
04YkBW/03DYk00<004jKCY/04DjK00<007ooOol03goo0P008Goo000VOol00`00Oomoo`0@Ool20008
D]`20009D[`00`00C[a>_003C[`00`00CWY>NP02CWX20009CWX00`00CQM>5`0@CQL01000DOAAm57d
0P001fKH00<007^hNkP01G^h0`001W^b00<006MKIe/01fMK00<005Yh00001dii0P001dii00@003iL
000000Y6>@03001:NdYk00Y:N`800003CWX004jK011>V`03001B^`00019oo`03001oogoo01ioo`00
9Goo10003goo00<005;LD]`02U;L00<005:lD[`015:l0P001djl00@004ijCWX000Y>NP0300166000
011>5`03001Am57d00AAm003001Vf6KH00AVf003001k^7^h009k^0<00003Og4007^b00Ek/P03001W
FfMK00QWF`04001JN5Yh0008CWT20006CWT00`00ASU6>@0;AST20009BW/00`00CWY>NP02CWX2000=
CY/20003D[/00`00Oomoo`0@Ool00`00Oomoo`0<Ool3000>Ool002Aoo`03001oogoo011oo`03001B
g5;L00aBg003001B_5:l009B_003001>_4jl00Q>_08000Y>NP04001664HH000@CQL00`00DOAAm005
DO@20003I]P01000NkQk^7^h0P000gma00<007^bNk8017^b00<006MKIe/026MK00<005YhFWP00UYh
00<004iiCWT01dii00<004iiCWT00Tii00<004XG00003THi00<004YkBW/014Yk0P001dij00<004jK
CY/02DjK00<005:kD[/015:k00<007ooOol03Woo00@007oo000000aoo`03001oo`0000ioo`008goo
00<007ooOol047oo00<005;LD]`03U;L0P0000=B_000C[`02Tjl00<004jl000024ij00<004HHAQP0
0THH00<004hGCQL034hG00<0057dDO@0257d0P0000=Vf00000000P001Gma00<007^bNk800g^b00<0
06MKIe/026MK00<005YhFWP015Yh00<004iiCWT01dii0P0000=>N@00BQL00TXG00<004HiAST034Hi
00<004YkBW/00TYk00<004ijCWX024ij00<004jKCY/01djK00<005:kD[/01U:k0P004Woo00<007oo
Ool02Goo0`003Woo000ROol00`00Oomoo`0@Ool01000D_d0000045;L00<004jlC[`02Djl00D004jl
C[a>_00000E>NP8000I66003001>5dhG00]>5`03001Am57d00YAm08000MoL@03001k/W^b00=k/P03
001WFfMK00QWF`03001JN5Yh00IJN003001>NDii00Q>N@03001:5dXG009:5`030016>DHi00e6>@04
001:N`00000<CWX00`00CY]>V`05CY/00`00D[]B^`09D[/00`00Oomoo`0@Ool20009Ool3000>Ool0
025oo`03001oogoo00moo`8000ABo@8000aBg0800003C]d0000000Q>_003001>_4jl00=>_005001>
NTijCWX00008AQP00`00CQM>5`0:CQL00`00DOAAm00;DO@00`00Og5oL@06Og400`00Nk9k/P02Nk80
0`00Ie]WF`09Ie/00`00FWQJN007FWP00`00CWU>N@05CWT200000dXG00000003BQL00`00ASU6>@0=
AST00`00CWY>NP0=CWX20003CY/2000=D[/00`00Oomoo`0AOol00`00Oomoo`06Ool00`00Ool0000>
Ool0021oo`03001oo`0000moo`03001BoE;m00IBo@8000UBg003001>gDkM00=>g@03001>_4jl00A>
_003001>_4jl00E>_003001>NP0000Y66003001>5dhG00U>5`03001Am57d00YAm003001oLGma00Mo
L@03001k/W^b009k/P03001WFfMK00QWF`03001JN5Yh00UJN003001>NDii00=>N@03001:5dXG00=:
5`80009:5`030016>DHi00]6>@03001>F@00011>NP03001>V`00011B^`03001oogoo00moo`04001o
o`000007Ool00`00Oomoo`0=Ool001moo`03001oogoo00moo`03001BoE;m00UBo@8000EBg08000M>
g@03001>_4jl009>_003001>_4jl00M>_003001664HH00Y66003001>5dhG00M>5`03001Am57d00]A
m003001oLGma00IoL@03001k/W^b009k/P03001WFfMK00QWF`03001JN5Yh00]JN005001>NDiiCWT0
0008BQL01000BQM:5`002dHi00D004iICUU>F@00011>NP03001B^e:k011B^`03001oogoo019oo`03
001oogoo01Aoo`007Woo00<007ooOol03Woo0P003U;m0P0000=Bg00000002TkM0P0000=>_000C[`0
1djl0P0000=2W@00AQP02THH00<004hGCQL01dhG00<0057dDO@02e7d00<007maOg401Wma00@007^b
Nk9k/P<000QWF`03001JN5Yh00eJN003001>N@0000Y:5`800003BQL004Hi00Q6>@03001>FDiI00=>
F@03001>NTij00a>NP03001BVP0000mB^`800003E[/007oo01=oo`8001Aoo`007Goo00<007ooOol0
3Woo00<005;mD_d045;m00<004kMC]d034kM00<004jlC[`01Tjl00D004:M@Ye2W@0000a66003001>
5dhG00E>5`03001Am57d00aAm003001oLGma00EoL@05001k/W^bNk800003Fgh50003Ie/00`00FWQJ
N00>FWP00`00BQM:5`0;BQL00`00BQL00006AST20007CUT00`00CWY>NP09CWX20003DYX2000<D[/0
0`00E[]F^`02E[/2000DOol00`00Oomoo`0AOol001aoo`8000moo`04001Bo@00000?D_d01000D_d0
00002dkM00<004kM00001Djl0P001D:M00<004HHAQP02THH00<004hGCQL014hG00<0057dDO@02e7d
00<007maOg401Wma00D007^bNk9k/P0000QKOP<0011JN0030015]00000e:5`8000E6>@03001>FDiI
00Q>F@8000Q>NP03001BVU:J00EBVP03001B^e:k00QB^`03001F^eJk00EF^`03001oogoo00moo`<0
01=oo`006goo00<007oo00003Woo00<005;mD_d00U;m0P002e;m0P0015;m00<004kMC]d01dkM00@0
04kMC]e>g@800003C[`0000000M2W@03001664HH00]66003001>5dhG009>5`03001Am57d00aAm003
001oLGma00EoL@05001k/W^bNk80000:Fgh00`00BWX0000>FWP01000AKA5]0003dXG0P000THi00<0
04iICUT02diI00<004ijCWX014ij00<005:JDYX01e:J00<005:kD[/01E:k0P002EJk00<007ooOol0
3Goo00@007ooOol001=oo`006Woo00<007ooOol03Woo00<005;mD_d01E;m0P0025;m00<005;mD_d0
1E;m0P001DkM0P001TkM00<004:M@Yd024:M00<004HHAQP02THH00<004hGCQL00ThG00<0057dDO@0
357d00<007maOg401Gma00@007^bNk8000UKOP8000=:NP03001JN5Yh00]JN0050015]4FdAK@0000?
BQL3000?CUT01000CWY>NTij0P002e:J0P0015:k00<005JkE[/02UJk0P0037oo00<007ooOol00Woo
00<007ooOol047oo000IOol00`00Oomoo`0>Ool00`00D_eBo@08D_d20005D_d00`00D_eBo@08D_d2
0002C]d00`00C]e>g@04C]d200000dKn0012W@09@Yd00`00AQQ6600:AQP01000CQM>5`003e7d00<0
07maOg401Gma00<007^b00002E]n00<004YjBWX014Yj00<005YhFWP02EYh00<004FdAK@00dFd00<0
04XGBQL03DXG0`003diI00<004ij00003e:J00@005:k000000mF^`03001oogoo00Moo`8000=oo`<0
019oo`0067oo00<007ooOol03Woo00<005;mD_d02e;m0P0000=Bo@0000003E;m0P001DkM0P0014Kn
0P0024:M00<004HHAQP02dHH00<004hG00003U7d00<007maOg401Gma00@007^bNk8000QKOP03001:
NTYj00I:NP03001JN5Yh00MJN0030015]4Fd00A5]003001:5dXG00a:5`05001B5P00CUT0000?CUT0
0`00DYYBVP0?DYX00`00E[]F^`0@E[/00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`0@Ool0
01Moo`<000ioo`03001BoE;m00iBo@03001BoE;m00eBo@<0009>g@8000Q6oP030012WD:M00I2W@03
001664HH00Y6608000mAm003001oLGma00EoL@03001k/P0000@000=KOP8000Y:NP8000IJN0030015
]4Fd00I5]003001:5dXG00Y:5`06001B5U8FDQH004iI0P0034iI00<005ZI00003e:J00<005Zj0000
45Jk00@005KK000000=oo`8000Qoo`03001oogoo011oo`005Woo00<007ooOol03Woo0P003e;m00@0
05;m000000aBo@04001BoE;mD_d2000;A_h00`00@Ye2W@06@Yd00`00AQQ6600:AQP00`00DOAAm00=
DO@00`00Og5oL@04Og400`00Nk800003@id5000>BWX00`00FWQJN002FWP00`00AKA5]008AK@00`00
BQM:5`09BQL00`00DQIB5P02DQH01000CUU>F@002TiI00D005ZIFYUJV@0000eBVP04001J^UZjF[X2
000=E[/00`00E]]Ff`02E]/00`00Ool0000:Ool00`00Oomoo`0@Ool001Eoo`03001oogoo00ioo`03
001Fo5Kl008000aBo@03001BoE;m009Bo@8000UBo@03001BoE;m0080009?7P8000Y6oP030012WD:M
00E2W@03001664HH00U6608000mAm003001oLGma00AoL@03001k/P0000<000DanP03001:NTYj00a:
NP05001JN5YhFWP0000:AK@00`00BQM:5`08BQL00`00DQIB5P04DQH00`00CUU>F@020007CUT00`00
FYUJV@03FYT00`00DYYBVP09DYX00`00F[YJ^P04F[X00`00E[]F^`09E[/00`00E]]Ff`04E]/20009
Ool2000BOol000Qoo`<000Uoo`03001oogoo00ioo`03001Fo5Kl00=Fo08000QBo@8000MBo@8000IB
o@04001BoE;m0006Cah20009A_h20006@Yd00`00AQQ66006AQP20002>ID00`00DOAAm00;DO@00`00
Og5oL@05Og430009<OX00`00BWY:NP0<BWX00`00FWP0000<AK@00`00BQM:5`06BQL00`00DQIB5P06
DQH01000CUU>FDiI0P0014iI00<005ZIFYT01EZI00<005:JDYX01e:J00<005ZjF[X01UZj00<005Jk
E[/01UJk0P002EKK00<007ooOol027oo00@007ooOomoo`D000Uoo`0027oo00<007ooOol027oo00<0
07ooOol03Goo0P0025Kl0P001E;m00<005;mD_d02E;m0P000e;m00@005;m000000U?7P8000U6oP03
0012WD:M00=2W@03001664HH00E66003000iUCVE008iU@03001Am57d00]Am003001oLGma00AoL@80
009NV003000anS7j00LanP03001:NTYj00a:NP030015]4Fd00a5]003001:5dXG00A:5`03001B5U8F
00MB5P03001>FDiI00=>F@04001>FDiI0009FYT00`00DYYBVP05DYX00`00F[YJ^P08F[X00`00E[]F
^`04E[/00`00E]]Ff`0:E]/20008Ool00`00Oomoo`03Ool00`00Oomoo`09Ool000=oo`<000=oo`03
001oogoo00Ioo`<000eoo`03001Fo5Kl00YFo080009Bo@03001BoE;m00aBo@D000e?7P8000E6oPD0
00A2W@03001664HH00=66003000iUCVE00@iU@03001Am57d00YAm003001oLGma00AoL@05001NV5jH
GYP0000:<OX00`00BWY:NP09BWX3000>AK@00`00BQM:5`03BQL00`00DQIB5P09DQH00`00CUU>F@03
CUT3000:FYT00`00DYYBVP03DYX00`00F[YJ^P0:F[X20003E[/00`00E]]Ff`0=E]/00`00Oomoo`04
Ool20005Ool00`00Oomoo`09Ool000Uoo`03001oogoo00Eoo`03001oogoo00eoo`03001Fo5Kl00eF
o080011Bo@<0011?7PD000DVoP8000=2W@03001664HH008000LiU@03001Am57d00YAm003001oLGma
00=oL@8000ANV003000anS7j00PanP03001:NTYj00M:NP05000mUCfE?ID0000>AK@01@00BQM:5dXG
00003E8F00<004iICUT00diI0P002eZI00D005:JDYYBVP0000mJ^P03001F^`0000mFf`03001Jf`00
00Ioo`03001oogoo00=oo`03001oogoo00Uoo`0027oo00<007oo00001Goo00<007ooOol03Goo00<0
05KlE_`03UKl00@005Km000000eBo@80009C7@8000e?7P80009;?`8000LVoP@00003AQP003VE00Ti
U@03001Am57d00QAm003001oLGma00AoL@03001NV5jH00ANV003000anS7j00PanP03001:NTYj00A:
NP8000@mU@030015]4Fd00e5]004001:5dXG000>DQH01@00CUU>FDiI00000UZI0P002UZI00<005:J
00004EZj00<005KKE]/035KK0P000e[K0P0017oo00<007ooOol00goo00<007ooOol02Goo0009Ool0
0`00Oomoo`03Ool00`00Oomoo`0=Ool01000E_`000003EKl00<005KmE_d00UKm0P002U;m0P001E<M
0P002TlN00<004/oBcl014/o0`001RKn0`002cVE00<0057dDO@0257d00<007maOg400gma00<005jH
GYP01UjH00<0037j<OX0237j00<004YjBWX00TYj00<003fE?ID013fE00<004FdAK@03DFd00<004XG
0000458F00<004iI00001EZI0P002EZI00<005ZjF[X03eZj00<005[K000035KK00<005[KF]/01E[K
00@007ooOomoo`8000=oo`8000]oo`003Woo00<007ooOol03Goo00<005KlE_`00UKl0P002UKl00<0
05KmE_d01EKm0P001U;m0`0025<M0P001TlN0P002T/o0P001RKn00<003VE>ID02CVE00<0057dDO@0
257d00<007maOg400gma00<005jHGYP01ejH00<0037j<OX0237j00@004Yj000000PmU@030015]4Fd
00e5]003001B5U8F011B5P03001JVEZI00IJV@03001JVEZI00EJV@03001NfP0000iJ^P8000=Jf`80
00UFf`03001Jfe[K00MJf`05001oo`00Ool0000@Ool000ioo`<000]oo`8000MFo08000MFo003001F
oEKm00QFo@8000=Bo@8000aC7@80009?7P8000i;?`P000/iU@03001Am57d00MAm003001oLGma009o
L@03001NV5jH00UNV003000anS7j00PanP03000mUCfE00PmU@030015]4Fd00e5]080011B5P03001V
]`0000QJV@8000AJV@04001NfUkJG]X2000;F[X00`00F]]Jf`05F]/00`00E]]Ff`05E]/00`00F]]J
f`09F]/200000goo001oo`0?Ool000ioo`03001oogoo008000Qoo`03001Fo5Kl00UFo08000AFo003
001FoEKm00]Fo@@000mC7@<000i;?`8000I?G`03000iUCVE00TiU@03001Am57d00IAm003001oLGma
009oL@03001NV5jH00YNV003000anS7j00HanP<000/mU@030015]4Fd00]5]003001Ad`00011B5P04
001V]fJg0009FYT01000FYUJV@001UkJ00<005ZjF[X01eZj00<005[KF]/01e[K00<005KKE]/00UKK
0P003U[K0P0047oo000=Ool00`00Oomoo`03Ool20005Ool00`00E_aFo00<E_`200000eKl001Fo@0>
E_d3000>Dad20002Dah40008Bcl20009Cel00`00>IDiU@09>ID00`00DOAAm005DO@00`00Og5oL@02
Og400`00GYQNV00;GYP00`00<OXanP03<OX20003?OP00`00?IDmU@08?ID00`00AKA5]00;AK@01000
DM=Ad`003U8F00<006JgI[L00VJg00<005ZIFYT01eZI0P0025kJ00<005ZjF[X01EZj00<005[KF]/0
2E[K0P0000=Ff`00F]/03U[K0`0047oo000=Ool00`00Oomoo`05Ool20002Ool00`00E_aFo00?E_`2
000>E_d20002Ead3000:Dad00`00DaiC7P06Dah40002Bcl2000;Cel00`00>IDiU@09>ID00`00DOAA
m005DO@01@00Og5oLGma00003ejH00<0037j<OX00P001Cgh00<003fE?ID023fE00<004FdAK@02dFd
00@0057CDM<000iB5P03001V]fJg00=V]`03001JVEZI00IJV@04001NfP000007G]X20003F[X2000>
F]/00`00F]]Jf`0>F]/200000goo001oo`0>Ool000eoo`03001oogoo00Moo`800003E_`0000000iF
o003001Fo5Kl008000]Fo@8000IG7@8000MC7@03001C7U<N00]C7P<000]?G`8000`iU@03001Am57d
00AAm004001oLGma000AGYP20008?OP00`00?IDmU@08?ID00`00AKA5]009AK@00`00DM=Ad`02DM<0
0`00DQIB5P0:DQH00`00I[MV]`05I[L00`00FYUJV@05FYT01@00G]YNfUkJ000025kJ00<005Zj0000
3e[K00@005[k000000eJf`05001oogooOol0000?Ool000eoo`03001oogoo00Moo`03001Fo5Kl009F
o08000]Fo003001Fo5Kl00=Fo08000QFo@8000UG7@<0009C7@8000iC7P03001G?ELm00<000M?G`04
001KGE]M000;>ID00`00DOAAm003DO@01000Og5oLGma0P003ejH00<0059H000023gh00<003fE?ID0
23fE00<004FdAK@02DFd00<0057CDM<00e7C00<0058FDQH02E8F00<006JgI[L01VJg00<005ZIFYT0
0eZI00<005kJG]X00ekJ0P001ekJ00<005[KF]/03E[K00<005[kF_/00U[k00<005[KF]/02E[K00<0
07ooOol00Woo00<007ooOol03Goo000=Ool00`00Oomoo`06Ool00`00E_aFo005E_`20007E_`20008
E_`20005E_d00`00EaeG7@0<Ead3000=Dah20006Ecd40002Cel01@00FeeKGE]M000033VE00<0057d
DO@00U7d00@007maOg40009N^@8000aNV004001BF59H0008?OP00`00?IDmU@08?ID00`00AKA5]008
AK@00`00DM=Ad`04DM<00`00DQIB5P08DQH00`00I[MV]`08I[L01@00FYUJVEZI000025kJ00<005kJ
G]X00ekJ00@005kk000000aJf`03001Jne[k00AJn`8000MJf`8000Aoo`8000moo`003Goo00<007oo
Ool01Goo00<005KlE_`025Kl0P0015Kl00<005KlE_`02UKl0P000UKm00<005LMEad03ELM00<005LM
Ead00P002U<N00<005LmEcd02ULm0`0015]M00<003VE>ID02CVE00<0057dDO@00U7d00@007maOg40
00AN^@03001NV5jH00QNV003001BF59H009BF003000mn3gh00Hmn003000mUCfE00PmU@030015]4Fd
00M5]003001Ade7C00EAd`03001B5U8F00IB5P03001V]fJg00YV]`03001JV@0000YNfP80009NfP03
001Nnekk009Nn`03001Jfe[K00MJf`8000UJn`03001Jfe[K00=Jf`03001oogoo00Eoo`03001oogoo
00eoo`0037oo00<007ooOol01Goo00<005KlE_`02eKl0P0000=Fo000E_`03UKl0`003ELM0P001ELM
0`001U<N00<005LmEcd02eLm00<005/LFa`00`0000=KG@00>ID02SVE00<0057dDO@00U7d00<007ma
00001Uji00<005jHGYP01UjH00<0059HDUP0159H00<003gh?OP01Cgh00<003fE?ID023fE00<004Fd
AK@01dFd00<0057CDM<01U7C00<0058FDQH01E8F00<006JgI[L02fJg00<005kJG]X02ekJ0P001Ukk
0P001U[K00<005[kF_/02U[k0P0000=Jf`00000027oo00<007ooOol03Goo000<Ool00`00Oomoo`04
Ool00`00E_aFo00>E_`2000?E_`00`00E_aFo002000:Ead00`00EaeG7@08Ead20002Dah2000=Ecd0
0`00FaaK7004Fa`3000;>ID01P00DOAAm000Og4000QN^@03001NV5jH00ANV003001BF59H00EBF003
000mn3gh00Hmn003000mUCfE00PmU@030015]4Fd00E5]003001Ade7C00MAd`03001B5U8F00AB5P03
001V]fJg00]V]`04001[6@00000;G]X00`00G_/00007G_/00`00F]]Jf`02F]/00`00F_]Jn`0=F_/0
0`00Oomoo`07Ool3000>Ool000aoo`03001oogoo00=oo`8000mFo003001Fo5Kl008000aFo003001F
o5Kl00=Fo0<000IG7@03001G7ELM00]G7@<000eG?@03001K75/L00MK7003000iUCVE00TiU@06001A
m57d001oL@002Eji0P000ejH00<0059HDUP01e9H00<003gh?OP01Cgh00<003fE?ID023fE00<004Fd
AK@01DFd00<0057CDM<0257C00<0058FDQH00e8F00<006JgI[L02fJg00D006/IJaU[6@0000UNfP04
001NnekkG_/20006G_/200000e[K001Jn`0>F_/00`00Oomoo`0:Ool00`00Oomoo`0<Ool000aoo`03
001oogoo009oo`03001Fo5Kl008000aFo003001Fo5Kl00=Fo08000QFo08000UFo080009G7@8000iG
7@03001K75/L008000UG?@8000YK7003000iUCVE00XiU@04001Am000000<G[T00`00GYP0000;DUP0
0`00?OPmn005?OP00`00?IDmU@07?ID00`00AKA5]005AK@00`00DM=Ad`08DM<00`00DQIB5P02DQH0
0`00I[MV]`0;I[L00`00JaU[6@03JaT20006G]X00`00G_]Nn`04G_/00`00G_]Nn`05G_/00`00F_]J
n`0<F_/2000=Ool00`00Oomoo`0<Ool000aoo`05001oogooOol00005E_`20008E_`20008E_`20005
E_`00`00E_aFo00;E_`3000>Ead00`00FaaK7003Fa`30005Ecd00`00FaaK700;Fa`00`00>IDiU@09
>ID00`00DO@0000>G[T00`00DUQBF00:DUP00`00?OPmn005?OP00`00?IDmU@08?ID00`00AKA5]003
AK@00`00DM=Ad`0:DM<01@00DQIB5U8F00003FJg00<006/IJaT01F/I00<005kJG]X00UkJ00<005kk
G_/01Ukk0P0015kk00@005kk000000]Jn`03001oogoo00eoo`03001oogoo009oo`<000Moo`0037oo
00@007oo000000QFo08000EFo003001Fo5Kl00YFo080009Fo003001Fo5Kl00aFo003001Fo5Kl0080
00]G7@03001K75/L00MK7080009G?@03001K75/L00]K708000`iU@8000eN^@03001JV@0000aBF003
000mn3gh00@mn003000mUCfE00PmU@030015]4Fd00=5]003001Ade7C00]Ad`03001B5P0000eV]`03
001[6F/I00M[6@800003G]X005kk00YNn`800003G_/005kk00=Nn`8000QJn`03001oogoo00eoo`80
00Aoo`03001oogoo00Moo`002goo00<007oo000035Kl0P000UKl00<005KlE_`03EKl0P003UKl00<0
05KlE_`00eKl0P0025LM00<005/LFa`02U/L0`0035/L00@005kkG_/000/iU@03001N^Eji00]N^@05
001JVEZIFYT0000<DUP00`00?OPmn004?OP00`00?IDmU@07?ID00`00AKA5]003AK@00`00DM=Ad`0;
DM<00`00DQH0000<I[L00`00JaU[6@0:JaT00`00G_]Nn`0<G_/00`00G_]Nn`05G_/20004F_/2000B
Ool00`00Oomoo`02Ool00`00Oomoo`06Ool000]oo`8000mFo0<000mFo004001Fo000000;E_`00`00
E_aFo006E_`20005Ead00`00FaaK700;Fa`00`00F_aJo0020009Fa`01@00G_]Nnekk00002SVE0`00
2eji00<005ZIFYT00eZI00<0059HDUP02E9H00<003gh?OP013gh00<003fE?ID023fE00D004FdAKA5
]00000mAd`03001V]fJg00]V]`03001[6F/I00U[6@04001W>`00000:G_/200000ekk00000007G_/2
00000e[k001oo`0COol00`00Oomoo`02Ool00`00Oomoo`06Ool000]oo`8000mFo003001Fo5Kl0080
00aFo003001Fo5Kl009Fo08000QFo003001Fo5Kl00UFo080009G7@03001K75/L00]K7003001Jo5[l
00=Jo0<000EK7003001Nnekk009Nn`03000iUCVE00LiU@05001NfUkJG]X00009G[T00`00FYUJV@05
FYT00`00DUQBF009DUP00`00?OPmn004?OP00`00?IDmU@07?ID01@00AKA5]4Fd00003e7C0`002VJg
00<006/IJaT02F/I00<006LkIc/00VLk0P001ekk00<005kkG_/00ekk00<005kkG_/01Ukk00<007oo
Ool04Woo0P000goo00<007oo00001goo000;Ool01000Ool0000035Kl00<005KlE_`00eKl0P0025Kl
0P001eKl0P001EKl00<005KlE_`035Kl0`0035/L00<005[lF_`01e[l0P000U/L00<005kkG_/015kk
00<003VE>ID01CVE00<005kJG]X00ekJ0P001Uji00<005ZIFYT01UZI00<0059HDUP02U9H00<003gh
?OP00cgh00<003fE?ID023fE00<004Fd0000457C00<007mBOe800P001fJg00<006/IJaT02V/I00<0
06LkIc/016Lk0P0015kk00<005kkG_/01Ekk0P001Ekk00<007ooOol057oo00<007ooOol00Woo00<0
07ooOol01Woo000;Ool01000Oomoogoo0P0025Kl0P0025Kl0P001EKl0P002UKl0P000UKl00<005Kl
E_`03EKl00<005[lF_`00P002E/L00<005[lF_`02U[l0P001ekk00<003VE>ID00cVE0P0025kJ00<0
05jiG[T00Uji00<005ZIFYT025ZI00<0059HDUP02E9H00<003gh?OP00cgh00<003fE?ID023fE00<0
04Fd00003e7C00<007mBOe800gmB00<006JgI[L016Jg00<006/IJaT02F/I00<006LkIc/01fLk0P00
00=Nn`00G_/02Ekk00D005kkG_]Nn`0001Moo`03001oogoo00]oo`002goo00<007ooOol00goo0P00
1EKl00<005KlE_`02UKl0P000UKl0P003EKl0`003EKl0P001E[l0`001E/L00<005[lF_`02e[l00@0
05[k000000INn`04000iUCVE>ID2000:G]X200000eji001JV@0;FYT00`00DUQBF008DUP20005?OP0
0`00?IDmU@07?ID00`00AK@0000?DM<00`00Oe9oDP04Oe820003I[L00`00JaU[6@09JaT00`00Ic]W
>`0:Ic/00`00G_]Nn`0:G_/3000HOol00`00Oomoo`0;Ool000Yoo`03001oogoo00Ioo`80009Fo003
001Fo5Kl00eFo0<000iFo003001Fo5Kl008000YFo003001Jo5[l00QJo080009K7003001Jo5[l00]J
o003001Jne[k009Jn`8000ANn`03000iUCVE008000eNfP03001JVEZI00aJV@03001BF59H00ABF0<0
0092>P8000<mn003000mUCfE00PmU@03001Ade7C00iAd`03001oDWmB00IoDP800003I[L006/I00U[
6@03001W>fLk00YW>`04001O7000000:G_/4000FOol00`00Ool0000<Ool000Yoo`03001oogoo00Qo
o`<000mFo0@000aFo003001Fo5Kl00=Fo0<000IFo003001Jo5[l00]Jo08000eJo003001Jne[k00EJ
n`8000=Nn`<000eNfP03001J^P0000iJV@03001BF59H00<000E2>P030000m`0000<mn003000mUCfE
00HmU@80011Ad`03001oDWmB00QoDP8000U[6@03001W>fLk00YW>`03001O75lL009O708000MNn`03
001oogoo009oo`03001oogoo01Eoo`03001oogoo00Yoo`002Woo00<007ooOol02goo0P0035Kl0P00
0eKl0P0025Kl0P002EKl0P000UKl0P003U[l00@005[l000000YJo003001Jne[k00QJn`800003G_/0
000000eNfP05001J^UZjF[X0000>FYT20009@SX01P000?L00000?OP000DmU@<00003>E@0057C00mA
d`03001oDWmB00QoDP03001k]`00008000I[6@03001W>fLk00UW>`03001O75lL00EO708000ANn`03
001oogoo00Aoo`8001Eoo`03001oogoo00Yoo`002Woo00<007ooOol03Goo0P0025Kl0`001UKl0P00
1EKl00<005KlE_`02eKl0P003e[l00<005[lF_`00U[l0P0025[l00<005[kF_/02U[k0P003EkJ00<0
05ZjF[X00eZj00<005ZIFYT02UZI00<005:J00002T8j00<0003g0?L00`0000@mU@00000000DiE003
001Ade7C00aAd`03001oDWmB00QoDP03001k]g^g00=k]`<0009[6@03001W>fLk00QW>`8000YO7080
0003G_/007oo00Qoo`03001oogoo019oo`03001oogoo00Yoo`002Woo00<007ooOol03goo0P001EKl
0P002UKl0P000UKl00<005KlE_`035Kl00@005Kl000000aJo003001Jo5[l00EJo08000EJo003001J
ne[k00]Jn`04001Jf`00000:G]X00`00F[YJ^P05F[X20008FYT20003DYX00`00@SY2>P07@SX00`00
0?L0m`020?L20008>E@00`00DM=Ad`0<DM<00`00Oe9oDP08Oe800`00NkMk]`06NkL30009Ic/00`00
GaaO700<Ga`00`00Oomoo`09Ool2000AOol2000<Ool000Yoo`03001oogoo015oo`80009Fo08000eF
o08000iFo003001Fo5Kl009Fo08000QJo08000YJo080009Jo003001Jne[k00]Jn`03001Jfe[K009J
f`8000MNfP03001J^UZj00QJ^P03001JVEZI00AJV@03001BVU:J00ABVP030012>T8j00M2>P050000
m`3g0?L0000:>E@00`00DM=Ad`0;DM<00`00Oe9oDP07Oe800`00NkMk]`07NkL00`00IgaWO0020006
Ic/00`00GaaO700<Ga`00`00Oomoo`0<Ool2000AOol00`00Oomoo`09Ool000Uoo`03001oogoo01Ao
o`<000iFo004001Fo000000;E_`00`00E_aFo005E_`20005F_`00`00F_aJo00<F_`3000<F_/00`00
F]]Jf`05F]/20004G]X00`00F[YJ^P0:F[X00`00FYUJV@02FYT00`00DYYBVP06DYX00`00@SY2>P06
@SX00`000?L0m`020?L00`00>E@iE007>E@00`00DM=Ad`0;DM<00`00Oe9oDP07Oe800`00NkMk]`06
NkL00`00IgaWO003Ig`30002Ic/00`00GaaO700;Ga`2000AOol00`00Oomoo`0>Ool00`00Oomoo`09
Ool000Uoo`03001oogoo01Eoo`<000aFo003001Fo5Kl009Fo08000QFo003001Fo5Kl00QFo080009J
o003001Jo5[l00eJo003001Jne[k008000QJn`8000YJf`800003G]X005Zj00eJ^P04001JV@00000:
DYX00`00@SY2>P06@SX01@000?L0m`3g00002CUD00<0057CDM<02e7C00<007mBOe801WmB00<007^g
NkL01W^g00<006MlIg`01fMl0`0035lL00<007ooOol04Woo0P003Goo0P002goo0009Ool00`00Oomo
o`0DOol01000Oomoogoo0P0025Kl0P001eKl0P001EKl00<005KlE_`02eKl0P003e[l00<005[kF_/0
0e[k0P001E[k00<005[KF]/035[K00<005ZjF[X03UZj00<005:JDYX02e:J00<0048j@SX01T8j00@0
003g0?L000XiE003001Ade7C00UAd`03001oDWmB00MoDP03001k]g^g00Ek]`03001WO6Ml00QWO003
001O?5ll008000UO7003001oogoo01Eoo`03001oogoo00]oo`03001oogoo00Uoo`002Goo00<007oo
Ool04goo00<007ooOol017oo0P001EKl00<005KlE_`02EKl0P000UKl00<005KlE_`035Kl00@005[l
000000aJo003001Jne[k00IJn`80009Jn`03001Jfe[K00aJf`04001Jf`00000=F[X00`00E[X0000=
DYX00`00@SY2>P05@SX01@000?L0m`3g00002CUD00<0057CDM<02E7C00<007mBOe801WmB00<007^g
NkL01G^g00<006MlIg`026Ml00<005llGc`00ell0P001ElL0P006Goo0P002goo00<007ooOol02Goo
0009Ool00`00Oomoo`0BOol00`00Oomoo`07Ool20002E_`00`00E_aFo00<E_`3000=E_`00`00F_aJ
o002F_`20008F_`2000;F_/2000>F]/00`00F]]Jf`02F]/00`00F[YJ^P09F[X01000E[YF^UJj0P00
35:J00<0048j@SX01D8j00@0003g0?L000XiE003001Ade7C00QAd`03001oDWmB00IoDP03001k]g^g
00Ak]`03001WO6Ml00QWO003001O?5ll00IO?080009O7003001oogoo01]oo`8000Yoo`03001oogoo
00Qoo`002Goo00<007ooOol04Goo00<007ooOol02Woo0P003eKl00<005KlE_`00P002EKl0P001e[l
0P001E[l00<005[kF_/02e[k00@005[K000000]Jf`03001Jfe[K00AJf`03001J^UZj00MJ^P03001F
^UJj00AF^P03001BVU:J00YBVP030012>T8j00E2>P030000m`0000XiE003001Ade7C00QAd`03001o
DWmB00EoDP03001k]g^g00Ak]`03001WO6Ml00MWO08000]O?080021oo`03001oogoo00Ioo`8000Ao
o`8000Aoo`0027oo00<007ooOol04Goo00<007ooOol03Goo0P0035Kl00<005KlE_`00eKl0`001EKl
00<005[lF_`02E[l0P000U[l00<005[kF_/02e[k00<005[KF]/00U[K0P0025[K00<005[KF]/01U[K
0P001UZj00<005JjE[X01UJj00<005:JDYX02U:J10000d8j00@0003g0?L000TiE003001Ade7C00MA
d`03001oDWmB00IoDP03001k]g^g00=k]`03001WO6Ml00MWO003001O?5ll00]O?003001oogoo021o
o`8000Moo`03001oogoo00Aoo`03001oogoo005oo`0027oo00<007ooOol047oo00<007ooOol047oo
0P0025Kl0P002EKl0P000UKl00<005[lF_`035[l0`0035[k00<005[KF]/01E[K00<005[KF]/01E[K
00<005[KF]/025[K00<005ZjF[X00UZj00<005JjE[X025Jj00<005:JDYX01e:J0P0000A:W0007QdN
7@D000030?L003UD00TiE003001Ade7C00IAd`03001oDWmB00EoDP03001k]g^g00=k]`8000QWO003
001O?5ll00YO?08002Eoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo009oo`0027oo00<0
07ooOol03goo00<007ooOol04goo0P001EKl00<005KlE_`02eKl0P003e[l00<005[kF_/00P002E[k
00<005[KF]/01e[K0P0015[K00<005[KF]/02U[K0P0000=J^P00E[X02eJj0P001E:J0P0014ZL00<0
01hM7Qd00ahM00<0003g00002SUD00<0057CDM<01U7C00<007mBOe801GmB00@007^gNkMk]`80009K
WP@000=WO003001O?5ll00YO?003001oogoo02Ioo`8000Aoo`03001oogoo00Aoo`03001oogoo005o
o`0027oo00<007ooOol03Goo0P0067oo0P000UKl00<005KlE_`035Kl00@005Kl000000aJo003001J
ne[k00=Jn`<000EJn`03001Jfe[K00YJf`800003F]/005[K00iJf`03001F^UJj00eF^P03001BVU:J
008000M:W003000N7AhM00<N7@030000m`0000TiE003001Ade7C00IAd`03001oDWmB00AoDP05001k
]g^gNkL00008Fih4000;Gc`00`00Oomoo`0YOol200000goo00000004Ool00`00Ool00003Ool000Qo
o`03001oogoo00aoo`03001oogoo01Yoo`8000iFo003001Fo5Kl009Fo08000QJo08000UJn`80009J
n`03001Jfe[K00eJf`03001Jfe[K00eJf`03001Ff`0000mF^P8000Y:W08000<N7@030000m`0000Xi
E003001Ade7C00EAd`03001oDWmB00AoDP04001k]`00000:Fih00`00FceK?@030006Gc`2000^Ool0
1000Oomoo`0017oo00<007ooOol00Woo0008Ool00`00Oomoo`0;Ool00`00Oomoo`0MOol2000;E_`0
0`00E_aFo005E_`20005F_`00`00F_]Jn`0;F_/2000?F]/01000F]/0000035[K00@005KKE]]Ff`80
00aF^P03001B^`0000a:W004000N7AhM7Qd2000:>E@00`00DM=Ad`04DM<00`00Oe9oDP04Oe83000:
Fih20006Fcd30002Gc`00`00Oomoo`0_Ool30009Ool000Moo`03001oogoo00]oo`03001oogoo021o
o`8000QFo003001Fo5Kl00QFo080009Jo003001Jne[k00aJn`04001Jf`00000<F]/00`00F]]Jf`02
F]/00`00F]]Jf`08F]/00`00E]]Ff`04E]/00`00E[YF^P07E[X20003D[/2000;BY`01P007QdN7@00
0?L000XiE003001Ade7C00=Ad`03001oDWmB00AoDP8000YKWP03001K?E/m00UK?@8003Aoo`03001o
ogoo00Moo`001goo00<007ooOol02Woo00<007ooOol08goo0P001EKl00<005KlE_`02eKl0P003U[k
00<005[KF]/00U[K00<005[KF]/025[K00<005[KF]/015[K0P001U[K0P0025KK00<005JjE[X01EJj
00<005:kD[/01E:k00<004ZLBY`02DZL00<001hM7Qd00P002SUD00<0057CDM<00e7C00<007mBOe80
0gmB0`002E^N00<005/mFcd02E/m0P00<goo0P002Woo0007Ool00`00Oomoo`09Ool00`00Oomoo`0V
Ool20002E_`00`00E_aFo00<E_`01000F_`000002e[k00<005[KF]/015[K0P001U[K0P002E[K00<0
05[KF]/00U[K00<005KKE]/02EKK0P0015Jj00<005:kD[/01e:k00<004ZLBY`024ZL1@002SUD00<0
057CDM<00e7C00<007mBOe800WmB00@004LoAcm7?`@000=KWP8000]K?@03001oogoo039oo`03001o
ogoo00Yoo`001goo00<007ooOol027oo00<007ooOol0:Goo0`003EKl00<005[lF_`00U[l0P0025[k
00<005[KF]/01e[K00<005[KF]/00U[K00<005[KF]/02U[K0P0000=Jf`00E]/03EKK00@005Jj0000
00]B^`8000I:W0800096_@8000030?L003UD00TiE003001Ade7C009Ad`03001oDWmB009oDP030017
?dLo00E7?`@000YK?@8003=oo`8000eoo`001goo00<007ooOol01goo00<007ooOol0;Goo0P002EKl
0P001e[l0P001E[k00<005[KF]/02E[K0P0000=Jf`00F]/03U[K00<005KKE]/03UKK00<005:kD[/0
3E:k00<004ZLBY`00`001TJm0P002SUD00D0057CDM=Ad`0000AoDP030017?dLo00I7?`80009C7P80
00MK?@03001oogoo035oo`8000moo`001goo00<007ooOol01Woo00<007ooOol0<7oo0`001EKl00<0
05[lF_`02E[l0P000U[k00<005[KF]/035[K00<005[KF]/03E[K00@005KK000000aFf`800003E]/0
000000iB^`8000U6_@030000m`0000XiE004001Ade7C0003Oe800`00Acm7?`05Acl20006Dah30002
Fcd2000cOol00`00Oomoo`0?Ool000Ioo`03001oogoo00Ioo`03001oogoo03Aoo`80009Fo003001J
o5[l00aJo08000iJf`04001Ff`00000<F]/00`00E]]Ff`02E]/20009E]/00`00E]]Ff`03E]/00`00
D[]B^`09D[/200000dkL00000009A[d2000:>E@01000DM=Ad`000WmB00<004LoAcl014Lo0P002e<N
0P00<goo0P004Woo0006Ool00`00Oomoo`05Ool00`00Oomoo`0gOol2000?F_`01000E_/000002e[K
00<005KKE]/00UKK0P0025[K0P001eKK0P001EKK0P001eKK0P0025:k00<004kLC]`00dkL00<004Jm
A[d01TJm0P002SUD00L0057CDM<007mB0016oP020002Acl2000<Dah2000cOol00`00Oomoo`0BOol0
00Ioo`03001oogoo00Aoo`03001oogoo03Yoo`8000aJo003001FneKk009Fn`8000MJf`8000MFf`80
00EJf`03001FfeKK00UFf`800003E]/0000000]Ff`03001B^e:k00=B^`8000M>g08000M6_@8000Xi
E004001Ad`000004A_h3000<Dah00`00Oomoo`0aOol2000EOol000Ioo`03001oogoo009oo`8003mo
o`8000QJo08000MFn`8000AJf`03001FfeKK00UFf`80009Jf`03001FfeKK00aFf`03001FfeKK00aF
f`800003D[/0000000]>g0030016_DJm00A6_@8000XiE0800003Oe8004Kn0096oP80009>oP<000MC
7P8003=oo`03001oogoo01Eoo`001Woo00D007ooOomoo`0004=oo`8000EJo003001FneKk00UFn`80
0003F]/005KK00eFf`8000iFf`04001Ff`00000>E]/00`00C]a>g00<C]`20002A[d200000d[M000i
E00:>E@20002A_h20007C_h30002Dah2000cOol2000HOol000Ioo`04001oogoo0016Ool20002F_`0
0`00E_]Fn`0<E_/00`00E]]Ff`0=E]/01000E]/000002eKK00<005KKE]/00UKK00<005KKE]/02EKK
0P0000=Bg00000003TkL0P000d[M0P002SUD00@004Kn000000a>oP8003Aoo`03001oogoo01Qoo`00
1Goo00@007ooOol004Uoo`8000iFn`04001Ff`00000;E]/20004E]/20007E]/20006E]/20008E]/0
0`00D]aBg003D]`00`00C]a>g009C]`200000e;L00000002B]d20009>E@3000=C_h2000cOol2000K
Ool000Eoo`03001oo`0004aoo`8000]Fn`03001FfeKK009Ff`8000QFf`03001FfeKK00IFf`8000AF
f`03001FfeKK00QFf`03001FfeKK00=Ff`8000MBg08000Q>g003001Bg5;L00=Bg004001:gD[M0007
>E@20002C_d2000:C_h2000cOol2000MOol000Eoo`8004moo`8000MFn`8000MFf`8000EFf`03001F
feKK00UFf`800003E]/005KK00]Ff`800003E]/0000000]Bg003001>g4kL00=>g08000MBg0@000Di
E003001>oDkm00A>o@8000I>oP8003Aoo`03001oogoo01eoo`001Goo0P00DGoo0P0015Kk00<005KK
E]/02EKK0P0000=Ff`0000003UKK00<005KKE]/03EKK00<005;LD]`035;L0P0000=>g00000002e;L
0P0013UD00<004kmC_d01dkm0P000Tkn0P00=7oo0P0087oo0007Ool2001AOol200000eKk001Ff`0=
E]/00`00E]]Ff`0=E]/01000E]/0000035KK00@005KL000000iBg003001Bg5;L00aBg003000iE3UD
008000a>o@8003Eoo`03001oogoo021oo`002Goo0P00DGoo00<005KKE]/035KK00@005KK000000]F
f`8000AFf`03001FfeKK00QFf`03001Fg5KL009Fg003001Bg5;L00UBg0800003D]`0000000]Bg0D0
00a>o@8003Aoo`8002=oo`002goo0P00D7oo0P002eKK00<005KKE]/00UKK0P0025KK00<005KKE]/0
1EKK0P001UKK0P001UKL0P0025;L00<005;LD]`00e;L00<005;LD]`01e;L00@005;mD_d0009Bo@80
00U>o@03001oogoo03=oo`03001oogoo02=oo`003Goo0P00D7oo0P001eKK0P001eKK0P001EKK00<0
05KKE]/025KK00<005KKE]/00UKK00<005KLE]`025KL00<005;LD]`00e;L0P001e;L0P001E;L0P00
25;m0P001Dkm0P00=7oo0P009Woo000?Ool2001@Ool20004E]/00`00E]]Ff`09E]/200000eKK0000
000<E]/200000eKK001Fg00;E]`200000e;L0000000;D]`200000e;L0000000<D_d200000dkm0000
000dOol2000XOol0015oo`80051oo`800003E]/005KK00eFf`03001FfeKK00iFf`03001Fg5KL00eF
g003001Bg5;L00eBg003001BoE;m00iBo@03001oogoo03=oo`03001oogoo02Qoo`004goo0`00Cgoo
00<005KKE]/035KK00@005KL000000aFf`800003E]`0000000]Fg0800003E]`0000000]Bg0800003
D]`0000000aBo@8003Aoo`8002]oo`005Woo0P00CWoo0P002eKK00<005KLE]`00UKL0P002EKK00<0
05KLE]`00eKL00<005KLE]`01eKL00<005KLE]`00eKL0P0025;L00<005;LD]`00e;L0P002E;m00<0
07ooOol0<goo00<007ooOol0:goo000HOol2001>Ool20007E]/20007E]`20005E]/20007E]`20005
E]`20008E]`20005D]`00`00D]aBg006D]`20005D_d2000dOol2000^Ool001Yoo`8004ioo`8000AF
f`03001Fg5KL00UFg0800003E]/0000000]Fg0800003E]`0000000aFg0800003D]`0000000]Bg080
0003D_d0000003Eoo`03001oogoo02ioo`0077oo0P00CWoo0P0000=Ff`00E]`03EKL00<005KLE]`0
3EKL00<005KLE]`03UKL00<005;LD]`03E;L00<007ooOol0<goo0P00<Goo000NOol2001>Ool2000<
E]`200000eKL0000000;E]`200000eKL0000000<E]`200000eKL0000000;D]`2000eOol00`00Oomo
o`0aOol0021oo`<004eoo`8000UFg003001Fg5KL00=Fg08000QFg003001Fg5KL00=Fg08000UFg003
001Fg5KL00=Fg08000MBg08003Eoo`8003Aoo`008goo0P00CGoo0P001UKL00<005KLE]`01UKL0P00
1EKL00<005KLE]`01UKL0P001EKL0P0025KL0P000e;L0P00=Goo0P00=Woo000UOol2001=Ool20002
E]`2000;E]`200000eKL0000000;E]`200000eKL0000000<E]`3000fOol00`00Oomoo`0fOol002Mo
o`8004eoo`8000mFg003001Fg5KL00eFg08000aFg08003Ioo`8003Uoo`00:Goo0P00CGoo0P002eKL
0P0000=Fg00000002eKL0P000UKL0P002EKL00<007ooOol0=Goo00<007ooOol0>Goo000[Ool2001=
Ool20008E]`00`00E]aFg003E]`20008E]`00`00E]aFg004E]`20006E]`00`00Oomoo`0dOol2000l
Ool002eoo`8004eoo`8000EFg003001Fg5KL00IFg08000EFg003001Fg5KL00MFg080009Fg08003Io
o`03001oogoo03aoo`00;goo0`00C7oo0P0000=Fg00000002eKL0P0000=Fg000000035KL0P00=Woo
0P00?goo000bOol2001<Ool00`00E]aFg00=E]`00`00E]aFg00;E]`2000eOol20011Ool003Aoo`80
04]oo`8000]Fg0800003E]`0000000YFg003001oogoo03Aoo`03001oogoo045oo`00=Woo0P00Bgoo
00<005KLE]`01eKL00<005KLE]`00eKL0P001UKL0P00=Goo0P00A7oo000hOol2001:Ool20005E]`2
0008E]`20002E]`2000fOol00`00Oomoo`14Ool003Yoo`8004Yoo`800003E]`0000000aFg08003Io
o`8004Moo`00?7oo0`00BGoo0P0035KL0P00=Woo00<007ooOol0Agoo000oOol20019Ool20009E]`0
0`00Oomoo`0dOol2001:Ool0045oo`8004Uoo`8000IFg003001oogoo03Aoo`03001oogoo04Yoo`00
@goo0P00BGoo0P000UKL0P00=Goo0P00CGoo0015Ool20019Ool2000eOol2001?Ool004Moo`8004Qo
o`03001oogoo039oo`03001oogoo04moo`00BGoo0P00AWoo00<007ooOol0<7oo0P00DWoo001;Ool3
0013Ool00`00Oomoo`0_Ool00`00Oomoo`1BOol004ioo`80045oo`03001oogoo02eoo`8005Eoo`00
D7oo0P00?goo00<007ooOol0;7oo00<007ooOol0EGoo001BOol2000mOol00`00Oomoo`0ZOol2001H
Ool005Aoo`8003]oo`03001oogoo02Qoo`8005Yoo`00EWoo0P00>Goo00<007ooOol09goo00<007oo
Ool0FWoo001HOol3000fOol00`00Oomoo`0UOol2001MOol005]oo`8003Aoo`03001oogoo02Aoo`03
001oogoo05eoo`00GGoo0P00<Woo00<007ooOol08Woo0P00H7oo001OOol2000`Ool00`00Oomoo`0Q
Ool00`00Oomoo`1POol0065oo`8002ioo`03001oogoo01moo`8006=oo`00Hgoo0P00;7oo00<007oo
Ool07Woo00<007ooOol0Hgoo001UOol2000ZOol00`00Oomoo`0LOol2001VOol006Moo`<002Moo`03
001oogoo01Yoo`8006Qoo`00JWoo0P009Goo00<007ooOol06Goo00<007ooOol0J7oo001/Ool2000S
Ool00`00Oomoo`0GOol2001[Ool006ioo`80025oo`03001oogoo01Ioo`03001oogoo06]oo`00L7oo
0P007goo00<007ooOol057oo0P00KWoo001bOol2000MOol00`00Oomoo`0COol00`00Oomoo`1^Ool0
07Aoo`<001Yoo`03001oogoo015oo`80075oo`00Mgoo0P0067oo00<007ooOol03goo0P00Lgoo001i
Ool2000FOol00`00Oomoo`0>Ool00`00Oomoo`1cOol007]oo`8001Aoo`03001oogoo00aoo`8007Io
o`00OGoo0P004Woo00<007ooOol02goo00<007ooOol0MWoo001oOol2000@Ool00`00Oomoo`09Ool2
001iOol0085oo`8000ioo`03001oogoo00Qoo`03001oogoo07Uoo`00Pgoo0`002goo00<007ooOol0
1Woo0P00O7oo0026Ool20009Ool00`00Oomoo`05Ool00`00Oomoo`1lOol008Qoo`8000Moo`03001o
ogoo00=oo`8007moo`00RWoo0P001Goo00@007ooOomoo`80085oo`00S7oo0P000goo00@007ooOol0
08=oo`00SWoo0P0000Aoo`00000008Aoo`00T7oo0P00QWoo0000\
\>"],
  ImageRangeCache->{{{0, 279.25}, {238.938, 0}} -> {-0.00553266, -0.0140121, 
  0.00371842, 0.00371842}}]
}, Open  ]],

Cell[TextData[{
  "Here is the magnitude of the frequency response ",
  Cell[BoxData[
      \(TraditionalForm
      \`\( | H(\[ExponentialE]\^\(\ j\ \[Omega]\ \)) | \)\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[
      Abs[H[z]\  /. \ z -> \[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\)], 
      \ {\[Omega], \(-\[Pi]\), \[Pi]}]; \)\)], "Input",
  CellLabel->"In[50]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.151576 0.0147151 0.0967725 [
[.04527 .00222 -6 -9 ]
[.04527 .00222 6 0 ]
[.19685 .00222 -6 -9 ]
[.19685 .00222 6 0 ]
[.34842 .00222 -6 -9 ]
[.34842 .00222 6 0 ]
[.65158 .00222 -3 -9 ]
[.65158 .00222 3 0 ]
[.80315 .00222 -3 -9 ]
[.80315 .00222 3 0 ]
[.95473 .00222 -3 -9 ]
[.95473 .00222 3 0 ]
[.4875 .11149 -6 -4.5 ]
[.4875 .11149 0 4.5 ]
[.4875 .20826 -6 -4.5 ]
[.4875 .20826 0 4.5 ]
[.4875 .30503 -6 -4.5 ]
[.4875 .30503 0 4.5 ]
[.4875 .4018 -6 -4.5 ]
[.4875 .4018 0 4.5 ]
[.4875 .49858 -6 -4.5 ]
[.4875 .49858 0 4.5 ]
[.4875 .59535 -6 -4.5 ]
[.4875 .59535 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.04527 .01472 m
.04527 .02097 L
s
[(-3)] .04527 .00222 0 1 Mshowa
.19685 .01472 m
.19685 .02097 L
s
[(-2)] .19685 .00222 0 1 Mshowa
.34842 .01472 m
.34842 .02097 L
s
[(-1)] .34842 .00222 0 1 Mshowa
.65158 .01472 m
.65158 .02097 L
s
[(1)] .65158 .00222 0 1 Mshowa
.80315 .01472 m
.80315 .02097 L
s
[(2)] .80315 .00222 0 1 Mshowa
.95473 .01472 m
.95473 .02097 L
s
[(3)] .95473 .00222 0 1 Mshowa
.125 Mabswid
.07559 .01472 m
.07559 .01847 L
s
.1059 .01472 m
.1059 .01847 L
s
.13622 .01472 m
.13622 .01847 L
s
.16653 .01472 m
.16653 .01847 L
s
.22716 .01472 m
.22716 .01847 L
s
.25748 .01472 m
.25748 .01847 L
s
.28779 .01472 m
.28779 .01847 L
s
.31811 .01472 m
.31811 .01847 L
s
.37874 .01472 m
.37874 .01847 L
s
.40905 .01472 m
.40905 .01847 L
s
.43937 .01472 m
.43937 .01847 L
s
.46968 .01472 m
.46968 .01847 L
s
.53032 .01472 m
.53032 .01847 L
s
.56063 .01472 m
.56063 .01847 L
s
.59095 .01472 m
.59095 .01847 L
s
.62126 .01472 m
.62126 .01847 L
s
.68189 .01472 m
.68189 .01847 L
s
.71221 .01472 m
.71221 .01847 L
s
.74252 .01472 m
.74252 .01847 L
s
.77284 .01472 m
.77284 .01847 L
s
.83347 .01472 m
.83347 .01847 L
s
.86378 .01472 m
.86378 .01847 L
s
.8941 .01472 m
.8941 .01847 L
s
.92441 .01472 m
.92441 .01847 L
s
.01496 .01472 m
.01496 .01847 L
s
.98504 .01472 m
.98504 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .11149 m
.50625 .11149 L
s
[(1)] .4875 .11149 1 0 Mshowa
.5 .20826 m
.50625 .20826 L
s
[(2)] .4875 .20826 1 0 Mshowa
.5 .30503 m
.50625 .30503 L
s
[(3)] .4875 .30503 1 0 Mshowa
.5 .4018 m
.50625 .4018 L
s
[(4)] .4875 .4018 1 0 Mshowa
.5 .49858 m
.50625 .49858 L
s
[(5)] .4875 .49858 1 0 Mshowa
.5 .59535 m
.50625 .59535 L
s
[(6)] .4875 .59535 1 0 Mshowa
.125 Mabswid
.5 .03407 m
.50375 .03407 L
s
.5 .05342 m
.50375 .05342 L
s
.5 .07278 m
.50375 .07278 L
s
.5 .09213 m
.50375 .09213 L
s
.5 .13084 m
.50375 .13084 L
s
.5 .1502 m
.50375 .1502 L
s
.5 .16955 m
.50375 .16955 L
s
.5 .18891 m
.50375 .18891 L
s
.5 .22761 m
.50375 .22761 L
s
.5 .24697 m
.50375 .24697 L
s
.5 .26632 m
.50375 .26632 L
s
.5 .28568 m
.50375 .28568 L
s
.5 .32439 m
.50375 .32439 L
s
.5 .34374 m
.50375 .34374 L
s
.5 .3631 m
.50375 .3631 L
s
.5 .38245 m
.50375 .38245 L
s
.5 .42116 m
.50375 .42116 L
s
.5 .44051 m
.50375 .44051 L
s
.5 .45987 m
.50375 .45987 L
s
.5 .47922 m
.50375 .47922 L
s
.5 .51793 m
.50375 .51793 L
s
.5 .53729 m
.50375 .53729 L
s
.5 .55664 m
.50375 .55664 L
s
.5 .576 m
.50375 .576 L
s
.5 .6147 m
.50375 .6147 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .08613 m
.02499 .08613 L
.02605 .08614 L
.02729 .08614 L
.02846 .08615 L
.03053 .08616 L
.03279 .08619 L
.03527 .08622 L
.0379 .08626 L
.04262 .08636 L
.04749 .0865 L
.05205 .08665 L
.06244 .08711 L
.07305 .08773 L
.08274 .08844 L
.10458 .09059 L
.12357 .09316 L
.14429 .09688 L
.16396 .10152 L
.18493 .10804 L
.20635 .11704 L
.21615 .12226 L
.22652 .12876 L
.23609 .13591 L
.24659 .14538 L
.26507 .16809 L
.27527 .18569 L
.28458 .20667 L
.28972 .22111 L
.29532 .23989 L
.30056 .26128 L
.30549 .28571 L
.31489 .34883 L
.31988 .39438 L
.32527 .45478 L
.3306 .52318 L
.33352 .55901 L
.33494 .57424 L
.33622 .58598 L
.33742 .59454 L
.33854 .60019 L
.33973 .60329 L
.34102 .60305 L
.34166 .60153 L
.34235 .5988 L
.34308 .59481 L
.34375 .59005 L
.34497 .57928 L
.34627 .56489 L
.35584 .42432 L
Mistroke
.36109 .35481 L
.36602 .30208 L
.37188 .25316 L
.37719 .21868 L
.38223 .19235 L
.38755 .16962 L
.39751 .1369 L
.40666 .11449 L
.41651 .09569 L
.42731 .07934 L
.44686 .05677 L
.46779 .0383 L
.47799 .03047 L
.48907 .02242 L
.49414 .01883 L
.49692 .01687 L
.49829 .01592 L
.49953 .01504 L
.50061 .01514 L
.50175 .01594 L
.50413 .01762 L
.5092 .02119 L
.54736 .05124 L
.56701 .07202 L
.578 .08693 L
.58797 .1037 L
.59798 .12514 L
.6072 .15103 L
.61731 .19022 L
.62241 .2164 L
.62801 .25237 L
.6332 .29479 L
.63885 .35404 L
.64913 .49979 L
.65163 .53714 L
.65398 .56786 L
.65526 .58147 L
.65643 .59142 L
.65773 .59917 L
.65841 .60174 L
.65913 .60328 L
.66024 .60332 L
.66143 .60031 L
.66254 .59478 L
.66356 .58771 L
.66605 .56391 L
.6684 .53588 L
.67745 .42281 L
.68705 .33365 L
.69205 .29983 L
Mistroke
.69757 .26998 L
.70728 .23073 L
.71742 .20167 L
.7267 .18191 L
.73741 .16447 L
.74758 .15157 L
.75718 .14175 L
.7674 .13315 L
.7858 .12115 L
.80722 .11101 L
.8274 .10398 L
.84749 .09867 L
.86597 .09491 L
.88481 .09194 L
.90548 .0895 L
.925 .08786 L
.93595 .08719 L
.94592 .08673 L
.95346 .08647 L
.96042 .08629 L
.96406 .08623 L
.96615 .0862 L
.96807 .08618 L
.97009 .08616 L
.97112 .08615 L
.97226 .08614 L
.97325 .08614 L
.97417 .08614 L
.97515 .08613 L
.97619 .08613 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[50]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000DOol2
000WOol3000VOol5001;Ool5000UOol3000WOol2000DOol001Ioo`03001oogoo02Aoo`03001oogoo
02Qoo`03001oogoo04eoo`03001oogoo02Eoo`03001oogoo02Uoo`03001oogoo015oo`003goo0`00
0goo00<007ooOol087oo0`000goo00<007ooOol08Goo0`000goo00<007ooOol0CGoo00<007ooOol0
9Woo00<007ooOol09goo00<007ooOol04Woo000FOol00`00Oomoo`0UOol00`00Oomoo`0WOol00`00
Oomoo`1=Ool00`00Oomoo`0VOol00`00Oomoo`0XOol00`00Oomoo`0AOol001Aoo`03001oo`0002Io
o`03001oo`0002Qoo`03001oogoo04eoo`03001oogoo02Eoo`03001oo`0002Moo`03001oo`0001=o
o`005Goo00<007ooOol09Woo00<007ooOol09Woo0P00CWoo0P00:7oo00<007ooOol09goo00<007oo
Ool04Woo003oOolQOol008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomo
o`2>Ool008moo`03001oogoo08ioo`001gooo`004P0027oo000;Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomo
o`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`03Ool40006Ool0
0`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool0
0`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool0
0`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool0
0`00Oomoo`0:Ool001=oo`03001oogoo02Ioo`03001oogoo02Moo`03001oogoo02=oo`05001oogoo
001oo`02000UOol00`00Oomoo`0WOol00`00Oomoo`0VOol00`00Oomoo`0BOol008Yoo`8000=oo`05
001oogooOol0002<Ool008Uoo`03001oogoo00=oo`03001oogoo009oo`8008Yoo`00Qgoo0P001Woo
0P001Goo00<007ooOol0Qgoo0026Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`26Ool0
08Eoo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo08Eoo`00Q7oo00<007ooOol027oo00<0
07ooOol01goo0P00QGoo0023Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`22Ool0089o
o`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo085oo`00PGoo00<007ooOol02goo0P0037oo
00<007ooOol0P7oo0020Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`1oOol007moo`03
001oogoo00eoo`03001oogoo00aoo`03001oogoo07moo`00OWoo00<007ooOol03Woo00<007ooOol0
3Goo00<007ooOol0OWoo001nOol00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`1mOol007eo
o`03001oogoo00moo`80011oo`03001oogoo07aoo`00O7oo00<007ooOol047oo00<007ooOol047oo
00<007ooOol0Ngoo001kOol00`00Oomoo`0AOol00`00Oomoo`0@Ool00`00Oomoo`1kOol000eoo`D0
06Qoo`03001oogoo019oo`03001oogoo015oo`03001oogoo06Moo`D000ioo`004Woo3P00FGoo00<0
07ooOol04goo00<007ooOol04Woo00<007ooOol0EGoo4@004goo000POol;001>Ool00`00Oomoo`0C
Ool2000DOol00`00Oomoo`1>Ool6000TOol002]oo`D004Qoo`03001oogoo01Aoo`03001oogoo01=o
o`03001oogoo04Uoo`D002Yoo`00<7oo0P00AWoo00<007ooOol057oo00<007ooOol057oo00<007oo
Ool0@goo1@00;goo000bOol40011Ool00`00Oomoo`0=Ool50003Ool00`00Oomoo`0EOol00`00Oomo
o`0mOol5000dOol003Ioo`@003eoo`03001oogoo00moo`03001oogoo00=oo`03001oogoo01Eoo`03
001oogoo03]oo`8003Uoo`00>Woo0P00>Woo00<007ooOol047oo00<007ooOol00goo0`005Woo00<0
07ooOol0>7oo0P00>goo000lOol2000hOol00`00Oomoo`0@Ool00`00Oomoo`03Ool00`00Oomoo`0F
Ool00`00Oomoo`0fOol2000mOol003ioo`<003Aoo`03001oogoo015oo`03001oogoo00=oo`03001o
ogoo01Moo`03001oogoo03=oo`8003moo`00@Goo0P00<Woo00<007ooOol047oo0P001Goo00<007oo
Ool05goo00<007ooOol0<Goo0P00@Goo0013Ool00`00Oomoo`0^Ool00`00Oomoo`0HOol00`00Oomo
o`0HOol00`00Oomoo`0^Ool20013Ool004Aoo`03001oogoo02eoo`03001oogoo01Qoo`03001oogoo
01Qoo`03001oogoo02aoo`8004Eoo`00AGoo0P00;7oo00<007ooOol06Goo0P006Woo00<007ooOol0
:Woo00<007ooOol0AGoo0017Ool00`00Oomoo`0YOol00`00Oomoo`0IOol00`00Oomoo`0IOol00`00
Oomoo`0YOol00`00Oomoo`16Ool004Qoo`03001oogoo02Qoo`03001oogoo01Uoo`03001oogoo01Uo
o`03001oogoo02Qoo`03001oogoo04Moo`00BGoo00<007ooOol09Woo00<007ooOol06Woo00<007oo
Ool06Goo00<007ooOol09goo00<007ooOol0B7oo001:Ool00`00Oomoo`0UOol00`00Oomoo`0JOol0
0`00Oomoo`0JOol00`00Oomoo`0UOol00`00Oomoo`19Ool004]oo`03001oogoo02Aoo`03001oogoo
01Yoo`8001]oo`03001oogoo02Aoo`03001oogoo04Yoo`00C7oo00<007ooOol08Woo00<007ooOol0
6goo00<007ooOol06Woo00<007ooOol08goo00<007ooOol0Bgoo001<Ool00`00Oomoo`0ROol00`00
Oomoo`0KOol00`00Oomoo`0KOol00`00Oomoo`0QOol00`00Oomoo`1<Ool004eoo`03001oogoo025o
o`03001oogoo01]oo`03001oogoo01]oo`03001oogoo025oo`03001oogoo04aoo`00CWoo00<007oo
Ool07goo00<007ooOol077oo00<007ooOol06goo00<007ooOol087oo00<007ooOol0CGoo001?Ool0
0`00Oomoo`0NOol00`00Oomoo`0LOol2000LOol00`00Oomoo`0OOol00`00Oomoo`1>Ool0051oo`03
001oogoo01eoo`03001oogoo01aoo`03001oogoo01aoo`03001oogoo01ioo`03001oogoo04ioo`00
D7oo00<007ooOol07Goo00<007ooOol077oo00<007ooOol077oo00<007ooOol07Goo00<007ooOol0
Cgoo001AOol00`00Oomoo`0KOol00`00Oomoo`0MOol00`00Oomoo`0LOol00`00Oomoo`0MOol00`00
Oomoo`1?Ool0055oo`03001oogoo01]oo`03001oogoo01eoo`03001oogoo01aoo`03001oogoo01ao
o`03001oogoo051oo`00DWoo00<007ooOol06Woo00<007ooOol07Goo0P007Woo00<007ooOol06Woo
00<007ooOol0DGoo001BOol00`00Oomoo`0JOol00`00Oomoo`0MOol00`00Oomoo`0MOol00`00Oomo
o`0JOol00`00Oomoo`1AOol005=oo`03001oogoo01Uoo`03001oogoo01eoo`03001oogoo01eoo`03
001oogoo01Uoo`03001oogoo059oo`00Dgoo00<007ooOol06Goo00<007ooOol07Goo00<007ooOol0
7Goo00<007ooOol06Goo00<007ooOol0DWoo001DOol00`00Oomoo`0HOol00`00Oomoo`0FOol30004
Ool00`00Oomoo`0MOol00`00Oomoo`0HOol00`00Oomoo`1COol005Aoo`03001oogoo01Moo`03001o
ogoo01Moo`03001oogoo00Aoo`03001oogoo01ioo`03001oogoo01Moo`03001oogoo05=oo`00E7oo
00<007ooOol05goo00<007ooOol067oo00<007ooOol00goo0`007Woo00<007ooOol05Woo00<007oo
Ool0E7oo001EOol00`00Oomoo`0FOol00`00Oomoo`0HOol00`00Oomoo`03Ool00`00Oomoo`0NOol0
0`00Oomoo`0FOol00`00Oomoo`1DOol005Eoo`03001oogoo01Ioo`03001oogoo01Moo`03001oo`00
00Aoo`03001oogoo01ioo`03001oogoo01Ioo`03001oogoo05Aoo`00EWoo00<007ooOol05Goo00<0
07ooOol067oo00<007ooOol00goo00<007ooOol07Woo00<007ooOol05Woo00<007ooOol0E7oo001F
Ool00`00Oomoo`0EOol00`00Oomoo`0NOol00`00Oomoo`0NOol00`00Oomoo`0EOol00`00Oomoo`1E
Ool005Ioo`03001oogoo01Eoo`03001oogoo01ioo`80021oo`03001oogoo01Aoo`03001oogoo05Eo
o`00Egoo00<007ooOol04goo00<007ooOol07goo00<007ooOol07goo00<007ooOol057oo00<007oo
Ool0EGoo001GOol00`00Oomoo`0COol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0DOol0
0`00Oomoo`1EOol005Moo`03001oogoo01=oo`03001oogoo01moo`03001oogoo01moo`03001oogoo
01=oo`03001oogoo05Ioo`00Egoo00<007ooOol04goo00<007ooOol07goo00<007ooOol07goo00<0
07ooOol04goo00<007ooOol0EWoo001HOol00`00Oomoo`0AOol00`00Oomoo`0POol2000QOol00`00
Oomoo`0BOol00`00Oomoo`1FOol005Qoo`03001oogoo015oo`03001oogoo021oo`03001oogoo021o
o`03001oogoo019oo`03001oogoo05Ioo`00F7oo00<007ooOol04Goo00<007ooOol087oo00<007oo
Ool087oo00<007ooOol04Goo00<007ooOol0Egoo001IOol00`00Oomoo`0@Ool00`00Oomoo`0POol0
0`00Oomoo`0POol00`00Oomoo`0AOol00`00Oomoo`1GOol005Uoo`03001oogoo011oo`03001oogoo
021oo`03001oogoo021oo`03001oogoo015oo`03001oogoo05Moo`00FGoo00<007ooOol047oo00<0
07ooOol087oo00<007ooOol087oo00<007ooOol04Goo00<007ooOol0Egoo001IOol00`00Oomoo`0?
Ool00`00Oomoo`0QOol2000QOol00`00Oomoo`0@Ool00`00Oomoo`1HOol005Uoo`03001oogoo00mo
o`03001oogoo025oo`03001oogoo021oo`03001oogoo011oo`03001oogoo05Qoo`00FWoo00<007oo
Ool03Woo00<007ooOol08Goo00<007ooOol08Goo00<007ooOol03goo00<007ooOol0F7oo001JOol0
0`00Oomoo`0>Ool00`00Oomoo`0QOol00`00Oomoo`0QOol00`00Oomoo`0>Ool00`00Oomoo`1IOol0
05Yoo`03001oogoo00ioo`03001oogoo025oo`03001oogoo025oo`03001oogoo00ioo`03001oogoo
05Uoo`00FWoo00<007ooOol03Woo00<007ooOol08Goo0P008Woo00<007ooOol03Woo00<007ooOol0
FGoo001JOol00`00Oomoo`0=Ool00`00Oomoo`0ROol00`00Oomoo`0QOol00`00Oomoo`0>Ool00`00
Oomoo`1IOol005Yoo`03001oogoo00eoo`03001oogoo029oo`03001oogoo025oo`03001oogoo00eo
o`03001oogoo05Yoo`00Fgoo00<007ooOol037oo00<007ooOol06goo0P001Goo00<007ooOol08Goo
00<007ooOol03Goo00<007ooOol0FWoo001KOol00`00Oomoo`0<Ool00`00Oomoo`0MOol00`00Oomo
o`02Ool00`00Oomoo`0QOol00`00Oomoo`0=Ool00`00Oomoo`1JOol005]oo`03001oogoo00aoo`03
001oogoo01aoo`03001oogoo00=oo`<0025oo`03001oogoo00eoo`03001oogoo05Yoo`00Fgoo00<0
07ooOol037oo00<007ooOol07Goo00<007ooOol00Woo00<007ooOol08Goo00<007ooOol03Goo00<0
07ooOol0FWoo001KOol00`00Oomoo`0<Ool00`00Oomoo`0KOol00`00Ool00004Ool00`00Oomoo`0R
Ool00`00Oomoo`0<Ool00`00Oomoo`1JOol005]oo`03001oogoo00aoo`03001oogoo01aoo`03001o
ogoo00=oo`03001oogoo029oo`03001oogoo00aoo`03001oogoo05Yoo`00G7oo00<007ooOol02goo
00<007ooOol08Woo00<007ooOol08Woo00<007ooOol02goo00<007ooOol0Fgoo001LOol00`00Oomo
o`0;Ool00`00Oomoo`0ROol2000SOol00`00Oomoo`0;Ool00`00Oomoo`1KOol005aoo`03001oogoo
00]oo`03001oogoo029oo`03001oogoo029oo`03001oogoo00]oo`03001oogoo05]oo`00G7oo00<0
07ooOol02Woo00<007ooOol08goo00<007ooOol08Woo00<007ooOol02goo00<007ooOol0Fgoo001L
Ool00`00Oomoo`0:Ool00`00Oomoo`0SOol00`00Oomoo`0ROol00`00Oomoo`0;Ool00`00Oomoo`1K
Ool005aoo`03001oogoo00Yoo`03001oogoo02=oo`03001oogoo029oo`03001oogoo00]oo`03001o
ogoo05]oo`00GGoo00<007ooOol02Goo00<007ooOol08goo00<007ooOol08goo00<007ooOol02Woo
00<007ooOol0Fgoo001MOol00`00Oomoo`09Ool00`00Oomoo`0SOol2000TOol00`00Oomoo`0:Ool0
0`00Oomoo`1KOol005eoo`03001oogoo00Uoo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo
00Uoo`03001oogoo05aoo`00GGoo00<007ooOol02Goo00<007ooOol08goo00<007ooOol08goo00<0
07ooOol02Goo00<007ooOol0G7oo001MOol00`00Oomoo`09Ool00`00Oomoo`0SOol00`00Oomoo`0S
Ool00`00Oomoo`09Ool00`00Oomoo`1LOol005eoo`03001oogoo00Uoo`03001oogoo02=oo`03001o
ogoo02=oo`03001oogoo00Uoo`03001oogoo05aoo`00GGoo00<007ooOol02Goo00<007ooOol08goo
0P0097oo00<007ooOol02Goo00<007ooOol0G7oo001MOol00`00Oomoo`09Ool00`00Oomoo`0SOol0
0`00Oomoo`0SOol00`00Oomoo`09Ool00`00Oomoo`1LOol005eoo`03001oogoo00Uoo`03001oogoo
02=oo`03001oogoo02=oo`03001oogoo00Uoo`03001oogoo05aoo`00GWoo00<007ooOol027oo00<0
07ooOol08goo00<007ooOol08goo00<007ooOol02Goo00<007ooOol0G7oo001NOol00`00Oomoo`08
Ool00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`08Ool00`00Oomoo`1MOol005ioo`03001o
ogoo00Qoo`03001oogoo02=oo`8002Eoo`03001oogoo00Moo`03001oogoo05eoo`00GWoo00<007oo
Ool027oo00<007ooOol08goo00<007ooOol097oo00<007ooOol01goo00<007ooOol0GGoo001NOol0
0`00Oomoo`08Ool00`00Oomoo`0SOol00`00Oomoo`0TOol00`00Oomoo`07Ool00`00Oomoo`1MOol0
05ioo`03001oogoo00Moo`03001oogoo02Aoo`03001oogoo02Aoo`03001oogoo00Moo`03001oogoo
05eoo`00GWoo00<007ooOol01goo00<007ooOol07Woo0`000goo00<007ooOol097oo00<007ooOol0
1goo00<007ooOol0GGoo001NOol00`00Oomoo`07Ool00`00Oomoo`0OOol00`00Oomoo`02Ool00`00
Oomoo`0TOol00`00Oomoo`07Ool00`00Oomoo`1MOol005ioo`03001oogoo00Moo`03001oogoo01eo
o`@000=oo`<002Aoo`03001oogoo00Moo`03001oogoo05eoo`00GWoo00<007ooOol01goo00<007oo
Ool07Goo00<007oo000017oo00<007ooOol097oo00<007ooOol01Woo00<007ooOol0GWoo001NOol0
0`00Oomoo`07Ool00`00Oomoo`0NOol20004Ool00`00Oomoo`0TOol00`00Oomoo`06Ool00`00Oomo
o`1NOol005ioo`03001oogoo00Moo`03001oogoo01moo`03001oogoo009oo`03001oogoo02Aoo`03
001oogoo00Ioo`03001oogoo05ioo`00GWoo00<007ooOol01goo00<007ooOol097oo00<007ooOol0
97oo00<007ooOol01Woo00<007ooOol0GWoo001NOol00`00Oomoo`07Ool00`00Oomoo`0TOol2000U
Ool00`00Oomoo`06Ool00`00Oomoo`1NOol005ioo`03001oogoo00Moo`03001oogoo02Aoo`03001o
ogoo02Aoo`03001oogoo00Ioo`03001oogoo05ioo`00Ggoo00<007ooOol01Woo00<007ooOol097oo
00<007ooOol09Goo00<007ooOol01Goo00<007ooOol0GWoo001OOol00`00Oomoo`06Ool00`00Oomo
o`0TOol00`00Oomoo`0UOol00`00Oomoo`05Ool00`00Oomoo`1NOol005moo`03001oogoo00Ioo`03
001oogoo02Aoo`03001oogoo02Eoo`03001oogoo00Eoo`03001oogoo05ioo`00Ggoo00<007ooOol0
1Woo00<007ooOol097oo0P009Woo00<007ooOol01Goo00<007ooOol0GWoo001OOol00`00Oomoo`06
Ool00`00Oomoo`0TOol00`00Oomoo`0UOol00`00Oomoo`05Ool00`00Oomoo`1NOol005moo`03001o
ogoo00Ioo`03001oogoo02Aoo`03001oogoo02Eoo`03001oogoo00Eoo`03001oogoo05ioo`00Ggoo
00<007ooOol01Goo00<007ooOol09Goo00<007ooOol09Goo00<007ooOol017oo00<007ooOol0Ggoo
001OOol00`00Oomoo`05Ool00`00Oomoo`0UOol00`00Oomoo`0UOol00`00Oomoo`04Ool00`00Oomo
o`1OOol005moo`03001oogoo00Eoo`03001oogoo02Eoo`8002Ioo`03001oogoo00Aoo`03001oogoo
05moo`00Ggoo00<007ooOol01Goo00<007ooOol09Goo00<007ooOol09Goo00<007ooOol017oo00<0
07ooOol0Ggoo001OOol00`00Oomoo`05Ool00`00Oomoo`0UOol00`00Oomoo`0UOol00`00Oomoo`04
Ool00`00Oomoo`1OOol005moo`03001oogoo00Eoo`03001oogoo02Eoo`03001oogoo02Eoo`03001o
ogoo00Aoo`03001oogoo05moo`00H7oo00<007ooOol017oo00<007ooOol09Goo00<007ooOol09Goo
00<007ooOol017oo00<007ooOol0Ggoo001POol00`00Oomoo`04Ool00`00Oomoo`0UOol00`00Oomo
o`0VOol00`00Oomoo`03Ool00`00Oomoo`1OOol0061oo`03001oogoo00Aoo`03001oogoo02Eoo`80
02Moo`03001oogoo00=oo`03001oogoo05moo`00H7oo00<007ooOol017oo00<007ooOol09Goo00<0
07ooOol09Woo00<007ooOol00goo00<007ooOol0Ggoo001POol00`00Oomoo`04Ool00`00Oomoo`0U
Ool00`00Oomoo`0VOol00`00Oomoo`03Ool00`00Oomoo`1OOol0061oo`03001oogoo00Aoo`03001o
ogoo01moo`03001oogoo00=oo`03001oogoo02Ioo`03001oogoo00=oo`03001oogoo05moo`00H7oo
00<007ooOol00goo00<007ooOol07goo00<007oo000017oo00<007ooOol09Woo00<007ooOol00goo
00<007ooOol0Ggoo001POol00`00Oomoo`03Ool00`00Oomoo`0QOol00`00Oomoo`02Ool3000VOol0
0`00Oomoo`03Ool00`00Oomoo`1OOol0061oo`03001oogoo00=oo`03001oogoo01moo`8000Eoo`03
001oogoo02Ioo`03001oogoo00=oo`03001oogoo05moo`00H7oo00<007ooOol00goo00<007ooOol0
7goo00<007ooOol017oo00<007ooOol09Woo00<007ooOol00goo00<007ooOol0Ggoo001QOol00`00
Oomoo`02Ool00`00Oomoo`0OOol30004Ool00`00Oomoo`0VOol00`00Oomoo`02Ool00`00Oomoo`1P
Ool0065oo`03001oogoo009oo`03001oogoo02Ioo`03001oogoo02Ioo`03001oogoo009oo`03001o
ogoo061oo`00HGoo00<007ooOol00Woo00<007ooOol09Woo0P009goo00<007ooOol00Woo00<007oo
Ool0H7oo001QOol00`00Oomoo`02Ool00`00Oomoo`0VOol00`00Oomoo`0VOol00`00Oomoo`02Ool0
0`00Oomoo`1POol0065oo`03001oogoo009oo`03001oogoo02Ioo`03001oogoo02Ioo`03001oogoo
009oo`03001oogoo061oo`00HGoo00<007ooOol00Woo00<007ooOol09Woo00<007ooOol09Woo00<0
07ooOol00Woo00<007ooOol0H7oo001QOol00`00Oomoo`02Ool00`00Oomoo`0VOol00`00Oomoo`0V
Ool00`00Oomoo`02Ool00`00Oomoo`1POol0065oo`03001oogoo009oo`03001oogoo02Ioo`8002Mo
o`03001oogoo009oo`03001oogoo061oo`00HGoo00<007ooOol00Woo00<007ooOol09Woo00<007oo
Ool09Woo00<007ooOol00Woo00<007ooOol0H7oo001ROol01000Oomoo`00:Goo00<007ooOol09Woo
00<007ooOol00Woo00<007ooOol0H7oo001ROol01000Oomoo`00:Goo00<007ooOol09Woo00<007oo
Ool00Woo00<007ooOol0H7oo001ROol01000Oomoo`00:Goo00<007ooOol09Woo00D007ooOomoo`00
06=oo`00HWoo00@007ooOol002Uoo`03001oogoo02Moo`04001oogoo001SOol0069oo`04001oogoo
000YOol2000XOol01000Oomoo`00Hgoo001ROol01000Oomoo`00:Goo00<007ooOol09goo00@007oo
Ool006=oo`00HWoo00@007ooOol002Uoo`03001oogoo02Moo`04001oogoo001SOol0069oo`04001o
ogoo000YOol00`00Oomoo`0WOol01000Oomoo`00Hgoo001ROol01000Oomoo`00:Goo00<007ooOol0
9goo00@007ooOol006=oo`00HWoo00@007ooOol002Uoo`8002Qoo`04001oogoo001SOol0069oo`04
001oogoo000YOol00`00Oomoo`0WOol01000Oomoo`00Hgoo001ROol01000Oomoo`00:Goo00<007oo
Ool09goo00@007ooOol006=oo`00HWoo00<007oo00008goo0P001Goo00<007ooOol09goo00@007oo
Ool006=oo`00HWoo00<007oo00008goo00<007oo000017oo00<007ooOol0:7oo0P00I7oo001SOol2
000SOol00`00Ool00004Ool3000XOol2001TOol006=oo`8002=oo`8000Eoo`03001oogoo02Qoo`80
06Aoo`00Hgoo0P008goo00<007ooOol017oo00<007ooOol0:7oo0P00I7oo0029Ool20004Ool00`00
Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool2002?Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.47156, -0.470181, 
  0.0241921, 0.0378923}}]
}, Open  ]],

Cell["\<\
Here is an illustration of aliasing, as a result of undersampling a signal. \
Note how aliasing causes the signal to sound as if the frequency was actually \
decreasing, as the sampling rate falls below the Nyquist rate.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Play[Cos[\[Pi]\ 1800\ t\^2 + 2\ \[Pi]\ 500\ t], {t, 0, 2}, 
      SampleRate \[Rule] 8192]; \)\)], "Input",
  CellLabel->"In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sampled sound
1 string
8192 16384 8
{ currentfile 1 index readhexstring pop }
 false 1 sampledsound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pop
% End of sampled sound
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oo`008@0000000`00
Oomoo`3oOolMOol100000003001oogoo0;Ioof800004Ool00000Ool100000003001oogoo08Yoob<0
0004Ool00000Oolk00000goo0000000Y000017oo001oogoo0@0000000`00Oomoo`1XOolX00000goo
0000001A00000goo0000000F00000goo0000000700000goo0000000@0002Ool100000003001oogoo
04]oobd0009oob@00003Ool0000000/00004Ool007ooOol>00001Goo00000000Ool0<`0000=oo`00
0000100000=oo`000000300000=oo`0000002P000goo0@0000000`00Oomoo`0_Ool[00000goo0000
000K0002OolO00000goo0000000500000goo0000000800001Woo001oogoo001oobP00003Ool00000
01T0009oo`L00003Ool0000000<00003Ool007oo014000=oo`40000000<007ooOol05Woo=`0000=o
o`0000005`0000=oo`0000003P000Woo<P0000Ioo`00Oomoo`00OolG00000goo0000000=0002OolA
00000goo0000000H00000goo00000002000017oo000007oo2@000goo0@0000000`00Ool000140000
0goo0000000A0002OolN0002OolF00000goo0000000500000goo0000000300000goo0000000;0000
17oo001oogoo2`0000Aoo`00001oo`<00003Ool0000001@0009oo`T00004Ool00000Ool400000goo
0000000<00000goo001oo`0500000goo0000000300000goo0000000;00000goo001oo`02Ool10000
0003001oo`0005P0009ooad00003Ool0000001H00003Ool0000000H00003Ool0000000D00003Ool0
000001800003Ool0000000D00005Ool00000001oo`0B000017oo000000000Woo4@0000=oo`000000
3P0000=oo`0000000P0000=oo`0000004P0000=oo`00Ool00Woo0@0000000`00Ool0000X00000goo
0000000G0002OolE00000goo0000000K000017oo000007oo7P0000=oo`0000004@0000=oo`000000
4P0000=oo`0000001@0000=oo`0000007`0000=oo`0000003P0000=oo`0000000`0000Eoo`000000
07oo00l00003Ool007oo009oo`40000000<007oo0000@`0000=oo`00000080000Woo3`0000=oo`00
00003@0000=oo`0000003`0000=oo`0000000P0000=oo`000000300000Aoo`00001oo`d00003Ool0
000002H00003Ool0000000`00003Ool0000001000003Ool0000000/00003Ool007oo009oo`400000
00<007oo0000C0000Woo:P000Woo4P0000=oo`0000005@0000=oo`0000001P0017oo1@0000=oo`00
00001@0000=oo`0000008`0000=oo`0000001@0000=oo`0000001`0000=oo`0000001@000Woo0`00
00Eoo`00000007oo00@00003Ool0000000800003Ool0000000<00003Ool007oo009oo`40000000<0
07ooOol04WooIP000Woo<`0017oo4@0000=oo`000000100000Eoo`00000007oo00800003Ool00000
00P00003Ool0000001l00003Ool0000000800003Ool0000001800003Ool007oo009oo`40000000<0
07ooOol0:goo;@000Woo3@0000=oo`0000003P000Woo3@0000=oo`0000001P0000=oo`0000001P00
00=oo`0000000P0000Aoo`00001oo`/000Aooa400003Ool0000002L00003Ool0000000h00003Ool0
000000<00003Ool0000000H00003Ool0000000X000=oo`40000000<007ooOol0AGoo<`000Woo<`00
17oo1@0000=oo`0000001@0000=oo`000000:`0000Aoo`00001ooaL00003Ool0000000l000=oo`40
000000<007ooOol0HWoo1@0000=oo`000000@`0000Aoo`00001oobP0009oo`T00003Ool0000000D0
0003Ool0000000L00003Ool0000001<00003Ool0000000X000=oo`40000000<007ooOol0Q7ooE@00
0Woo6`0000=oo`000000100000=oo`000000600000Aoo`00Oomoo`40000000<007ooOol0ZWoo00@0
07ooOol0009oofP00004Ool007ooOol100000003001oogoo0>eoo`T00003Ool0000000@00003Ool0
000001H00003Ool007oo0080005oo`40000000<007ooOol0ogoo7Goo0@00003o000Q00000003001o
ogoo0?mooaeoo`40000000<007oo00004P0000=oo`000000;`0000=oo`0000004@000Woo7P000Woo
5@000Woo7`0000=oo`0000009P000Woo4@0000=oo`0000009`0000=oo`00Ool00P000Goo0@000000
1000Ool000000goo00<007ooOol01@000Woo200000=oo`00Ool00`0000Eoo`00001oo`0000Aoo`<0
0003Ool0000000800007Ool007oo001oo`00Ool01@0000=oo`00000010000Woo00<007oo00001@00
0Woo100000=oo`0000000P0000Aoo`00001oo`<00003Ool000000080009oo`H00003Ool007oo009o
o`<00005Ool00000001oo`020002Ool900000goo001oo`090002Ool400001Goo00000000Ool00`00
0Woo00D007oo000007oo00L00003Ool00000009oo`L00003Ool0000000P00004Ool00000Ool70000
0goo001oo`03Ool2000017oo000000000Woo1P000goo0P0000Moo`00Ool007oo001oo`03000017oo
001oogoo200000=oo`0000000P000Woo00<007ooOol00`0000=oo`0000001`0000=oo`0000000P00
00Aoo`00Oomoo`40000000@007oo001oo`<000=oo`04001oo`00Ool20005Ool00`00Ool00002Ool0
1@00Ool007oo000017oo0`0000=oo`00Ool00goo0`000Woo0P0000=oo`0000000Woo00<007oo0000
0P0000=oo`00Ool00P000Woo00@007ooOol000Moo`03001oogoo00Aoo`800003Ool0000000=oo`80
0003Ool007oo00Aoo`P000Eoo`07001oo`00Ool007oo00001Goo00<007ooOol00P000Woo00@007oo
001oo`8000Aoo`05001oo`00Ool00003Ool00`00Ool00003Ool200000goo001oo`02Ool00`00Oomo
o`020003Ool20003Ool3000017oo000000000Woo00<007ooOol00Woo00@007oo000000Aoo`03001o
o`0000D000=oo`8000Eoo`03001oogoo00800007Ool007oo001oo`00Ool00`0000=oo`00Ool00P00
00=oo`0000000Woo0P000goo10001Goo0P000goo0`0000=oo`00Ool00Woo00@007oo0000009oo`<0
009oo`03001oo`00009oo`40000000@007oo001oo`800005Ool007oo001oo`030003Ool5000017oo
000000000Woo0P0000Eoo`00000007oo00800003Ool000000080009oo`04001oo`000002Ool40006
Ool30002Ool500000goo0000000200001Goo00000000Ool01@000goo00@007oo001oo`800003Ool0
000000=oo`@0009oo`06001oo`00Ool007oo0P0000Eoo`00000007oo00800004Ool007ooOol20003
Ool700000goo0000000400000goo00000009000017oo000000000goo00<007oo00000`000Woo1000
00Aoo`00Oomoo`800004Ool007oo0002Ool300000goo0000000200001Goo001oo`00Ool00P000Woo
1P000Woo0`0000Aoo`00000000=oo`@0009oo`H00006Ool00000001oo`0017oo100000Eoo`000000
07oo00<00007Ool00000001oo`00Ool01P000Woo100000=oo`00Ool00P0000Eoo`00001oo`00009o
o`40000000@007ooOol0009oo`<000Aoo`03001oogoo00=oo`04001oo`000003Ool01@00Ool00000
Ool00`000goo1P0000Moo`00Oomoo`00Ool00003Ool00`00Oomoo`02000017oo001oogoo0P0000=o
o`0000000`0000Ioo`00Ool007oo0002Ool20003Ool30002Ool3000017oo001oo`000Woo00<007oo
00001@000Woo10001Goo00@007ooOomoo`<0009oo`<00004Ool007ooOol20002Ool00`00Ool00005
0002Ool300001Goo001oo`00Ool00P001Goo0`000Woo00<007oo00000goo0P0000=oo`0000000Woo
0P000goo0`000Woo00<007oo00000goo0P0000=oo`00000010000goo3@000goo0P0000=oo`000000
1P0000=oo`00Ool00Woo00<007oo00000P0000=oo`0000000P000goo0P000goo00<007oo00000goo
0`000Woo0P0000Aoo`00Oomoo`@00003Ool0000000=oo`03001oogoo0040000000<007ooOol01Goo
00@007ooOol000=oo`03001oo`0000<00003Ool00000009oo`03001oo`0000Ioo`<0009oo`8000=o
o`800003Ool0000000Moo`03001oo`0000=oo`03001oo`0000Ioo`03001oo`00009oo`04001oogoo
0003Ool02000Ool00000Ool007oo0002Ool01000Oomoo`0027oo00@007ooOol000=oo`04001oo`00
Ool20003Ool01`00Oomoogoo001oo`00009oo`03001oogoo00800004Ool007oo0002Ool300001Goo
001oogoo00000Woo00<007ooOol00Woo00<007ooOol00`0027oo00H007ooOol007oo0003Ool40004
Ool20004Ool20007Ool00`00Oomoo`05Ool00`00Oomoo`020002Ool00`00Ool0000200001Goo001o
ogoo000027oo0P000goo00L007oo000007oo001oo`0200001goo000007oo001oo`0000Aoo`03001o
ogoo00=oo`8000Aoo`03001oogoo00=oo`06001oogoo001oo`000Woo0@0000002000Oomoogoo001o
o`00Ool200000goo001oo`02Ool50004Ool00`00Oomoo`02Ool200000goo001oo`02Ool01000Ool0
00000Woo00<007oo00000P000Woo00<007oo00000P000goo0`0000=oo`0000000P000Woo00<007oo
00000Woo0P0000Aoo`00Ool000=oo`@0009oo`04001oogooOol30002Ool00`00Ool0000300000goo
000000030002Ool400000goo001oo`0400001Goo001oogoo00000Woo0`0000=oo`00Ool01`000Woo
1`000goo00L007oo001oo`00Ool00003Ool01@00Ool007oo00000Woo0P0000Aoo`00Ool000=oo`03
001oogoo00800003Ool000000080009oo`80009oo`03001oo`00008000Ioo`04001oogooOol20000
1Goo00000000Ool01@0000Eoo`00Ool007oo00<000Aoo`800003Ool007oo00=oo`@00003Ool007oo
00P00003Ool0000000@00003Ool007oo009oo`8000=oo`<00003Ool0000000<00004Ool007ooOol1
00000004001oo`000002Ool01@00Ool007oo00000Woo0P001Goo00@007oo001oo`<00004Ool00000
0004Ool3000017oo000000001Woo0P0000Aoo`000000009oo`04001oo`00Ool300000goo00000003
0002Ool00`00Oomoo`030002Ool300000goo001oo`02000017oo000007oo0P000Woo00@007ooOol0
009oo`80009oo`800004Ool00000Ool30003Ool50003Ool4000017oo001oogoo0P000Woo00L007oo
Oomoo`00Ool00002Ool200001Goo00000000Ool00`0000=oo`0000000`001Woo0P000Woo00D007oo
Oomoo`00009oo`@00003Ool007oo00800008Ool007ooOol007oo001oo`800003Ool007oo00800003
Ool0000000=oo`8000Aoo`03001oogoo00H0009oo`06001oogooOol007oo0`0000=oo`0000001Goo
00H007ooOomoo`00Ool30002Ool01000Oomoo`000Woo1@0000Aoo`00Oomoo`<000Aoo`<000=oo`03
001oo`00009oo`40000000<007ooOol01Woo0P000goo0`001Woo00D007oo001oo`0000Aoo`8000Yo
o`800004Ool007oo000:Ool00`00Oomoo`0:Ool01P00Oomoo`00Ool000=oo`03001oogoo009oo`80
009oo`04001oo`000004Ool00`00Oomoo`08Ool30005Ool01@00Ool007oo00000goo0P001Goo00<0
07oo00001Woo00@007ooOomoo`80009oo`800003Ool007oo00Eoo`03001oo`0000Uoo`05001oo`00
Ool00008Ool00`00Oomoo`08Ool20005Ool20004Ool200000goo001oo`03Ool01@00Oomoogoo0000
0goo00<007ooOol02Goo00D007ooOomoo`00009oo`09001oo`00Ool007oo001oo`00009oo`<000=o
o`04001oogoo0005Ool00`00Ool00002000<Ool100000004001oogooOol60003Ool01@00Oomoogoo
000017oo00<007ooOol02Woo00<007ooOol04goo00@007ooOomoo`8000Aoo`80009oo`<0009oo`03
001oo`0000800003Ool007oo00H00003Ool0000000l00004Ool007ooOol40003Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool20003Ool00`00Ool00003Ool00`00Oomoo`02Ool00`00Ool00005Ool20008
Ool200000goo000000070003Ool00`00Ool00002Ool2000017oo001oogoo0P000Woo00<007ooOol0
17oo00<007oo000010000goo00<007oo00001Goo100000=oo`00Ool00P000Woo00@007ooOol0009o
o`8000=oo`80009oo`03001oo`00008000=oo`03001oogoo009oo`03001oo`0000=oo`800003Ool0
07oo00=oo`80009oo`800003Ool0000000800004Ool007ooOol100000006001oo`00Ool007oo0`00
0Woo00<007ooOol00P000goo0P0000Eoo`00000007oo00<0009oo`05001oogooOol00004Ool30000
0goo001oo`0300001Goo001oogoo00000Woo10000Woo00@007oo001oo`<0009oo`800006Ool00000
Ool007oo0P0000Moo`00Ool007oo001oo`0200000goo00000003Ool4000017oo000000000Woo0`00
0Woo00<007ooOol00P0017oo0`000Woo00H007ooOol007oo0006Ool01P00Ool00000Ool0009oo`<0
0003Ool007oo00Aoo`04001oo`00Ool50009Ool01000Oomoo`000Woo100000=oo`00Ool00Woo00<0
07oo00000P001Goo00L007ooOomoo`00Ool00002Ool200001goo001oo`00Ool007oo00<00004Ool0
0000Ool3000017oo001oo`0017oo0P0000Aoo`00Ool000Aoo`8000Aoo`800005Ool007oo001oo`02
00001Goo000007oo00000Woo10000Woo0`000goo00L007oo001oo`00Ool00002Ool100000006001o
o`00001oo`001Goo00L007ooOomoo`00Ool0000<Ool300001Goo001oogoo00000goo00D007ooOomo
o`0000Aoo`8000Eoo`06001oo`00Ool007oo0`0000=oo`00Ool01Goo0P005Woo00@007oo0000009o
o`03001oogoo00=oo`8000Aoo`8000Eoo`04001oogoo0004Ool01P00Oomoo`00Ool000=oo`05001o
ogoo001oo`0300000goo00000002Ool01000Ool007oo0P0017oo0P004Woo00<007ooOol00goo0P00
00Aoo`00Ool000Moo`03001oogoo00800005Ool007ooOol00004Ool00`00Oomoo`03Ool20005Ool0
0`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoogoo0P00
0goo00D007oo000007oo0080009oo`05001oogooOol00004Ool100000003001oogoo009oo`8000Mo
o`03001oo`00009oo`8000Aoo`<0009oo`D000Aoo`8000Aoo`04001oogooOol200000goo001oo`03
Ool00`00Ool00003Ool2000017oo001oo`0017oo00D007ooOomoo`0000=oo`03001oogoo00Eoo`05
001oogooOol00007Ool01@00Oomoogoo00001Woo00D007oo001oo`00009oo`03001oogoo00=oo`03
001oo`0000D0009oo`8000=oo`80009oo`03001oo`0000<00004Ool007oo0002Ool00`00Oomoo`02
Ool01P00Oomoogoo001oo`80009oo`03001oogoo00<0009oo`03001oogoo00800003Ool000000080
0003Ool007oo00Aoo`06001oogoo001oo`000Woo00D007ooOol007oo00<000Aoo`04001oogooOol2
0005Ool01@00Oomoo`00Ool00P0000=oo`0000000Woo00<007ooOol00Woo00<007oo00001goo00H0
07ooOol007oo000;Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000Woo0@0000001000
Ool000001Goo00H007ooOomoo`00Ool2000:Ool40002Ool500001goo000007oo001oo`0000Aoo`80
0003Ool0000000Qoo`05001oogoo001oo`020002Ool00`00Ool00002Ool00`00Ool000020006Ool2
0006Ool01@00Oomoogoo00000Woo0P000goo00D007oo000007oo00<000=oo`06001oo`00001oo`00
0goo0P000goo0P001goo00D007oo000007oo00800004Ool007oo0004Ool2000017oo000000000Woo
00<007oo00000P000goo00D007oo001oo`0000=oo`8000Aoo`<000Eoo`<000Ioo`03001oo`00009o
o`800003Ool0000000Aoo`06001oogoo001oo`001goo00D007ooOomoo`0000=oo`800003Ool00000
00Eoo`05001oo`00Ool00002Ool01@00Ool007oo00000Woo00@007ooOomoo`<0009oo`03001oogoo
00800004Ool00000Ool20002Ool00`00Oomoo`0100000003001oo`0000Qoo`03001oo`0000Qoo`04
001oogooOol20008Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`0=
Ool00`00Ool00009Ool00`00Oomoo`03Ool01P00Oomoo`00Ool000Aoo`03001oogoo00Ioo`06001o
o`00001oo`001Woo00<007ooOol027oo0P0027oo0P0027oo00<007ooOol01Goo00<007ooOol00goo
00@007oo000000Eoo`03001oo`0000Uoo`03001oogoo00Eoo`8000Eoo`03001oo`0000Aoo`03001o
o`0000Eoo`03001oogoo009oo`8000Moo`03001oogoo00Aoo`03001oogoo009oo`80009oo`800005
Ool007ooOol00007Ool00`00Oomoo`03Ool00`00Ool00002Ool01000Oomoo`000Woo00<007ooOol0
0Woo0@0000001000Ool000000goo00<007ooOol00Woo00<007ooOol0100000=oo`00Ool00P0000Mo
o`00000007oo001oo`0400000goo00000005Ool01@00Oomoogoo00000goo00<007oo00000Woo00@0
07ooOomoo`800005Ool007ooOol00005Ool5000027oo00000000Ool007oo0004Ool00`00Oomoo`02
Ool30007Ool00`00Oomoo`02Ool20006Ool00`00Ool0000200001Woo000007oo001oo`80009oo`03
001oogoo008000Eoo`04001oogoo0002Ool00`00Oomoo`05Ool03`00Oomoogoo001oo`00Ool007oo
001oo`00Ool00002Ool30006Ool01000Ool000000goo00<007ooOol00P0000Aoo`00Ool0009oo`05
001oogooOol00009Ool2000017oo000007oo0P0000Aoo`00Ool000Yoo`<00003Ool007oo00=oo`<0
009oo`04001oo`00Ool3000017oo000007oo0`0000Eoo`00Oomoo`0000Aoo`03001oogoo00Qoo`03
001oogoo0040000000@007ooOomoo`800004Ool007ooOol30004Ool4000017oo001oo`000Woo00<0
07ooOol00goo00@007ooOomoo`8000Aoo`03001oogoo008000=oo`03001oo`00009oo`03001oo`00
008000Aoo`03001oo`0000800003Ool007oo00Moo`03001oo`0000=oo`03001oogoo00Aoo`03001o
o`0000Ioo`04001oogoo0002Ool20008Ool00`00Ool00002Ool00`00Oomoo`04Ool01000Oomoo`00
0goo00<007ooOol00P0000=oo`00Ool01Goo00<007ooOol00P0000Aoo`00Ool000Ioo`80009oo`04
001oogoo0003Ool00`00Oomoo`0200001Woo001oo`00Ool0009oo`04001oogooOol20002Ool20000
17oo000000000Woo0P000Woo00@007ooOol000Aoo`05001oogoo001oo`030004Ool01@00Ool007oo
00000Woo00<007ooOol00Woo10000Woo00<007ooOol01Goo00<007ooOol017oo00@007ooOomoo`@0
00Moo`80009oo`800004Ool007ooOol100000004001oogooOol3000AOol01@00Oomoogoo00000Woo
00D007ooOomoo`0000=oo`03001oo`0000D000]oo`05001oogooOol00003Ool00`00Oomoo`02Ool2
0004Ool00`00Ool00004Ool20002Ool20003Ool01@00Oomoogoo00003goo00L007ooOomoo`00Ool0
0003Ool20006Ool00`00Oomoo`05Ool00`00Oomoo`02000<Ool20007Ool00`00Oomoo`03Ool00`00
Oomoo`0;Ool00`00Ool00003Ool00`00Ool00003Ool01000Ool007oo0P002Goo10001Goo00<007oo
Ool00P000Woo00D007ooOomoo`00009oo`06001oogoo001oo`002Woo00<007oo000027oo00<007oo
00002goo00<007ooOol01Goo00<007ooOol00@0000001000Ool007oo0P0017oo100017oo0P000Woo
0P000Woo00<007ooOol00P0000Eoo`00001oo`00009oo`D000Aoo`03001oogoo00Eoo`03001oo`00
0080009oo`06001oo`00001oo`001Goo0`0000=oo`00Ool00Woo00<007oo00000Woo0`000Woo00<0
07ooOol01Goo00<007ooOol00goo00@007oo000000Qoo`06001oogooOol007oo0P000Woo0P0000=o
o`00Ool010001Goo0P000Woo00D007ooOomoo`00009oo`04001oo`000006Ool20006Ool01000Oomo
ogoo0`0017oo1@000Woo00<007ooOol00`000Woo00@007ooOomoo`800005Ool007ooOol00002Ool0
1@00Oomoogoo00000goo00@007oo000000Eoo`<00003Ool000000080009oo`03001oo`0000Aoo`03
001oo`00009oo`04001oo`00Ool200000goo00000006Ool20005Ool00`00Oomoo`020003Ool00`00
Ool00006Ool100000003001oogoo009oo`03001oogoo009oo`05001oogooOol00009Ool200000goo
001oo`04Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000=oo`04001oogoo0004Ool01@00Ool007oo
00000goo00<007ooOol00P001Goo00<007oo00000goo00H007ooOomoo`00Ool20002Ool2000;Ool0
0`00Oomoo`05Ool01000Oomoo`000goo0P000Woo0P0000=oo`00Ool00P000Woo00<007ooOol00goo
10001Woo00@007oo001oo`8000Uoo`07001oogooOol007oo00000Woo00<007ooOol017oo0`0000Ao
o`00Oomoo`@00003Ool0000000=oo`03001oo`0000Ioo`03001oo`0000Aoo`04001oo`000004Ool3
0004Ool00`00Ool00002Ool20004Ool01@00Oomoo`00Ool00P0000=oo`00Ool00Woo00<007ooOol0
0P0000Aoo`00000000Ioo`05001oo`00001oo`050003Ool3000017oo001oo`000Woo0@0000001000
Oomoo`0027oo00<007oo00000goo00<007oo00001goo00<007ooOol00goo00<007ooOol01Goo00<0
07oo000027oo00<007ooOol01Goo00<007ooOol01goo00<007ooOol01Woo00D007oo000007oo0080
009oo`04001oo`000003Ool00`00Oomoo`03Ool200001Goo001oogoo000037oo00D007ooOol007oo
008000Aoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00=oo`03001oo`0000Aoo`03001o
ogoo00Uoo`03001oogoo009oo`03001oogoo01Uoo`03001oogoo00eoo`03001oogoo009oo`03001o
ogoo009oo`03001oogoo00Uoo`05001oogooOol0000;Ool02P00Oomoo`00Ool007oo001oo`000goo
00@007oo0000009oo`8000Aoo`03001oogoo00=oo`40000000<007ooOol00goo0P0000=oo`00Ool0
0P0000=oo`0000000goo00D007ooOol007oo00<000=oo`800004Ool007oo0002Ool00`00Oomoo`02
Ool01P00Oomoo`00Ool000=oo`800004Ool000000006Ool01@00Ool007oo000017oo0P000goo0P00
0goo0P000goo00<007ooOol00P0000Aoo`00Oomoo`80009oo`03001oo`0000Eoo`8000Aoo`03001o
ogoo00Eoo`8000Aoo`03001oo`0000=oo`03001oo`00009oo`04001oogooOol20002Ool00`00Oomo
o`020006Ool20008Ool00`00Oomoo`0200000goo0000000@Ool30005Ool20004Ool01000Oomoo`00
0Woo00D007ooOol007oo00@000=oo`05001oogoo001oo`0300000goo001oo`0COol00`00Ool00002
00001Goo001oogoo000017oo0P000Woo0P0000Eoo`00001oo`0000=oo`04001oogooOol100000003
001oogoo00Aoo`06001oogooOol007oo0P000Woo00H007oo001oo`00Ool20002Ool01000Oomoogoo
0P0000Aoo`00001oo`@00003Ool007oo00Ioo`03001oo`0000Eoo`04001oogooOol300000goo001o
o`03Ool40003Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Ool000040003Ool30005Ool01000
Oomoo`000Woo00<007ooOol00goo00@007oo001oo`8000=oo`04001oogoo0004Ool40002Ool00`00
Oomoo`04Ool200001Goo001oogoo00000Woo00@007oo001oo`800003Ool007oo0080009oo`<000Eo
o`800009Ool007ooOol007oo001oo`0000Eoo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Io
o`80009oo`@0009oo`06001oo`00001oo`000Woo00@007ooOol0009oo`03001oogoo00Qoo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`06Ool01@00Oomoogoo00001Goo0P000goo0@000000
1@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`04001oogoo0007Ool01@00Oomoo`00Ool00P00
00Aoo`00001oo`800003Ool0000000=oo`<00004Ool007ooOol300000goo00000005Ool01`00Oomo
ogoo001oo`0000Aoo`<000Moo`8000Aoo`03001oogoo009oo`80009oo`03001oogoo00800004Ool0
07oo0007Ool01000Oomoo`000Woo0P000goo00<007oo00000Woo0P0027oo0`0017oo00<007ooOol0
1Woo00T007ooOomoo`00Ool007oo000017oo00D007oo001oo`0000Aoo`03001oo`0000aoo`04001o
o`000005Ool00`00Oomoo`08Ool00`00Oomoo`030002Ool01000Oomoo`0017oo00<007ooOol00P00
00Aoo`00Ool000Eoo`<00006Ool00000001oo`0017oo00<007ooOol00goo0P001Goo00@007oo0000
009oo`03001oo`0000Ioo`40000000T007ooOomoo`00Ool007oo000037oo0P002goo00<007ooOol0
17oo00@007ooOol000=oo`03001oo`0000=oo`80015oo`05001oogooOol00003Ool01@00Ool007oo
00001Goo00<007ooOol01Woo00@007oo000000Ioo`04001oogoo0005Ool01000Oomoogoo0P001Goo
00<007ooOol00Woo0P000goo00<007ooOol01Goo00<007ooOol00goo00@007ooOol000aoo`03001o
ogoo019oo`8000=oo`03001oogoo00Moo`03001oogoo00=oo`03001oo`0000ioo`03001oogoo00Uo
o`8000Aoo`03001oogoo011oo`03001oogoo00Ioo`03001oo`0000=oo`03001oo`0000=oo`400000
00@007oo000000Ioo`04001oogoo0007Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Ool00000
0goo0`000goo0P001Goo00<007ooOol00goo0P0000=oo`00Ool00Woo00<007oo00000Woo00<007oo
Ool01Goo00<007ooOol00P0017oo00<007ooOol00goo00@007ooOomoo`@000Uoo`80009oo`03001o
o`00009oo`05001oo`00001oo`0200001Goo001oo`00Ool00`000Woo0P0000=oo`0000000P001Woo
00<007ooOol01Goo00<007oo00000P0000=oo`00Ool01goo0P000goo00`007ooOol007oo001oo`00
Ool007oo0008Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol00`0000=oo`00Ool01Goo
0P0000=oo`00Ool01Woo00<007oo00000`001Goo00<007ooOol00Woo00<007ooOol00Woo0P000Woo
00@007oo000000Uoo`<000Aoo`40000000<007ooOol01Woo00D007ooOomoo`0000Aoo`06001oogoo
001oo`000Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol00P0000=oo`0000000`0000=o
o`00000017oo00H007ooOomoo`00Ool30002Ool01000Oomoogoo0P000Woo00D007ooOomoo`0000Ao
o`03001oogoo008000=oo`03001oogoo00Aoo`D000Ioo`<000=oo`03001oogoo008000=oo`04001o
ogoo0002Ool01000Ool007oo0P002Goo00@007ooOomoo`<0009oo`04001oogoo0006Ool01000Ool0
000017oo00D007ooOomoo`00009oo`<00004Ool007oo0002Ool01000Ool000000goo00<007oo0000
0P000Woo00<007oo00000P000goo00H007ooOomoo`00Ool200001Woo00000000Ool000Eoo`03001o
o`00009oo`05001oo`00Ool00004Ool01@00Ool007oo00001Goo00<007ooOol00P001Woo00H007oo
Ool007oo0003Ool00`00Ool00003Ool01000Oomoogoo0@0000000`00Oomoo`03Ool00`00Ool0000:
Ool00`00Oomoo`06Ool20005Ool01@00Ool007oo00000Woo0P0000=oo`00Ool00goo0P000Woo00<0
07ooOol00Woo0P0000Aoo`00Ool000ioo`04001oogoo0005Ool20003Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool01@00Oomoogoo00000goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol04Woo
00H007ooOol007oo0006Ool20002Ool00`00Oomoo`0GOol20005Ool01@00Oomoogoo000017oo00<0
07oo00000Woo00<007ooOol027oo00<007ooOol02Goo0P0000Aoo`00Ool000=oo`80009oo`03001o
o`0000moo`03001oo`00009oo`03001oo`0000Ioo`04001oogoo0007Ool100000003001oogoo00Eo
o`04001oogoo0003Ool01000Oomoogoo0`0017oo00D007ooOomoo`00009oo`05001oogooOol00005
Ool20003Ool01P00Oomoogoo001oo`@000Moo`04001oogooOol2000017oo001oo`002Goo00<007oo
Ool00goo00T007oo001oo`00Ool007oo00000goo00<007ooOol00goo00@007oo0000009oo`06001o
ogooOol007oo0P0000=oo`00Ool00Woo0`001Woo00@007ooOomoo`8000=oo`03001oogoo00aoo`05
001oogooOol00002Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01000Oomoogoo0P0017oo0`000goo
0P002goo1P000goo0P001Woo0P0017oo00P007oo000007oo001oo`001Goo00<007ooOol00goo00<0
07oo00000`0000Ioo`00Oomoo`00Ool2000017oo001oo`002Woo00H007ooOol007oo0003Ool10000
0004001oogooOol30003Ool00`00Oomoo`02Ool00`00Oomoo`05Ool30002Ool00`00Oomoo`04Ool0
1000Oomoogoo0P000Woo00<007ooOol017oo0P000Woo0P000Woo00@007ooOol0009oo`03001oogoo
00Eoo`04001oo`000005Ool00`00Oomoo`04Ool00`00Oomoo`03Ool01@00Oomoo`00Ool00`000goo
0`000goo0P002Woo00<007oo000017oo00<007oo00000Woo00@007oo000000=oo`03001oo`0000Io
o`03001oogoo00800003Ool007oo009oo`04001oogoo0002Ool00`00Ool00002Ool40005Ool40003
Ool01000Ool000000Woo00D007oo001oo`0000=oo`05001oogooOol00002Ool20004Ool00`00Oomo
o`04Ool20003Ool00`00Oomoo`02Ool2000;Ool20004Ool20006Ool40003Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool01`00Oomoogoo001oo`0000Aoo`40000000@007ooOol000aoo`<000=oo`03001o
ogoo00=oo`05001oo`00Ool00007Ool00`00Ool00002Ool00`00Oomoo`07Ool00`00Oomoo`04Ool0
1@00Oomoogoo00003Goo00<007oo00000goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol0
1Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol03Goo00<007oo00000goo00<007ooOol0
0Woo00@007ooOol000moo`8000Moo`05001oogooOol00005Ool01@00Oomoogoo00002Woo00<007oo
Ool00goo0P002Goo00<007ooOol02Goo00<007ooOol017oo00<007ooOol01Goo00D007ooOomoo`00
00aoo`03001oo`0000Uoo`04001oogoo0003Ool00`00Ool00003Ool100000004001oo`000003Ool0
1000Ool000000goo00D007oo000007oo00<001Qoo`8000Aoo`03001oo`0000800004Ool007ooOol2
0006Ool2000:Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`0001=oo`03001oo`0000<0009oo`03
001oogoo009oo`8000Aoo`04001oo`000002Ool00`00Oomoo`03Ool00`00Oomoo`03Ool20003Ool0
0`00Oomoo`02Ool200000goo001oo`020004Ool01@00Ool007oo000017oo00<007ooOol00goo00<0
07ooOol00Woo00<007oo00000Woo00<007ooOol00Woo0P000Woo0P001Goo0P000Woo00D007ooOomo
o`0000Ioo`03001oogoo008000Ioo`800005Ool007ooOol00002Ool01000Ool007oo0P0000=oo`00
Ool00goo10001goo00<007ooOol00Woo0P000Woo00<007oo00001Woo0@0000000`00Oomoo`070003
Ool01P00Oomoo`00Ool000Moo`03001oogoo009oo`03001oogoo009oo`04001oogoo0006Ool01000
Oomoo`0017oo0P0000=oo`00Ool017oo00<007oo00000Woo0P000goo00L007ooOomoo`00Ool00002
Ool01000Oomoogoo0P0000=oo`0000000Woo00<007ooOol01goo00D007oo000007oo00@0009oo`80
00=oo`05001oogooOol00005Ool20002Ool00`00Ool00002Ool3000017oo001oo`002Woo00D007oo
Oomoo`00009oo`<00003Ool007oo00=oo`80009oo`03001oogoo00Eoo`03001oogoo00=oo`03001o
ogoo00Aoo`03001oo`0000=oo`05001oogooOol0000<Ool01@00Oomoogoo00000Woo00@007ooOol0
00=oo`03001oogoo009oo`06001oo`00001oo`001Goo00<007ooOol017oo00D007ooOomoo`00009o
o`03001oo`00009oo`03001oogoo009oo`03001oogoo008000Aoo`8000=oo`40000000<007ooOol0
0Woo00@007oo000000eoo`03001oogoo00Aoo`03001oo`0000=oo`03001oogoo00=oo`04001oogoo
0007Ool00`00Ool0000;Ool01@00Ool007oo00001goo00<007ooOol00goo00<007ooOol01Goo00H0
07ooOol007oo0003Ool01000Oomoo`001Woo0P003goo0P000goo00<007ooOol02Goo00@007ooOol0
00Qoo`05001oogoo001oo`02000BOol00`00Oomoo`0<Ool00`00Oomoo`020006Ool00`00Ool00003
Ool40004Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Ool00005Ool00`00Oomoo`05Ool00`00
Oomoo`020003Ool00`00Oomoo`04Ool00`00Ool00005Ool100000003001oo`00009oo`03001oogoo
00=oo`03001oo`00008000=oo`05001oogooOol00002Ool01000Ool000000Woo00<007ooOol00Woo
00<007ooOol01goo00<007ooOol00goo0`001Goo0`001Goo00<007ooOol00`0000Aoo`00Ool000=o
o`03001oogoo00Eoo`03001oogoo00Ioo`8000Aoo`8000eoo`800006Ool007oo001oo`002Woo00@0
07ooOol000Uoo`03001oo`0000Qoo`05001oogooOol00002Ool20004Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Ool00003Ool00`00Ool00004Ool20002Ool300000goo001oo`020003Ool01000
Ool000001Woo0P005Goo00<007oo000017oo00<007oo00001goo00<007oo00000Woo00H007ooOol0
07oo0002Ool00`00Oomoo`07Ool100000004001oo`000002Ool00`00Oomoo`04Ool01000Oomoo`00
0goo00D007ooOomoo`0000=oo`03001oogoo009oo`04001oogoo0005Ool01000Ool007oo0P002goo
00<007oo00000P000goo00@007ooOol000=oo`04001oo`000002Ool00`00Oomoo`02Ool300000goo
001oo`03Ool30004Ool30003Ool01@00Oomoo`00Ool00P003Goo0P000goo00<007ooOol01Goo00@0
07ooOomoo`8000Qoo`800003Ool007oo00Eoo`03001oo`00009oo`04001oogooOol20004Ool00`00
Ool00003Ool00`00Oomoo`040004Ool20002Ool00`00Oomoo`04Ool02@00Oomoogoo001oo`00Ool0
0002Ool20009Ool00`00Oomoo`04Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0002Ool00`00
Oomoo`02Ool20006Ool00`00Ool0000300001Goo001oo`00Ool01@000goo0@0000000`00Oomoo`0C
Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`05Ool01000Oomoo`000goo00<007ooOol0
1Woo0P0000=oo`00Ool00P0067oo00D007ooOomoo`0000Ioo`03001oogoo00Eoo`03001oo`0000Ao
o`03001oogoo01Eoo`03001oogoo00Eoo`04001oogoo0004Ool00`00Oomoo`0>Ool01@00Oomoogoo
00001Woo00<007ooOol00P0000=oo`00Ool017oo0P0027oo00<007ooOol027oo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol047oo00<007ooOol01Goo00<007oo00000goo00D007ooOomoo`00
009oo`03001oogoo00Ioo`40000000@007oo000000Moo`04001oogoo0002Ool00`00Oomoo`04Ool0
1@00Oomoogoo00000Woo00D007ooOomoo`00011oo`04001oogoo0004Ool00`00Oomoo`02Ool00`00
Ool00002Ool00`00Oomoo`02Ool01@00Oomoogoo00001Goo00<007oo00000Woo00P007oo000007oo
001oo`000Woo0P001Goo00L007oo001oo`00Ool00004Ool01@00Oomoogoo00000Woo0P0000=oo`00
Ool00Woo00T007ooOol007oo001oo`00Ool00P001Goo0`0000Aoo`00Ool000=oo`03001oo`0000=o
o`8000Aoo`06001oogoo001oo`001Woo00<007ooOol00goo00<007ooOol027oo00<007ooOol00Woo
0P000goo0`0000Eoo`00001oo`0000Eoo`<0009oo`8000Eoo`06001oo`00Ool007oo0P000Woo0P00
00=oo`00Ool00goo0`0000Ioo`00Ool007oo0005Ool02@00Oomoogoo001oo`00Ool00008Ool01000
Oomoogoo0@0000000`00Oomoo`0>Ool00`00Oomoo`0:Ool01000Ool000000Woo00D007oo001oo`00
00Aoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00005Ool01@00Oomoogoo00001Goo
0P000Woo00@007ooOomoo`800003Ool0000000Eoo`04001oogoo0004Ool20005Ool00`00Oomoo`02
00001Goo001oo`00Ool00P001goo0P0000Aoo`000000009oo`04001oogooOol30008Ool00`00Oomo
o`0=Ool01@00Oomoogoo00000Woo00<007ooOol00goo00<007ooOol00P000Woo00<007ooOol01goo
00@007oo001oo`8000Yoo`03001oogoo00=oo`04001oogoo0002Ool00`00Oomoo`0>Ool00`00Ool0
00020004Ool01000Ool000005Goo00@007ooOomoo`8000Eoo`40000000<007ooOol01Woo00<007oo
Ool00goo00<007ooOol01Goo0`002goo00<007ooOol017oo00<007ooOol017oo00<007ooOol00goo
0P000goo00<007oo000017oo00<007ooOol097oo00<007oo00001goo00<007oo00002Goo00@007oo
Ool0009oo`8000Eoo`<0009oo`04001oo`000003Ool01`00Ool007oo001oo`00009oo`05001oogoo
Ool00003Ool00`00Oomoo`0:Ool00`00Oomoo`0@Ool00`00Oomoo`04Ool01000Ool000002goo00<0
07oo00000P0017oo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Ioo`04001oogoo0003
Ool00`00Oomoo`03Ool3000;Ool00`00Oomoo`02Ool100000005001oo`00Ool00002Ool00`00Ool0
0004Ool200000goo001oo`07Ool00`00Oomoo`020008Ool00`00Oomoo`04Ool02000Oomoo`00Ool0
07oo0004Ool01000Ool000001Woo0`0027oo00@007oo000000=oo`04001oo`000002Ool01000Ool0
07oo10004Goo00<007ooOol00Woo00@007ooOol000Eoo`8000Yoo`03001oogoo00Ioo`03001oogoo
00Aoo`03001oo`0000Eoo`06001oogoo001oo`000Woo00<007ooOol01Goo00@007ooOol0009oo`03
001oogoo00<000Moo`04001oogoo0004Ool30005Ool00`00Oomoo`07Ool00`00Oomoo`04Ool4000:
Ool00`00Ool0000;Ool01@00Oomoogoo000017oo00<007ooOol00Woo0P0017oo00@007ooOomoo`40
000000@007ooOomoo`8000Yoo`800005Ool00000Ool00002Ool00`00Oomoo`030004Ool01000Oomo
o`000Woo00<007ooOol01Goo0P000Woo00<007ooOol027oo0`0000Ioo`00Ool007oo0004Ool01000
Ool000000Woo00<007ooOol017oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol017oo00<0
07oo00000Woo00@007ooOol000Qoo`03001oogoo009oo`8000Eoo`03001oogoo00Aoo`800005Ool0
07ooOol00003Ool01000Oomoo`0017oo00<007oo00001Goo00D007ooOomoo`00009oo`04001oo`00
0005Ool01@00Ool007oo00000goo00@007ooOomoo`@000=oo`03001oogoo00Aoo`03001oo`0000=o
o`04001oo`00000>Ool00`00Oomoo`03Ool00`00Oomoo`020005Ool01@00Ool007oo00000Woo00<0
07ooOol01Woo00@007ooOol0009oo`03001oo`0000Eoo`40000000<007ooOol00Woo00<007oo0000
0goo00<007oo000027oo00<007ooOol00Woo00<007oo00001Woo10000Woo00<007ooOol01Goo00<0
07ooOol00Woo00<007ooOol01Goo00<007ooOol00goo00<007ooOol01Woo00<007oo00000Woo00<0
07ooOol04Goo0`000Woo00<007ooOol02Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001o
ogoo00moo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo00Aoo`03001o
ogoo00Qoo`800003Ool007oo01eoo`03001oo`0000Aoo`800003Ool007oo00Ioo`04001oogooOol2
0005Ool01@00Oomoogoo00000Woo00<007ooOol03goo00<007ooOol017oo0@0000001000Oomoogoo
0`001Goo0`0000Eoo`00Oomoo`0000Aoo`03001oogoo00Eoo`03001oogoo00Eoo`05001oogooOol0
0002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomo
o`04Ool00`00Oomoo`02Ool00`00Ool00005Ool00`00Oomoo`02000017oo000000001goo00<007oo
Ool027oo100000Moo`00Oomoo`00Ool00003Ool00`00Oomoo`07Ool01@00Ool007oo00001Woo0P00
2goo00@007ooOol000=oo`03001oogoo00Eoo`04001oogoo0003Ool01000Ool007oo0`000Woo00<0
07ooOol00Woo00<007oo000027oo00<007ooOol01goo00@007ooOol0009oo`8000=oo`<0009oo`03
001oo`0000Eoo`07001oogooOol007oo000017oo00<007ooOol00Woo100017oo00<007ooOol01Woo
00<007oo00000P000goo0@0000000`00Oomoo`07Ool20004Ool01@00Oomoogoo00000Woo0P002Woo
00<007ooOol00Woo0P0017oo0P000Woo00<007oo00002Goo00D007ooOomoo`00009oo`0:001oogoo
001oo`00Ool007oo000:Ool01@00Oomoogoo000027oo00D007ooOol007oo00800003Ool007oo00io
o`8000=oo`03001oogoo009oo`8000Qoo`03001oo`0000=oo`03001oo`00009oo`05001oogoo001o
o`020004Ool20003Ool3000AOol01P00Ool00000Ool000Moo`800007Ool007ooOol007oo00000Woo
0`0037oo00<007ooOol01Goo00<007ooOol00Woo00D007oo001oo`0000=oo`07001oo`00Ool007oo
00000Woo00@007ooOol000Eoo`80009oo`03001oo`0000Uoo`40000000H007ooOol007oo0009Ool2
0009Ool00`00Oomoo`07Ool00`00Ool00002Ool00`00Oomoo`06Ool00`00Oomoo`0DOol30008Ool0
0`00Oomoo`03Ool00`00Oomoo`0;Ool01@00Oomoogoo00001goo00<007ooOol05Goo0P0000=oo`00
Ool00goo00<007oo000017oo00@007ooOomoo`8000Uoo`8000eoo`04001oogoo0004Ool00`00Oomo
o`02Ool01@00Oomoogoo00001Goo0P000Woo0P0027oo00<007oo00000goo0P0047oo00<007ooOol0
6Goo00@007ooOol0009oo`03001oogoo00Aoo`40000000<007ooOol01goo00<007oo00000goo00<0
07ooOol03Goo0P001Goo00<007ooOol00Woo00@007ooOol0009oo`@0009oo`08001oo`00001oo`00
Ool0009oo`80009oo`06001oogoo001oo`000goo0P000Woo00@007ooOol000Qoo`03001oogoo00Ao
o`80009oo`03001oogoo00800003Ool007oo009oo`03001oogoo00Ioo`06001oogoo001oo`001Goo
00D007ooOomoo`0000=oo`04001oogoo0005Ool00`00Oomoo`07Ool00`00Ool00007Ool00`00Ool0
0003Ool00`00Oomoo`020003Ool00`00Oomoo`02Ool00`00Ool00007Ool00`00Oomoo`02Ool20005
Ool01P00Oomoo`00Ool000=oo`03001oogoo00Moo`03001oogoo009oo`03001oo`0000Uoo`04001o
ogoo0009Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`04001oogooOol1
00000003001oogoo00Aoo`05001oogooOol00005Ool00`00Oomoo`07Ool20007Ool00`00Oomoo`06
Ool00`00Oomoo`08Ool00`00Oomoo`04Ool01000Ool007oo0`000goo00<007ooOol00Woo00<007oo
00000Woo00D007ooOomoo`0000Ioo`80009oo`80009oo`06001oogoo001oo`000Woo00P007ooOol0
07oo001oo`000goo0P001Woo00D007ooOomoo`0000Eoo`03001oogoo009oo`04001oo`000005Ool2
00000goo001oo`09Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool00`00Ool0000JOol20009Ool01@00
Oomoogoo00000goo00<007ooOol017oo00<007oo00000P0000=oo`00Ool00goo00<007oo00000Woo
00<007ooOol017oo00P007ooOol007oo001oo`002Goo00<007ooOol00goo0@0000000`00Oomoo`03
Ool01000Oomoogoo100017oo00D007ooOomoo`00009oo`03001oogoo00=oo`03001oogoo00=oo`05
001oogooOol00004Ool01000Oomoo`0027oo0P0017oo00D007ooOomoo`00009oo`06001oogoo001o
o`000Woo00L007oo000007oo001oo`0200000goo00000002Ool00`00Oomoo`02Ool20003Ool00`00
Oomoo`09Ool01000Ool007oo0`0017oo00<007oo00000P000goo0P0000Ioo`00Oomoo`00Ool30000
1Goo000007oo000017oo00@007oo000000Moo`03001oo`00009oo`07001oogooOol007oo00002Woo
00<007oo00000P002Goo00<007ooOol00goo00<007ooOol01Goo00@007ooOol000=oo`04001oogoo
Ool2000017oo001oo`000Woo00H007oo000007oo0002Ool00`00Oomoo`04Ool00`00Ool00003Ool3
0007Ool20006Ool00`00Ool00005Ool00`00Ool00003Ool100000003001oogoo00Ioo`03001oogoo
00Eoo`<000Ioo`05001oogooOol00008Ool3000;Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00
Oomoo`08Ool00`00Oomoo`07Ool00`00Ool00008Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00
Oomoo`09Ool00`00Oomoo`0>Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00
Oomoo`0?Ool01@00Oomoogoo000037oo00<007ooOol01Goo0P0017oo00<007ooOol02goo00D007oo
Oomoo`0000aoo`03001oogoo00Aoo`03001oogoo00=oo`04001oogooOol30006Ool100000005001o
o`00Ool00002Ool00`00Oomoo`04Ool02000Oomoogoo001oo`00Ool20003Ool00`00Oomoo`030002
Ool00`00Oomoo`06Ool300000goo001oo`0<Ool00`00Oomoo`04Ool01000Oomoo`000goo0P000Woo
0P000Woo00L007ooOomoo`00Ool00004Ool01@00Oomoo`00Ool00P001goo00<007ooOol02Woo00@0
07ooOol000Moo`03001oogoo00Yoo`03001oo`00009oo`03001oogoo009oo`03001oo`0000Aoo`03
001oogoo00Ioo`04001oogoo0003Ool00`00Oomoo`0200000goo001oo`02Ool00`00Oomoo`02Ool0
1000Oomoo`0027oo00<007oo00004Goo0P0000Aoo`00Ool000Eoo`07001oo`00Ool007oo00000goo
0P0000=oo`00Ool00Woo00<007ooOol017oo00<007oo00000goo00<007ooOol01Goo00<007ooOol0
1Goo00@007ooOomoo`40000000<007ooOol00P000Woo00<007ooOol00Woo00<007ooOol00goo00D0
07oo001oo`00009oo`@000=oo`04001oo`00000:Ool01000Oomoo`000goo00<007ooOol02Woo00<0
07ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool20006Ool30003Ool20003Ool01@00
Oomoogoo000017oo00@007oo001oo`8000Ioo`03001oogoo00=oo`06001oo`00001oo`000goo00/0
07ooOomoo`00Ool007oo001oo`0000Aoo`03001oo`0000=oo`03001oogoo009oo`05001oo`00Ool0
0002Ool00`00Oomoo`03Ool01`00Oomoogoo001oo`0000Eoo`03001oogoo009oo`03001oogoo009o
o`<0009oo`03001oo`0000Uoo`03001oogoo00800004Ool007oo0004Ool00`00Ool00002Ool01000
Ool007oo0`000Woo00<007ooOol00goo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00Eo
o`<00003Ool007oo00Eoo`04001oogooOol100000003001oogoo00=oo`03001oo`00009oo`04001o
ogoo000;Ool200000goo00000002Ool2000>Ool00`00Oomoo`05Ool01000Oomoo`0017oo00<007oo
Ool03Woo0P003Goo00<007ooOol01goo00<007ooOol00goo0P003Woo00<007oo00000Woo0P006goo
00<007ooOol00goo00@007ooOol000=oo`03001oogoo00Aoo`03001oogoo00Qoo`03001oo`00009o
o`03001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`04001oogoo000?Ool2000BOol00`00
Oomoo`0COol01000Ool000001Woo0@0000000`00Oomoo`05Ool00`00Oomoo`0200000goo001oo`03
Ool00`00Oomoo`02Ool01000Oomoo`000goo00<007ooOol03Woo0P001Woo00<007ooOol00goo00<0
07oo000017oo00<007ooOol00goo00@007oo000000Yoo`80009oo`03001oogoo00Aoo`05001oogoo
Ool00003Ool00`00Oomoo`02Ool00`00Ool00004Ool00`00Ool00004Ool00`00Oomoo`04Ool00`00
Ool00005Ool01@00Oomoogoo00000Woo0`0000Eoo`00Oomoo`0000aoo`03001oogoo008000Eoo`07
001oogooOol007oo000017oo00<007ooOol017oo0P000Woo0P000Woo0P001Goo00@007ooOol0009o
o`03001oogoo00Yoo`05001oogooOol00006Ool01000Ool000000Woo00X007ooOomoo`00Ool007oo
001oo`8000=oo`07001oogooOol007oo00000Woo00D007ooOomoo`0000Aoo`03001oogoo00=oo`40
000000<007ooOol01Goo00@007ooOomoo`@000Eoo`03001oo`00009oo`04001oogoo0004Ool01000
Oomoo`001Woo00D007ooOomoo`00009oo`03001oogoo00=oo`03001oogoo008000aoo`07001oogoo
Ool007oo00002Goo00<007ooOol00goo00<007ooOol01goo00<007ooOol01Goo00@007ooOomoo`80
009oo`03001oogoo008000Moo`80009oo`04001oogoo0004Ool20008Ool20002Ool00`00Ool00002
Ool00`00Oomoo`04Ool20008Ool00`00Ool00003Ool01@00Ool007oo00001goo00@007ooOomoo`80
00Ioo`<00003Ool007oo00Aoo`03001oogoo00Ioo`03001oo`00015oo`8000Aoo`03001oogoo00Ao
o`<000=oo`<000Qoo`03001oo`0000=oo`40000000<007ooOol03goo00<007ooOol017oo00<007oo
Ool037oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol02goo00@007ooOol000Yoo`03001o
ogoo00moo`04001oogooOol20007Ool00`00Ool00002Ool00`00Ool0000?Ool01000Oomoogoo0P00
00=oo`00Ool01Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol017oo00<007ooOol01Woo
00<007ooOol037oo00<007ooOol00goo0P000Woo00<007ooOol01goo00D007ooOomoo`0000Qoo`03
001oogoo00Ioo`8000Uoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo
00Ioo`03001oogoo00Moo`40000000L007ooOomoo`00Ool0000:Ool01000Oomoo`000Woo00X007oo
Oomoo`00Ool007oo001oo`8000Ioo`8000Aoo`04001oo`00Ool30003Ool00`00Ool0000;Ool2000=
Ool00`00Oomoo`05Ool00`00Ool00002Ool01`00Ool007oo001oo`0000Ioo`03001oogoo00=oo`04
001oo`00000:Ool20002Ool40003Ool01000Oomoo`0027oo0P000goo00<007ooOol00Woo0P000goo
00L007ooOomoo`00Ool00003Ool20002Ool200000goo000000030003Ool01000Oomoogoo0P000goo
00<007ooOol01Goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Goo
00<007ooOol00`002Goo10001Goo0P0000=oo`00Ool01Goo0@0000000`00Ool000030002Ool30002
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Ool007oo00000goo00<007ooOol00P0017oo00@0
07ooOol000Aoo`04001oogoo0004Ool00`00Oomoo`02Ool2000017oo000007oo0P000goo00<007oo
Ool027oo0P000goo0P000Woo00D007ooOomoo`00009oo`05001oogooOol00002Ool40004Ool00`00
Oomoo`0<Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool01P00Oomoo`00Ool000ao
o`05001oogooOol00003Ool01@00Ool007oo00001Woo00<007ooOol017oo00<007ooOol00goo00<0
07ooOol00goo00<007oo00000Woo00D007oo001oo`0000Aoo`<000=oo`03001oogoo00Yoo`03001o
ogoo00=oo`05001oogoo001oo`030006Ool01P00Oomoo`00Ool000Moo`04001oogooOol100000003
001oo`0000Eoo`03001oogoo00ioo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00]oo`03
001oogoo00=oo`03001oogoo00Eoo`05001oogooOol00003Ool00`00Oomoo`04Ool00`00Oomoo`0:
Ool00`00Oomoo`05Ool00`00Oomoo`08Ool00`00Oomoo`08Ool01000Oomoo`000Woo00@007ooOol0
00=oo`03001oogoo00ioo`03001oogoo00=oo`04001oogoo0004Ool00`00Oomoo`0>Ool00`00Oomo
o`05Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool00`00Oomoo`0HOol00`00Oomoo`07Ool00`00Oomo
o`020003Ool01000Oomoo`000goo00<007ooOol01Goo0@0000001000Oomoo`000Woo00<007ooOol0
27oo00D007oo001oo`0000=oo`03001oogoo00=oo`03001oogoo009oo`80009oo`03001oogoo00=o
o`<000Uoo`8000Moo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`09Ool00`00Ool0
0004Ool00`00Ool0000>Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03
001oogoo00Aoo`03001oo`000080009oo`80009oo`03001oogoo008000Eoo`05001oo`00Ool00002
Ool01000Oomoo`001goo00<007ooOol00goo00<007ooOol02Goo0P0000Aoo`00001oo`800003Ool0
07oo008000Eoo`8000Eoo`03001oo`0000=oo`07001oo`00Ool007oo00000goo00P007ooOol007oo
001oo`000Woo0`0027oo00@007ooOol0009oo`03001oogoo009oo`03001oogoo009oo`04001oogoo
0005Ool100000005001oogooOol00006Ool00`00Ool00006Ool01@00Ool007oo00000Woo00@007oo
0000009oo`800004Ool00000Ool20004Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Ool00002
Ool20003Ool00`00Ool00002Ool01@00Oomoogoo000017oo00H007ooOol007oo0003Ool01P00Ool0
0000Ool0009oo`05001oogoo001oo`0500000goo001oo`03Ool00`00Ool00006Ool20003Ool00`00
Oomoo`020003Ool300000goo001oo`04Ool20003Ool01@00Ool007oo00001Woo0P001goo0P003Goo
00<007oo00000Woo0P000goo00P007oo000007oo001oo`000Woo00@007ooOol000Uoo`04001oogoo
0002Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol00goo00<007oo000017oo00<007oo
Ool00goo00<007ooOol00P002Goo00@007ooOol000=oo`40000000<007oo00001goo00<007ooOol0
=7oo00<007ooOol01Goo0P0017oo00@007ooOol0031oo`03001oogoo00Eoo`04001oogooOol30002
Ool200000goo001oo`06Ool20009Ool00`00Ool00006Ool00`00Oomoo`03Ool00`00Oomoo`06Ool0
0`00Oomoo`04Ool00`00Oomoo`0:Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol02Goo00@007ooOol000aoo`04001oogoo0003Ool01000Oomoo`000goo00<007ooOol0
0Woo00D007ooOomoo`0000=oo`40000000<007ooOol00Woo0`0000=oo`00000037oo00H007oo0000
07oo0003Ool01000Oomoo`001Woo00@007ooOol000Aoo`03001oogoo00Eoo`04001oogooOol20004
Ool2000>Ool00`00Oomoo`040002Ool00`00Oomoo`05Ool00`00Oomoo`07Ool01`00Oomoogoo001o
o`0000Uoo`03001oo`00009oo`03001oogoo00=oo`80009oo`03001oo`0000Qoo`03001oogoo00Ao
o`800006Ool007oo001oo`001Goo00<007ooOol017oo00<007ooOol02goo00D007ooOomoo`0000Qo
o`07001oogooOol007oo00002Woo00<007oo00000Woo0`000goo00<007ooOol02Goo00@007ooOol0
00Moo`07001oo`00Ool007oo000017oo00<007ooOol03goo0@0000001`00Ool00000Ool007oo00@0
00Aoo`04001oogoo0002Ool01000Oomoo`0027oo00<007ooOol027oo00<007ooOol01Woo00<007oo
Ool017oo0P0000=oo`00Ool02Goo00L007oo000007oo001oo`020003Ool00`00Oomoo`06Ool00`00
Oomoo`03Ool01@00Ool007oo000017oo00<007oo00001Woo0P0000Qoo`00Oomoo`00Ool007oo1000
1Goo00D007oo001oo`0000=oo`800003Ool007oo009oo`8000Moo`<0009oo`800003Ool007oo009o
o`03001oo`0000Aoo`03001oo`0000=oo`04001oogooOol20002Ool01000Oomoo`000Woo0P0000Eo
o`00Ool007oo00@00003Ool0000000=oo`80009oo`03001oogoo00Ioo`03001oogoo00<000Uoo`80
00Ioo`03001oogoo00=oo`03001oogoo00800004Ool007oo0003Ool01000Oomoo`001goo00@007oo
Oomoo`40000000<007ooOol037oo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<0
07ooOol02goo00<007ooOol02Woo00<007ooOol06Woo00D007ooOomoo`00009oo`03001oogoo00Qo
o`03001oogoo00Eoo`03001oo`0000]oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`0=
Ool00`00Oomoo`07Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool00`00Oomoo`0FOol2000>Ool01@00
Oomoogoo00001Woo00D007ooOomoo`0000=oo`03001oogoo009oo`8000Aoo`80009oo`03001oogoo
00Aoo`40000000@007oo000000Aoo`03001oogoo00Qoo`03001oo`0000Eoo`03001oogoo00800004
Ool007oo0002Ool00`00Oomoo`08Ool20002Ool00`00Oomoo`04Ool300000goo001oo`05Ool00`00
Oomoo`03Ool00`00Oomoo`07Ool01000Oomoo`000goo0P000Woo00@007oo001oo`<000Moo`06001o
ogoo001oo`000goo0P000goo00<007ooOol00Woo00L007ooOomoo`00Ool00003Ool2000:Ool01000
Ool007oo0P003Goo0P0000=oo`00Ool00Woo00<007oo00000P006Woo00<007ooOol00goo00@007oo
Ool000Eoo`04001oogoo0008Ool00`00Oomoo`02Ool01000Oomoo`000Woo00<007ooOol00goo00<0
07ooOol00Woo00<007oo00001Goo00<007ooOol00goo0`001Goo00<007oo00000goo0@0000000`00
Oomoo`03Ool00`00Oomoo`0:Ool01@00Ool007oo00001goo00<007ooOol017oo0P000goo00@007oo
Ool000=oo`03001oogoo00Aoo`04001oogoo0003Ool40004Ool01000Oomoo`000Woo00D007ooOomo
o`0000Ioo`800003Ool007oo00Aoo`800003Ool007oo00Aoo`03001oogoo00=oo`03001oogoo00=o
o`03001oogoo00Qoo`04001oogoo0005Ool01@00Oomoogoo00000Woo100027oo00<007oo00000goo
00<007ooOol017oo00<007ooOol01Woo00@007ooOomoo`@000Qoo`04001oogoo0006Ool20005Ool0
1000Ool000001Woo00@007oo0000009oo`03001oogoo009oo`06001oogoo001oo`0027oo00<007oo
Ool01Woo00@007ooOol000eoo`03001oogoo008000Qoo`40000000<007ooOol02Woo00@007ooOol0
00]oo`03001oogoo009oo`8000Eoo`800003Ool007oo00Aoo`04001oogoo0003Ool3000:Ool01@00
Oomoogoo00001Woo00<007ooOol00goo00<007ooOol047oo00<007oo000027oo00<007ooOol02Woo
00<007ooOol01Goo00@007ooOol000]oo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo01Io
o`03001oo`0000Ioo`03001oogoo015oo`03001oogoo00=oo`03001oo`00009oo`04001oogoo0008
Ool00`00Oomoo`05Ool2000:Ool00`00Oomoo`02Ool01000Oomoo`000goo00@007ooOomoo`400000
00<007oo000027oo00D007ooOol007oo0080009oo`8000Aoo`03001oogoo00=oo`03001oogoo00Io
o`<000=oo`06001oogoo001oo`000goo0P0000Aoo`00Ool000Aoo`03001oogoo00Eoo`05001oogoo
Ool00002Ool00`00Oomoo`02Ool2000;Ool30009Ool20004Ool00`00Ool00002Ool00`00Oomoo`02
000;Ool20006Ool20004Ool01P00Oomoo`00Ool000eoo`03001oogoo009oo`03001oogoo00=oo`04
001oo`000002Ool00`00Oomoo`04Ool200000goo001oo`02Ool20007Ool00`00Oomoo`020002Ool0
0`00Oomoo`02Ool01@00Oomoo`00Ool00P000goo00P007ooOomoo`00Ool007oo0P0000=oo`00Ool0
1Woo0P004goo00D007ooOomoo`00009oo`04001oogoo0003Ool100000003001oogoo00]oo`05001o
o`00Ool0000:Ool01000Ool000001goo00<007oo00000P001goo00<007ooOol01Woo0P0017oo0P00
0goo00@007ooOol0009oo`03001oogoo009oo`800003Ool007oo00Qoo`04001oogoo0008Ool20000
17oo001oo`000Woo00<007ooOol047oo00<007ooOol01goo0P000goo00<007oo00001Woo0`000goo
00<007oo00002goo00@007ooOol000Ioo`04001oo`00Ool20004Ool01000Oomoo`000Woo00@007oo
Oomoo`@000=oo`800005Ool007ooOol00009Ool00`00Oomoo`04Ool01`00Oomoogoo001oo`0000Ao
o`03001oogoo009oo`04001oogoo0002Ool00`00Oomoo`05Ool01000Oomoo`001Goo00<007ooOol0
1Woo0@0000001@00Oomoogoo000027oo00<007ooOol03Goo00@007ooOomoo`<0009oo`03001oogoo
00Aoo`03001oo`0000Eoo`03001oogoo00=oo`03001oogoo00]oo`03001oo`0000=oo`03001oogoo
00aoo`03001oogoo00Moo`03001oogoo00800005Ool007ooOol00002Ool00`00Oomoo`0?Ool00`00
Oomoo`09Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool30004Ool20005Ool00`00Oomoo`03Ool20006
Ool00`00Oomoo`0:Ool2000=Ool00`00Ool0000=Ool01@00Oomoogoo000047oo00<007ooOol02Goo
00<007ooOol037oo0@0000001000Oomoo`001goo00D007oo001oo`00009oo`<00003Ool000000080
00aoo`03001oogoo00Eoo`03001oogoo00Qoo`03001oo`0000Moo`05001oogooOol00005Ool00`00
Oomoo`03Ool00`00Oomoo`03Ool2000027oo00000000Ool007oo000<Ool20003Ool01`00Ool007oo
001oo`00009oo`04001oo`00000<Ool20002Ool01000Ool000001Goo00@007ooOol000]oo`03001o
ogoo00Aoo`03001oogoo00Eoo`03001oo`0000Eoo`03001oogoo00=oo`03001oogoo00Eoo`03001o
o`0000Ioo`03001oo`0000Ioo`05001oo`00Ool00004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
1000Oomoo`000goo00D007ooOomoo`0000Eoo`03001oogoo00Ioo`03001oogoo00Moo`05001oo`00
Ool00003Ool100000004001oogooOol2000017oo001oo`001Goo00@007ooOol0009oo`05001oogoo
Ool00002Ool20004Ool01000Ool007oo0P000Woo0P000goo00D007ooOomoo`0000Uoo`@000Ioo`03
001oogoo00Yoo`07001oogooOol007oo00001Goo00<007oo00000goo00D007ooOomoo`00009oo`03
001oo`0000Ioo`04001oogoo0005Ool00`00Oomoo`08Ool20006Ool20002Ool00`00Oomoo`02Ool0
0`00Oomoo`05Ool00`00Oomoo`04Ool40005Ool30007Ool01000Ool000004Goo00<007ooOol01Woo
00<007ooOol01Goo0`000goo0`001Goo0P0000=oo`00Ool00Woo00<007ooOol00`001Woo00<007oo
00000`001Woo00@007ooOol000Aoo`04001oogoo0003Ool100000003001oogoo00Ioo`03001oogoo
009oo`03001oo`00009oo`03001oogoo00=oo`03001oogoo00Ioo`04001oo`000004Ool01000Ool0
00001Goo00D007oo001oo`0000Qoo`03001oogoo008000Eoo`800005Ool007ooOol0000@Ool20003
Ool01000Oomoo`002Goo0P001Goo00@007ooOol0009oo`03001oogoo009oo`04001oogoo0002Ool2
0003Ool00`00Oomoo`04Ool01000Oomoo`001Goo0P000goo00@007ooOol0011oo`03001oogoo00Eo
o`06001oogoo001oo`000Woo00<007ooOol00Woo00<007oo00001@0000=oo`00Ool02goo00<007oo
00001goo00<007oo00000Woo00@007ooOomoo`8000=oo`05001oogooOol00003Ool00`00Oomoo`03
00000goo001oo`0BOol100000003001oogoo00Aoo`03001oogoo01Aoo`03001oo`0000aoo`03001o
ogoo02Yoo`04001oo`00Ool20002Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
1@00Oomoogoo00001Goo00<007ooOol01Goo00@007ooOol000Yoo`04001oogoo000<Ool00`00Oomo
o`0>Ool00`00Oomoo`04Ool01@00Oomoogoo00000Woo00<007ooOol017oo00@007ooOol000Qoo`03
001oogoo0080009oo`03001oo`0000]oo`03001oo`0000Eoo`03001oogoo00Uoo`03001oogoo00Mo
o`03001oogoo009oo`03001oogoo00Uoo`04001oogooOol100000005001oogoo001oo`02000:Ool0
0`00Oomoo`02Ool00`00Oomoo`04Ool20005Ool00`00Oomoo`020003Ool00`00Oomoo`09Ool00`00
Oomoo`04Ool400000goo001oo`03Ool01000Oomoo`0027oo00@007ooOol000Ioo`03001oo`0000Eo
o`05001oogooOol0000<Ool00`00Oomoo`08Ool00`00Oomoo`03Ool20002Ool00`00Ool000020003
Ool00`00Oomoo`09Ool30003Ool00`00Oomoo`02Ool5000<Ool01@00Oomoogoo00002goo00<007oo
Ool00goo00<007ooOol02Goo00D007oo001oo`0000Moo`03001oogoo009oo`03001oogoo00Eoo`08
001oogooOol007oo001oo`<000=oo`07001oogooOol007oo000017oo00<007ooOol01goo00@007oo
Oomoo`40000000<007ooOol00Woo00<007ooOol00goo00D007ooOomoo`0000Aoo`04001oogoo0002
Ool00`00Ool00008Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00D007ooOomoo`00009oo`03
001oogoo00Aoo`03001oogoo008000=oo`03001oo`0000Eoo`03001oo`0000<000=oo`8000=oo`07
001oogooOol007oo000027oo00<007oo00000Woo00<007ooOol01Woo00H007ooOol007oo0002Ool0
0`00Ool00003Ool00`00Oomoo`03Ool00`00Oomoo`08Ool01000Ool007oo0P000Woo00<007ooOol0
1Goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oo`0000Eoo`03001oogoo00Eoo`03001o
ogoo00aoo`03001oogoo00=oo`03001oogoo00Yoo`80009oo`03001oogoo009oo`04001oogooOol2
0006Ool20002Ool00`00Oomoo`02Ool01000Oomoogoo0P0000=oo`0000000Woo1@001Goo0@000000
0`00Oomoo`0;Ool01000Oomoo`003goo00<007oo00001Woo00<007ooOol03goo00<007oo00002Goo
00D007ooOomoo`0000Aoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo008000Qoo`05001o
ogooOol00009Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`0AOol0
1@00Ool007oo00001Goo0P0000Ioo`00Ool007oo0009Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
0`00Ool0000?Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
2000Oomoo`00Ool007oo000AOol100000003001oo`0000Uoo`800003Ool007oo00Eoo`03001oo`00
00Eoo`03001oogoo00Aoo`07001oogooOol007oo000017oo00D007ooOomoo`0000Eoo`04001oo`00
0009Ool00`00Oomoo`02Ool00`00Ool00002Ool01000Ool000000Woo00H007ooOol007oo0002Ool0
0`00Oomoo`06Ool00`00Oomoo`0;Ool20002Ool01000Oomoo`0017oo0P0000=oo`00000027oo00<0
07oo00000Woo00<007oo00002goo0P001Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol0
1Woo0`000goo00@007oo000000Ioo`03001oo`0000Qoo`03001oogoo00Eoo`03001oogoo00=oo`<0
009oo`80009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00<00003Ool007oo00=oo`80
00Moo`03001oo`0000<000=oo`03001oo`0000=oo`40000000<007ooOol00goo0P000Woo00@007oo
000000=oo`03001oogoo00Ioo`03001oo`0000=oo`03001oogoo00Ioo`03001oogoo00]oo`04001o
ogoo0006Ool01000Oomoo`000goo00<007oo00001Goo00<007ooOol01Woo00<007ooOol017oo00<0
07ooOol01Goo00<007ooOol00Woo00H007ooOol007oo0002Ool00`00Oomoo`07Ool01000Ool007oo
0P001goo00<007ooOol01Goo0P0000Aoo`00Oomoo`800004Ool00000000COol01000Oomoo`001Goo
00<007ooOol00Woo00D007oo001oo`00009oo`8000=oo`03001oogoo00Ioo`03001oogoo009oo`03
001oogoo0080009oo`03001oogoo00Moo`03001oogoo00Ioo`03001oo`0000=oo`03001oogoo00Eo
o`03001oogoo00Eoo`04001oo`000006Ool01000Ool000000Woo00@007ooOomoo`40000000<007oo
Ool00goo00<007ooOol00goo00D007ooOomoo`0000Moo`03001oogoo00=oo`03001oogoo009oo`03
001oo`0000Ioo`04001oogoo000:Ool20003Ool01@00Oomoogoo00002Woo0P001goo00<007ooOol0
3Goo00<007ooOol05goo00<007ooOol09goo00<007ooOol02Woo00<007ooOol027oo00@007oo0000
00Aoo`03001oogoo00aoo`03001oogoo00Qoo`03001oogoo00Qoo`05001oogooOol00005Ool00`00
Oomoo`0?Ool00`00Oomoo`04Ool200000goo001oo`07Ool100000003001oogoo008000Eoo`05001o
ogooOol00002Ool00`00Ool00009Ool00`00Ool00007Ool00`00Oomoo`020004Ool01000Ool007oo
0P000goo00@007oo000000Moo`03001oogoo00=oo`80009oo`03001oogoo009oo`03001oo`0000Eo
o`800003Ool007oo00Aoo`04001oogooOol40007Ool01P00Oomoogoo001oo`80009oo`03001oogoo
00Moo`80009oo`800005Ool007ooOol00008Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00<0
07oo00000Woo00@007oo001oo`8000Aoo`03001oogoo00Eoo`8000Uoo`<000=oo`05001oogooOol0
0006Ool00`00Oomoo`020007Ool00`00Oomoo`06Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<0
07oo000017oo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol00goo00@007ooOomoo`400000
00D007ooOomoo`0000Moo`05001oogooOol00006Ool00`00Oomoo`02Ool00`00Oomoo`020006Ool0
0`00Oomoo`06Ool20003Ool01@00Oomoogoo00001goo0P0017oo00L007ooOomoo`00Ool00002Ool0
0`00Ool00002Ool20007Ool01000Oomoo`004goo0P0000=oo`00Ool01goo0`0000=oo`0000001Woo
00@007ooOol000moo`06001oogoo001oo`003Goo00<007ooOol00Woo00L007ooOomoo`00Ool00003
Ool30005Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`04Ool20003Ool30002Ool00`00
Oomoo`03Ool01`00Ool007oo001oo`0000Yoo`@000Ioo`800003Ool007oo009oo`05001oogooOol0
0008Ool01000Oomoogoo0@0000000`00Oomoo`04Ool00`00Oomoo`020004Ool01@00Oomoogoo0000
0Woo0P000goo00<007ooOol02goo0P004Woo00<007ooOol027oo00<007ooOol00goo00<007ooOol0
2Goo0P001goo0`000goo00<007ooOol017oo0`001Goo00L007ooOomoo`00Ool00005Ool3000?Ool0
1@00Oomoogoo000017oo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol00goo00<007ooOol0
0Woo00H007ooOol007oo0004Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00
Ool00006Ool01000Oomoo`0027oo00T007ooOomoo`00Ool007oo00003Woo00@007ooOol000=oo`03
001oogoo00Ioo`03001oogoo00=oo`40000000<007ooOol00goo0P0000Aoo`00Ool000=oo`80009o
o`03001oogoo00800003Ool007oo00eoo`03001oogoo009oo`@0009oo`80009oo`80009oo`03001o
ogoo00Eoo`07001oogooOol007oo00001Goo0P0000Aoo`00Ool0009oo`8000Aoo`03001oogoo00=o
o`08001oo`00Ool007oo001oo`8000Aoo`03001oogoo00Ioo`03001oogoo00Eoo`04001oo`00Ool2
000017oo001oogoo100017oo00<007oo00001Woo0`001Woo0`000goo00D007oo001oo`0000Aoo`07
001oogooOol007oo000017oo00D007ooOomoo`00009oo`8000moo`800003Ool0000000800003Ool0
000000Aoo`03001oogoo009oo`03001oogoo009oo`80009oo`8000=oo`05001oogooOol00003Ool0
1@00Oomoogoo00001Woo0`000Woo00<007ooOol017oo0P001Goo0@0000000`00Oomoo`09Ool20006
Ool00`00Ool00002Ool00`00Oomoo`05Ool01000Ool000001Woo0P000goo00<007oo00000goo00@0
07ooOol000=oo`800006Ool007oo001oo`0027oo00<007ooOol00Woo00@007ooOol000=oo`04001o
o`000007Ool00`00Ool00003Ool00`00Oomoo`020003Ool00`00Oomoo`05Ool00`00Oomoo`02Ool2
0005Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Ool00002Ool00`00Oomoo`05Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01000Oomoo`0027oo0P0000=oo`00Ool017oo00@0
07ooOomoo`8000=oo`04001oogoo0003Ool01000Ool007oo0P0057oo00@007oo000000=oo`800005
Ool007ooOol00005Ool01000Oomoo`000Woo00L007ooOomoo`00Ool00005Ool01@00Oomoogoo0000
0goo0@0000000`00Oomoo`05Ool00`00Oomoo`0>Ool20004Ool00`00Oomoo`08Ool00`00Oomoo`03
Ool20004Ool00`00Oomoo`0MOol00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Ool00003Ool00`00
Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0IOol00`00Oomoo`0AOol00`00Oomoo`08Ool00`00
Ool00004Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`0COol00`00
Ool00002Ool00`00Oomoo`09Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`05Ool01000
Oomoogoo0@0000000`00Ool000020003Ool00`00Oomoo`06Ool00`00Oomoo`09Ool01000Ool00000
0goo0P0000=oo`00Ool01goo00@007ooOol0009oo`<00005Ool007ooOol00003Ool01@00Ool007oo
00000Woo00D007ooOomoo`0000Yoo`<000Ioo`03001oogoo009oo`03001oo`0000Ioo`03001oogoo
009oo`04001oo`000009Ool00`00Oomoo`04Ool00`00Oomoo`06Ool20007Ool20009Ool01000Ool0
00000goo00@007ooOomoo`8000Eoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00=oo`03
001oogoo00=oo`05001oogoo001oo`020002Ool01000Oomoo`000goo0`0017oo00<007ooOol017oo
00L007ooOomoo`00Ool0000AOol00`00Ool00003Ool01P00Oomoo`00Ool000Ioo`40000000<007oo
Ool00Woo0P0000Aoo`00Oomoo`800003Ool007oo009oo`03001oogoo009oo`8000Eoo`04001oogoo
0006Ool00`00Oomoo`07Ool01000Ool007oo0P002Goo00<007ooOol01Goo100000=oo`00Ool00P00
0Woo00D007oo001oo`00009oo`80009oo`80009oo`03001oogoo009oo`05001oogooOol0000AOol0
0`00Oomoo`02Ool400000goo00000003Ool200000goo00000002Ool00`00Oomoo`04Ool00`00Ool0
000;Ool00`00Oomoo`07Ool20002Ool01@00Oomoogoo00000goo00@007ooOol000Aoo`05001oo`00
Ool00002Ool00`00Oomoo`03Ool20004Ool300000goo001oo`07Ool30003Ool20002Ool00`00Oomo
o`03Ool00`00Oomoo`05Ool00`00Ool00009Ool00`00Oomoo`02Ool00`00Oomoo`08Ool01000Oomo
ogoo0@0000001000Oomoo`001goo0P002goo00<007ooOol00P001Woo00<007ooOol00goo00D007oo
Oomoo`0000Eoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo01eoo`03001oogoo00Ioo`03
001oogoo00=oo`05001oogooOol00003Ool00`00Oomoo`07Ool00`00Oomoo`0@Ool00`00Ool00004
Ool00`00Ool00005Ool00`00Oomoo`08Ool00`00Oomoo`0MOol00`00Oomoo`07Ool00`00Oomoo`0>
Ool00`00Oomoo`0@Ool01000Oomoogoo10001Goo00<007ooOol017oo00D007oo001oo`0000=oo`40
000000@007ooOol000Yoo`03001oogoo00<000Uoo`8000moo`8000Ioo`8000=oo`05001oogooOol0
0004Ool00`00Oomoo`020003Ool00`00Ool000020007Ool00`00Oomoo`0300001goo001oogoo001o
o`0000aoo`04001oogoo0002Ool01000Ool000004Woo0P001goo00<007ooOol037oo00D007ooOomo
o`00009oo`<00003Ool007oo009oo`03001oo`0000@0009oo`03001oogoo00Ioo`03001oogoo00=o
o`80009oo`06001oogooOol007oo0P0000=oo`00Ool00Woo00<007ooOol00goo00H007oo001oo`00
Ool20005Ool01000Oomoo`001goo00<007ooOol00Woo00<007ooOol01goo00<007oo000027oo0P00
0Woo00<007ooOol00goo0@0000002000Ool007oo001oo`00Ool20002Ool00`00Ool00003Ool00`00
Ool00005Ool00`00Oomoo`07Ool01000Oomoo`0017oo00<007oo00000goo0`0000=oo`0000001Woo
0`0017oo00<007ooOol01Woo0`0027oo00H007oo000007oo0009Ool00`00Oomoo`020006Ool20004
Ool01@00Oomoogoo00001goo00<007ooOol017oo00<007ooOol01Goo0P0000=oo`00Ool03goo00<0
07ooOol00goo00<007ooOol00Woo00<007ooOol057oo00<007ooOol00goo00<007ooOol017oo00<0
07ooOol00Woo00@007ooOol0009oo`03001oogoo009oo`04001oogooOol20006Ool00`00Oomoo`03
Ool00`00Oomoo`040003Ool01000Oomoo`000goo0P0017oo00@007ooOomoo`80009oo`03001oogoo
00Aoo`40000000<007ooOol02Woo00<007ooOol01Woo00<007ooOol0<7oo00<007ooOol03goo0P00
0Woo00<007ooOol00goo00<007oo000037oo00<007ooOol02Woo00<007ooOol06Woo00<007ooOol0
6Woo00@007ooOomoo`80011oo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Qoo`07001o
ogooOol007oo00005goo00<007ooOol01goo00@007ooOomoo`40000000H007oo000007oo0004Ool0
0`00Oomoo`02Ool01P00Oomoo`00Ool000]oo`05001oogoo001oo`0200001Woo001oo`00Ool000Ao
o`03001oogoo009oo`8000Aoo`8000Aoo`03001oo`00009oo`03001oogoo008000moo`04001oogoo
0004Ool00`00Ool00003Ool20002Ool00`00Oomoo`04Ool300000goo001oo`0>Ool01P00Oomoo`00
Ool0009oo`03001oogoo00Eoo`03001oogoo00800004Ool007oo0003Ool00`00Oomoo`0200000goo
001oo`03Ool2000;Ool00`00Oomoo`05Ool20007Ool00`00Ool00006Ool200000goo001oo`020000
1Goo001oogoo00000Woo00<007ooOol00goo00D007ooOomoo`0000Uoo`03001oogoo009oo`8000=o
o`03001oogoo00D000=oo`03001oogoo009oo`04001oogoo0005Ool01000Oomoogoo0@0000000`00
Ool00002Ool2000?Ool2000017oo001oo`004Woo0P0000Ioo`00Oomoo`00Ool400000goo001oo`02
Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`06Ool40006Ool20002
Ool00`00Oomoo`03Ool01000Oomoo`001Woo0P000Woo00<007ooOol00Woo00<007oo00000Woo0`00
00=oo`00000017oo00@007ooOol000Moo`03001oogoo00Eoo`<000Moo`8000Aoo`8000Moo`04001o
ogoo0003Ool2000017oo001oo`000Woo00D007oo001oo`0000ioo`800003Ool0000000Eoo`03001o
ogoo00Aoo`80009oo`800003Ool007oo00]oo`07001oogooOol007oo00000Woo0`000Woo00<007oo
00001Goo0@0000002000Oomoo`00Ool007oo0002Ool01000Oomoo`0017oo0P000Woo00L007ooOomo
o`00Ool00007Ool40005Ool00`00Oomoo`06Ool200000goo001oo`020004Ool00`00Oomoo`07Ool0
1000Ool007oo0P000goo00<007ooOol00`0027oo00D007ooOomoo`00009oo`03001oogoo00Qoo`80
0005Ool007ooOol00002Ool00`00Oomoo`06Ool00`00Ool00006Ool00`00Oomoo`02Ool01@00Ool0
0000Ool00P0017oo0`0000=oo`0000001Goo0P0000Eoo`00Oomoo`0000Aoo`800004Ool007oo0002
Ool01000Oomoo`000Woo0P001Woo00<007ooOol00Woo1@000Woo00@007ooOol0009oo`03001oogoo
00=oo`04001oogoo0009Ool2000<Ool300000goo001oo`03Ool20008Ool00`00Ool00004Ool20000
0goo001oo`02Ool100000003001oogoo00Aoo`<001Ioo`03001oogoo00=oo`03001oogoo00Ioo`03
001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00moo`03
001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Yoo`04001oogoo0006Ool20002Ool00`00Oomo
o`02Ool00`00Oomoo`04Ool01@00Oomoogoo00001goo0P001Goo0P001Woo00<007ooOol05Woo0P00
00=oo`00Ool027oo0P0000=oo`00Ool01goo0P000goo0`0027oo00@007ooOol000Qoo`8000=oo`03
001oogoo01Ioo`40000000<007oo000017oo00<007ooOol00P0000=oo`00Ool00Woo00<007ooOol0
1goo00<007ooOol00goo00<007oo00000Woo0P0037oo00L007oo001oo`00Ool00005Ool00`00Oomo
o`04Ool40002Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`020003Ool01@00Oomoogoo
000017oo0`001goo00<007ooOol01Goo00@007oo0000015oo`04001oogoo0003Ool00`00Oomoo`02
Ool2000:Ool20005Ool20005Ool00`00Ool00004Ool00`00Oomoo`03000017oo001oo`000Woo00<0
07oo000027oo00<007ooOol00Woo1@000Woo00@007oo000000=oo`03001oogoo00=oo`05001oo`00
Ool00002Ool30008Ool00`00Oomoo`0?Ool00`00Oomoo`06Ool100000003001oogoo00=oo`03001o
o`00008000Qoo`<00003Ool0000000<0009oo`8000Aoo`03001oogoo009oo`03001oogoo008000Mo
o`<00003Ool00000009oo`05001oogoo001oo`020005Ool20006Ool01P00Oomoo`00Ool000Ioo`03
001oogoo009oo`80009oo`<000=oo`08001oogoo001oo`00Ool000moo`03001oogoo00Aoo`80009o
o`03001oogoo00Uoo`04001oo`000002Ool00`00Oomoo`04Ool00`00Oomoo`03Ool01000Ool00000
0Woo00<007ooOol01Goo0P000Woo00<007ooOol00P000Woo0P000Woo00H007oo000007oo0002Ool2
0009Ool00`00Oomoo`060002Ool00`00Ool00002Ool2000AOol01@00Oomoogoo00002Goo0`0000=o
o`00Ool00goo0P000Woo00@007ooOomoo`40000000<007ooOol05goo0`002goo00<007oo00002goo
0P0037oo00<007ooOol02Woo00D007oo001oo`0000=oo`03001oogoo00Ioo`03001oogoo011oo`03
001oogoo00<0009oo`03001oogoo00Eoo`03001oo`0000Qoo`06001oogooOol007oo0P0000Eoo`00
Oomoo`0001aoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00800003Ool007oo00]oo`04
001oogoo000:Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Ool0000MOol0
1000Oomoogoo0@0000001@00Oomoogoo000037oo00<007ooOol01Goo00<007oo00000Woo0P0017oo
00<007oo00000Woo00<007ooOol00Woo00<007ooOol01Goo0P001Woo00D007oo000007oo00<000=o
o`03001oogoo00Aoo`800003Ool007oo00moo`<00003Ool007oo00800005Ool007ooOol00005Ool0
0`00Oomoo`05Ool00`00Ool00003Ool20004Ool00`00Oomoo`0;Ool300001Woo001oo`00Ool000Ao
o`03001oogoo00=oo`06001oogoo001oo`000goo00H007oo000007oo0003Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool00`00Oomoo`05Ool01@00Ool007oo00000goo0P001Woo00H007ooOol007oo0006
Ool00`00Ool00004Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo0P001Goo0P001Woo00@007oo
Ool0009oo`03001oogoo00=oo`40000000@007ooOol000moo`05001oogooOol00002Ool00`00Oomo
o`0200000goo001oo`06Ool20002Ool00`00Oomoo`04Ool30007Ool20008Ool20003Ool01000Ool0
00000Woo00@007ooOomoo`<000Eoo`8000Aoo`800004Ool007oo0004Ool2000017oo001oo`001Woo
00<007ooOol01Goo0`001Woo00<007oo00000goo00<007ooOol027oo00@007ooOol000Eoo`03001o
ogoo00Aoo`03001oogoo00Aoo`04001oogooOol20003Ool00`00Oomoo`04Ool2000<Ool00`00Oomo
o`04Ool00`00Oomoo`03Ool00`00Oomoo`07Ool20006Ool01000Oomoogoo0`000Woo0P0000=oo`00
Ool02goo0P000Woo0P000Woo00D007oo001oo`0000=oo`03001oo`0000=oo`40000000<007ooOol0
37oo00<007ooOol01Woo00<007ooOol037oo00<007ooOol01goo00<007ooOol067oo0P001Goo00<0
07ooOol00goo00<007ooOol04Goo00<007oo00001Goo00<007ooOol057oo00@007oo000000aoo`03
001oogoo00=oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Aoo`80
00Yoo`800003Ool0000000Yoo`05001oogooOol0000AOol00`00Oomoo`08Ool00`00Oomoo`05Ool0
1000Oomoo`000goo00D007ooOomoo`0000Uoo`40000000@007ooOomoo`8000Eoo`05001oogooOol0
0004Ool30004Ool01000Ool007oo0`0000Aoo`00Ool000]oo`03001oo`0000Aoo`04001oogoo0003
Ool01000Oomoo`000Woo00<007ooOol01Woo00<007ooOol00Woo0`0000=oo`0000001Goo100000=o
o`00Ool00goo00<007ooOol01Goo00<007ooOol00goo0`0000Moo`00Oomoo`00Ool00002Ool30002
Ool01000Ool000001Goo00@007ooOomoo`8000Moo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo00Aoo`06001oogoo001oo`000goo00<007ooOol017oo0P0027oo00<007ooOol00Woo00@007oo
Oomoo`8000Eoo`03001oogoo008000Aoo`8000=oo`<000Aoo`03001oogoo00Moo`04001oogooOol3
0004Ool20003Ool01000Oomoo`0017oo00<007ooOol017oo0P000Woo00@007ooOomoo`40000000P0
07ooOol007oo001oo`001Goo00<007ooOol00Woo00<007ooOol00goo0`000Woo00<007ooOol00Woo
0P000goo00<007ooOol017oo0P000Woo0P000goo00H007ooOomoo`00Ool20002Ool00`00Oomoo`02
Ool00`00Ool00002Ool00`00Ool00007Ool20006Ool01000Oomoo`002Goo0`004Goo0P003Goo00D0
07oo001oo`0000Aoo`03001oogoo009oo`03001oogoo009oo`8000Ioo`03001oogoo009oo`04001o
o`000004Ool20004Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Ool0000027oo00<007ooOol0
0Woo0P000goo00<007ooOol02Woo0P0000Aoo`00Ool000Eoo`03001oo`00009oo`05001oogooOol0
0004Ool200001Goo000007oo00000goo00<007ooOol00goo00<007ooOol017oo00@007ooOomoo`40
000000<007ooOol02goo00<007ooOol027oo00@007ooOol000]oo`05001oogooOol00002Ool01000
Oomoo`001Goo00<007ooOol04Goo00<007ooOol02Goo00P007ooOol007oo001oo`000goo00@007oo
Ool000Qoo`8000Aoo`80019oo`03001oo`0001Yoo`03001oogoo00Qoo`80009oo`03001oogoo00Ao
o`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`04001oogoo000=Ool00`00Oomoo`0?
Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`06
Ool00`00Oomoo`07Ool100000003001oogoo009oo`80009oo`03001oo`0000Aoo`03001oogoo009o
o`03001oo`0000Moo`04001oogoo0006Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`04
Ool400000goo001oo`02Ool01000Oomoo`0027oo00@007ooOol000Aoo`04001oo`00000:Ool00`00
Ool00005Ool01000Ool000001goo00D007ooOomoo`00009oo`03001oogoo008000Yoo`03001oogoo
00Aoo`03001oogoo009oo`05001oogooOol00002Ool00`00Oomoo`0200000goo00000006Ool20000
0goo001oo`05Ool3000017oo001oo`0017oo00@007ooOomoo`8000moo`<000]oo`03001oogoo00Qo
o`07001oogooOol007oo00000Woo00<007ooOol017oo00<007oo00000Woo00<007oo00000Woo0`00
1Woo0`001Goo0@0000000`00Ool00004Ool00`00Ool00003Ool200001Woo000007oo001oo`800005
Ool00000Ool0000AOol00`00Oomoo`02Ool00`00Ool00004Ool200001Goo001oogoo00000Woo00D0
07oo001oo`0000=oo`03001oogoo009oo`80009oo`03001oogoo009oo`03001oogoo008000Aoo`03
001oogoo00Yoo`80009oo`80009oo`800003Ool007oo009oo`04001oogoo0004Ool30003Ool20000
0goo001oo`020002Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool01@00Oomoo`00Ool010000Woo0P00
1Woo00<007ooOol00Woo00D007ooOol007oo008000eoo`8000=oo`03001oo`0000Eoo`05001oogoo
Ool00002Ool00`00Oomoo`03Ool00`00Ool00004Ool00`00Oomoo`04Ool01000Ool000000goo00@0
07ooOol000=oo`04001oogooOol40004Ool00`00Ool00002Ool30003Ool100000003001oogoo019o
o`03001oogoo00Qoo`8000=oo`03001oogoo01aoo`03001oogoo00=oo`03001oogoo00Ioo`04001o
ogoo0005Ool00`00Oomoo`09Ool01000Oomoo`000goo00<007ooOol01Woo00<007ooOol03goo00<0
07ooOol02Woo00D007oo001oo`00009oo`<000Ioo`03001oogoo00Moo`8000eoo`09001oogooOol0
07oo001oo`0001=oo`8000Qoo`03001oogoo00Aoo`04001oogoo0003Ool00`00Oomoo`04Ool00`00
Oomoo`08Ool00`00Oomoo`07Ool01000Ool000002goo0@0000000`00Oomoo`0<Ool2000017oo001o
o`001Goo00<007ooOol00`0000=oo`0000000Woo00<007ooOol017oo00<007oo00000goo0`000Woo
00H007ooOol007oo0006Ool01000Ool0000017oo00D007ooOomoo`0000=oo`<00005Ool007oo001o
o`020009Ool00`00Ool00002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00
Oomoo`02Ool01P00Oomoo`00Ool000Uoo`8000Aoo`05001oogooOol00002Ool20002Ool01000Oomo
ogoo0`000goo00H007oo000007oo0003Ool40002Ool01P00Oomoo`00Ool000Aoo`8000Eoo`05001o
ogooOol00003Ool00`00Oomoo`04Ool00`00Ool00005Ool00`00Oomoo`03Ool20005Ool01000Oomo
o`001goo00T007ooOomoo`00Ool007oo00001Goo00@007ooOomoo`8000eoo`40000000<007ooOol0
0P0000=oo`00Ool01Woo0P001Goo00<007oo000017oo00<007ooOol017oo00<007ooOol01goo0P00
0Woo00@007ooOol000Aoo`04001oogooOol20002Ool01@00Oomoogoo00000goo00<007ooOol01Woo
0P000goo00<007ooOol02Goo00@007ooOol000Ioo`800005Ool007ooOol00006Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`04001oogoo0005Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007oo
Oomoo`8000Ioo`03001oo`0000Eoo`8000=oo`05001oogooOol00003Ool01000Ool000002Woo0P00
0Woo00D007oo000007oo0080009oo`03001oo`000080009oo`800004Ool007oo0003Ool30002Ool0
0`00Oomoo`0300000goo001oo`07Ool00`00Oomoo`04Ool30002Ool01000Oomoo`0017oo0P000Woo
00@007oo001oo`8000=oo`40000000<007ooOol017oo00<007ooOol027oo00<007ooOol037oo00@0
07ooOol000=oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Qoo`04001oogoo0002Ool0
0`00Oomoo`0BOol2000<Ool00`00Oomoo`06Ool00`00Ool00009Ool01000Oomoo`000Woo00<007oo
Ool01Goo0P004Woo0P001Woo00<007ooOol01Woo0P0000Eoo`00Oomoo`0001Aoo`800006Ool007oo
001oo`000goo00@007ooOol000Eoo`03001oo`00009oo`04001oogoo0007Ool01000Oomoo`0057oo
0P002goo00D007ooOomoo`0000Eoo`40000000D007ooOomoo`00009oo`05001oogooOol00004Ool0
1000Ool0000027oo00<007ooOol00goo00@007oo000000=oo`03001oogoo009oo`03001oo`00015o
o`03001oogoo00800003Ool0000000Moo`03001oogoo00Uoo`800003Ool007oo00]oo`07001oogoo
001oo`00Ool00P000goo00<007ooOol00Woo1@0000=oo`00Ool00`000Woo0P0000Moo`00001oo`00
Ool00002Ool00`00Oomoo`04Ool00`00Oomoo`03Ool200001Goo001oo`00Ool00P001Goo0P000Woo
00<007ooOol00Woo0P001Goo0P000goo0P0000=oo`00Ool00goo00<007oo00001Goo0P000Woo00<0
07oo00000P000Woo00<007oo00001goo0P0000=oo`00Ool00goo0P000goo00<007oo000017oo00<0
07ooOol02Goo00<007ooOol00goo00<007ooOol00goo00<007ooOol01Goo0@0000000`00Oomoo`07
Ool00`00Ool00004Ool01000Ool000000Woo00<007ooOol017oo00<007oo00000goo0P0000=oo`00
Ool00P0000=oo`00Ool02Woo0P001Goo00<007ooOol017oo00H007oo001oo`00Ool20002Ool20002
Ool01000Oomoogoo0P0000Aoo`00001oo`800003Ool0000000Uoo`03001oo`00009oo`8000Eoo`03
001oo`00009oo`03001oo`0000Ioo`05001oogooOol00003Ool01000Oomoogoo0P0000=oo`00Ool0
0Woo00<007oo00001goo00<007ooOol01Woo00<007ooOol00Woo0P000Woo00<007oo00000Woo00@0
07ooOomoo`8000Aoo`04001oogoo0002Ool40003Ool00`00Oomoo`030005Ool200000goo001oo`05
Ool00`00Oomoo`06Ool01000Oomoo`002Woo00<007ooOol00Woo0P000goo0P000Woo00<007ooOol0
17oo0P0000Aoo`00Oomoo`800003Ool007oo009oo`40000000<007ooOol02goo0P001Goo0P000goo
00<007oo000017oo00<007oo000017oo0P001goo00D007ooOomoo`00009oo`03001oo`0000Eoo`<0
00=oo`03001oogoo00Eoo`05001oogooOol0000?Ool00`00Oomoo`08Ool20002Ool00`00Oomoo`03
Ool00`00Ool0000=Ool00`00Ool00002Ool01000Ool000000goo0P0067oo00D007ooOomoo`0000Ao
o`04001oogoo0003Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000Aoo`8000Moo`03001oogoo00@0
01=oo`04001oogooOol20003Ool01@00Oomoogoo00000goo00<007ooOol01goo00@007ooOol0009o
o`8000Ioo`03001oogoo009oo`40000000@007oo0000009oo`80009oo`06001oo`00001oo`0027oo
00<007ooOol017oo00<007oo00001Goo0P000goo0P000Woo00<007ooOol027oo00<007ooOol00Woo
00@007ooOomoo`<000=oo`04001oo`00Ool200000goo001oo`05Ool200000goo00000004Ool01000
Oomoogoo1@0000=oo`0000001Woo0P003Goo00<007ooOol01`0000=oo`00Ool00goo00@007ooOol0
00Aoo`04001oogoo0006Ool200000goo001oo`05Ool200001Goo000007oo00000goo00D007ooOomo
o`00009oo`80009oo`04001oogoo0004Ool00`00Ool00002Ool00`00Oomoo`02Ool01000Oomoo`00
0goo0P0000Eoo`00Oomoo`0000Moo`8000=oo`04001oo`000003Ool20003Ool30002Ool20008Ool2
00000goo001oo`08Ool01@00Oomoogoo00000goo0@0000001@00Oomoogoo00000Woo00@007oo0000
00Ioo`04001oogoo0004Ool01`00Oomoogoo001oo`0000=oo`03001oogoo00Uoo`8000Aoo`03001o
ogoo009oo`03001oo`00008000Ioo`8000Aoo`<000Aoo`05001oogooOol00008Ool00`00Ool00004
00000goo001oo`03Ool00`00Oomoo`05Ool01@00Ool007oo00000Woo00<007oo000027oo00D007oo
Oomoo`0000=oo`04001oogooOol20003Ool300000goo001oo`07Ool00`00Oomoo`06Ool01000Oomo
ogoo0P0000=oo`00Ool00goo00<007oo00000goo00D007ooOomoo`00009oo`80009oo`03001oo`00
00=oo`08001oogooOol007oo001oo`80009oo`<000=oo`05001oogooOol00002Ool00`00Oomoo`03
Ool01000Oomoo`0017oo00<007ooOol00goo00<007oo000010000goo00@007oo0000009oo`03001o
o`0000Aoo`<0009oo`03001oogoo00=oo`40000000@007ooOol000Qoo`03001oogoo00Eoo`03001o
o`00009oo`03001oogoo00=oo`8001Yoo`03001oogoo01Aoo`05001oogooOol0000BOol00`00Oomo
o`0:Ool00`00Oomoo`08Ool01@00Ool007oo00000goo00<007oo00002Woo00@007ooOol000Aoo`80
009oo`03001oogoo00eoo`03001oogoo00Ioo`03001oogoo00Moo`05001oogooOol0000SOol00`00
Ool0000COol00`00Ool00004Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`04Ool10000
0005001oo`00001oo`0200001Goo001oogoo00000Woo00@007oo000000Yoo`80009oo`<0009oo`80
00=oo`05001oogooOol00002Ool00`00Ool00008Ool01000Oomoo`000Woo00<007ooOol00P001Goo
00D007ooOomoo`0000=oo`08001oo`00Ool007oo001oo`80009oo`06001oogoo001oo`002goo00D0
07ooOomoo`0000=oo`04001oo`00Ool200000goo001oo`05Ool00`00Oomoo`02Ool00`00Oomoo`02
000017oo000000005goo00<007ooOol00Woo0P003goo0P002Goo00<007ooOol017oo00@007ooOomo
o`@000Aoo`800004Ool000000006Ool200000goo001oo`03Ool01`00Oomoogoo001oo`0000Eoo`03
001oogoo009oo`04001oogoo0005Ool01000Oomoo`0027oo0P000goo0@0000001@00Ool007oo0000
0goo00D007ooOomoo`0000=oo`8000Aoo`8000Eoo`03001oogoo00Ioo`03001oogoo00Aoo`03001o
o`000080009oo`04001oogooOol20007Ool01000Oomoogoo0P0000=oo`00Ool00goo00<007oo0000
1goo00<007ooOol017oo00<007oo00000Woo0P001goo0P002Goo0P002Goo00<007ooOol02goo0`00
0goo00<007ooOol00Woo00<007oo00000`000goo00@007ooOol000=oo`06001oogooOol007oo0P00
0Woo0P001Goo0P0000Aoo`00Oomoo`@000Aoo`05001oo`00Ool00002Ool01@00Oomoogoo00002Goo
00@007ooOomoo`8000=oo`03001oo`0000]oo`04001oogooOol300000goo00000007Ool00`00Oomo
o`0:Ool01000Ool007oo0P001Goo0@0000001000Oomoo`000Woo00<007ooOol017oo00@007oo0000
009oo`03001oogoo00Aoo`03001oogoo00Aoo`<0009oo`8000Aoo`8000Ioo`8000Yoo`04001oo`00
0004Ool00`00Oomoo`0:Ool01000Oomoogoo0P0000=oo`00Ool00Woo00<007oo00000Woo1@0000Ao
o`00Ool0009oo`03001oogoo009oo`80009oo`06001oo`00Ool007oo0`0000=oo`00Ool00Woo00<0
07oo00000goo00T007oo001oo`00Ool007oo00000Woo00<007oo00000goo0`0000=oo`00Ool00P00
17oo00<007ooOol00Woo00D007oo000007oo0080009oo`03001oogoo00Yoo`03001oogoo00Moo`03
001oogoo00Qoo`07001oogooOol007oo000027oo00D007ooOomoo`0000=oo`04001oogoo000:Ool0
0`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Ool007oo0`000goo0@0000000`00
Ool00005Ool01000Oomoo`0017oo00<007ooOol01Goo00@007ooOomoo`<000Aoo`03001oogoo009o
o`03001oogoo00ioo`06001oogoo001oo`0017oo00<007ooOol01goo00@007ooOol000Eoo`03001o
ogoo00Eoo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`05Ool01@00Ool007oo0000
2Woo00<007ooOol04goo00<007ooOol00Woo00<007ooOol017oo00D007ooOomoo`0000Qoo`8000Ao
o`8000=oo`07001oogooOol007oo000027oo00<007ooOol057oo00<007ooOol01goo00<007ooOol0
3goo00D007ooOomoo`0000]oo`04001oogooOol2000;Ool100000006001oogoo001oo`000Woo0P00
00Eoo`00001oo`0000Aoo`80009oo`03001oogoo00Aoo`05001oo`00Ool00003Ool01P00Oomoo`00
Ool000Uoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00<00004Ool000000004Ool00`00
Ool00002Ool200000goo001oo`08Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`04Ool2
0002Ool200000goo001oo`05Ool20003Ool01000Ool000000Woo00@007oo0000009oo`8000Qoo`@0
0003Ool00000009oo`800003Ool007oo00=oo`05001oo`00Ool00006Ool00`00Ool00002Ool00`00
Ool000020004Ool01@00Oomoogoo00000Woo00<007oo000017oo00@007ooOomoo`8000Eoo`03001o
ogoo00=oo`05001oogooOol00002Ool01@00Oomoogoo00000goo0P0017oo10000goo0P0000Uoo`00
Oomoo`00Ool007oo00000goo00@007ooOomoo`40000000<007oo00000Woo0P000Woo00@007ooOol0
00Yoo`04001oogoo0007Ool01P00Ool007oo001oo`@000Ioo`03001oogoo00Aoo`04001oo`00Ool2
00000goo00000007Ool300000goo000000040002Ool01000Ool007oo0P0000=oo`0000002Goo0P00
17oo00L007ooOomoo`00Ool00005Ool02000Ool00000Ool007oo0003Ool01000Oomoogoo0P002Woo
0P003Goo00@007ooOol000=oo`@0009oo`03001oo`0000=oo`8000=oo`03001oo`0000Uoo`03001o
ogoo00Aoo`8000Ioo`05001oogooOol00004Ool01@00Oomoo`00Ool010000Woo0P003Woo00<007oo
Ool00Woo00D007ooOomoo`00009oo`03001oo`00009oo`800005Ool00000Ool00002Ool01@00Oomo
ogoo00001Woo0@0000000`00Oomoo`04Ool01P00Oomoo`00Ool000Aoo`05001oogoo001oo`020004
Ool01000Oomoo`001Goo0P001goo00<007ooOol04Goo00H007ooOol007oo0008Ool00`00Oomoo`02
Ool00`00Oomoo`0;Ool4000017oo000000000goo00<007ooOol01Woo0P000goo00<007ooOol00Woo
00<007ooOol00P0000=oo`00Ool00Woo0P0027oo00<007ooOol04Goo00<007ooOol057oo00<007oo
Ool04Goo00<007ooOol017oo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol00goo0`0027oo
00<007ooOol03goo00<007oo00001Woo0`000goo0@0000000`00Oomoo`04Ool00`00Oomoo`03Ool2
0003Ool01000Oomoogoo0`0027oo00D007ooOol007oo0080009oo`<000Aoo`<000Aoo`04001oo`00
000=Ool00`00Ool00002Ool01000Oomoogoo0P000goo0P0000=oo`00Ool00goo00<007ooOol00Woo
0P001Goo00<007ooOol03Goo0P0027oo00@007ooOol000=oo`03001oogoo00=oo`80009oo`08001o
ogoo001oo`00Ool000Moo`05001oo`00Ool00003Ool02000Ool00000Ool007oo0005Ool00`00Ool0
0002Ool00`00Oomoo`06Ool00`00Oomoo`03Ool01000Oomoo`001Goo00<007ooOol017oo0P0000=o
o`00000017oo0P000Woo00<007oo000027oo0`000Woo0`000goo00L007oo001oo`00Ool00006Ool2
000027oo001oogoo001oo`00Ool20005Ool100000003001oogoo00Eoo`<000Aoo`04001oo`000006
Ool00`00Oomoo`050002Ool00`00Ool00007Ool01000Ool007oo0P000Woo00<007ooOol00goo00@0
07ooOol0009oo`03001oogoo00=oo`800003Ool007oo009oo`05001oogooOol00003Ool02000Ool0
07oo001oo`00Ool4000:Ool00`00Oomoo`02Ool00`00Oomoo`05Ool01000Ool0000017oo0`001goo
00@007ooOol000Yoo`03001oogoo00Aoo`<000=oo`800003Ool0000000Eoo`03001oogoo00<0009o
o`03001oo`00008000Eoo`03001oogoo009oo`800005Ool00000Ool00002Ool01000Ool000000goo
00D007oo001oo`0000=oo`03001oo`0000=oo`80009oo`03001oogoo00Ioo`8000Aoo`8000Eoo`05
001oo`00Ool00002Ool00`00Oomoo`050002Ool60005Ool01000Oomoogoo0@0000000`00Oomoo`02
00000goo001oo`05Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01000Oomoo`002Woo0P0000=oo`00
00002Goo00<007ooOol01goo00<007ooOol00goo00<007oo000017oo00<007ooOol00P000goo00<0
07ooOol00Woo00D007ooOomoo`0000Eoo`03001oogoo00=oo`8000Eoo`8000=oo`03001oogoo00Ao
o`05001oogooOol00007Ool00`00Oomoo`02Ool01000Oomoogoo0P0000=oo`00Ool00`0000=oo`00
Ool02goo00<007ooOol02goo00D007ooOomoo`0000=oo`03001oogoo00Uoo`03001oogoo00=oo`03
001oogoo009oo`8001=oo`03001oo`0000Ioo`8000Ioo`04001oogoo000LOol00`00Oomoo`02Ool1
00000003001oogoo00Eoo`@000Moo`06001oogooOol007oo0P0017oo0P0017oo00@007ooOol000=o
o`@0009oo`03001oo`0000Eoo`04001oogoo0003Ool200000goo001oo`04Ool00`00Ool00002Ool2
0002Ool00`00Oomoo`09Ool00`00Oomoo`02Ool200000goo001oo`02Ool200000goo001oo`05Ool0
0`00Ool00003Ool20002Ool00`00Oomoo`05Ool30005Ool300000goo001oo`02Ool01`00Ool007oo
001oo`0000=oo`8000=oo`03001oo`0000=oo`05001oo`00Ool00002Ool01000Oomoo`0027oo00H0
07ooOol007oo0003Ool20007Ool30004Ool30007Ool200000goo001oo`020006Ool01000Ool007oo
0P000Woo00<007ooOol00Woo00D007ooOol007oo008000Ioo`800003Ool007oo00Aoo`04001oogoo
Ool20003Ool01000Oomoogoo0@0000001@00Oomoogoo00001Goo00@007ooOol000Aoo`03001oo`00
00=oo`03001oogoo00Qoo`03001oogoo00Aoo`06001oo`00001oo`0017oo00<007ooOol00Woo00<0
07ooOol00Woo0P000goo0P001Woo0`001Goo0P001Goo00D007oo001oo`00009oo`03001oogoo00Eo
o`8000Aoo`800005Ool00000001oo`04000017oo000007oo0`0000Eoo`00001oo`0000Moo`05001o
ogoo001oo`0200000goo001oo`06Ool00`00Ool00003Ool00`00Oomoo`02Ool02000Oomoo`00Ool0
07oo0004Ool00`00Oomoo`02Ool30002Ool30002Ool2000017oo001oo`0017oo0P0000Aoo`00Ool0
00=oo`8000=oo`07001oogoo001oo`00Ool00P000goo00<007oo00000Woo00@007ooOol000=oo`<0
00=oo`<000Ioo`03001oo`0000Ioo`<000Ioo`800004Ool000000005Ool100000006001oogoo001o
o`003Woo00<007oo00003Woo00@007ooOomoo`8000eoo`05001oogooOol00006Ool01@00Ool007oo
00000Woo00<007ooOol017oo0P001Woo0P0017oo00<007oo00000Woo0P000Woo00<007ooOol00Woo
00H007oo000007oo0008Ool00`00Oomoo`03Ool01000Oomoo`002Woo0P003Goo00<007ooOol03Goo
00<007oo00000Woo00<007ooOol02Goo0P0000Eoo`00001oo`0000Aoo`03001oogoo00Moo`03001o
o`0000Qoo`05001oogooOol00004Ool00`00Oomoo`03000017oo001oogoo0P000Woo0P001goo00@0
07ooOol0009oo`04001oogoo0006Ool00`00Oomoo`09Ool01000Oomoogoo0@0000000`00Ool0000>
Ool30002Ool00`00Oomoo`02Ool500000goo001oo`04Ool01@00Ool007oo00001goo00<007oo0000
0Woo0`0000=oo`0000000P0000Aoo`00000000Aoo`03001oogoo009oo`03001oo`000080009oo`04
001oo`000005Ool01000Oomoo`001Goo1@0000=oo`00000017oo00<007ooOol00goo0P0000=oo`00
000017oo00H007ooOol007oo0002Ool00`00Oomoo`03Ool00`00Oomoo`050003Ool20004Ool20000
0goo001oo`08Ool00`00Oomoo`04Ool00`00Ool0000200000goo001oo`02Ool00`00Oomoo`02Ool0
1`00Ool00000Ool007oo00800004Ool00000Ool40003Ool200000goo00000002Ool00`00Oomoo`02
0004Ool01@00Oomoogoo00000goo00<007oo00000goo00<007ooOol010000Woo00@007oo0000009o
o`8000=oo`03001oogoo00Eoo`05001oogooOol00002Ool00`00Ool00004Ool100000003001oogoo
009oo`<000=oo`03001oogoo00Uoo`04001oogoo0002Ool01000Oomoo`000Woo0P000Woo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo00Eoo`03001oo`00009oo`03001oogoo00Aoo`03001o
o`0000Aoo`03001oogoo009oo`800003Ool00000009oo`03001oogoo0080009oo`<000Aoo`03001o
o`0000=oo`<000Eoo`8000=oo`8000=oo`05001oogooOol00002Ool01000Oomoogoo0P0000=oo`00
Ool00Woo0P000goo00D007oo001oo`0000Aoo`03001oogoo009oo`03001oogoo00=oo`<0009oo`07
001oogoo001oo`00Ool00P001Goo00<007ooOol00Woo00<007oo00000goo00<007ooOol017oo0P00
0goo00<007ooOol027oo00<007ooOol017oo0P0000=oo`00Ool00P0027oo0P0000=oo`00Ool00Woo
0`001goo0P000Woo00D007ooOomoo`0000=oo`04001oogoo0005Ool00`00Oomoo`0100000003001o
ogoo00Aoo`03001oogoo00Moo`03001oo`00009oo`03001oogoo00Eoo`03001oo`0000]oo`03001o
ogoo009oo`05001oogooOol0000>Ool200000goo0000000@Ool00`00Oomoo`04Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool01000Oomoogoo0P0000Aoo`00Ool0009oo`04001oogooOol20006Ool00`00
Oomoo`07Ool00`00Ool00003Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00
Oomoo`020003Ool00`00Oomoo`02Ool00`00Ool00004Ool20004Ool00`00Oomoo`0EOol00`00Oomo
o`02Ool01000Oomoo`001Woo00<007ooOol00goo00<007oo00000goo00<007ooOol017oo0P000Woo
00<007ooOol00Woo0P0017oo00H007ooOol007oo0002Ool30004Ool2000017oo001oogoo0@000000
1000Oomoo`001Goo00L007oo001oo`00Ool00004Ool20003Ool00`00Ool00008Ool01P00Oomoogoo
001oo`8000=oo`<000Eoo`06001oo`00Ool007oo0P0000=oo`0000001goo00<007oo00000goo0P00
00=oo`0000000Woo00D007oo001oo`0000Ioo`<000=oo`05001oogooOol00002Ool01000Oomoogoo
10000goo00D007oo000007oo00<00003Ool0000000=oo`04001oo`000002Ool300000goo001oo`02
Ool02`00Ool007oo001oo`00Ool007oo00002Woo0P000Woo00<007oo00000Woo00@007ooOol0009o
o`03001oogoo00<00008Ool00000001oo`00Ool000=oo`05001oogoo001oo`02000017oo001oogoo
0P000goo0P000goo00<007ooOol00goo00<007oo00000Woo00<007ooOol00goo00<007ooOol01Goo
00<007ooOol00goo00<007oo00000Woo10000Woo00H007oo000007oo0008Ool00`00Oomoo`05Ool1
00000007001oogooOol007oo00000Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOomoo`@0
0003Ool007oo00Eoo`05001oo`00Ool00003Ool00`00Ool00002Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool00`00Oomoo`04Ool20006Ool00`00Ool0000:Ool2000017oo001oogoo0`003Goo00@007oo
0000009oo`03001oo`0000Ioo`04001oogooOol30002Ool20002Ool60002Ool01000Oomoo`000Woo
00<007ooOol00Woo00<007oo00000P0000=oo`00Ool00P000Woo0P000goo00@007ooOol0009oo`03
001oogoo009oo`05001oogooOol00002Ool30002Ool00`00Oomoo`04Ool2000017oo001oogoo0`00
00=oo`0000000Woo00<007oo00000Woo00<007ooOol00Woo00<007oo00000P001Woo00@007oo0000
00=oo`<00005Ool007ooOol00003Ool00`00Ool000060002Ool00`00Ool00002Ool01000Ool007oo
1@000goo00<007ooOol00@0000001@00Oomoogoo00000Woo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol01Woo00<007ooOol00Woo00<007ooOol01goo1@000goo00<007oo00000goo00<007oo
Ool00Woo00<007ooOol01goo00@007ooOol001aoo`05001oogoo001oo`02000017oo001oo`001Goo
0`0000=oo`00Ool00Woo00D007ooOomoo`0000Aoo`8000=oo`03001oogoo00aoo`03001oogoo009o
o`800005Ool007ooOol00004Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`02Ool20002
Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`05Ool30002Ool01000Oomoo`002Woo0P00
0goo00<007ooOol027oo00<007oo00000goo00<007ooOol00goo0P0000=oo`0000001Goo00<007oo
00000Woo0@0000001000Ool000000goo00<007ooOol00goo0P0000=oo`00Ool00Woo0P0000=oo`00
Ool00`001goo0P000Woo0`000goo00<007oo00000P000Woo00<007ooOol00P001Goo0`000Woo0`00
00=oo`00Ool00goo00D007ooOol007oo00800004Ool007oo0002Ool20007Ool20002Ool00`00Ool0
00020003Ool01000Ool000002Goo00<007oo00000Woo0P0000=oo`00Ool00`000Woo0`0017oo00<0
07ooOol00Woo00<007ooOol00goo0P001Goo00<007ooOol00Woo0`0017oo0P000Woo0`000Woo00<0
07ooOol00`000goo00<007ooOol00Woo0P0000=oo`00Ool00Woo0`000Woo0`000goo00<007ooOol0
0goo100000=oo`00Ool00goo00<007oo00000P0000Moo`00Ool007oo001oo`020003Ool20002Ool0
1@00Oomoogoo00000goo00H007ooOol007oo0003Ool00`00Oomoo`020003Ool01000Oomoo`001Goo
0@0000000`00Ool0000200000goo00000002Ool20002Ool4000027oo001oogoo001oo`00Ool30000
0goo001oo`020003Ool20009Ool00`00Ool000030004Ool00`00Oomoo`02Ool20002Ool00`00Oomo
o`02Ool200001Goo001oo`00Ool00P0000Eoo`00Oomoo`0000Aoo`03001oogoo00<00004Ool00000
0002Ool500000goo001oo`03Ool00`00Ool00003Ool30003Ool20007Ool30005Ool00`00Ool00003
Ool20003Ool2000017oo001oogoo0`000Woo00<007ooOol00Woo00@007oo001oo`8000Moo`800003
Ool00000009oo`03001oo`0000D0009oo`06001oogoo001oo`000Woo00<007oo00000P000Woo0P00
0Woo0P001Woo00@007oo000000=oo`800003Ool00000009oo`8000Eoo`D0009oo`06001oogoo001o
o`000goo00<007oo00000goo100000=oo`00Ool00`001Goo00<007ooOol00@0000001000Oomoo`00
1Woo00<007ooOol00Woo00@007ooOomoo`<0009oo`8000=oo`03001oo`0000Aoo`03001oogoo00Io
o`03001oogoo00<000Moo`05001oo`00001oo`020007Ool00`00Oomoo`06Ool01@00Oomoogoo0000
0goo00<007ooOol017oo00<007oo00000goo00<007ooOol00Woo0P003Woo00<007ooOol017oo00<0
07ooOol00goo00D007oo001oo`0000Aoo`03001oogoo00Aoo`05001oogooOol00008Ool00`00Oomo
o`04Ool01@00Ool007oo00000Woo00<007ooOol00P001Goo00<007ooOol017oo00<007ooOol00Woo
00L007ooOomoo`00Ool00004Ool01@00Oomoogoo00000Woo00@007ooOol000Eoo`03001oogoo00Ao
o`03001oogoo00Aoo`03001oogoo00Ioo`<00005Ool007ooOol0000:Ool01@00Oomoogoo000027oo
00<007oo00000Woo0@0000000`00Ool00002Ool300001Goo000007oo00001Goo00<007ooOol00`00
00Eoo`00000007oo00<000=oo`03001oo`0000<00005Ool007oo001oo`020002Ool01000Oomoogoo
0P0000=oo`0000000P0000Aoo`00Oomoo`@0009oo`03001oo`000080009oo`03001oogoo00800004
Ool000000003Ool00`00Oomoo`04Ool00`00Oomoo`0200000goo001oo`02000017oo001oo`000Woo
00@007oo001oo`D000=oo`03001oo`0000Aoo`06001oogooOol007oo0P0000=oo`00Ool00`000Woo
00<007oo0000100000Ioo`00Ool007oo0003Ool01000Oomoo`001goo00<007ooOol00Woo0`000Woo
00<007ooOol00goo00<007ooOol017oo00<007ooOol0100000=oo`00Ool00Woo00H007oo000007oo
0002Ool00`00Oomoo`02Ool20003Ool20005Ool2000017oo001oo`000Woo00D007ooOol007oo0080
009oo`03001oogoo00Qoo`<00005Ool00000Ool00008Ool2000017oo001oo`000Woo0@0000000`00
Ool0000200000goo001oo`0300000goo00000003000017oo000000000goo00@007ooOomoo`800003
Ool0000000=oo`04001oo`000004Ool00`00Ool00003Ool3000017oo000000001Woo00<007ooOol0
0`001Woo00P007ooOol007oo001oo`0017oo10000Woo0P0000=oo`0000000Woo0P001Goo00@007oo
000000Moo`03001oo`00009oo`04001oo`00Ool5000027oo00000000Ool007oo0002Ool20005Ool4
0002Ool01000Oomoo`000goo00@007oo001oo`<0009oo`03001oo`00009oo`04001oogoo0004Ool0
0`00Ool000030008Ool01@00Ool00000Ool00`002Woo00@007ooOol0009oo`03001oogoo00800004
Ool007oo0003Ool00`00Ool00004Ool01000Ool007oo0P000goo0P0000=oo`00Ool00goo0P0000Io
o`00Ool007oo0003Ool01@00Oomoogoo00000Woo00<007oo00000Woo0P0000Aoo`00Oomoo`400000
00H007oo000007oo0003Ool01000Ool000000Woo00d007oo001oo`00Ool007oo001oo`00Ool00005
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool20008Ool01@00Ool007oo00001Goo00<007ooOol01Goo
0P000Woo00D007oo001oo`0000Aoo`03001oo`0000Ioo`05001oo`00Ool00005Ool20003Ool00`00
Ool00004Ool00`00Oomoo`06Ool00`00Ool00004Ool01000Oomoogoo0P0000=oo`0000000Woo00L0
07ooOomoo`00Ool00002Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool01000Oomoo`001Woo00<007oo
Ool027oo00@007ooOol000Aoo`03001oogoo00Ioo`03001oogoo00=oo`80009oo`04001oogoo0002
Ool00`00Oomoo`020002Ool00`00Oomoo`05Ool01000Oomoogoo0P000goo00<007ooOol00Woo00@0
07ooOomoo`800005Ool007ooOol00003Ool00`00Oomoo`02Ool300000goo001oo`05Ool00`00Oomo
o`0100000003001oogoo009oo`04001oogoo0005Ool01000Oomoo`000Woo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol00P0000Aoo`00001oo`<0000:Ool007ooOol007oo001oo`00Ool40000
17oo001oogoo0P000Woo00@007oo0000009oo`<00004Ool000000005Ool00`00Oomoo`020002Ool0
1000Ool007oo0P001Goo0P0000Moo`00Oomoo`00Ool00003Ool01@00Oomoo`00Ool01@000Woo00@0
07ooOol000=oo`800006Ool007oo001oo`000Woo00@007ooOol000Ioo`06001oogoo001oo`0017oo
0P0000Yoo`00001oo`00Ool007oo001oo`<0009oo`<0009oo`@00004Ool007oo0002Ool3000017oo
001oo`000goo1@001Goo0P0000=oo`00000017oo00<007ooOol00`001Woo00@007oo000000Eoo`04
001oo`000002Ool3000017oo000007oo0`000goo0P0000Aoo`000000009oo`03001oogoo009oo`09
001oo`00Ool007oo001oo`00009oo`40000000<007ooOol00goo0P0000=oo`00Ool00`0000Aoo`00
0000009oo`@000Aoo`L000Aoo`03001oo`0000=oo`03001oogoo00Aoo`04001oo`000002Ool01000
Oomoo`000Woo00<007oo00000P000goo00D007ooOomoo`0000=oo`03001oo`0000800004Ool00000
Ool20002Ool00`00Ool0000200000goo00000002Ool01P00Ool00000Ool000Ioo`03001oo`0000Ao
o`03001oogoo00=oo`D000Eoo`<0009oo`<0009oo`@0009oo`80009oo`<0009oo`03001oogoo00=o
o`800003Ool00000009oo`04001oogoo0002Ool00`00Ool00002Ool01`00Oomoo`00Ool007oo0080
00=oo`H00003Ool0000000Aoo`<000Aoo`05001oogoo001oo`02000017oo001oo`0017oo00@007oo
Ool0009oo`80009oo`800003Ool00000009oo`05001oogoo001oo`020004Ool01@00Oomoo`00Ool0
0P001Goo0P0000=oo`00Ool00`000Woo00<007ooOol00@0000000`00Oomoo`0200002Goo00000000
Ool007oo001oo`0300001goo001oo`00Ool007oo00<00003Ool007oo00=oo`<00003Ool007oo0080
00=oo`03001oo`0000Eoo`03001oo`0000<00003Ool007oo00=oo`D0009oo`03001oogoo00<00005
Ool00000Ool00002Ool00`00Oomoo`02Ool01@00Oomoo`00Ool00P0000=oo`00Ool00Woo10001Goo
00<007ooOol00P0000Aoo`00001oo`800004Ool007ooOol30002Ool4000017oo001oo`000Woo0`00
00=oo`00Ool00Woo00<007ooOol00Woo0`0000=oo`00Ool00P0000=oo`0000000goo0P0000=oo`00
00001@000Woo1@0000Eoo`00Oomoo`00009oo`03001oogoo009oo`@0009oo`8000=oo`<0009oo`03
001oogoo009oo`<0009oo`@000=oo`80009oo`07001oogoo001oo`00Ool00`000goo00D007ooOomo
o`00009oo`04001oo`000004Ool20002Ool20002Ool00`00Ool0000300000goo001oo`04Ool00`00
Ool00002Ool100000005001oo`00Ool00004Ool00`00Oomoo`07Ool01000Oomoo`000Woo00<007oo
Ool00Woo00@007oo000000=oo`05001oogooOol00004Ool00`00Oomoo`04Ool30003Ool2000017oo
000000000Woo00<007oo00000goo00<007oo00000Woo00<007oo00001@000Woo00<007oo00001goo
00@007oo000000=oo`03001oo`000080009oo`04001oo`000005Ool01@00Oomoogoo000017oo00<0
07ooOol00goo00@007ooOol000Eoo`03001oogoo00=oo`03001oogoo00Aoo`8000Eoo`03001oogoo
00eoo`03001oogoo00Eoo`<000Aoo`800004Ool007oo0005Ool00`00Oomoo`0@Ool01P00Oomoogoo
001oo`@0011oo`800004Ool007ooOol20002Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Ool0
0003Ool00`00Oomoo`0100000006001oogoo001oo`000Woo100000=oo`0000000Woo00@007oo0000
009oo`05001oogoo001oo`0200001Goo00000000Ool00`000Woo00@007ooOomoo`800005Ool007oo
001oo`0200000goo0000000600001goo000007oo001oo`00009oo`8000Aoo`04001oo`000002Ool2
00001goo00000000Ool007oo00<00004Ool007ooOol700000goo0000000200001Goo001oogoo0000
0Woo0`0000=oo`00Ool00Woo00@007oo001oo`80009oo`@0009oo`<00003Ool00000009oo`@0009o
o`800003Ool00000009oo`<00003Ool007oo00<0009oo`03001oo`000080009oo`800004Ool007oo
Ool6000017oo001oo`000Woo00@007ooOomoo`8000=oo`04001oogooOol500000goo000000020002
Ool20002Ool20003Ool400001Woo001oo`00Ool000=oo`06001oo`00Ool007oo0P000Woo100000=o
o`00Ool00goo100000Aoo`00Oomoo`<00003Ool0000000800005Ool00000Ool00002Ool100000005
001oogoo001oo`030005Ool01000Ool007oo0P0000=oo`00Ool00`0000=oo`00Ool00P0000=oo`00
00000`0000=oo`00Ool0100000=oo`0000000P000Woo0P000goo00@007ooOol0009oo`800003Ool0
0000009oo`800003Ool0000000P00008Ool00000Ool007oo001oo`800003Ool0000000H00003Ool0
07oo009oo`03001oo`00009oo`D0009oo`H0009oo`800004Ool000000002Ool00`00Oomoo`020004
Ool40002Ool4000017oo001oo`0017oo0P000goo00<007ooOol00Woo1`000Woo20000Woo00<007oo
00000Woo00D007ooOomoo`00009oo`D000=oo`<00003Ool0000000D0009oo`800007Ool007oo001o
o`00Ool00P0000Aoo`00001oo`800004Ool00000Ool50002Ool300001Goo000007oo00000Woo0P00
00Moo`00000007oo001oo`030002Ool30002Ool2000017oo001oo`000Woo0@0000001@00Ool007oo
00000Woo00D007ooOomoo`0000Ioo`8000=oo`8000Eoo`04001oogoo0003Ool00`00Ool000020002
Ool00`00Ool00002Ool50002Ool01@00Oomoo`00Ool00P0000=oo`00Ool00P0000Ioo`00Ool007oo
0004Ool00`00Ool00002000017oo000000000goo00<007ooOol017oo0P000goo00<007oo00000Woo
00D007ooOomoo`0000=oo`04001oogoo0006Ool300000goo001oo`02Ool40003Ool30005Ool01P00
Ool007oo001oo`800003Ool007oo00800004Ool007oo0002Ool200001Woo001oo`00Ool000Qoo`<0
0003Ool007oo00800004Ool00000Ool20002Ool01000Oomoo`000Woo0`0000=oo`00000017oo00@0
07ooOol000Aoo`8000Ioo`800003Ool007oo009oo`04001oo`00Ool200000goo0000000200001Goo
001oo`00Ool00P0000Eoo`00001oo`0000Aoo`80009oo`80009oo`05001oo`00Ool00003Ool01000
Oomoo`000Woo0@0000000`00Ool00002000037oo000007oo001oo`00Ool007oo001oo`@00003Ool0
000000<00003Ool0000000L00003Ool00000009oo`05001oo`00001oo`030002Ool200000goo001o
o`0700000goo0000000300000goo0000000300000goo000000030002Ool00`00Ool0000300000goo
00000005000017oo001oogoo0P0000=oo`0000001`0000Eoo`00000007oo00@0009oo`800004Ool0
07ooOol700000goo0000000<000017oo000007oo0P0000=oo`0000003`000Woo1@0000=oo`000000
0`0000=oo`0000000`0000=oo`00Ool00`0000=oo`000000100000=oo`0000000P0000=oo`00Ool0
200000=oo`0000001P0000=oo`0000000P0000Aoo`00000000=oo`04001oo`00Ool200000goo001o
o`030002Ool600001goo00000000Ool007oo00800003Ool0000000<00004Ool007oo0002Ool10000
0003001oo`0001l00003Ool000000140009oob800003Ool0000001h0009oo`03001oo`000340009o
o`h00003Ool0000002X00003Ool0000002P00003Ool007oo0080005oo`40000000<007ooOol0ogoo
7Goo0@00003o000Q00000001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0263022, -0.0250053, 
  0.00366761, 0.00593432}},
  ImageSoundCache->{{{0, 287}, {176.938, 0}} -> GraphicsData["WindowsSound", "\<\
DTU6ARA0001G@EI5IVed8100000100400200000P000100P0I65dH@10003fg;B4
E2X<00HNA7>TcnonnnK1Tf8e4`425SUWVLKYoOg[bIaZ?1P30A8dHI?1i_cnk/bO
KChI104A<f2B`NKlo^g;WF/l5`<14cITUlKZoOgYaIIT=A<10aToKZ7>koojh[Z9
Eb/<00LRC7j`foOom=JZMdHM1@0@<V2C`nWmoNW3Tela40057dQj[MWfooCFZGI4
70@14SIVV/W]o__S^XQD:0X02bUFR[gUo?k[aYEP<@l01R5<P;?NnOo_cIeX=a<1
11e7NZoKmooad:1[>A@111a6NJkKmooacimY>1<11Am9O[;NnOo^bYUS<Pl01bAA
Q[[To?gX`HiH:@X032iNU<O/o_[O/gi97@@15Ca`Y]Keoo;@WfTf4@078e67_>Km
o>FkQU0S1P0B>6^SdoColm6PJ3D@00PVEHc1jOkkh;AmAa`30QU3NK3Nn_k[`hiF
9PP04CIZX]Ceoo7=VV8_300;;V2Ic?7omMBRJSH@00TYFY?8k_ogejI^>14022MH
TLK^ooOGYVdh4@08:E^DbNoom]BRJ3@>00/]HI[?loobcYUP;0X03cI[YMOgonc4
SE<S1@4G@WZch_clhkEl@aL11B=CSLC]ooKEXFLa300>=6ZTeoSojl68CQl30aa;
QKkYo_SIYV/d3P0=<VVTeoSoj[j5Ba`2121AS<C^ooGAW60[2@0C?WNbh_ckgjib
>Q402c1VXmOho^VlPDLH0@HVFIK=loo_aXeA7`<37e2<a^oollbEF2@50Q];Ql7/
ooG@VE`W1P4IB8Bok?oedIUL9`H16TV6`Ngom<jFFB@50Qa>RlG_oo;9Se8O0`@R
EYC=m?o]`HE86047:V6Pe_SniKAg?1003CIa[n;mn]ZTIBd801M7Q<7]oo?:T54N
0PDVG9_CmokV]GLk3`0?>WJdi_kgdiYK9@@385BDc_GojKUk?Q403SUe]>Knmm:H
F28312=JV]?ho^BaLSD<01A3P/3^oo76R4TG00XaK:gRoOWEW5/T10@SFicEnOgQ
[6/`2@4IC8g:m?oY^7Pj3P0B@X70k_o_`H=34`0>>WVij_ocb8Y95`0;=G>diooe
bhi<6@0:<g6bi_oec8i=6@0:<g6cioodbXa:5`0;=WFgjOobaXM5500>?7bmkOo_
_ghn3`0CA8K6l_oY]G<d2P4JD9?An?gPZ6@X1@<UGj?Mo?WDUe<L0@TcL[GYoo74
PT0@01=5R<SdonF_Jbd60R9MXMclnM>EDAX02cMh^ngokK]h=`/06e>GeO[kfIaG
7P49<gBhjoo^_7Tg2`0KE9WGno_FV5<K00/iNkk_onVdKbl70R=PYN3nm/^9AA80
54R=c_SmgJ1J7`49=GNlk_oZ]6h^1P<VI:[Too?4P3`=01YDV]WlnM6@BQ@04TJ<
c_SmfieF6`0<?875m?kRYUlR0PTeN;k`onN^IRL31S1b^>goj[9[:P@5;Fjejoo[
]Fd/1@D/KKG[on^dKB/41Be_]^coj[9Z:@@6<7>jkooW[F@U0PPeN/3bon:UG1l1
33f3bOKmfi]B600AAhoBn_[ASTH@01UDW]gnmLEn>0T296F^j?o/]F`Y0`LcN<3b
o^2QEa/044F>d__ichY23P0NG:KTonnjL2`41S5g_o;ngimE6@0BBYCHo?O8PCT9
0RIY/ncoijYO7`0>@XcAn_W>Qch;0B=U/>[oj:aQ804=@XcBnoW<Q3/:0RIZ]Ngo
i:EI6`0BBiKJoOC2N3451C5h`_GmfIE94@0MGJWWonZ_HR003TF@e_cfaG/b1PDa
NL?eoMNAA@h18FBak?oTYELI01EBWn7okkEY904=@XkEo?K3N3041cJ0b_SjchHj
2@</Ll3doMNAA0d196Vgl?oNVT`A01iQ[ncohj5C5@0JFj[YonJVEaP065RWiooX
Z5TI01MFYNKoj:UJ6@0GEjKVonNWF1P065VYj?oUY5@E01]N[N_ohYi?4P0PIKC_
omfFA`h19VjllogES3h90biia_Sjc80c1@LiQ]7lmL1a:08=AYKMonjaHAd05UJW
j?oTX4lB029Y^O;meX/l20@bOlcjmlAe:P8=AYONonb]G1T06Uj`k_oLTd<;0bij
bOWhaWH[0Pe7V=oojZYH5P0NIKOboMF9>@L6>8ODoO:hIQl05UR[jooMU4<;0c1n
cO_f_fdS01=CY^Woh9Q530<_OLckm[i/8`0DEJW[omfD@@X4<h?AoO>gI1d06Enb
l?kER3L523nAg?o[ZEDC02E``oSiaG@W0A5BY^[ogI8o20DhR]OnkZeI5@0SK/7h
nLEb9P0CEJ[]omR;>@D8@9?NonRRC@h2;Gg>o?>fHAT07fVnm_[7M2H055N]k_kE
QC<32dRMiOoPUD081S^?g?oYXdd>0S22d_g_[UPD02Mfb__d^68I021]`_Sh`6XO
01]U^oKjaW4S01MO]_?kbWHW01EK/_;lcGXY0A=H/?7mcW/Z0A=G[o3mcg/Z0A=H
/?7lcGTX01AK/o;lbgHV01MO]oCjaW4R01YU_?Oh`6TM01m]`o[e^F4G02Ifboca
[eLB0Bj2e?k[Y4/<13R?g_oSUSl62DFMiooIQc8245B]l?c<MR@06VFnn?NlHaP0
9gW?oNjYC`d4=hoNon6C>`D;C:G]o]1k:00HHkghmk]Q5`0ZO]?njZ572@I0V^Ko
f8@^0A=L]_Gi_fHI02MkdOk[XDL91d:Lj?oEP2X05f>mn?JgG1<1<8OKon>C>P@=
DJganlI/700UN=3njj5520Q6X^cncWHS01i`bOc_Z4`:1T6LjOkBNRH076g7o?2Y
C0/6@IgYo]5h900OL<[mkJA720Q7Y>gmbW0N02Ejd_oWVCd43E>`m?VnHQD1<H[N
omb8;P4GIL7klZa>2`I3X>cmbg0M02Mne_oSTSH24Ufkn?BaD`d5@9g[o/aa7P0W
OmOohXhc0AES`?[aZT/924VWl?_2IAH1<XkRomIn9P0PMM3niiDh0a9N_O[bZd`9
24ZYlOZnH1<2>9KWo/mc7P0YPm_og8D[01eac_kWUSP24f70no2UA@H<Dk?fm[9B
2`M7Yo7j_UhA0cbLjog7JAL1<i7Uolmb7@0/R=ooeW/R02J0f_oKPRL08W[Fomn8
:`0NMM;ohX`^01abcooTSc406Vo>o^F@<P4JKlgniI0b0AY_c_kTSc006g7?on><
;P0MM=;ohHP[021ie_oMPbL097oJomQl8P0YQn3odg@M032?iOk;JaL2>9W[o<9P
4@A2YO7i^5@;24famoB[B0H>FkkkkIdk0QIZbokTSBd087_HomUk8@0]SNGnbVPE
0cfPkoZiE@/9D;ChlZE111=Ub?kVSRh08GgJomEf7@0cU^[l`Ed>1TZ_m_BXA0@B
I<OniHd/02>1g_oAKaP2>io_nKMA2@]G_?_/V3D17GOGomMg704fV^gk^U@:2UFk
nnbH=00NNMWoe7<I0CZOl?VcC@L>G/CmiXd[02N7h_k8Ha45BK3hlJ8l0QUceOoG
MQ/1>Yoan;5:1Q5TbOkQQ2@0;i?Zo;aD2@aJ`OgWSBX0:H_VoL9K30UE_?cYTBd0
9hSTo/=L30UD_?cYT2`0:8[VoL5I2`YH`?gVRbP0;I7ZnkYA20iQb?kPP200=Yg`
n:i611E^dooELAL3@jcglIhf0261hOk6GP`9El3miHPU03:Ik_V`AP@FL=GodVdD
1DZdn^bD;@0YSnWk^4h64VW@omMb5PA7/OW]UBh0:HoZnkM<1A=]dooCK1<5CKSk
jHdW036Il?N[@@8KNmkoaed;2eg7omei6P92[_S^URh0;9?]nK140aUigOo7G0/<
GlWofWDG14RdnnV=9P0dW_?dXcP08hWWo;M;11Icf_o9GP/<H<[of74E1DjjoNF4
804nZ_S^UB`0<9[amZDi02B:jO^cAP<JO>3n`5<64VkFol]O2`aRcOoDJa48ElCo
g7HF14fkoN>07094/__XR281?J_hk90W03NTm_2G;00bW_?cW300;YWam:0d02^E
l?JT=P0YTnkgYSP09i7]mjLi02N@kORX>@0WT>ggYcT0:9;^mjDg02VDkoJR=@0/
Uo7dWc40;icclYX]03>QmNnD:@0iZ?S/SB@1?jojihDN0TNgoN9l60A?`?kKLA88
F/WodfH=36GBolUJ219bg?jnCP@JOnGk/D4198k]mj<d032NmO2C9`0m[__VPA/3
CKonfVl@2Uo?olaL21=cgOjjB08OR>_hYSH0;ikeki0T0D:do>5h5@MHbOo@H0TA
LMcn^TP288_/mj4a03FVn>Z67@==`?oGJ@d=JMOo`4d37XO[n:<b03BVnNV46`AA
a?oCH`XALMgm]d<19I?alYHW0D:eoMib4@YSe?o2CP<NRNcfWbh0>jkkhgPD25o@
olEA11b7joNP;P0k[ocRMQ<9H]?o`Dd288g_m9PX0D>ho]][3@i^g?fe@00[W?K/
R1`4DlOoc5P66H?Zmj0^03fcoMe_3Pe]g?fd?`0]X?OZPQP6Flkoa4h38HoalY8R
0Tg3olmK1QV3j_NM:`13^OkGI@XCN^GjYC40?;;mg6/<47CRnjXd03V_o=i^3@mb
hO^[=@0i[ocMK@d@M>;kZ3<0?;?mfVT;4WWVnJ8^04:io]EQ1aN2joJI9P9;`oo<
E@@OSo7`S1d5FLoo_dL1:YohigXC2f[Lo:hf03ZboMUV2AF0j_JH9@9?aoo7CP8U
VOKYOQ@:J=cm[SH0?;CneV476HO^lXlN15W@ok]2036Xnmm/2a=ljOJI909Ab_o1
B04/Xo[RL0dAN^OgVRD2DL[o`4H0;ZKkgfd;57oZmI@Q15S@okTn03J`oMQQ1a^;
lNn65`UWg?bY<015`?o9C`8XX?WRL0`CO^_dTQh5GMGn/SL0?k[ocE<29Yghi78=
4Wk[m90M1V3HoJdc04G0olM;0BfVnmaV21Z;l^f150a`hoRL90=GdOjd>010_?o:
CP4/YO_LI@LKS_?[O14?MnSeTah6H][lZ2d1CL[o^ch0>kSoc501:jKlff<67Y?f
igD=4h7^l8LF2g3TmiLP1F3Io:L/0E3=okHh04?1ol9503NdoliA0BbXo=QM12>L
nN1Y21^@mNMe31B5l>eo4@mkjo:95`]ai_JB70MYh?VJ8@EQfo^R9`=Je_fX:`9D
dOj^<05?cOnc=01:bOng=`17a_nj>P14`onl?@12`Onn?P10`?no?`0o_oo0@00o
_oo0@010`?no?`11`Onm?@13`onk>`15a_nh>019bOnd=01=cOj`<05BdOjZ;09G
e_bT9`=Nfo^M8PIUh?RF70Q^iOF=5`agjo634Q21l>ai3AJ;mNI^21fGnMiR12FS
o=EF0Rn_o/]:03Zloklm04K8ok8a0ECDo:<U1FCPn9<J2WCZlH8@4XKcj7097ISj
g5h3:Z[ncD/0>[go_CX0C<knZBT3H=kiU1X;M^__OPhFSOKRI`DTY?gBD00g^_nm
>P1=cofV9PEVh_J<5@n0lNUa21jKnmMF0C:fol4l04_>oJHU1FOTmHTC4HKdiFX6
9:Cmcd`0?L7o]302Fm_iU1T<Nno[L`TOWOcDD@0i__ng<P5If_VE6@all>U`1b6Q
oM1<03k4ok0/0f;QmXXC4XWehF83;;3o`cd0C];lWAh:M^g/M0PPX?g@B`11aojZ
9`EZio5o3AVGn]MC03[1ok4/0fCSm8<?5i?ifED0>Koo/B`3INCcPPhHUO[FDP0l
`on/:0E[j?1k2afNo<m904G<oJ4O2GS_jFd59jco`c/0EMWiT1@BRoOMF@4g_on_
:@E[j>mh2B2So/U104oEnY@F48SfgUX1><3o[BL6Kn_/LPLUZoo2>@5Ig_J73aRG
nm9;04O?o9XJ3XCege/1><7oZR@7MNkYJP@/]?ng;P=Winmf22BZol4g0EgQm80<
7J7nb3h0E]cgQ`lIV_c=A01Af?R<4ANGo=1604kFnHhB5YGkdDL0C]KiSA4FUoc?
A@1@f?R:41VJoLa105GLmXD=7:7naS/1G>7cO0TRZOnn<`=Vj>ia1RZdok<Y1W?_
iV@2=L7oYAl<P_KLE014co^D51BDo<i305GMmH0;8JWo_C43Jn_ZJP<b__nW80b3
m]]A04SCnXd@6IknaCT2H^K^L0D^^_nZ8P^1m]]A04WDnHX>7:;n`3<3J^_YI`8f
`ojO6A6?nm1305SQlWP7:KGo[B<:POKJC`1=f?N32b:/okHZ1gScgeH0Am?iR@dN
Yonj;0IelN5H04GCnHT=7jSo^2/6N??OE@19e_R42b>^ok8V2H3ffD`0D]gdN@L[
^?nV7@n=nli00F3Wk6T2><OmUA8IX?jn;`Eel]mD04cImWh8:KOoYad?So_;?09V
jnQQ0D7@nXT<8Zko[b8<R?WA@@5Qj>YU0Ck>nXX=8Jko[R8<R_[>?P5VjnMO04CD
n8899kKoYA/BUOg4<`Acl]iA05?OlG44=/OlTA0NZ_n`8Pb;nl`k0V__hUL0C]cc
M0@daOfB41j[ojhQ3Xklb3H4L_;MC`1GhniY0Sk?nH@9:;WoWaHGX?ng9`Z7n/dk
0Vk`ge40E^?]J050d_R01bfooYLA7J[o[Ah@U?g1;PMon=900FW_hE<0EN?]IP53
eOIj1C;6o8d<9;GoX1HHY?na8@jBoL4^1h7icc`3L?;KBP1Pj^II057PkVP1@mKe
M`@fboZ52B^ooI<?8[?oX1DIYon/7A:JokPU38om`Rh8Po[;=PAim]<o0VkbfdP0
INgQD@1Lj>MI05CSk640C=k`J@55fO=`0SoDmWL4>LohO@Ddb_Z31c36nhP9;<;l
S0/Y__f@32JkoY@>9;SnU`lR]OnI426coi/A7k;oW18O/OnM4QjaoidB7[7oWA8O
/OnL4Qnboi/A8;CoVA0R]_jG3bBhoY@=9[_nT0`X_of<2Rc2o8P8;lKjP`HdboUm
1CS@mgL3?]GdL094f_5Y04_OkF40D^CYF@1JjNAA06?^gDP1K??F?`=gmllf1X7j
aRh:SOfl9@nHok4M5JCoYADL/?nH3RFloH/9<<SiO@@ke?A^0DSNkEl0EnSTD01V
lMU10gOgc3<7R?bn9PjIojhJ6:_oW10T_?f923;<mgH2@m__HP1Fj>A?06[ceC`4
Oo[4:`bEok4K5j[oV`lV_ob41SSBm6d1CN?XE@1Tl=Po17gja2X=Uon]6AZ_oi@;
;<OiN@=3g>iN05c]gD@2N?W8;@^DojhI6[3oTPX_b_Md0TSPjUH0IO;E>`F5o;`R
4ZCoWPlW`O]n0d7KkUd0H>oI?PB1o;hT4Z?oWPlW`oYk0dCNjeP0I_;D>0N:o[DM
6:koT@Tbc_E/05?XhDP2N?W4:0nOoj0@9l?jN@98hNQA06ofbbh<V?nW4b>nngd3
A=oZE01]m/`_2iSoYQ8T`?Yk0TSRidl1L_S7:PnOoid>:lSgL01BjMm40h3l^QlG
[_j=1cWFkeh0IO?A<PZEojHB9/?iM@5?in550h3l^AhH/Oj91CkKk5H0K_O8:A2R
oiP;<]7bH`1Ql]8c2YOoXQ0Zb?I/05W^f3T7SonY4bG4n780E>_K?@J<oZ/D9<;i
L`1Djm/l1XgoZQ<Ua?Q`05O]f3P8T_nT42[:mFP0Go7A<@bLoi/;<]?aG@1[m/LW
4ZWoS0HogNQ>0W_l^1`L^O]j0E3Zg3`7T?nU42_<m6<0I_G::A6Xoh`5@N3VBP>2
oK4F8/;hKP1MlM4_3J7oTPLlg>U=0Wom/aLR`_Q]05kbcbd?YOn=1D7QiDL4QojZ
4RW;m680JoO38aNco7d1DN_H=PZKoiH8>mcXC0>3oZdC:<_dH@1]n<4P6[SkMP1I
l=4^3jKoR@A7i]hm29GoVPXhfnU<0hGnZA0/d?5I07Kk]QPRaOIV06[h`AlK^oYa
05ocbRLE/_ak0EO_dBd@Z_j20U3/eS8=Y?n80d_YfSH;X?n=14OWg3T:WOn?1DGU
gSX9W?n@1DGUgSX:W?n?1DKVg3T:W_n<14WXfSH<X_n80dg[eS4?Z?j20U?_dB`B
[oej05_cbRDG^?Y`06Gg`AhN`OMU077k]QHWc?5H0GknZ@laenY:18koVPPoh^0k
2YkoR@=?kM</4[3lMP1Qm/8N7/?fH@1fo:lA;]C[C0B>oiT7@^GL=PfVoX01FO;8
8Q^nmfD0M?b`4RkEjTX5TOnD1DOYec0A[oae06Gh_ATTbo5D0XKoW@Toi=`f3JWm
NP1Qm/0K8lWaEP:6oid8@NGK<`n/o7D0I_Rj5bS@kDd4T?nB1D_/dBTF^_QV07Km
ZPhfg^8l2jCnO@1QmkhI9/k^CPBAoi04Cno=91[0mEd1POnO24;Wf2lC]OYZ07Gm
ZPdhh=lg3ZclL`1/nk4A<]_S?@^VoGP0J?Ve4boIiCl:Xoij06Ki]Q<_fNDo2ZGn
N01Yn[<A<]_S>`bYoG<0K_b]3SSPgS@@/OYZ07SnY0Y1imH[5[cfG@65oiH5C^o:
823:kdh5U_n50Eog^QD^fNDl3:[lL01doJH:@>SE:AS0m5P2SOn<0UWe_aL[e^Hn
3:[lK`1foZ89AN_@9Ag7l4l5V?n106Gj/Plgh]/_5;_fF`:<oh`2FoJk533LhCH@
]?UR0HKoT@=Gm;hF;M[R=a2cnF81Q_n@0eSe_1D`g>0d4[SgG@:<ohT1H?Rd43OS
fB`H`O9A1IWoO01^o:H9ANc<82?@jD4;Zo]X08;oTP=Im[TB=>7J;AS2lTl5W?if
07GnWPI>lL8H;M[P<a>kmEH4Uomk077mX@M<lL@H;=[P<aBmm5<5V_ig07KnV`EC
m;`C=>7I:Q[7kdP9YoaY08GoR`5SnZ`;@nc:7BSGhSDC_?AB1IgnLP1moi82GOVa
3D3[c1hWe^<e4kgcD0JQoFd0Pon;0FGkZ0U9l<<G<=oJ:Q_:k48</OQL0iKoM`1j
oi<2GoV]2dG^aAP_gmXZ7<_[?`jemeH4W?i_08?oR01ZoJ46D_Fh3cgYc1dYf]h^
6LS/@@fdmeH5W_e/08SoPP1boYP3G?V]2TSa`1@fiM4P9]OP;aW8k40>]_EB1ZCl
I@6AogP0O_n:06_mW@AJn:h:BO6n4SWXcA`/gMXX8=7U=1K4kT8=]_EA1jOjG`>H
oVh0ROmm07[oS01/oIX3G_ZW1e7f]0a5l<0B>^W;6RoQe28VfMdZ7]3U<aO7jcdA
_O573;CfD0RZnEX4X?aT0YKnK@2=ogL0Q?n007_oR01coi01JofH0V?lX0ALnZL6
EOR]2Doe/`]9lkT>@o2n4Ck]`a<jj/LF=^O;6C;Uca`_h]8N;=oE8BWMeb<VfmXU
9=WL9b?GgBTQeMlZ8=CP:aoChB`Nd^4]7M;R;QgAhRhMdN8^7M7R;QgBhBdNd^4/
7m?P:b3EgbXQe]dX8]SL9RCJfR@Vg=PR:MkE82_QdQd^hllJ<^K;63GYaaDjjl<B
?^jn3d?a^@e8m;@:C_J^1eGiY`EKnj03H_fI0V[nT@1bohT0Non008?oM`2<ofh1
U_eT0iokF`JYn549/oA73[g_?A?6jC@Jd>4[8MWI8R[Qd1XdjLHC?nnk3D[e[`MG
nZ83I?fD0G;oQP21ogL0T?iX0YokF@N^mDX=_>hl5L[U;aoGfR8[h/dG>Nbo3TSe
[`MInih2J_j<07goN@2@oVH3XoUC2KGb@A;7ic0Ne]XQ;NC:53k`^0YAnJ@3I_j?
07_oN02BoF84Z?M=3Kg]>1W@gbHXhLhG>nni2e7iXP=YoXX0P_ma0I_kF0RclT0D
b^@[9=gA6CS]^`]@nJ83J_n708KoJ`:RnE0;_>dg6]CK8BoWaA17mZX5Hoj=087o
K`:OnE4;_>df6mGI7c7Z`@e=n:<3Jon408_nH`F[mDDBbN@Y9n7<54;c[PEQoXd0
Pom[0jGgB@o5iR`Th<dE@O>^1F;nR`26ofL4Z_E44l_Q9R_Ua@m:mj<2K_mn09Gl
F0VikCDMfM@I>o2c1eomS@26oVD5[O<o5]3L83;/^`YGo9@0P?m[0jWe@aC>gR8a
jk`:E_bD087oJ@B[m40FdM/N=Njg25gmS02:oUl7]Nlf7][A5T7dZ@=/og`0V_Y?
3/GT9b_W`@aDni@0PomT1K;`>1cJdQI2mJL3L?mf0J7gAa?=gAlek[D6H_j409Gk
DPg4i2L]jKd:F_f<08gmF0Zoj2/Xi/4<E_b@08[mF`VmjB`Xi/4;E_b>08cmF0_0
ibT[j;d9Foj809?kD@k7hB<bkKD6IOmm0IkhAQCAf1Xnm:L2MOm]1:ka=aoNbQ1>
ni@0ROeI2l7U9Ro/]`IUog`1XOI26=KC5DKhW021oUl8_NPY;>Zi1fCoO06RmT0I
f=0CB_ZF08SmE`c5hR8el:d3LOm]1;7^<RGT`@YMoX80W_M26=S@4T_jU02=o54?
bm`K?_FR0GkoG`W0iB@ckjh3L_mZ1KK[;2_Z]`IYog<3[^lb9NJn26;oNP:XlSLQ
hl8:G_mm0JGc>B3Qa0]LoWl1YO<i8>732UgnO@6VlcLQhl49HOmi0Z_`<bGV_0MW
og84/Nd]:n^d16ooJ@JjibHcl:X2NomN2lGO7CkfW@29o50AdMDDC?^=09Wg@A_N
a`]Mog/2[>l`:NZe177oI@S0hb0kmIl0ROa>4m?A4E7mQP2RlcLSi[/6K?mZ1kgT
8C[eW`2:o4`De/h?E_io0J[_<2[//0=hoe`<b]XGB?^=09ge>R7U^`I^ofH8`^0L
@ORD09Og?akR_`MZofT7`>4M@?RD09Og?QoS_@I]ofD9a=hIA_Z>09od=bGY]0=g
oeX>c]DBDOf00Jc]:c7aY@28ndTGg<H:I?m/1l3P6dCjSP2Plc@Xk:l2OoeA4mO;
35ooL0JmhQe2nHl0XO<c:^f/0H?lC1KKaPUWofL9a]/FCOf20Jk/9cKdW02Emc/S
j;@3O?iA5=S92VGoJ0W6fQE?oGh2/nPR??NC09oc<R__Y`2;nT8Ni;T4N?iC4mS8
2VOoI0_;eQ5Gog@5_N4JB?b40JoZ93_hTP2RlBh`lYl0UOHh9nb[0HWj@QoV]@=o
oD/Hgkh5MOiD4mW626coG0oCc@]Tof@<cM8>G_mZ2LSF4EWoK`O4fQ=Dog<6`MdE
DOif1KkN5donN@Bmh1Q=oGX4_>0HCOej1;cP64knN@BngaM?oWL5`=dED_ic1/?J
4eKoK`S6ea5KofX:bm<>H?mT3=3>2fOoGA3Fa`Q_oeDDg<05N?e<6^>g0X?k@R7Y
[@2>n3PYkj40V_<^<oFE0:O/93kjQP:ei1Y;oGL5`]TBF_mW2m3=2V_oEQCM_PAm
o4DOjJd0T?Le;O>J0:C^9CkjQ@:hhAMAofl9bm4<IomI4mbn17ol@R;[Y`2Hlbhe
mhh1/>HKC?id1lSC3FKoFA?M_0>2nchVkZ40WnlW?OZ30kcM4eWoI0kFa@IioDDP
jjL0V_8Z>_V60[[N55WoH`kG``Elo48TkZ40XNhT@Oal1L?F3VGoEQGQ]P6<mc<a
mY01/n<GE?mW3MK41Ggk?bK`W02XjQi:oW49c//8MOe68NbS0:;]8TGmM@S<cPUb
oTPPk:<0X^`QAoec2Lk;1gKm@bC_WP2XjAa=of/<eL<4P?Xj;?BB0KCQ55[oGA?O
]P6Am2`jnX05aM<;K_i98>bQ0:OY74ooJ0kH_P>8mc8dn8H3`MH<Joi;7nbQ0:SX
6e7oI13L^@6?m2`kng`6b/d7N?`n:O>B0KSM46?oD1cYY@2VjA]Aof8Ag[H1UO8V
@_eb2]?318Kh<SKiP0G8cPQinc`/mH`2_]L<K_i59O6F0KKM46GoC1o]W@2`hQ=O
oe8KjZ80ZnDFFomF6NRU0:SV5eWoEaSWY`2XiaQIoeLIj:H0ZNHFFomE6^ZS0:cS
55ooD1g/W@2bh15UodXRl9H1^MX=KOe2:OB=0l;B2GSk>37hP@K<b0F5mbhlo7<;
ek`1U?4RB_mS4n:]0:GW5e_oDAg]V`2gf`e^oCl/mXH5bLX5QOL]?_e_3M^f09g/
6eGoEQ_[W@2ff`e_oCd^n846c/D3SO<VAomS4nBY0:_R4VKnABSeR@C9bPB8mBQ4
oVHBhjX0Zn8AIoi2:_J51Lg50hkb8dcoGAOYX02ffPadncLengD;fKH0X>TGG_m:
9OB:1<[818cc8dcoFaW[W06ke@UlnBlnoFTAhjT0[mh>L?`h=O]d3=bc0:KT4VOn
?bkiO0WG^@2Pj1ERoT<[mgl8e;/0W^TFH?m4:_N02=Fk09oX5F;n@RghO0WH]`2T
iA9XoCdbnWD<gJl0[>0>LO/d>_eZ4^BT0;OG2Gkg:TKoG1[]UP;5bPB?l1iFod/V
mH<7e;X0XnDBJodh=oa/4NBT0;WD1hCe9DgoDb7bR@G@_P6Pia=YoCPgo6/BiZ40
_M05R_8OEOm::?Mn2]Zb0:kM2g[h:TOoF1kaR`G@_@2Ri11_nc8ooV0IkI<3b/<1
W>PCJ_`f>oiT5n^F0lW40IcX4f[l=CcnHQS]T`?<`@6PiA1`nc12oe/MlHX6dkP0
Z]h;NoLWCOm>9_Ml2mjZ0;SC1Hc`6ekn?SClJAGZU`?;`@6Rh`menBY9oe4UmWd;
gjT0_<l4T^dGI_df?OiM7?691mNc0;?G1hWa75kn>cOmHaW_S@KD]@2af0N8lAaN
oS/ioV0Jl8T7ek40]]@5SnhGI_`c@OmG8OEn2n2U0<790YgU3gKh9e3oARokJaG/
TPGC]P2bePJ=kQMXo354oe4Vn7D?iYX2c;d0[=X8R?0II?dc@_mC9OQf4>NI0ljk
0:oG1Xg]5V[k;DWoBRckJaG]S@KH[P2lc0:Mi0ekmB1JoSTloeLSmgL?iiP3dKL0
]M84UnP@MoLRF?lk>omG8oMf4>RE1=Bb0;[=0YkS383c76;m<DKoBbgkIaWaQ0[P
X@;;_02be0BFi`mjmAmNoCA4od`/nfLIlX8;hYd3ckL0^<h2Wn4:Q?0HJ_XYDOln
>OmF9OU_5Nj92MnR0/fi0;O>0Z3P2XO_5Foi9EOn=d7oC2glHagdNPoYTPKJZ078
_@2dd0>Oh@V8kQAbmb5LoC98od@eoUPUnFdGlH8<iIL5ej/0akh0]Ll2X]h8S^X@
N_@KIo/XE?lg@_m8<_iJ9?U/6?9o3^RA1mbS0/nd0<340;3B0j3O28oY3gkb66gi
8ecm;dgo?3koBc7mFRGjJA[dNA7]R0[TU`GJYP;>]032`@2ec@6Xf0BJhPV<jPmo
lAIamaiTnbMGoS5;oca0odLeoU8[o5hRnFXJmGHDkh8>jHd9hYP5fj<2djh1b[L0
`L40^<T0[m82YMT4W>07T^H;RN/?Oo0DM_@IK_LNIOXTGO`ZEOhaCOlgA_ln?om4
>Om;<oiB;OeH:?aO8oYU7oQ[6oEb5o=h5?1n4Nf33^Z93>N>2NBC2>6H1]jL1M^Q
0mRU0]FY0]:/0Ln`0Lbc0<Vf0<Ni0<Bl0<:n0;o00;g20;_40;[60;S70;K90;G:
0;C;0;?<0;;<0;;=0;7=0K7=0K7=0K7=0K7=0;;<0;;<0;?;0;C:0;G90;K80;S6
0;[50;_30;g10;no0<:l0<Bj0<Ng0<Vd0<ba0Ln^0M:Z0]FV0mRR1=^N1MjI1n6E
2>B@2^N:3>Z53nf04_1j5O=d6?E^7?QW8?YQ9OaJ:_eD;oi==Om6>om0@OliB?lc
D?h/Eo`VGoXPJ?LKL?@FNO0AP^/<S>H9UN05WmT3Z=81//X0^l40a;P0cJh2eJ<4
gIP8iHd<jh8BlGHHmVXPnUhXoE<aodLloca7oc5CoBMOnQi]mAIjk`n8i`VFg`BS
e06ab@2n_@3:[`;FX@GPTP[ZPa7bM1[hI2GlEC7oASko>4gn:ecj7fgd5Gg/38oR
1Z3G0[390<2j0<nY0mbG2NR54O9c6oUP:?i>=olmB?l]F_/OKO@CPNX:UMh4Z<l0
^kh0c:/3g9L9jH8Cm6dPneP_odA1oc9Eo25[mAB1jPVGg0>]bP31]`7DX@KTRPoa
LacjFbgoAD7o<EOk7fob4HOV1j3E0KO10<bZ1=nA3>ih6_UN:oi6@Ol`FOXML_0>
SN44Ylh0`;L1eYh8j88DmFLUoD`kocADnam`l@n<h@BXc@33]0;IV0[/NaWhGRgo
@TKn:V;g5X3Y29kE0KZl0=BO1nR05_MR:_m4A?lZH_LEPNP7XM80_kL1fIP:kGLK
nULcocY@o21`l0fAg@:b``3?Y0KWPQGgH2co@4Wn9F[c48gP0jo50<jU1^N25_QN
;_lmCOdQL?0=U=X1]kd0eI/:kGHMne4ioc5Kn1N1i`JVc038Z`CTQAGgGbko>e3l
7WK]2IgC0<6b0n2<4OET:oloC?`PLnh:W=@0`K43hHXBmV4]oc]AnaajjPNScP39
Z@GWOaWjECOo<5kg4hSQ0k;00=JG3?5/9_i3BOdPM>d9X=00b:T6j7dJne4lob]U
l`nCf@6n]0?QR1ChFSCo<Egg4X_N0[Ri0]f<4_IN<OlcFoLCRml2^;T2gX/Cme/d
oc1OmQ6@f`6n/`?SPaSjDSco:F[a2i_B0<VV1n]e8Oi5BO`MN^P5[<<0ei@?mF4`
oc9NmQ2Af@32[@GXNQkmB4Om7WWX1Jg20=Z@4OMK=Ol/I_8<Vm40c:4:kf/YocUG
n1>=f`71[@GYMb3n@dgk6H?R0[Vf0nAo6oa9AodMOND3];X2hH<Inda4oAikiPBc
^P;QPaWlBTKm7GkT0kNg0nAn7Oe5Bo/IQN01_K05jGDSoSeDn1>@f038Y0W`J2co
<F;c39o<0=BD4?MH>_lTM>T5/K`2hX0LoDA>nQJ;f`36YPW`Ibko;VO`2JG60=^:
5_];A_`JQMl1`ZX8kfX/obmVl0VWa07MQaWlAd_k5XcI0<VQ2o=O=OlVLnT4];L3
j7HTocMMm0bPb@3JRQOkB4_k5HkH0<fL3_IH??hOON82`:X8l6H`obU`jPFd]PCY
LRSo<FG`2:^o0^=k8OlhGO@;XlD1gh8MoSeGmPfNb@3LQQ[m@5Cg3Yc;0=^76_e1
E?L>W</0fhHKoD1FmPfOb03NPagn?5[d2jC40N9l8OlfHO48[;d3ig<Xobi[k0Ff
/`K]J37o9GSU0/6V2_AJ?OhKQmX0cYLBnTY<nA6Hc@3LQ1gn>Ukb2:bl0nU_;?lX
M>H2`:H;mEQ0oAR=e@3ESASm?eSd2ZRo0nQa:olXMND2`j<=mU=5naBEc`3LPaoo
=FG^1KJa1o5O>_hKRML0eHdIoCaMlPR_]`G^ICGn7XGJ0=:?6?dmG?88[kH5kf<h
oQ^9e`3FRA_n>6?^1KN^2?=I@?`EU<h0gg`TobaaiP;5WQ3iBE7f3:Nm1>aW=?hM
R=L0f8HNoc=ZjP?0Y0ghC4kg3:Jn0naV=_hKRm@0fh4Robebi@78VQ?k@E[b1k>`
2?AFA?XAW/@2jF/boaf9e@3LP2?o:gGR0<fC5odiHnd4_Z@>nDQCm@V_/`OcEdGj
4:710naU>OdGU<`1i78^oan7e@3MOBKo9WgM0=F77ol]Ln<0cY0IoSA[j078V1Gm
>VC/0l>N4_`oGnh4_j8@nT9Kl0FkY@kjAESa1[ZW3OU6Eo86^JP=nDIGlPJiY`gi
AEWa1K^U3oY3Fo04_Z8@ncmPk@?2WA?l>VGZ0/NG5oheK>H1cHlKobidh@3DQR7o
9gkJ0=al:OlORM80hg0boQREb0;[Hcgk4:>l1_9EB_L:/Jh;n4IIl0C0WQ?m=f[W
0Ln<7_lYOMX0gGP/oa^Ab`;ZHcgk3jJh1oE>D_<6^j8Ao3UYi`7@RR3o9X;F0>9`
<ohEW<04lEI;mPRgY`ok?6KX0M2:8?lTQ=@0iF/ho16T^@OeC5Ga1<:J5oh_M]h0
gGL^oQNI`PCaE4ge1kbP4odcLN40fW//oaRH``CaE4kd1[jN5Oh`M]d0gW@aoQBP
^`OeBeS_0lRB7?lVQ=<0j6@onPbaZ`kk>F_T0=Ql;?lGVkl6m4aGk`?9T1ko8hS>
0NaMA_L8^Z0DoRmifP3SJc[k3Jj/3_`hK^40g7DboA:V]@[i?fKV0=Ml;OhEX;T8
n4=Rj@3EOb_o5Yjk2?M4HNT0eGl[oQFP^@Wh@VCW0=Mk;ohCYKD;nSaZh`3MLcGl
3jf/3o`dM=`0i6Pon@VhX1Ko:H;A0NaIC?<4aY0PoafD``GeB5kZ0=Il;ohAZ;0>
o3Edf`3VI4?g1knH6olQSlL4m4YLjP3FNc3m4:b/4?d`NmH1je]<l`C9RbCo69ji
2_XkKmh0i6I2m`K1U1ko7IJo1oQ0JN80hFXon0NoUQgo7IJo1oPoJ^40hfM2m`K3
TB7o6Ybi2_XhLm/0jEe;lP?=QBWn4ZV/4Oh/P/l2lDeLj@3JLSWj2KbH7OlMVK`9
nSQcfP3[FE3`0]=m<O`=]:0Hob6C`0Si>g3L0>UJCo02dg`bo0bgWA[o7IRk2_/e
N=D1ke5IjP3LKcgh1/B>9OlDZJ/BoRN<aPKg?VkL0>YHDnd1f7@jn@O2SbCo4jZZ
4olTT<88nCQee`7_CecW0>1WAO@3cX0`o0^jV1oo5jB^4OhVSL<7nCQge@7aBf7T
0>EPCO01eg@jn0K6RB[m3[FM7?lIXZlAoRF@`0Wk<gg@0oA3Jmd0k59Jj03RHd[a
0MMc??L5bX<_o0ZmTRCo4K2Q6_lIXZlBob:E^`cm;8O71oTfN]43mD5^fP7_Bf?R
0>YFF>P0hf1>kP3LJTGc0]Ed??L4cWdenPO7QRkl2/2>:?d=^IDSoa2cW1ko5:fR
6_lGYjPGoa^R[ACo7Yfb4OlQVKH?oRBE^@gn9Y:l3?dXSkh;oBZ=`0[l:h_22_`/
R/89o2f9``Wl;HW32O`]RL89o2b:`P[l:hc02_dZS[h;oBR@_0gn9Y>i3_hSUkH@
ob2K/Q;o7J2]5OlJYJPHoaNZXaco4k2L8?l@]iDUoPbmSR[l2LB6<OX6bgdhm`CB
M3od0]UZB>l0h61BjP3WEUcS0>e<Im`1ld5cd`Ch=Wo91o//S;h=oR:J/A?o6JNT
7?lA]IHVo@[2QS7i1Lmf?o@1ffI=k03VEUgQ0?16KmD3mcJ1a`Wl:9>g4OlKYZDL
oa2hTB[l2<Ym>_D2fFQ<k03WDf7O0O<oMlh6nbf=^`oo7JBV7?l@^Xh/n`K>MT3b
0>1NEnD0kdI`d`Ci<8Zm3_lMY:DMo`jmRS3i1=A^B>d0ie=Sg0;e>Go62_hSWJ`I
oa6iSRgj1M9`Anh0j55UfP;g=HG13OlNYJ<NoPc3PcOf0]eQEND0l49gc0Ol9YV^
6?l@^h/`n0?HJ53X0>i5Lll7o2NH[QSo4;b:<_P2fVADi@3a?g[92OhQXJDNoP_6
OSgb0>AFH]/2n36;^Q;o5KBB;OX4efMAiP3a?g_72ohNYYlSo@S>LdO]0>a8L/l7
oB>OYQkn2/Ui@^l0jDa^d@Kl9IfX7Oh:bGQ3kP3ZBG7?1odRXZ<Qo@S>LTW[0>m2
N/L;oa^/V2Wj1=MUEN81mCF9^Q?o4[^7=o@0i59Xe@Gl9IjV8?d8cfm<j03b?8:o
4?lD^8Xem@7TDfWD1_`SXJ8So0KDJ5?S0OHcSKDFo`g4Nd;^0>e2Nl@=oaJfS3Ce
0>E@K=08oQjYVB[i0meKHMT4nbFOXb?l1MMSFMh2nB^HZAom1m9YE>81mbjD[Acn
2=1/DN<1mbnC[Qcn2=1[D^81mbjEZakm1m=WE^02nBZKYR7l1MQQGM/4nbBSWRSj
0miGI]<7oQf]TS7f0>I;M<T<oaBkQ3g_0>lmQ;XEo`c:LTgU0OL]UjPQo0GIGF7F
1_dN[I8bm@3YAgW34?l?a7Q8j03f<9FZ8?`4fUaTe0On6k:<=o80kSj4^AKo2/mZ
E]h3nb>WV2kf0>Q7N/4Ao`g9LE3R0_XVXY`[m`7WBGW24Ol=bG1Ah@;j9:FH;oH0
jTAo_AGo2]1XFM/5oAf`SCS`0?0hSK0Mo@CLF6[>2olB`GU9iP7i9j:J;OH0jd:2
^ASn1mIOHm<9oaFmODOW0OPXXYX^m@3/?hJe6od5feQ[c0co3lMaD]l3o1j`Rc_^
0?@`VJ<Xn07Y@h6h6Oh6fUQ[b`go3/Y]E]/5oQVhPDCX0OTVYYDclP3a=9BV9_T1
j4>3]Q[m1=iBL/DAo`WCHF?A2_l@afmEf`Kn5kalBN@2nan`RCo[0?PWYY@el03d
;ibN;OD0l3JCYROh0>/mRjhQnP7WA8>d7O`3hdUm^QWm1>1>N;hFoPGMDWC15?h6
feEaa1?o1mUGL<DBo`OHEfo64_l7f5M_aA;o1mUFL<@Co`OKE7?25?h6gE5f_aOn
1>1=Nk/Io@?SB82f7O/2id:7[b;j0N/lSZPWm`3_=INP;_<0m2fQUSK_0?PUZh/o
j07k7KIoB^44oQK1LUKH2Ol>cFATc@oo2=QELl0Go@?SAXBa8OT0kCNEX2kb0?DY
Yhhnj@7l7;UjCm`7oa3;IV?=3ol7fe5i^Qck0NXlT:@/m03e:JR<@>L2oARoLeOF
2_l;e5Ua`AOm0nI0S:PZm03e:JR;@NH3oAK3KUgA3Ol8fe1k]aoj0>hdViPgk07k
7;YgE=L:o`[FEGJk7?/1kCJJVCK]0O/K_7EGe@_o2MY@O;DPn@3a;j>@?nH3oQC7
IfC:4_h4iD6>Y2ka0?TP]WYCf0[o2MY@OK<Rm`3c:ZZ7An06o`kAFW>l7?X0kc2R
Sd3U1?hAcEm^`1Wk0NhcWi8niPCn4LeOK/0Jn`7_<J:>@^<5o`oAFWBj7_T0lRZZ
QT[M2?l:fDn0[bOe0?PQ]gMGdPko1NA0TIldk07m5LQTJl8In`3`;ZN8B=h8o`WK
C8BZ:o40nQ[0K6?85Od1kC6SS4GO1ol:fd^5ZBg`0?/Ha6MY`aWk0?8Z[89?f0co
1N@oU9/ij0?o3m=EO;4Wl`3j6l5ZI/@In`3b:JinDm@>o`?X>9bA@^47o`WMAhbR
=>/2oQ3BEGb`:?80naO7Hfnl7oL0manlKV?66?/0lbNcNEW>4od1kbf[PE7D3oh3
jc>TR4_I3?l4j3NOSDOL2_l5iSZKT4CN2Ol6i3bJTT?O2Ol6i3bJTT?O2Ol6iC^K
T4GM2_l5icROS4WJ3?l4jCBTQdkF3_h2kBnZP5G@4_d1lBRcMeg95o/0mB6lK6S0
7_L0nQW6H7Bd9o41oA;BDX>W<^X4o`[MA9>G@>09o`GX=JB5DM<Ao@7b9[IaI<8M
m`3j6<ULNJl/kP;o3=Y6TIQ0h0Wo1>XaZGmGcAKk0?HN`VAb]BS`0Oh>f4V?VCoP
2_l3k2n]NUc86OT0nAS9FWb[<NX4o`SS>in8Cm<Bo03e7l5TLk<ZkP;o2mi0VHi:
eQ3m0?@Q_fIb]2[^0_l:gcjLRdkC4_`0mQg4GgV]<>X5o`OV=JMoFLTJn03k5=5@
RIdng`_o0_0V^F]^]bS_0_l9hSZQQ5G<6?T0naCACh^J@M`=oP7c8L1RMjh`j@Go
1NX_/7AU_BCa0Ol:h3^QPeO:6_L0o17GAiB@Bm@Cn`3i5lmARYY2f`km0?HLb5R2
XCcO2oh1m1o3GGfV>>8:o`7b8/5PNjPfh`Wo0_8R`F1kZ3OS2Ol1lb73GWjU>N4;
oP7d7/MIPj0ng@km0?LIcE:;V4KG4_/0nQCDB9F=D<hHm`3m3MdmXX1L`b7b0_l7
ic2aL6bd;NT6o`;a8l5NOj8mg@km0?TFdTZDSE7<6_H0oP[S=JaeJ;L[jPKo0_4Q
a5Z3WD;H4_/0na3J?j60G/0Tk`Co1>hV_emnXSoK4?/0na7J?j5nH;hWk@Go0o0R
a5V6VTKD5OP0oP_R=:iaK[4bi0[n0?PFddNJQE[38nl4o`?`8/EGRII:d1Wf0Ol8
j2bhIG^T?]XBnP3m3>4e[fma[CKP3O`0na3L>jQfJ[<ai0_m0?XBfCjUNFNe;nD:
oP3i4mTnYGQX]37T2od0nQ7L>jQdK;0dh@gl0?`>h3F_KGBX?=/BnP3n2NL]^V60
WDKB6OD1o`G_8/ICSheEaBC]1_l1mQOE@Z9jJ;<chPgl0?d<i32gHgnMAm0Jm0;o
0o8McDZIPV2i;^D;o@3l3N<a]VAoW4S?7?83o`;d6M=3XGUZ/3KN4OX0oPO[9LAD
THYJ_b[X2_d0o0gS;kUPQ9I>bB;^1_l0nA7N=[5WO9e8cQka1?l1n1?K>Ji[NZ16
caga1?l1n1?K>;1YO9e9cAo_1Ol0nA3O<kERPiI@aRC[2?h0o0cV:kmGShYK^bkS
3_/0o`K^8<e8WgU/ZcgG6?@3o`7g4m`f/fB2UU749nP:o03n2>`RbTZMNfb[?MDI
l`Co0OT@hC2kFhb;G;Xah17h0Ol3m1OH>K1VPIIB`RWV3O/0o`Ga6m@nZf]mVTk5
9nL<n`3o1O4Ke3j/JWjHDL<Yi@gj0?l4laOI>;=RQY1I_33O4_L2o`7h4N4^_UFD
PVN^?M@Kl0Kn0?d9k23?@jQ]O9U@`R_S3oT1o`;g4N4]`5>GOV^Y@/lPk0Wl0?l5
laOJ=[MMSHMS/C_E7>l7o@3n1_4JecRdGhb8H[4ke1c_2?d0oPGb5mXd^EVBPVVZ
@/hRjP_k0?l2ma7S:/A=WgAgW531;^0Cm@?o0?`8kQcE>[ANSXEV[4;>8nT<nP7o
0OT=j2?=@Z]WQHeO/ScC7n`:n`3o0_T>ibC<@Z]VQX]Q/3k@8NT<nP7o0O/;jaoC
>kALTH1/YDW6:n4Cm0Cn0?h5m1CP;<E:YFb1T5jb?M0Rj@gi0_l0o0S`6=/a`4nO
LGfCFkDkdR7Y3OT2o`3m1o4FgRg4BZEZQ8aR[D?::><Cm0Gn0?l3m`oX8]4k]UVF
NGJJE[Phe23Y3_P3o`3n1ODAiBG>?[=KU7YeVUJh>M8Qi`of1?h0o`?h3^XOeCJl
DJ1^PHeSZdK6;MdHk`Wk0Ol0o@Kd4^DTd3^gEY]bOY1Q[4G6;MdIkP[j0_l0oPCg
3^TNec?0C:IWRX=^We>i>]4Ti1?c1o`0o`3m1_DAib7E=Ki=YVN;PG2LE[Hnc2SP
5nl:nP;o0?l2n@__5mlYc3ffEIi^Q8M[XE:i>lhWh1O_2_T3o`3o0O/8lQ?U8]@d
`4ZZHI9iNY5RZ4^n=]8ThaG`2_T3oP3o0O`7m13Y7MX^b46dEYi/Qh=aVUZ_AL<b
eB;U5?4:n@?n0?l0o@Gg3NdHh2K@=km:ZejGLh68K9eH/DC4<m@ShaK_3?L4o@3o
0?l2n`Sc4>TKgBW>>Ki:[5fIL8F3LYMOZTbk>l//fQoV4o4:n0Cm0?l0o`7l1_H=
kQKT8ML_bCfjCJUNV727PGFCHjAC]4?4==8WgQ_Y4_4:n0Cm0Ol0o`3m0oT8l`o[
6>8Sebk:>ke9[UROIi1gP8IaUV:UDk=5`CS=;=TQhaS/4?<9n0Cl0Ol0o`3o0O`5
n0[c4>`Gi23J:]0daD2iC:eHX6FCLhJ0NHe/VUnVDk97_Sc9<M<Xg1oT5n/Al@_f
1oX3o@7o0?l0o`7m0o/6m`[c3nhDia_P8]TZdC?8?;m5]Dn[FJ5SUff=Mh>1N8a^
UVBOFjUA/TRk@<<hbc3C:MXRh1cV5n/Bl0gd2_L6nPCl0_h1o`3o0?l0o`7n0_`4
nPKh2OD<lA3^4nXHiAcP8M`VeR_A<L/faSc0@[Y8]4j^E:MKXF6KIiE]Sg>9NH=o
OHEgRg6AJiIVW66QFjIFZe6`CKE8^D>n?l8kaSO:<lh`dBcD:MPVfb?N8>0Mha_U
6NPFjQC/4^hAk`oa3O8<m0_e2OH8m`Oh1_T5nPGk1?/3o0?m0_d2o@7n0Oh1oP7o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o\>"]},
  ImageCacheContents->"Sound"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Play[Cos[\[Pi]\ 1800\ t\^2 + 2\ \[Pi]\ 500\ t], {t, 0, 2}, 
      SampleRate \[Rule] 5000]; \)\)], "Input",
  CellLabel->"In[45]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sampled sound
1 string
5000 10000 8
{ currentfile 1 index readhexstring pop }
 false 1 sampledsound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pop
% End of sampled sound
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[45]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oo`008@0000000`00
Oomoo`3oOolMOol100000003001oogoo061ooc`00004Ool00000Oolk0011Ool100000003001oogoo
04Iooa@0009oo`l00003Ool0000000H0009ooa@00003Ool0000001800003Ool0000000`00003Ool0
00000180009ooaP000=ooa400004Ool00000000WOol100000003001oogoo031oo`800003Ool00000
00@0009ooal0009ooaP000=ooaL00003Ool0000000X000=oo`X00003Ool0000000L00003Ool00000
00P00003Ool007oo00<0009oo`D00003Ool0000001400003Ool0000001d0009oo`X0019oo`400000
00<007ooOol07Woo@P0000Ioo`00000007oo0002Ool<00000goo0000000900000goo0000000:0000
0goo0000000;0004Ool=00001Goo00000000Ool01`0000=oo`0000000P0000=oo`000000400000=o
o`00Ool02@0000Eoo`00Ool007oo01000003Ool0000000800003Ool000000240009oo`40000000<0
07ooOol03Goo0P0000=oo`000000500000=oo`0000003`0000Aoo`00001oo`H00003Ool0000000<0
0005Ool00000001oo`0200000goo00000007000017oo000007oo1`0000=oo`0000000P0000=oo`00
Ool04P0000=oo`0000001@000Woo0P0000=oo`0000000P0000=oo`0000002@0017oo2@0000=oo`00
00000`0000Ioo`00001oo`00Ool200000goo0000000600000goo0000000<00000goo0000000;0000
1Goo00000000Ool01@0000=oo`00Ool00P0000=oo`0000000`0000Aoo`00001oo`<00003Ool00000
00800003Ool000000180009oo`L0005oo`40000000<007oo00007`0000=oo`000000100000=oo`00
00002@0000=oo`0000000`0000=oo`0000001@0000=oo`0000004P0000Eoo`00000007oo00800003
Ool0000000`00003Ool007oo00D00005Ool007oo001oo`090002Ool00`00Ool0000400001Goo001o
o`00Ool0300017oo0P0000=oo`0000000P0000=oo`00Ool01@0000=oo`0000002P0000Eoo`00Ool0
07oo00@00003Ool0000000H0009oo`04001oo`00Ool300000goo0000000300001Goo00000000Ool0
100000=oo`0000001@0000Eoo`00000007oo00@00003Ool0000001400003Ool0000000D0009oo`L0
005oo`40000000<007oo00003`0000=oo`0000009`000Woo300000=oo`0000000`000Woo400000Ao
o`000000009oo`07001oo`00001oo`00Ool01`0000=oo`00Ool01@000Woo00<007oo00000Woo0`00
00=oo`0000003P0000=oo`00Ool00P0017oo00<007oo00000Woo300000=oo`00Ool00`0000=oo`00
Ool00Woo00H007ooOomoo`00Ool300000goo000000060002Ool500000goo0000000500001Goo001o
o`00Ool00`0000=oo`0000001@0000=oo`0000001@0000Eoo`00Ool007oo00D0009oo`X00003Ool0
000000d0009oo`40000000<007oo000020000Woo5@0000=oo`000000200000=oo`0000001@0000Eo
o`00000007oo0080009oo`L0009oo`<0009oo`L00003Ool0000000800003Ool000000080009oo`D0
0005Ool00000Ool00002Ool500000goo001oo`0?0003Ool400000goo000000040003Ool300000goo
000000040005Ool00`00Ool0000600000goo00000003Ool400000goo000000030002Ool300000goo
001oo`0400000goo0000000900000goo001oo`03000017oo000007oo0P0000Eoo`00Ool007oo00D0
0003Ool007oo00T00003Ool0000000H00003Ool00000009ooa400003Ool0000000L0005oo`400000
00<007oo000060000Woo300000=oo`0000002@0000=oo`00000010000Woo00<007oo000070000Woo
0`0000=oo`00000020000Woo1@0000=oo`0000000`0000=oo`000000100000Moo`00000007oo001o
o`08000017oo000007oo0P0000=oo`00000010001Goo00<007oo00001P000Woo10000goo2`0000=o
o`0000000Woo3`0000=oo`0000002`0000Moo`00000007oo001oo`0600000goo001oo`03000017oo
000007oo100000=oo`0000000P000goo4@000Woo1`000Goo0@0000000`00Ool0000?00000goo0000
000600000goo0000000600000goo0000000200000goo0000000600000goo000000070002Ool:0000
1Woo000007oo001oo`/00004Ool000000002Ool500000goo0000000600000goo00000005000017oo
001oogoo2P0000=oo`0000001`0000Eoo`00Ool007oo00/000Eoo`04001oo`00Ool200000goo0000
000600000goo0000000<00000goo0000000300000goo0000000400000goo0000000500000goo0000
00080003Ool00`00Ool0000800000goo0000000300000goo0000000200000goo001oo`050003Ool9
00000goo000000050002Ool60002Ool100000003001oo`0001d00003Ool007oo00800005Ool00000
001oo`0;00000goo000000040002Ool500000goo00000005000017oo000000000goo2`000Woo2000
00=oo`000000100000=oo`00Ool01P000goo100000Qoo`00Oomoo`00Ool007oo1`0000=oo`000000
0`0000Aoo`00Oomoo`L000Aoo`03001oo`0000@00003Ool007oo00D00003Ool007oo00800003Ool0
07oo00800003Ool0000000800003Ool007oo00<0009oo`03001oo`0000<00003Ool0000000800003
Ool000000080009oo`<0009oo`04001oogooOol40002Ool;00001Woo000007oo001oo`@00003Ool0
0000009ooa80009oo`L0005oo`40000000<007oo00009P0000=oo`0000004@0000=oo`0000001@00
0Woo400000=oo`0000000`000Woo0`0000=oo`000000100000Ioo`00001oo`00Ool30002Ool30003
Ool<0002Ool80002Ool700000goo000000020004Ool400000goo0000000200001Woo000007oo001o
o`800003Ool0000000<00003Ool0000000<000Aoo`<000=oo`<00004Ool000000002Ool300000goo
000000080003Ool300000goo0000000;00000goo0000000400000goo0000000400000goo0000000@
0002Ool70001Ool100000003001oogoo00]oobL00003Ool0000000<00004Ool00000Ool;0002Ool=
000017oo000000000Woo00<007oo0000300000=oo`00Ool01P000Woo100000Eoo`00000007oo0080
0005Ool00000001oo`0700000goo0000000;0004Ool300000goo0000000=00000goo0000000>0000
0goo0000000500000goo0000000?0003Ool40003Ool400000goo001oo`0400001Goo00000000Ool0
1P0000=oo`0000002P0000=oo`0000003P000Goo0@0000000`00Oomoo`0KOol;00000goo0000000?
00000goo0000000O0002Ool800000goo0000000H0002Ool00`00Ool0000800001Goo001oo`00Ool0
2P0017oo20000Woo1@0000Eoo`00Ool007oo00<00004Ool007ooOol500000goo0000000800000goo
0000000@0003OolJ000017oo000007oo7@000Goo0@0000000`00Oomoo`0]Ool<0002OolO0002OolB
00000goo0000000?0002Ool200000goo0000000300000goo0000000>0004Ool?00000goo0000000<
00000goo0000000400000goo0000000F0003Ool600000goo0000000800000goo0000000:0002Ool:
00000goo001oo`0?Ool100000003001oogoo045oob<00003Ool0000000h00003Ool0000001X00003
Ool0000000X00003Ool0000000h00003Ool0000000`00003Ool0000000800003Ool0000001T00003
Ool0000001@002Eoo`40000000<007ooOol0FWoo0P0000=oo`000000?@0000Aoo`00001oo`h00005
Ool00000001oo`0Y000017oo00000000?7oo0@0000000`00Oomoo`22Ool00`00Ool0000200000goo
0000000B0002Ool00`00Ool0000B00000goo00000002001TOol100000003001oogoo0?mooaeoo`40
0000o`008@0000000`00Oomoo`3oOolMOol100000003001oo`0000P0009oo`D0009ooa@000=ooa00
0004Ool00000OolB00000goo000000080004Ool700000goo0000000400000goo0000000700000goo
0000000800000goo0000000300000goo0000000?000017oo001oo`000Woo00<007oo0000700000=o
o`0000004P0000=oo`0000002@0000=oo`0000003`000Woo2`0000=oo`0000004P000Woo1`000Goo
0@0000000`00Oomoo`020004Ool00`00Ool000020003Ool40003Ool00`00Ool0000300001Goo001o
o`00Ool00`0000Aoo`00Oomoo`800004Ool007oo0004Ool00`00Oomoo`0400001Goo001oo`00Ool0
0`0000Aoo`00001oo`8000Ioo`H00005Ool00000001oo`020004Ool8000017oo001oogoo0`0000Qo
o`00000007oo001oo`000Woo0`000Woo10000Woo0P000Woo0P0000=oo`00Ool00P000Woo00D007oo
000007oo00H00003Ool00000009oo`03001oo`0000Aoo`<00003Ool007oo00=oo`06001oogoo001o
o`000Woo00@007ooOomoo`800003Ool0000000D00003Ool000000080009oo`03001oogoo00=oo`03
001oo`0000<00004Ool007ooOol300000goo001oo`0:00001Goo001oo`00Ool00P000goo0P000Woo
0P0000Eoo`00Ool007oo0080009oo`800005Ool00000001oo`0200001goo00000000Ool007oo00<0
009oo`03001oogoo0040000000<007oo00000Woo00D007ooOol007oo008000Aoo`03001oo`00009o
o`8000Qoo`<00004Ool000000006Ool00`00Ool00002Ool00`00Ool00003Ool00`00Oomoo`0:Ool0
0`00Ool00002Ool200000goo001oo`03Ool00`00Oomoo`02000:Ool01000Oomoo`000goo00<007oo
Ool017oo00D007ooOomoo`0000Aoo`03001oo`00009oo`03001oo`00009oo`80009oo`03001oogoo
0080009oo`03001oo`0000<0009oo`80009oo`05001oogooOol00003Ool20003Ool00`00Oomoo`03
Ool00`00Ool00005Ool20003Ool01@00Ool007oo00000Woo0`000Woo00<007oo00000goo00<007oo
Ool00goo0P0000Ioo`00Ool007oo0002Ool00`00Oomoo`02000017oo001oogoo0P0000Moo`00Oomo
o`00Ool00005Ool40003Ool00`00Oomoo`03Ool00`00Ool00004Ool00`00Oomoo`04Ool00`00Oomo
o`05Ool00`00Ool00005Ool20001Ool100000003001oogoo008000Aoo`@0009oo`04001oo`00Ool2
00000goo001oo`02Ool00`00Oomoo`0200000goo001oo`04Ool00`00Oomoo`03Ool50005Ool01000
Oomoo`000Woo00D007oo000007oo0080009oo`8000Qoo`800003Ool0000000<00003Ool000000080
00Aoo`8000Moo`@00004Ool00000Ool50004Ool600001Woo001oogoo001oo`800003Ool00000009o
o`8000Eoo`03001oogoo00Aoo`05001oo`00001oo`020002Ool3000017oo001oogoo0`001Goo00<0
07ooOol017oo00/007ooOomoo`00Ool007oo001oo`0000=oo`D0009oo`04001oogoo0002Ool00`00
Oomoo`03Ool01000Ool007oo0P0000Aoo`00Ool0009oo`80009oo`80009oo`800007Ool00000Ool0
07oo00000goo00P007oo001oo`00Ool007oo0`000Woo0P0017oo0`0000Aoo`00Oomoo`80009oo`<0
00=oo`40000000<007oo00000P000Woo0P000Woo00@007oo000000=oo`03001oogoo009oo`03001o
o`0000Moo`80009oo`<00004Ool000000002Ool20003Ool40004Ool01000Oomoo`000goo0`0000Ao
o`00Ool000Aoo`800005Ool00000Ool00003Ool01@00Ool007oo000017oo00@007ooOol0009oo`03
001oo`00009oo`8000=oo`06001oogooOol007oo0P0000=oo`00Ool00Woo00<007ooOol00Woo00@0
07oo001oo`800008Ool00000Ool007oo001oo`<0009oo`03001oo`0000Eoo`800004Ool007ooOol2
000017oo000000000Woo00<007oo00000`000Woo00<007ooOol00P0000=oo`00Ool017oo00L007oo
Oomoo`00Ool00008Ool40004Ool4000027oo000007oo001oo`00Ool200000goo001oo`05Ool20002
Ool00`00Oomoo`0200000goo00000002Ool00`00Ool000030006Ool01@00Oomoogoo00001Goo0P00
0goo00D007oo000007oo00@0005oo`40000000<007ooOol01Goo00D007ooOomoo`0000=oo`05001o
ogoo001oo`020002Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`05Ool01000Oomoo`000goo00@007ooOol000Aoo`03001oogoo009oo`05001oogoo
Ool00006Ool20005Ool01@00Oomoogoo00001Woo00<007ooOol017oo00D007oo001oo`0000Ioo`03
001oogoo009oo`06001oogoo001oo`000goo00<007oo00000Woo0`0000Eoo`00Ool007oo008000Eo
o`03001oo`0000Eoo`<0009oo`06001oogoo001oo`000goo0P002Woo00D007ooOomoo`00009oo`@0
00=oo`04001oogoo000DOol01@00Oomoogoo00000Woo00D007ooOol007oo008000=oo`04001oogoo
0005Ool01000Ool000001Woo00@007ooOol000Aoo`80009oo`40000000<007ooOol00Woo00H007oo
Oomoo`00Ool20002Ool01000Oomoogoo0P000Woo0P0000=oo`00Ool00goo00<007oo00001Woo0P00
0goo00@007ooOol000=oo`03001oogoo00800003Ool007oo009oo`03001oo`00009oo`07001oogoo
Ool007oo000017oo0P0000=oo`00Ool00Woo00<007oo00000goo00<007ooOol00Woo00<007ooOol0
1Goo0`0037oo00<007oo00000Woo0P0000=oo`00Ool00Woo00H007ooOomoo`00Ool30002Ool20002
Ool20002Ool01@00Oomoogoo00000Woo0P0000=oo`00Ool01goo0`000Woo00@007ooOol000Moo`80
009oo`<00005Ool007ooOol00003Ool2000017oo000000000Woo0P0000=oo`0000002Goo0`0000=o
o`00Ool00P000Woo00<007oo00000Woo00D007ooOomoo`0000=oo`05001oo`00Ool00006Ool00`00
Oomoo`03Ool200000goo00000004Ool01@00Ool00000Ool00`0000=oo`00Ool00goo0@000Goo0@00
00000`00Oomoo`020003Ool01@00Oomoo`00Ool00`0000=oo`00Ool00goo00<007ooOol00P000Woo
00D007ooOol007oo008000Aoo`03001oo`0000Eoo`04001oogoo0004Ool200000goo001oo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`05Ool200000goo00000003Ool01@00Oomoogoo000027oo00<007oo
Ool00`000Woo00<007oo00001Goo00<007oo00001Woo0P0017oo00D007ooOol007oo008000Ioo`80
00=oo`04001oogooOol30002Ool01@00Oomoo`00Ool00P0000=oo`0000000goo00<007oo00001goo
00<007oo000017oo00<007ooOol01Woo00@007ooOol000Eoo`06001oogoo001oo`0027oo0P001Goo
00<007oo00000P0000Ioo`00Ool007oo0004Ool20007Ool01000Oomoo`0027oo0P001Goo00@007oo
Ool000Aoo`04001oo`000002Ool00`00Ool00003Ool100000003001oogoo00Moo`07001oo`00Ool0
07oo00001Goo00<007ooOol027oo00<007oo000017oo00<007ooOol02Goo00<007ooOol017oo00<0
07ooOol00goo00<007ooOol00Woo00<007ooOol01goo0P001Woo00@007oo000000Ioo`<000Eoo`05
001oogooOol00005Ool01000Ool000000goo00<007ooOol00goo00<007ooOol017oo00<007ooOol0
0P001Woo00<007ooOol00Woo00<007ooOol00goo00<007oo00000goo0P001Goo00D007ooOomoo`00
01Uoo`04001oogoo0007Ool00`00Ool00006Ool20003Ool00`00Oomoo`0=Ool20007Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool01@00Oomoogoo00001Goo00<007oo00000goo0P000goo00<007ooOol0
0Woo0@0000000`00Ool00006Ool200001Goo001oogoo00000goo0P003Goo00<007oo00000P000goo
00<007ooOol00Woo00@007oo001oo`800003Ool0000000Ioo`06001oogoo001oo`000goo0P002Goo
00@007ooOomoo`800003Ool007oo009oo`@000=oo`8000Ioo`05001oo`00Ool00005Ool00`00Ool0
0008Ool01000Ool000000Woo00@007ooOol000Uoo`04001oo`000004Ool300001Goo001oogoo0000
0Woo00<007ooOol03Goo00<007oo000027oo00D007ooOomoo`0000Ioo`8000=oo`03001oogoo00Eo
o`06001oo`00Ool007oo0P001Goo00<007ooOol027oo00D007ooOomoo`00009oo`03001oo`0000Ao
o`05001oogooOol00002Ool01`00Ool007oo001oo`0000=oo`8000Eoo`03001oogoo00Eoo`400000
00<007ooOol00goo0P000goo0P001Goo00<007ooOol00Woo00<007ooOol017oo0`000goo00<007oo
Ool00P0000Aoo`00000000Uoo`8000=oo`03001oogoo00Ioo`80009oo`80009oo`04001oogoo0005
Ool20003Ool00`00Ool000020004Ool00`00Oomoo`07Ool20004Ool01000Ool007oo0P0017oo00@0
07ooOol000Eoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Yoo`04001oo`000006Ool2
0002Ool00`00Ool000020003Ool01@00Oomoogoo000017oo00<007ooOol00goo0P000goo00<007oo
000017oo00@007ooOol000Eoo`04001oogoo0004Ool01000Ool000000goo0`000Woo10000Woo00<0
07ooOol01Goo00<007oo00000P0000=oo`00Ool01Woo0P000goo00@007ooOol000Moo`03001oogoo
00Aoo`40000000<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00D007ooOomoo`00009o
o`<000=oo`8000]oo`04001oo`000006Ool00`00Oomoo`07Ool00`00Ool00005Ool00`00Oomoo`08
Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`0:Ool00`00Oomoo`07
Ool00`00Oomoo`0@Ool3000017oo001oo`000goo00<007ooOol00goo00<007ooOol017oo00<007oo
Ool02Woo0P0017oo00<007ooOol017oo00<007ooOol00P0000=oo`00Ool03Woo00<007oo00000Woo
0P002Goo00@007ooOol000]oo`03001oogoo00Moo`8000Uoo`03001oogoo009oo`03001oogoo00=o
o`40000000<007oo00000Woo0P002Goo00<007ooOol00goo00<007oo00001goo00<007ooOol00Woo
0P000goo00H007ooOol007oo0007Ool01000Ool000001goo00<007ooOol01Goo00<007oo00001Goo
00<007ooOol017oo00@007ooOomoo`80009oo`04001oogooOol200001goo001oogoo001oo`0000Mo
o`05001oo`00001oo`020003Ool01P00Oomoo`00Ool000Ioo`03001oogoo00=oo`04001oo`000004
Ool00`00Oomoo`03Ool30004Ool20002Ool01000Oomoo`0017oo0P0000=oo`00Ool00goo00@007oo
Oomoo`800006Ool007oo001oo`001Goo00<007oo00000goo100000=oo`0000000Woo0`0000Qoo`00
000007oo001oo`000Woo00<007ooOol00goo00D007ooOomoo`00009oo`03001oogoo00Eoo`05001o
ogooOol00003Ool00`00Oomoo`02000017oo000000000goo0P002Woo00<007ooOol00@0000000`00
Oomoo`030007Ool01@00Oomoo`00Ool00P000goo00@007oo0000009oo`03001oogoo00Eoo`800003
Ool007oo00Moo`80009oo`03001oo`0000=oo`06001oogoo001oo`001Woo00<007ooOol00goo00<0
07ooOol00goo00<007ooOol01Goo1@000Woo00L007ooOomoo`00Ool00006Ool00`00Oomoo`02Ool0
1`00Oomoogoo001oo`0000Aoo`03001oogoo00=oo`03001oogoo00Moo`8000Aoo`05001oo`00Ool0
0002Ool00`00Oomoo`020002Ool01000Oomoogoo0P000goo10000Woo0P0000Ioo`00000007oo0009
Ool00`00Oomoo`0=Ool01000Oomoogoo0`000Woo00<007oo00000Woo00@007ooOol0009oo`04001o
o`000003Ool00`00Ool00002Ool01`00Oomoo`00Ool007oo0080009oo`03001oogoo00=oo`03001o
ogoo00Ioo`03001oo`00009oo`8000]oo`40000000<007oo00004Goo00<007ooOol00Woo00D007oo
Oomoo`0000Ioo`07001oogooOol007oo00001Woo00D007ooOomoo`0000Uoo`04001oogoo0005Ool2
0005Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Ool00008Ool20003Ool00`00Oomoo`04Ool0
0`00Oomoo`0=Ool00`00Oomoo`0BOol01000Oomoo`000goo00@007ooOol000]oo`03001oogoo00Uo
o`03001oogoo00=oo`03001oogoo00=oo`03001oogoo01=oo`05001oo`00Ool00008Ool00`00Oomo
o`05Ool01@00Oomoogoo00002goo00<007ooOol017oo00<007ooOol03goo0@0000002000Ool007oo
001oo`00Ool30002Ool00`00Oomoo`03Ool01000Oomoo`002goo00<007ooOol01Goo00@007ooOomo
o`80009oo`03001oogoo011oo`03001oogoo00Eoo`03001oogoo00Eoo`03001oo`0000Eoo`800003
Ool007oo00Eoo`<00003Ool007oo00Uoo`03001oo`0000Uoo`04001oo`000005Ool00`00Oomoo`02
Ool01@00Oomoogoo00002Woo0`000Woo00<007ooOol017oo00D007ooOomoo`0000Ioo`<000Eoo`07
001oogooOol007oo00000goo0P002Woo00D007oo001oo`0000Qoo`03001oogoo00Eoo`8000Uoo`80
009oo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo009oo`04001oo`00000:Ool00`00Oomo
o`03Ool100000008001oo`00001oo`00Ool000Ioo`05001oogooOol00002Ool00`00Oomoo`07Ool2
00000goo0000000200000goo001oo`07Ool50009Ool00`00Ool00006Ool00`00Oomoo`03Ool00`00
Oomoo`03Ool00`00Oomoo`04Ool01000Oomoogoo0P001goo00<007ooOol00P0017oo00H007oo001o
o`00Ool30002Ool01000Ool000000Woo00<007ooOol017oo00@007ooOol000=oo`8000ioo`80009o
o`03001oo`0000=oo`03001oogoo00Aoo`80009oo`8000Ioo`03001oogoo009oo`8000eoo`03001o
ogoo00Aoo`07001oogooOol007oo000027oo00@007ooOol0009oo`04001oo`000004Ool01P00Oomo
o`00Ool000Ioo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo009oo`03
001oogoo00Aoo`40000000<007ooOol00Woo00<007ooOol00Woo00@007ooOol000=oo`<000ioo`03
001oogoo00=oo`03001oogoo00=oo`03001oo`0000Eoo`03001oogoo00Uoo`03001oo`0000Eoo`03
001oogoo00Uoo`03001oogoo00Aoo`03001oogoo00Moo`05001oo`00Ool00003Ool00`00Oomoo`06
Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool01000Oomoo`000Woo00D007oo001o
o`0000aoo`80009oo`04001oogoo0002Ool20002Ool00`00Oomoo`0<Ool01000Oomoo`004Woo00<0
07ooOol03Woo0P001Goo00<007ooOol00goo00@007oo000001ioo`40000000D007ooOomoo`0000Ao
o`03001oogoo00Ioo`03001oo`0000Eoo`03001oogoo00Ioo`04001oogooOol200000goo001oo`03
Ool00`00Ool00007Ool00`00Ool00002Ool01@00Oomoogoo00001Woo00H007ooOol007oo0005Ool2
0002Ool01@00Ool007oo00001Goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol00`000Woo
00<007ooOol00Woo00<007ooOol01goo00<007ooOol00goo0P001goo10000Woo0P005Goo00<007oo
Ool00goo0P000goo00<007ooOol01Goo00<007ooOol017oo00<007oo00000goo0P002Goo00<007oo
Ool02goo00<007ooOol02Goo0P002goo00D007oo001oo`0000Eoo`05001oogooOol00005Ool01`00
Ool00000Ool007oo0040000000<007ooOol037oo00<007ooOol02goo00D007ooOomoo`0000Qoo`80
0003Ool007oo00=oo`03001oogoo00=oo`03001oogoo00Eoo`05001oogooOol00007Ool01000Ool0
00000goo00L007ooOomoo`00Ool00003Ool2000>Ool00`00Oomoo`030004Ool200000goo00000002
00000goo001oo`06Ool00`00Oomoo`02Ool00`00Ool00002Ool00`00Oomoo`02Ool01@00Oomoogoo
00001goo00T007ooOomoo`00Ool007oo00001Woo00<007ooOol00Woo00@007ooOol000Aoo`03001o
o`0000=oo`03001oogoo00Moo`8000Ioo`05001oogooOol00002Ool20004Ool200000goo001oo`03
Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00Woo00@007ooOol0
00Uoo`04001oogoo0004Ool00`00Oomoo`03Ool100000003001oogoo00Aoo`03001oogoo00ioo`03
001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo009oo`03001oo`0001=oo`03
001oogoo00Eoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00moo`04
001oogoo000=Ool20008Ool00`00Oomoo`07Ool00`00Oomoo`07Ool01000Oomoogoo0P000Woo00<0
07ooOol01goo00<007ooOol00goo00<007ooOol00goo00<007ooOol017oo00<007ooOol00Woo00<0
07ooOol02goo00<007ooOol00goo00<007ooOol02goo00<007ooOol037oo00P007ooOol007oo001o
o`002Goo00<007ooOol00goo0@0000000`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`02Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool01000Ool007oo0P000goo0P0000Aoo`00Ool000=oo`03001o
ogoo00Ioo`04001oogoo0009Ool20002Ool01000Oomoogoo0P000goo1@0000Eoo`00001oo`00009o
o`8000Moo`03001oo`0000Qoo`8000=oo`05001oo`00Ool0000:Ool00`00Ool00003Ool00`00Oomo
o`03Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Ool0000=Ool00`00Ool00003Ool00`00Oomo
o`05Ool00`00Oomoo`03Ool20004Ool01@00Oomoogoo000037oo00@007ooOol0009oo`<00003Ool0
000000Yoo`04001oogoo0008Ool00`00Oomoo`03Ool01000Oomoo`0017oo0P001Goo0P000Goo0@00
00000`00Ool00002Ool00`00Oomoo`020003Ool00`00Ool00008Ool00`00Ool00003Ool01@00Ool0
07oo00001Goo00H007ooOomoo`00Ool20002Ool00`00Oomoo`09Ool00`00Oomoo`04Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool30009Ool00`00Oomoo`02Ool01000Oomoo`001Goo00<007ooOol00goo
00<007ooOol00Woo00@007oo001oo`8000Eoo`03001oogoo00Aoo`03001oogoo00=oo`80009oo`80
00Ioo`03001oogoo00Qoo`8000Aoo`8000Qoo`8000Eoo`03001oo`0000=oo`8000Eoo`03001oogoo
00Qoo`8000Eoo`8000=oo`03001oogoo00eoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Moo`800005Ool007ooOol00003Ool1
00000003001oogoo00Eoo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo
00Aoo`03001oogoo008000]oo`07001oogooOol007oo00000Woo00@007oo0000009oo`03001oogoo
00Aoo`8000Ioo`03001oogoo009oo`03001oogoo00Aoo`06001oogoo001oo`002Woo00<007oo0000
0goo0P001Goo00<007oo00000P000goo00D007ooOomoo`0000Moo`03001oogoo00=oo`05001oogoo
001oo`020005Ool01@00Oomoogoo00003Woo0P002Goo00@007ooOol000Ioo`8000=oo`03001oogoo
00=oo`04001oogoo000=Ool20005Ool01@00Oomoogoo00000goo00<007ooOol01Goo00@007ooOol0
00=oo`03001oogoo00Eoo`04001oogooOol20003Ool00`00Oomoo`02Ool20003Ool100000003001o
ogoo00=oo`04001oogoo0003Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00
Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`001goo0`0000=oo`00Ool00goo
00<007ooOol02Woo00<007ooOol057oo00<007oo00000Woo00<007ooOol00goo00<007ooOol01Goo
00<007ooOol04Goo0P0017oo00<007ooOol017oo00<007ooOol02Goo00<007ooOol05Woo00@007oo
000001]oo`03001oo`00009oo`03001oogoo01Ioo`03001oogoo00Ioo`40000000@007ooOol0009o
o`05001oogooOol00003Ool00`00Oomoo`06Ool00`00Ool00002Ool00`00Oomoo`020005Ool00`00
Oomoo`0<Ool00`00Oomoo`09Ool01000Ool007oo1@005Goo00<007ooOol017oo00<007ooOol01Woo
00<007oo000017oo00<007ooOol00Woo00<007ooOol027oo00D007oo001oo`0000=oo`04001oogoo
Ool20009Ool00`00Oomoo`05Ool01`00Oomoogoo001oo`00009oo`03001oogoo00Ioo`04001oogoo
Ool20005Ool01000Ool000000goo00<007ooOol01goo00<007oo00001Woo00<007ooOol017oo0`00
2goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol00goo00<007ooOol017oo00<007oo0000
0goo00H007ooOomoo`00Ool200000goo001oo`03Ool100000003001oogoo00Moo`03001oogoo00=o
o`8000Eoo`03001oogoo009oo`800004Ool007oo0004Ool4000JOol30003Ool20003Ool40003Ool0
0`00Oomoo`0200001Goo001oogoo000027oo00<007ooOol00Woo00<007ooOol01goo00<007oo0000
17oo0`001Woo00D007ooOomoo`0000Qoo`03001oogoo00Aoo`03001oogoo00Qoo`800003Ool007oo
00Aoo`04001oogoo0004Ool01000Oomoogoo0P000Woo00<007oo00000goo00<007ooOol027oo00<0
07oo00000Woo00<007ooOol01Woo00<007ooOol01goo00D007ooOomoo`0000=oo`03001oogoo00Mo
o`03001oogoo00Qoo`8000aoo`800003Ool007oo00Moo`40000000D007ooOomoo`00011oo`07001o
ogooOol007oo00001goo00<007ooOol00goo00<007ooOol01Goo00L007ooOomoo`00Ool0000>Ool0
0`00Oomoo`02Ool00`00Ool00006Ool00`00Oomoo`05Ool00`00Oomoo`0=Ool00`00Oomoo`05Ool0
0`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`08Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`0BOol00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`04Ool01P00Ool00000Ool000=oo`03001oogoo00Yoo`03001oogoo00ioo`05
001oogooOol00006Ool01@00Oomoogoo000017oo00<007ooOol01goo00H007oo001oo`00Ool10000
0003001oogoo00Aoo`03001oogoo00Eoo`03001oo`00009oo`03001oo`0000Eoo`03001oogoo00Eo
o`04001oogooOol20003Ool00`00Oomoo`03Ool01@00Oomoogoo00001Woo00<007oo00000Woo00D0
07ooOomoo`0000Eoo`03001oo`0000Ioo`03001oogoo009oo`03001oogoo00Eoo`03001oo`00009o
o`03001oo`0000Qoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oo`0000Moo`04001oogoo000:
Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool20006Ool300001Woo001oo`00Ool0019oo`04001oogoo
0006Ool00`00Oomoo`08Ool20006Ool01000Oomoo`000goo00<007oo00003Woo0`000Woo00<007oo
Ool00goo0P0000=oo`00Ool01Goo00<007ooOol00@0000000`00Ool0000<Ool00`00Oomoo`03Ool0
1000Oomoo`000Woo00<007ooOol00goo00@007ooOomoo`80009oo`05001oo`00Ool00002Ool00`00
Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`040005Ool01@00Oomoogoo00002Goo0P0027oo00<0
07ooOol03goo00<007ooOol03Woo00<007oo00001Woo00<007ooOol017oo0P0037oo00<007ooOol0
0goo00<007ooOol01goo0`0017oo00<007ooOol01Woo00@007oo000000Moo`03001oogoo009oo`06
001oogoo001oo`002Goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`03001oogoo009oo`03001o
ogoo00]oo`06001oogoo001oo`000Woo00<007ooOol01Woo0@0000000`00Oomoo`0;Ool00`00Oomo
o`0:Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool01@00Oomoogoo00001Woo00<007ooOol037oo0P00
00=oo`00Ool047oo00@007oo0000009oo`03001oogoo009oo`03001oogoo01Aoo`03001oogoo011o
o`07001oogooOol007oo00007Goo00<007ooOol00goo00<007ooOol027oo00<007ooOol06Goo00<0
07ooOol00Woo00<007ooOol03goo00<007ooOol00P0027oo00<007ooOol00goo00<007ooOol03Goo
0@0000000`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`09Ool2000017oo000000001Woo00<007oo000027oo00<007ooOol0
1goo00<007ooOol00Woo00<007ooOol057oo00L007ooOomoo`00Ool0000:Ool00`00Oomoo`08Ool0
0`00Oomoo`06Ool01000Oomoo`001Woo00D007oo001oo`0000aoo`800003Ool007oo00=oo`8000io
o`8000Ioo`03001oogoo011oo`03001oogoo01]oo`07001oogooOol007oo00000goo00<007ooOol0
3Woo0@0000000`00Oomoo`020008Ool00`00Oomoo`0;Ool00`00Ool00002Ool01@00Oomoogoo0000
2goo00<007ooOol00P0000=oo`0000000Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol0
0Woo00<007ooOol00Woo00<007ooOol01Goo0P0027oo00@007ooOol000=oo`07001oo`00Ool007oo
00001Woo00<007ooOol00Woo00<007oo000017oo00<007ooOol017oo0P000Woo00<007ooOol00goo
00<007ooOol03goo00<007ooOol017oo00<007ooOol00Woo00<007oo00001Woo0P0027oo00D007oo
001oo`00009oo`05001oo`00Ool00009Ool00`00Oomoo`07Ool01000Oomoo`000Woo00<007ooOol0
0goo00<007ooOol00goo00D007ooOomoo`0000=oo`03001oogoo00Uoo`03001oogoo00Eoo`05001o
ogooOol00007Ool10001Ool100000003001oogoo00]oo`03001oogoo00Ioo`04001oogoo0003Ool0
0`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`0IOol00`00Oomoo`03Ool00`00Oomoo`05Ool0
0`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`0?Ool00`00Oomoo`04Ool0
1`00Oomoogoo001oo`0000Qoo`03001oogoo00Aoo`03001oogoo00=oo`05001oo`00Ool00008Ool0
0`00Oomoo`0KOol00`00Oomoo`07Ool00`00Oomoo`0>Ool00`00Oomoo`0@Ool01000Oomoo`002Woo
00<007ooOol00goo00<007ooOol00@0000000`00Oomoo`06Ool00`00Oomoo`0@Ool00`00Oomoo`03
Ool00`00Oomoo`09Ool00`00Oomoo`0=Ool20004Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00
Oomoo`0:Ool01000Oomoo`0047oo00<007ooOol02goo0P0027oo00<007oo00000goo00@007ooOol0
009oo`03001oo`0000Ioo`03001oogoo00aoo`03001oo`00009oo`03001oogoo00]oo`03001oogoo
00=oo`03001oogoo00Moo`8000Moo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo008001Ao
o`03001oogoo00Uoo`03001oogoo009oo`03001oogoo00=oo`40005oo`40000000@007oo000000Ao
o`04001oogoo0009Ool00`00Oomoo`07Ool00`00Ool00005Ool00`00Oomoo`02Ool00`00Oomoo`05
Ool00`00Oomoo`09Ool00`00Ool00009Ool01@00Oomoogoo00002Goo00<007oo00001Goo0P001Woo
00<007oo00000goo0P0000=oo`00Ool037oo00<007ooOol01Goo00D007ooOomoo`0000Ioo`@000=o
o`03001oogoo00Eoo`03001oogoo009oo`03001oogoo0080011oo`03001oogoo015oo`03001oogoo
009oo`04001oogoo000?Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool200000goo001oo`08Ool00`00
Oomoo`03Ool01@00Oomoogoo00000goo0P001Goo0@0000000`00Oomoo`07Ool01000Oomoo`0027oo
00<007ooOol00Woo00<007ooOol02Goo00<007ooOol00goo0P0037oo00<007ooOol0<7oo00@007oo
Ool000=oo`03001oogoo011oo`03001oogoo00Ioo`05001oogooOol00006Ool00`00Oomoo`0>Ool0
0`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`07Ool2000AOol00`00Oomoo`08Ool00`00Oomo
o`04Ool00`00Oomoo`03Ool00`00Oomoo`0AOol2000;Ool00`00Oomoo`04Ool100000005001oogoo
Ool00005Ool30004Ool00`00Oomoo`07Ool00`00Oomoo`03Ool01000Oomoo`001goo00<007ooOol0
2Goo0P001Goo00<007ooOol03goo0P000Woo00<007oo00000`002goo00@007ooOol000=oo`8000Io
o`04001oo`00Ool20004Ool00`00Oomoo`0GOol00`00Oomoo`06Ool00`00Oomoo`020006Ool00`00
Ool00002Ool00`00Ool00003Ool01000Oomoo`000Woo0P0000Moo`00001oo`00Ool00002Ool00`00
Oomoo`02Ool01`00Oomoogoo001oo`00009oo`80021oo`03001oogoo00Uoo`05001oogooOol00005
Ool00`00Oomoo`03Ool01000Oomoogoo0P0017oo0@0000000`00Oomoo`04Ool00`00Oomoo`07Ool0
1000Oomoo`001Goo00@007ooOol0009oo`03001oo`0000Qoo`04001oogooOol20007Ool01000Oomo
o`002Goo00D007ooOomoo`0000moo`04001oogoo0002Ool00`00Ool00008Ool00`00Oomoo`07Ool0
0`00Oomoo`05Ool20004Ool01000Oomoo`000goo0`002Goo00<007ooOol00Woo00<007ooOol02Woo
00<007ooOol03Woo00<007ooOol03Goo00<007oo00000Woo0P0017oo00<007ooOol00Woo00@007oo
Oomoo`8000Qoo`04001oogoo0002Ool00`00Oomoo`08Ool01000Oomoo`0017oo0P000Woo00D007oo
001oo`00009oo`03001oogoo00Yoo`04001oogooOol20002Ool100000003001oogoo01Aoo`03001o
ogoo00=oo`03001oo`0000Ioo`03001oogoo00Yoo`<0009oo`03001oogoo00Moo`03001oogoo009o
o`03001oogoo00Yoo`03001oo`00011oo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Io
o`03001oogoo01ioo`05001oogooOol00007Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00Oomo
o`04Ool2000:Ool01@00Oomoogoo00003goo00<007ooOol01goo00<007ooOol01goo00<007ooOol0
3Woo0@0000000`00Oomoo`02Ool00`00Oomoo`0200000goo001oo`05Ool00`00Oomoo`02Ool2000B
Ool01000Oomoo`001Woo00<007ooOol01Woo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo
00Uoo`03001oogoo009oo`04001oogoo0006Ool01000Oomoo`0017oo0P003Goo00P007oo000007oo
001oo`000Woo00<007ooOol037oo00<007oo000017oo00<007oo00002Goo00@007ooOol000Aoo`03
001oogoo00Yoo`03001oogoo00=oo`8000Eoo`03001oo`0000Uoo`8000Eoo`03001oogoo009oo`03
001oogoo00Aoo`800003Ool007oo00=oo`80009oo`8000Uoo`8000]oo`03001oogoo00Aoo`03001o
ogoo009oo`40000000@007ooOol000=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Io
o`03001oogoo00moo`05001oogooOol00004Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Ool0
0002Ool2000017oo001oo`003Goo00@007ooOol000Aoo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00=oo`03001oogoo00Moo`03001oogoo01Uoo`03001oogoo008000Uoo`05001oogooOol0
000;Ool00`00Ool00004Ool01@00Oomoo`00Ool00P0017oo00@007ooOol000=oo`05001oo`00Ool0
0005Ool00`00Ool00002Ool00`00Oomoo`08Ool2000;Ool00`00Oomoo`04Ool2000<Ool100000003
001oogoo00Eoo`03001oogoo00Eoo`04001oogoo000;Ool00`00Oomoo`0COol00`00Oomoo`0?Ool0
0`00Oomoo`06Ool01000Oomoo`0057oo00<007ooOol01goo00<007ooOol057oo0P0017oo00<007oo
Ool017oo00D007ooOomoo`0000Moo`03001oogoo009oo`03001oogoo00=oo`03001oogoo01Ioo`03
001oogoo00Eoo`03001oogoo00]oo`03001oogoo00Uoo`03001oogoo00eoo`03001oogoo00Eoo`03
001oogoo00=oo`03001oogoo00]oo`04001oogoo0007Ool100000003001oogoo00eoo`03001oo`00
00Ioo`04001oo`000008Ool3000BOol00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
1000Oomoo`000Woo00<007ooOol017oo00@007ooOol0011oo`03001oogoo00Ioo`05001oo`00Ool0
0009Ool01@00Ool007oo000047oo00<007ooOol027oo0P0000=oo`00Ool027oo00@007ooOol000Eo
o`05001oogooOol00002Ool01@00Oomoogoo00004Woo00<007ooOol03goo00<007ooOol017oo0`00
1Goo00@007ooOol000Ioo`03001oo`0000Uoo`<000Aoo`03001oo`0000=oo`40000000D007oo001o
o`0000Eoo`03001oogoo00=oo`05001oogooOol0000>Ool00`00Ool00006Ool00`00Oomoo`04Ool0
0`00Oomoo`0;Ool00`00Ool00005Ool01000Oomoogoo0P003Goo00<007ooOol027oo00<007ooOol0
37oo00<007ooOol01Goo00<007ooOol02goo00<007ooOol00P002Woo00<007ooOol01Goo00@007oo
000000=oo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo009oo`03001oogoo00=oo`8000Qo
o`05001oogooOol0000>Ool01P00Oomoogoo001oo`8000Eoo`03001oogoo00Ioo`03001oogoo00Uo
o`03001oogoo00Eoo`03001oogoo00Eoo`40000000<007ooOol047oo00<007ooOol00Woo0P0000=o
o`00Ool04Woo00<007ooOol037oo0P0017oo0P004Goo00D007ooOomoo`0000Ioo`03001oogoo00=o
o`03001oogoo00Aoo`03001oo`00009oo`03001oogoo00moo`03001oogoo00ioo`03001oogoo00=o
o`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00ioo`03001oogoo02Qoo`03001oogoo01=o
o`03001oogoo00]oo`03001oogoo009oo`40000000<007ooOol01Woo00<007oo00000goo00@007oo
Ool000Uoo`<00003Ool007oo01eoo`03001oogoo019oo`03001oogoo009oo`03001oogoo00Ioo`80
01Eoo`@000Moo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo00eoo`80
0003Ool007oo00=oo`03001oo`0000moo`03001oogoo00Yoo`<000Aoo`<0019oo`03001oogoo009o
o`03001oogoo01Eoo`03001oogoo01Aoo`40000000<007ooOol02Goo0`002Goo00<007oo00000goo
0P000goo00D007ooOomoo`0000=oo`04001oogoo0007Ool01P00Oomoo`00Ool000]oo`03001oogoo
00=oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Aoo`8000Yoo`03
001oogoo00Moo`03001oogoo00@000Aoo`03001oogoo00moo`03001oogoo00Ioo`03001oogoo00Ao
o`05001oogooOol0000;Ool01`00Oomoogoo001oo`0000=oo`800003Ool0000000Qoo`8001Aoo`80
00]oo`8000]oo`03001oogoo00Uoo`03001oo`00009oo`03001oogoo00]oo`40000000<007ooOol0
1Goo00D007ooOomoo`0000Aoo`03001oogoo008000Eoo`03001oogoo00=oo`03001oogoo01aoo`03
001oogoo00Moo`03001oogoo00aoo`04001oogoo0002Ool01000Ool000003goo00<007ooOol027oo
00<007ooOol027oo00<007ooOol017oo00@007oo000001eoo`05001oo`00Ool00004Ool00`00Oomo
o`0;Ool00`00Oomoo`05Ool00`00Ool00002Ool01@00Oomoogoo00002Woo0P000goo00@007ooOol0
009oo`8000Yoo`8000Aoo`05001oogooOol0000=Ool00`00Ool0000:Ool100000003001oo`00011o
o`03001oogoo00Ioo`03001oogoo00ioo`03001oogoo01Qoo`03001oogoo021oo`03001oogoo00Ao
o`03001oogoo01eoo`03001oo`0000Ioo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo01Ao
o`05001oogooOol0000@Ool00`00Ool00005Ool00`00Oomoo`06Ool01000Oomoo`001goo00<007oo
Ool08Woo00<007oo000017oo0@0000000`00Oomoo`07Ool00`00Oomoo`05Ool01@00Oomoogoo0000
17oo0P001Goo00<007ooOol01Woo00<007ooOol00Woo00D007ooOomoo`00009oo`03001oogoo00Ao
o`03001oogoo00=oo`06001oogoo001oo`000Woo0P0000=oo`00Ool00goo00<007oo00002Goo00<0
07ooOol01goo00<007oo00000Woo00@007ooOol0009oo`8000Yoo`05001oogooOol00002Ool01000
Oomoo`001goo00D007ooOomoo`00009oo`03001oo`0000Moo`03001oogoo00Uoo`800003Ool007oo
00=oo`03001oogoo00=oo`03001oogoo00=oo`06001oo`00001oo`001Woo00<007ooOol01goo00@0
07ooOol000eoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00=oo`03001oogoo009oo`03
001oogoo00Aoo`05001oogooOol00003Ool100000003001oogoo009oo`8000Aoo`04001oogooOol2
0007Ool01@00Ool007oo00001Goo00@007ooOol000Ioo`05001oogooOol0000BOol01P00Oomoo`00
Ool000Yoo`03001oo`00009oo`80009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo
Ool01Goo00D007ooOomoo`0000=oo`03001oogoo00Yoo`03001oogoo00Moo`03001oo`0000Ioo`05
001oogooOol0000<Ool00`00Oomoo`06Ool01000Oomoo`003goo0P002Woo0P001Goo00<007ooOol0
4Woo00<007ooOol00Woo00<007ooOol027oo0P000goo00D007ooOomoo`0000Ioo`03001oo`0000=o
o`04001oogoo0007Ool100000003001oo`0000Aoo`03001oogoo00=oo`03001oogoo015oo`03001o
ogoo00]oo`03001oo`0000Yoo`03001oogoo01Qoo`03001oogoo01aoo`03001oogoo00Eoo`03001o
ogoo00=oo`03001oogoo00Yoo`05001oogooOol0000MOol00`00Oomoo`09Ool00`00Ool00007Ool0
0`00Oomoo`05Ool00`00Ool00004Ool00`00Oomoo`0AOol01@00Ool007oo000017oo00<007ooOol0
3Goo00<007ooOol017oo00<007ooOol00goo00<007ooOol02Woo0@0000000`00Ool000020002Ool0
0`00Ool0000<Ool00`00Oomoo`04Ool01000Oomoo`0017oo00<007oo00001Woo00<007ooOol00Woo
00L007ooOomoo`00Ool00007Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00
Oomoo`03Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`0000ioo`04001oogoo0004Ool00`00Oomo
o`03Ool00`00Ool00002Ool00`00Oomoo`02Ool00`00Oomoo`08Ool01@00Oomoogoo00001Woo00<0
07ooOol01Goo00<007ooOol027oo0P0017oo0P0037oo00<007oo00001Goo0`003goo00@007ooOol0
009oo`05001oogooOol00004Ool00`00Oomoo`08Ool00`00Oomoo`04Ool01@00Oomoogoo00001Woo
0`000Woo0@0000000`00Oomoo`02Ool20003Ool00`00Ool00002Ool00`00Oomoo`0QOol00`00Oomo
o`0<Ool2000EOol01000Oomoo`000Woo00L007ooOomoo`00Ool00008Ool00`00Oomoo`08Ool00`00
Oomoo`09Ool00`00Oomoo`08Ool01P00Ool007oo001oo`8000aoo`04001oogooOol2000;Ool00`00
Oomoo`03000;Ool20003Ool01P00Oomoo`00Ool000Uoo`03001oogoo00Qoo`8000Moo`05001oogoo
Ool00006Ool01000Oomoo`0017oo00<007ooOol00goo00<007ooOol00goo0`002Goo00H007ooOomo
o`00Ool100000003001oogoo00]oo`03001oogoo01Eoo`03001oogoo00Uoo`03001oogoo00Eoo`04
001oogooOol2000HOol00`00Oomoo`02000@Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomo
o`0<Ool00`00Oomoo`0:Ool2000;Ool00`00Oomoo`08Ool01000Oomoo`0027oo00<007oo00001Goo
00<007ooOol02Goo00<007ooOol057oo00<007ooOol03Goo00<007oo00008goo0@0000001@00Oomo
ogoo00001Woo0P001Woo00<007ooOol037oo00<007oo00001goo00<007ooOol00goo00D007oo0000
07oo00800003Ool007oo00Qoo`800003Ool007oo00Yoo`8001Moo`03001oo`0000=oo`03001oogoo
00ioo`03001oogoo00Aoo`80009oo`05001oo`00Ool0000BOol00`00Oomoo`09Ool00`00Oomoo`04
Ool00`00Oomoo`0<Ool00`00Oomoo`0POol00`00Oomoo`03Ool00`00Oomoo`0EOol01P00Oomoo`00
Ool000Ioo`03001oogoo00Eoo`80005oo`40000000<007oo00002Goo00<007oo00000Woo00L007oo
001oo`00Ool0000<Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol017oo00D007ooOomo
o`00009oo`03001oogoo00eoo`03001oogoo009oo`8000moo`07001oogooOol007oo00004Woo00<0
07ooOol00Woo00<007ooOol01Goo0P0027oo00<007ooOol017oo0P0047oo00@007ooOol000Aoo`03
001oogoo00Aoo`04001oogoo0003Ool01000Oomoo`000Woo0`004Woo00@007ooOomoo`800004Ool0
07ooOol20002Ool00`00Ool00003Ool01P00Oomoogoo001oo`800003Ool007oo00Eoo`03001oogoo
00Moo`07001oogooOol007oo00000goo00<007ooOol01Goo0@0000001000Oomoo`004Woo00<007oo
Ool01Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol05Woo00<007oo
Ool00Woo00@007ooOol000=oo`03001oogoo00eoo`03001oogoo019oo`03001oogoo00Qoo`03001o
ogoo009oo`<001ioo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00Eoo`04001oogoo000D
Ool2000<Ool20004Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`08Ool100000003001o
ogoo00=oo`03001oogoo009oo`04001oogooOol20003Ool00`00Oomoo`03Ool00`00Oomoo`02Ool0
0`00Ool00004Ool00`00Oomoo`09Ool01@00Oomoogoo00001goo00<007ooOol00P001Woo00<007oo
Ool01Woo00<007ooOol027oo00<007oo00000Woo00<007ooOol00goo00@007ooOol000Moo`04001o
ogoo0007Ool20003Ool01000Oomoo`0057oo00<007ooOol027oo00<007ooOol01Goo00D007ooOomo
o`0000Aoo`03001oogoo00=oo`03001oogoo008000Aoo`05001oogooOol00002Ool2000<Ool2000=
Ool00`00Oomoo`08Ool00`00Oomoo`02Ool01000Oomoo`001Woo00<007oo00002Woo00<007ooOol0
0goo00@007oo000000Aoo`40000000<007ooOol00`0067oo00<007ooOol02Woo0P0017oo00<007oo
Ool017oo00<007ooOol02goo00<007ooOol04Goo00<007oo00000goo0P0017oo00D007oo001oo`00
00Eoo`03001oogoo008000Aoo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Qoo`03001o
ogoo00aoo`03001oogoo00Yoo`03001oogoo00=oo`8000Moo`07001oogooOol007oo00000goo00<0
07ooOol027oo00@007oo0000019oo`03001oogoo009oo`03001oogoo00Aoo`8000Aoo`04001oogoo
0002Ool00`00Oomoo`04Ool20008Ool00`00Oomoo`0:Ool100000003001oogoo009oo`03001oogoo
01Ioo`03001oogoo009oo`03001oogoo01Ioo`03001oogoo00Uoo`05001oogooOol0000POol01@00
Oomoogoo000017oo00D007ooOomoo`00019oo`03001oogoo00Aoo`03001oogoo00eoo`04001oogoo
0003Ool00`00Oomoo`0ROol00`00Oomoo`04Ool00`00Oomoo`0COol00`00Oomoo`07Ool00`00Oomo
o`0@Ool2000COol100000003001oogoo00Aoo`8000moo`8000=oo`04001oogoo000<Ool00`00Oomo
o`02Ool01@00Ool007oo00002Woo00<007ooOol017oo0P000goo00@007ooOol000aoo`80009oo`04
001oogoo0003Ool00`00Oomoo`09Ool00`00Oomoo`03Ool30007Ool00`00Ool00007Ool00`00Oomo
o`04Ool00`00Oomoo`02000;Ool00`00Ool00003Ool2000BOol01`00Oomoogoo001oo`0000=oo`80
0005Ool00000Ool00006Ool01000Oomoo`0017oo00<007ooOol017oo00<007oo000017oo00<007oo
Ool01goo00<007ooOol01Goo00@007ooOomoo`<00003Ool00000015oo`06001oogooOol007oo0@00
00000`00Oomoo`06Ool01@00Oomoogoo00001Goo00@007ooOomoo`<000Aoo`05001oogoo001oo`02
000<Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01000Oomoo`0017oo0P002Woo0P0047oo0P001Goo
00<007ooOol00Woo0P0027oo00D007ooOomoo`0001Qoo`05001oo`00Ool00002Ool00`00Oomoo`0:
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool2000>Ool00`00Oomoo`06Ool00`00Oomoo`08Ool20000
0goo001oo`08Ool00`00Oomoo`0COol00`00Ool00002Ool00`00Oomoo`05Ool00`00Oomoo`0?Ool0
0`00Oomoo`0100000003001oo`0001Moo`03001oogoo00Qoo`03001oogoo00Ioo`05001oogooOol0
000=Ool2000jOol00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`0AOol00`00Oomoo`05Ool0
0`00Oomoo`02Ool01000Oomoo`004Goo00D007ooOomoo`0002eoo`03001oogoo00Aoo`03001oogoo
00Qoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00Aoo`40000000<0
07ooOol01goo00<007ooOol00goo00<007oo00000P0000=oo`00Ool027oo00@007ooOol000=oo`03
001oogoo00=oo`03001oogoo00aoo`04001oogoo0002Ool01@00Ool007oo00001Goo00<007oo0000
0P002Woo00@007oo000000Aoo`8000ioo`03001oo`0000Uoo`03001oo`0000=oo`03001oogoo00Mo
o`03001oogoo00Eoo`05001oogooOol0000DOol00`00Oomoo`05Ool00`00Ool00009Ool00`00Oomo
o`02Ool00`00Oomoo`08Ool20009Ool01@00Ool007oo00001Goo00<007ooOol00goo00D007ooOomo
o`0000ioo`03001oogoo00moo`800003Ool007oo00=oo`03001oogoo0040000000<007ooOol01goo
00<007ooOol017oo00<007ooOol00Woo00@007ooOol000Yoo`03001oogoo00Qoo`03001oo`0000Mo
o`03001oogoo00Yoo`03001oogoo00aoo`800003Ool007oo009oo`04001oogoo0009Ool01000Oomo
o`0027oo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000aoo`03001oogoo00Eoo`03
001oogoo00Ioo`03001oogoo00=oo`03001oogoo00=oo`03001oo`0000Aoo`05001oogooOol00005
Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000Woo00<007ooOol0
0Woo00D007ooOomoo`00009oo`04001oo`00Ool20007Ool01000Ool0000037oo00<007ooOol02Woo
0`0000=oo`00Ool02goo0@0000000`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`0EOol00`00
Ool00004Ool00`00Oomoo`03Ool00`00Oomoo`05Ool01000Oomoo`0067oo00@007ooOol000Aoo`03
001oogoo00Eoo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00moo`03001oogoo01]oo`80
00Moo`03001oogoo01aoo`03001oogoo00Uoo`03001oogoo01Qoo`03001oogoo00aoo`03001oo`00
015oo`40000000<007ooOol00Woo0P000Woo00<007ooOol017oo00<007ooOol0:Goo00<007ooOol0
1Goo0`001goo00@007ooOol000]oo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo00ioo`04
001oo`00000;Ool20002Ool00`00Oomoo`06Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo0P00
0Woo00<007ooOol017oo00D007ooOomoo`0001=oo`03001oogoo00Uoo`8000Moo`07001oogooOol0
07oo00001goo00<007ooOol00goo00<007ooOol02Goo0`0000=oo`00Ool00goo00<007ooOol00goo
0P001Goo00D007ooOomoo`0000=oo`40000000H007ooOol007oo0008Ool00`00Oomoo`09Ool00`00
Oomoo`0AOol01`00Ool007oo001oo`0000Aoo`07001oogooOol007oo00003Goo0P0027oo00@007oo
Ool000=oo`03001oogoo019oo`03001oogoo00aoo`06001oogoo001oo`000goo00<007ooOol02Goo
00<007ooOol02goo00<007ooOol00Woo00<007ooOol00Woo00H007ooOol007oo0008Ool01`00Oomo
ogoo001oo`00009oo`03001oogoo009oo`03001oogoo00Aoo`8000Ioo`04001oogoo0003Ool00`00
Oomoo`0DOol00`00Oomoo`03Ool2000<Ool00`00Oomoo`04Ool00`00Oomoo`09Ool100000003001o
ogoo02Qoo`04001oogooOol200000goo001oo`0YOol00`00Oomoo`09Ool00`00Oomoo`0=Ool00`00
Oomoo`0OOol2000:Ool00`00Oomoo`0;Ool00`00Oomoo`0COol01@00Ool007oo00007Goo00<007oo
Ool00goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol017oo00D007ooOomoo`0000moo`40
005oo`40000000<007ooOol03goo0P0000=oo`00Ool02Woo00<007ooOol00Woo00D007ooOomoo`00
00Ioo`03001oo`0000Qoo`03001oogoo00Qoo`03001oo`0000Aoo`04001oo`000002Ool01000Oomo
ogoo0P0017oo00<007oo00002Goo00<007ooOol03Goo00<007oo00002Goo00@007ooOomoo`<000mo
o`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00Uoo`04001oogoo000;Ool00`00Oomoo`0=
Ool01000Oomoo`0027oo0P0017oo00D007ooOomoo`0000Eoo`05001oogooOol0000<Ool01000Oomo
o`001Goo00D007ooOomoo`0000=oo`800004Ool007oo0002Ool20003Ool100000003001oogoo00=o
o`03001oo`0000Aoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo009oo`03001oogoo015o
o`03001oogoo00=oo`8000Aoo`03001oogoo00Eoo`03001oogoo011oo`05001oo`00Ool00008Ool0
0`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`03Ool20006Ool00`00Oomoo`07Ool00`00Oomo
o`06Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool01P00Oomoo`00Ool000=oo`80009oo`03001oogoo
00aoo`05001oogooOol00007Ool00`00Oomoo`07Ool01000Oomoogoo0P003Woo00<007ooOol03Woo
00<007ooOol05Woo00<007ooOol00@0000000`00Oomoo`03Ool01000Ool000002Woo00<007oo0000
1Woo00D007oo001oo`0000Aoo`03001oogoo00Aoo`03001oogoo00=oo`04001oogoo0002Ool01@00
Oomoogoo00002Woo00D007ooOomoo`0000Qoo`03001oogoo00Aoo`<000Qoo`03001oogoo00Uoo`05
001oogooOol00008Ool00`00Oomoo`0OOol00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`02
Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool01000Oomoo`0017oo00@007ooOomoo`8000Moo`03001o
ogoo00Qoo`03001oogoo00=oo`<000Moo`03001oogoo00=oo`03001oo`0000eoo`04001oo`000002
Ool100000005001oogooOol0000COol2000JOol00`00Oomoo`05Ool00`00Oomoo`0=Ool00`00Oomo
o`0;Ool00`00Oomoo`0[Ool00`00Oomoo`0POol200001Goo001oogoo000037oo00D007ooOomoo`00
009oo`04001oogooOol2000WOol00`00Ool00003Ool00`00Oomoo`03Ool00`00Oomoo`0@Ool00`00
Oomoo`0;Ool100000004001oogoo000=Ool3000<Ool00`00Oomoo`0<Ool00`00Oomoo`0:Ool20007
Ool01000Ool0000027oo00<007ooOol00goo0P000Woo00@007oo000000=oo`8000=oo`03001oogoo
00Eoo`03001oo`0001Eoo`03001oogoo00=oo`8001=oo`07001oo`00Ool007oo00004Goo00<007oo
Ool01Goo00<007ooOol05goo00L007ooOomoo`00Ool00005Ool00`00Oomoo`02Ool00`00Oomoo`04
Ool00`00Oomoo`0:Ool00`00Oomoo`020003Ool01000Oomoo`001goo00<007ooOol00goo00D007oo
Ool007oo0040000000<007ooOol01Woo00<007ooOol00goo00<007oo00001Goo00@007ooOol000Yo
o`<000Aoo`03001oogoo00Aoo`03001oo`0000800004Ool007ooOol2000017oo001oo`0017oo00<0
07ooOol01Woo0P000Woo00@007ooOol000Ioo`80009oo`03001oogoo00=oo`03001oogoo009oo`03
001oogoo00Eoo`03001oogoo009oo`8000Moo`07001oogooOol007oo000017oo00<007ooOol00goo
1@000Woo0P002Goo00@007ooOomoo`<0009oo`03001oogoo009oo`03001oogoo00]oo`03001oogoo
009oo`03001oogoo00Ioo`04001oogoo0004Ool20005Ool00`00Oomoo`03Ool00`00Ool00005Ool0
0`00Oomoo`0300000goo00000004Ool20002Ool00`00Ool00003Ool01000Oomoogoo0P0017oo00<0
07oo00001Goo0P0027oo0@0000000`00Oomoo`0?Ool20002Ool00`00Oomoo`0COol00`00Ool00006
Ool00`00Oomoo`05Ool00`00Oomoo`0BOol00`00Oomoo`08Ool2000:Ool00`00Oomoo`05Ool00`00
Oomoo`0;Ool00`00Oomoo`0>Ool00`00Oomoo`06Ool01000Oomoo`005Woo00<007ooOol0=Woo00<0
07ooOol057oo00D007ooOomoo`0001Moo`40000000<007ooOol017oo00@007ooOol0009oo`03001o
ogoo009oo`04001oogoo000<Ool00`00Oomoo`04Ool01@00Oomoogoo000037oo00@007oo000000Io
o`04001oogoo000;Ool00`00Oomoo`0AOol01000Oomoo`000Woo00@007ooOol000Yoo`03001oo`00
00ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo01Eoo`03001oogoo00Eoo`04001oogoo
0004Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool01000Ool000000goo00<007oo00000Woo00<007oo
Ool03Goo0P002Woo00<007ooOol04goo0P001Woo0@0000001000Oomoo`000goo00<007ooOol01Goo
00<007ooOol00goo00<007ooOol01Woo00H007ooOol007oo0005Ool2000=Ool01@00Oomoogoo0000
0goo0P001goo00<007ooOol01goo00<007ooOol02Woo00<007ooOol00goo00H007oo000007oo000F
Ool00`00Oomoo`0:Ool20007Ool00`00Oomoo`0LOol01000Oomoo`000goo00<007ooOol01goo0P00
1Goo00<007ooOol017oo00D007ooOomoo`0000Qoo`8001=oo`04001oogooOol30002Ool00`00Ool0
0002Ool00`00Oomoo`02Ool00`00Oomoo`0AOol100000003001oogoo009oo`03001oogoo015oo`03
001oogoo02=oo`04001oogoo000DOol00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`07Ool00`00Ool00005Ool00`00Oomoo`0BOol00`00Ool0000=Ool00`00Oomoo`02Ool0
0`00Oomoo`0XOol00`00Oomoo`03Ool00`00Oomoo`0FOol00`00Oomoo`07Ool00`00Oomoo`0HOol0
0`00Ool00006Ool100000005001oogooOol00005Ool00`00Oomoo`030004Ool00`00Oomoo`02Ool2
0003Ool20002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01000Oomoo`001Goo
00@007ooOol000Moo`03001oo`0000Aoo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo00Mo
o`8001Aoo`05001oogooOol00004Ool01000Ool000000Woo00<007ooOol00goo00<007oo00001Goo
00@007oo000000Ioo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00<000Aoo`03001oogoo
00Eoo`03001oogoo00Qoo`80009oo`03001oogoo00=oo`03001oogoo00Ioo`06001oo`00001oo`00
27oo00D007ooOomoo`0000Ioo`03001oogoo00Ioo`05001oo`00Ool00004Ool01@00Ool007oo0000
1Goo00@007ooOol000=oo`03001oo`0000=oo`40000000<007oo000077oo0P000Woo00<007ooOol0
1Goo00L007ooOomoo`00Ool0000:Ool00`00Oomoo`02Ool01000Ool000001goo0P002goo0P0027oo
00<007ooOol00Woo00<007ooOol017oo0P0000Aoo`00Oomoo`80009oo`8000Ioo`05001oogooOol0
0003Ool00`00Oomoo`05Ool20002Ool01@00Oomoogoo00002Woo0P005Goo00<007oo000047oo0P00
1goo00D007ooOomoo`0000Uoo`03001oogoo00Eoo`03001oogoo00ioo`05001oogooOol00003Ool0
0`00Oomoo`03Ool00`00Oomoo`0:Ool20004Ool100000004001oogoo000UOol00`00Ool0000<Ool0
0`00Oomoo`02Ool00`00Oomoo`0EOol00`00Oomoo`0^Ool00`00Oomoo`0YOol00`00Oomoo`0YOol0
0`00Oomoo`0:Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool01000Oomoo`006Woo0@0000000`00Oomo
o`0;Ool00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`08Ool01@00Oomoogoo00002Woo0P00
37oo00D007oo001oo`0000aoo`04001oogoo0006Ool01P00Oomoogoo001oo`800003Ool0000001=o
o`8000Aoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00Moo`03001o
ogoo00=oo`03001oo`0000Qoo`05001oo`00Ool00008Ool00`00Oomoo`06Ool01@00Oomoogoo0000
17oo00<007oo000017oo00<007ooOol05goo00<007ooOol017oo00<007ooOol00goo00<007oo0000
0Woo00@007oo000000=oo`03001oogoo009oo`40000000D007ooOomoo`0000moo`03001oogoo00Mo
o`03001oogoo00=oo`03001oogoo00Moo`03001oo`0000Moo`80009oo`03001oogoo00Aoo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00Ioo`04001oogoo0006Ool200000goo001oo`05Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
1000Ool000001Goo00<007ooOol03goo00<007ooOol03Goo00<007ooOol01Goo00<007ooOol017oo
0`000Woo00@007ooOol000Yoo`03001oo`0000Aoo`03001oogoo00Qoo`800003Ool0000000moo`03
001oo`0000=oo`06001oogoo001oo`001Woo0P0000=oo`00Ool00P002Woo0@0000000`00Oomoo`0M
Ool00`00Oomoo`02Ool00`00Oomoo`0EOol00`00Oomoo`0=Ool01`00Oomoogoo001oo`0001ioo`03
001oogoo01eoo`04001oogooOol2000AOol00`00Oomoo`0<Ool00`00Oomoo`0EOol01000Oomoo`00
1Goo00<007ooOol02goo00<007ooOol01Woo00<007ooOol02Woo00H007ooOomoo`00Ool2000@Ool2
0008Ool100000003001oogoo00eoo`03001oogoo00Moo`03001oogoo00Moo`07001oo`00Ool007oo
000017oo00<007ooOol03goo00<007ooOol00goo00D007ooOomoo`0000Uoo`03001oogoo00Qoo`05
001oogooOol00006Ool00`00Ool00002Ool01@00Oomoogoo00001Woo00<007ooOol00goo00<007oo
Ool01Goo00<007ooOol00goo00<007oo00000P0000=oo`00Ool017oo00<007ooOol017oo00<007oo
Ool00Woo0P0017oo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo00Moo`05001oogooOol0
0007Ool00`00Oomoo`08Ool00`00Oomoo`030002Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool01000Oomoo`001Woo00<007ooOol00Woo00<007ooOol05Goo0@0000000`00Oomoo`0>
Ool00`00Oomoo`0SOol00`00Oomoo`02Ool01000Oomoo`001Goo00<007ooOol00Woo00@007ooOol0
009oo`03001oogoo00Ioo`<001Moo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Uoo`03
001oogoo00Moo`03001oogoo00]oo`03001oogoo00Eoo`03001oogoo00ioo`8000Aoo`03001oogoo
00Qoo`03001oogoo00moo`03001oo`0000Eoo`03001oogoo008000aoo`800004Ool007oo0002Ool0
1000Ool000003goo00<007ooOol00P0017oo00@007ooOomoo`40000000<007ooOol01Goo0P003goo
00<007ooOol04Goo00<007ooOol05goo00D007ooOomoo`0000Aoo`04001oogoo000@Ool00`00Oomo
o`0;Ool00`00Oomoo`0COol01@00Oomoogoo00000goo00<007ooOol017oo00<007ooOol02goo00<0
07ooOol00goo00<007ooOol03Goo00D007ooOomoo`00009oo`03001oogoo00eoo`8001ioo`03001o
ogoo009oo`03001oogoo00Qoo`03001oogoo00]oo`03001oogoo00=oo`8000Aoo`03001oogoo0040
000000H007ooOol007oo0006Ool2000017oo001oo`004goo00<007oo000027oo00@007ooOol0009o
o`03001oogoo0080009oo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo00Uoo`8000=oo`03
001oogoo00Eoo`03001oogoo00Moo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`09Ool0
1000Oomoo`001Woo00<007ooOol02Goo00<007ooOol04Goo00H007ooOol007oo0003Ool00`00Oomo
o`0;Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool01P00Oomoo`00Ool000Qoo`03001oo`0001]oo`03
001oogoo00Uoo`40000000<007oo000017oo00<007ooOol017oo00<007ooOol01goo00<007ooOol0
17oo0P001goo00<007oo000057oo00<007ooOol027oo00<007ooOol01goo00<007ooOol02goo00D0
07ooOomoo`0000Qoo`03001oo`00009oo`05001oogooOol00007Ool00`00Ool00005Ool200000goo
001oo`02Ool00`00Oomoo`05Ool01000Oomoogoo0`0027oo00<007ooOol00Woo00<007ooOol00Woo
0`0000=oo`00Ool01Goo0P0037oo00<007ooOol05Woo00<007oo00001Woo00L007ooOomoo`00Ool0
0003Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Ool00002Ool00`00Ool0000=Ool20005Ool1
00000003001oogoo00Moo`8001aoo`03001oogoo00Uoo`8004Moo`03001oogoo02Uoo`04001oogoo
000COol00`00Ool00002Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomo
o`05Ool00`00Oomoo`06Ool00`00Oomoo`0KOol00`00Oomoo`0=Ool100000003001oogoo00Moo`80
009oo`03001oogoo00Moo`03001oo`0000Moo`03001oo`00008000Uoo`03001oogoo00Uoo`03001o
ogoo00Aoo`03001oogoo00Aoo`8000Moo`03001oogoo00<001Aoo`03001oogoo00Moo`03001oogoo
011oo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Qoo`04001oogoo
0008Ool00`00Oomoo`02Ool00`00Oomoo`0COol00`00Oomoo`03Ool00`00Ool0000ZOol01000Oomo
o`0017oo00<007ooOol02goo0@0000001@00Oomoogoo00000Woo0`0000=oo`00Ool01goo00@007oo
Ool000Eoo`03001oogoo00Yoo`03001oogoo00Qoo`8000Moo`03001oogoo00Yoo`05001oogooOol0
0006Ool01000Oomoogoo0P0017oo00<007ooOol01Woo0P0000Eoo`00Oomoo`0000Ioo`05001oogoo
Ool00002Ool40003Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`05Ool00`00Oomoo`08
Ool00`00Oomoo`06Ool01@00Oomoogoo00002Goo00<007ooOol017oo00<007ooOol00Woo00<007oo
Ool01goo00<007ooOol00Woo00H007ooOomoo`00Ool20002Ool00`00Oomoo`02Ool00`00Ool00009
Ool00`00Oomoo`02Ool00`00Ool00009Ool00`00Oomoo`0AOol100000003001oogoo00Uoo`8000Mo
o`03001oogoo00ioo`04001oogooOol30003Ool00`00Oomoo`02Ool01@00Oomoogoo00001Woo00<0
07ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`0@
Ool00`00Oomoo`07Ool00`00Oomoo`020003Ool00`00Oomoo`06Ool2000IOol20002Ool3000017oo
001oo`002Goo0P0000=oo`00000017oo00D007ooOomoo`00009oo`8000=oo`03001oo`0000Aoo`03
001oogoo00Aoo`03001oo`0000Aoo`03001oogoo00Aoo`03001oogoo00aoo`D000Qoo`03001oogoo
00Ioo`04001oogoo000=Ool100000003001oogoo00Eoo`03001oogoo00]oo`800003Ool007oo00Mo
o`<001]oo`03001oogoo00Moo`05001oogooOol00006Ool00`00Oomoo`09Ool00`00Ool00007Ool0
0`00Oomoo`09Ool00`00Oomoo`04Ool01@00Oomoogoo00002Woo00<007ooOol01goo00<007ooOol0
47oo00<007ooOol03Woo00<007ooOol00Woo00<007ooOol02goo00<007ooOol02goo00D007ooOomo
o`0002Qoo`03001oogoo009oo`03001oogoo00ioo`40000000<007oo00004Woo0P000Woo00<007oo
00000Woo00<007ooOol01goo00@007ooOol000Qoo`03001oogoo00Eoo`03001oogoo00Uoo`04001o
ogoo000LOol00`00Ool00003Ool00`00Oomoo`03Ool01@00Oomoogoo00001Goo00<007oo00002goo
00<007ooOol02Goo0P0000Aoo`00Ool0015oo`05001oogooOol00004Ool00`00Oomoo`030002Ool0
0`00Oomoo`08Ool01`00Ool007oo001oo`0001=oo`04001oogoo0005Ool00`00Oomoo`0BOol2000:
Ool20003Ool01@00Oomoogoo000017oo0@000Goo0@0000000`00Oomoo`08Ool00`00Oomoo`06Ool0
0`00Oomoo`07Ool02000Oomoo`00Ool007oo0002Ool00`00Oomoo`04Ool01@00Ool007oo00002Woo
00@007ooOol000Aoo`03001oo`00009oo`04001oogoo0008Ool00`00Ool0000<Ool01000Ool00000
17oo00<007oo00001goo00@007ooOomoo`8000Qoo`03001oogoo00Aoo`8000Moo`03001oogoo00=o
o`03001oogoo00Uoo`03001oogoo00Ioo`04001oo`000002Ool00`00Oomoo`0JOol02000Oomoo`00
Ool007oo0008Ool00`00Oomoo`06Ool20007Ool00`00Oomoo`03Ool01@00Oomoogoo000027oo0P00
47oo00@007oo001oo`40000000<007oo00004Woo00D007ooOomoo`0001=oo`03001oogoo019oo`03
001oogoo00eoo`03001oogoo00]oo`03001oogoo00eoo`03001oogoo00Eoo`04001oogoo000BOol0
0`00Oomoo`0FOol00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0OOol00`00Oomoo`09Ool0
0`00Oomoo`08Ool01@00Oomoogoo000027oo00<007ooOol00Woo00<007ooOol037oo00<007ooOol0
0Woo0@0000000`00Ool00009Ool00`00Oomoo`09Ool02@00Oomoogoo001oo`00Ool00006Ool01000
Oomoo`000Woo0P0027oo00D007ooOomoo`0000=oo`03001oogoo011oo`03001oogoo00ioo`03001o
ogoo00eoo`03001oo`00009oo`03001oogoo00Aoo`03001oo`0000=oo`<000Uoo`03001oogoo019o
o`8000Eoo`05001oogooOol0000:Ool01000Oomoo`003Goo00@007ooOol0009oo`03001oogoo00<0
00Aoo`@0009oo`03001oogoo009oo`03001oogoo00=oo`03001oo`00008000Ioo`03001oogoo009o
o`04001oogoo0005Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Ool00004Ool100000003001o
ogoo00Ioo`8000Ioo`03001oogoo00Qoo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo009o
o`04001oogoo0002Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`04001oogoo0002Ool00`00
Oomoo`02Ool01000Oomoo`001goo00<007ooOol047oo00@007ooOol000Aoo`03001oogoo009oo`04
001oogoo000?Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`0017oo00@007ooOomoo`80
00Moo`05001oogooOol00002Ool01P00Oomoogoo001oo`8000Aoo`03001oo`0000Aoo`03001oogoo
009oo`03001oogoo01=oo`03001oo`0000=oo`07001oogooOol007oo00001Goo0P001Goo00<007oo
Ool017oo00@007ooOomoo`@000Uoo`40005oo`40000000@007ooOol000eoo`03001oogoo00Moo`03
001oo`00015oo`04001oogooOol20003Ool00`00Ool00006Ool00`00Oomoo`06Ool00`00Oomoo`0C
Ool00`00Oomoo`0GOol00`00Oomoo`0DOol00`00Oomoo`0?Ool00`00Oomoo`06Ool00`00Oomoo`0T
Ool00`00Oomoo`0>Ool00`00Oomoo`05Ool00`00Oomoo`0GOol2000DOol00`00Oomoo`0100000004
001oogooOol20002Ool01000Oomoo`0047oo00@007ooOol0009oo`03001oogoo009oo`8001Eoo`03
001oogoo00Moo`03001oogoo00Yoo`800005Ool007ooOol00005Ool00`00Oomoo`08Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00@007oo0000
00Yoo`04001oogoo000=Ool2000DOol2000;Ool00`00Ool00009Ool00`00Oomoo`0=Ool01000Oomo
o`001goo00<007ooOol02goo00<007ooOol00goo0P000Woo00<007ooOol027oo0P001Goo0@000000
0`00Ool00003Ool00`00Oomoo`0<Ool00`00Ool00003Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool0
0`00Oomoo`09Ool01000Ool000000Woo00@007ooOomoo`8000Aoo`03001oogoo00Aoo`03001oogoo
00Moo`03001oogoo00eoo`03001oogoo011oo`8000=oo`03001oogoo00Ioo`80015oo`03001oogoo
009oo`05001oogooOol00009Ool01000Oomoo`001Goo00<007oo00000Woo00L007ooOomoo`00Ool0
0002Ool20007Ool20002Ool01@00Oomoogoo00001goo00<007ooOol00goo00<007ooOol02Woo00<0
07ooOol06Goo00<007oo00000goo0@0000000`00Oomoo`0LOol2000GOol00`00Oomoo`0;Ool2000=
Ool00`00Oomoo`0<Ool2000>Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Ool00002Ool00`00
Oomoo`03Ool00`00Ool00006Ool00`00Oomoo`07Ool00`00Oomoo`09Ool01000Oomoo`007goo00<0
07ooOol027oo00<007ooOol00goo00<007ooOol01Goo00<007ooOol05goo00<007ooOol057oo0@00
00001000Oomoogoo100027oo00L007ooOomoo`00Ool0000:Ool00`00Oomoo`06Ool01@00Oomoogoo
00001goo00@007ooOol000aoo`03001oogoo015oo`03001oogoo00Eoo`03001oogoo009oo`03001o
o`0000<000Uoo`<00003Ool0000000moo`05001oogooOol00004Ool00`00Ool0000=Ool00`00Oomo
o`09Ool01000Oomoogoo0`004Woo00D007ooOomoo`00009oo`8000=oo`05001oo`00Ool00005Ool0
1@00Oomoogoo00000goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol017oo0P0017oo00<0
07ooOol00goo00D007ooOomoo`0000=oo`03001oogoo00Eoo`04001oogooOol100000004001oogoo
0003Ool01@00Oomoo`00Ool01@0000=oo`00Ool01Woo00<007oo00005Goo00@007ooOol000Eoo`03
001oogoo00Qoo`03001oogoo01Moo`03001oogoo009oo`8000Aoo`03001oogoo00Qoo`03001oogoo
00Uoo`03001oogoo00ioo`03001oogoo00800004Ool000000006Ool01`00Oomoogoo001oo`0000Io
o`03001oogoo00Moo`06001oogoo001oo`000Woo00<007ooOol01goo00<007ooOol017oo00@007oo
Ool0009oo`03001oogoo021oo`04001oogoo0005Ool00`00Ool00002Ool200000goo0000000<Ool0
0`00Oomoo`02Ool100000003001oogoo00]oo`04001oogooOol20007Ool00`00Oomoo`07Ool01P00
Oomoo`00Ool000Aoo`03001oo`0000Eoo`03001oogoo00]oo`03001oogoo00Eoo`03001oogoo00Io
o`03001oogoo00ioo`04001oogoo0005Ool00`00Oomoo`0_Ool00`00Oomoo`04Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool01@00Oomoogoo00001goo0P0027oo00<007ooOol02Woo00H007oo000007oo
0008Ool00`00Oomoo`09Ool00`00Oomoo`06Ool01P00Oomoo`00Ool000Qoo`8000=oo`03001oogoo
009oo`40005oo`40000000<007ooOol01Woo00<007oo00004Goo00<007ooOol027oo00@007ooOol0
009oo`05001oogooOol00008Ool01000Oomoo`000goo00D007ooOomoo`00009oo`03001oogoo00=o
o`80011oo`05001oogoo001oo`020004Ool01@00Oomoogoo00001Woo00<007oo00000Woo00@007oo
Ool0009oo`03001oogoo00Uoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00Ioo`8000Qo
o`<000Qoo`8000Qoo`03001oogoo008000=oo`03001oogoo00Aoo`80009oo`03001oogoo00Aoo`03
001oogoo00Yoo`03001oogoo00=oo`04001oogoo0002Ool00`00Oomoo`06Ool01000Oomoogoo0P00
0goo00<007ooOol00P0027oo0@0000000`00Oomoo`02000BOol00`00Oomoo`07Ool00`00Ool00002
Ool01000Oomoogoo0P0000Moo`00Oomoo`00Ool0000<Ool20002Ool00`00Oomoo`04Ool00`00Oomo
o`0COol00`00Oomoo`03Ool01000Oomoo`006Woo00@007oo000000aoo`04001oogoo000MOol20008
Ool00`00Oomoo`03Ool01@00Oomoogoo000017oo0P000goo00<007ooOol00Woo00<007ooOol00goo
00<007ooOol017oo00@007ooOol000Qoo`03001oogoo00Qoo`03001oogoo00Aoo`03001oogoo00Mo
o`03001oogoo00Eoo`8000=oo`03001oo`00009oo`40000000<007ooOol00Woo00<007ooOol00Woo
00<007ooOol01Goo00<007ooOol01Woo00<007oo00004goo00<007ooOol00goo00<007ooOol01Woo
00D007ooOomoo`0001Ioo`03001oogoo00Uoo`03001oogoo00Aoo`03001oogoo00aoo`03001oo`00
00Moo`03001oogoo00Qoo`04001oogoo0011Ool00`00Oomoo`09Ool00`00Oomoo`0=Ool00`00Oomo
o`05Ool00`00Oomoo`0MOol20002Ool100000003001oo`00009oo`8000Eoo`8000Eoo`8000=oo`03
001oo`0000=oo`03001oogoo00Moo`03001oogoo00Aoo`8000Aoo`03001oogoo00Moo`03001oogoo
00Aoo`03001oogoo00=oo`03001oogoo009oo`05001oo`00Ool00005Ool00`00Oomoo`06Ool2000=
Ool00`00Oomoo`05Ool00`00Ool0000?Ool200000goo001oo`07Ool01000Ool000001Goo0P001Woo
00D007ooOomoo`0000Uoo`03001oogoo00Yoo`04001oogoo0006Ool00`00Oomoo`02Ool00`00Oomo
o`08Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool20002Ool01000Oomoo`001Goo00<007ooOol017oo
0P000Woo00<007ooOol00goo00<007ooOol00Woo00<007oo00001Woo0@0000000`00Oomoo`08Ool0
1`00Oomoogoo001oo`0000Uoo`03001oogoo009oo`06001oogooOol007oo0P0000Aoo`00Oomoo`80
00Aoo`03001oogoo009oo`05001oo`00Ool00007Ool00`00Oomoo`0:Ool20006Ool3000COol20007
Ool01000Ool000002Woo00<007ooOol027oo00<007oo00001Goo00<007ooOol02Woo00<007ooOol0
1Goo00<007ooOol00Woo00D007ooOomoo`0000Moo`03001oogoo011oo`03001oogoo009oo`04001o
ogoo0002Ool00`00Oomoo`04Ool20004Ool00`00Oomoo`020007Ool00`00Ool0000FOol00`00Oomo
o`04Ool01@00Ool007oo00001Goo0@0000000`00Oomoo`04Ool00`00Oomoo`0IOol00`00Oomoo`0=
Ool20005Ool00`00Oomoo`06Ool00`00Ool00006Ool01000Oomoo`0017oo0P006goo00<007ooOol0
37oo00<007ooOol01Goo00<007ooOol027oo00<007ooOol047oo00<007ooOol027oo00<007ooOol0
57oo00<007ooOol01Goo00<007ooOol02Woo0P0037oo00D007ooOomoo`00009oo`03001oogoo00Ao
o`03001oogoo02=oo`40000000<007ooOol01Goo00D007ooOomoo`0000=oo`03001oo`0000Yoo`03
001oo`0000Eoo`03001oogoo00<000=oo`04001oogoo0008Ool01`00Oomoogoo001oo`00009oo`03
001oogoo00eoo`05001oogooOol00008Ool20003Ool00`00Oomoo`0:Ool30006Ool00`00Oomoo`04
Ool00`00Oomoo`07Ool00`00Ool00002Ool200001Goo001oogoo00000Woo00@007ooOol000Aoo`03
001oogoo00=oo`800003Ool007oo00Aoo`06001oogooOol007oo0`000goo00D007ooOomoo`0000Yo
o`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Ioo`8000Moo`04001o
o`000002Ool00`00Oomoo`05Ool00`00Oomoo`09Ool01000Oomoogoo0P0017oo0P001Woo0@000Goo
0@0000001000Oomoo`0017oo00@007ooOol0009oo`8000=oo`<000=oo`05001oo`00Ool00006Ool0
1000Ool007oo0P001Goo00@007ooOol001Eoo`8000Eoo`03001oogoo00<000eoo`8000Ioo`800003
Ool007oo00Moo`03001oogoo00]oo`8000Eoo`<00003Ool0000000Yoo`03001oogoo00Ioo`06001o
ogoo001oo`0027oo0`0000=oo`00Ool00Woo00@007ooOol000Aoo`03001oo`0000Ioo`8000Uoo`03
001oo`00009oo`03001oogoo009oo`03001oo`0000Uoo`07001oogooOol007oo00001Woo00<007oo
00001goo0P0000=oo`00Ool02Woo00<007ooOol027oo0@000Goo0@0000000`00Oomoo`06Ool00`00
Oomoo`0<Ool00`00Oomoo`06Ool200000goo001oo`03Ool00`00Oomoo`05Ool00`00Oomoo`07Ool0
0`00Oomoo`0HOol00`00Oomoo`07Ool00`00Oomoo`05Ool20002Ool01000Oomoo`001Goo00<007oo
Ool04goo00<007ooOol00goo0P009goo00<007ooOol01Goo00<007ooOol03goo00@007ooOol0009o
o`80015oo`03001oogoo00Ioo`8002Eoo`40005oo`40000000<007ooOol00Woo00<007ooOol01Woo
00<007ooOol027oo00<007oo00000goo0`001goo00<007ooOol02Woo00<007ooOol00Woo00L007oo
Oomoo`00Ool00002Ool01P00Oomoo`00Ool000Moo`03001oogoo009oo`04001oogooOol20007Ool0
0`00Oomoo`02Ool00`00Oomoo`07Ool01`00Ool00000Ool007oo0080009oo`03001oogoo008000Ao
o`05001oo`00Ool00002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Ool00005Ool00`00Oomo
o`02Ool20002Ool00`00Oomoo`09Ool00`00Oomoo`0YOol20005Ool20003Ool00`00Oomoo`04Ool0
0`00Oomoo`02Ool01P00Oomoo`00Ool000Eoo`03001oogoo00Aoo`04001oogoo0002Ool200000goo
001oo`07Ool100000003001oogoo00=oo`8000ioo`03001oo`0000=oo`03001oogoo00Ioo`03001o
ogoo00Moo`03001oo`00008000moo`03001oogoo00Moo`800003Ool007oo00Eoo`05001oo`00Ool0
000:Ool01@00Oomoogoo00001Goo00<007oo00000Woo00<007ooOol017oo00<007ooOol00Woo00<0
07oo00003Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol01Woo00H007ooOomoo`00Ool2
0002Ool20003Ool2000>Ool00`00Oomoo`030006Ool20006Ool00`00Oomoo`03Ool00`00Oomoo`06
Ool01000Ool000001Goo00<007oo00002Goo00@007oo000000Moo`06001oogoo001oo`000goo00D0
07ooOomoo`0000Uoo`40000000<007ooOol01goo00<007ooOol00Woo00<007oo000027oo0P001Woo
00<007ooOol03Goo00<007oo00002Goo00@007ooOol000Moo`03001oogoo00aoo`03001oogoo00Io
o`<000Eoo`05001oogooOol00003Ool20009Ool01000Oomoogoo0P000Woo00<007oo000077oo00D0
07oo001oo`00009oo`03001oogoo00Ioo`03001oogoo00Uoo`03001oo`0000Uoo`08001oogoo001o
o`00Ool000]oo`05001oo`00Ool00006Ool00`00Oomoo`07Ool00`00Ool00002Ool2000;Ool20004
Ool00`00Oomoo`05Ool00`00Oomoo`09Ool100000004001oogoo0006Ool00`00Oomoo`04Ool00`00
Ool00002Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Ool0000;Ool00`00Oomoo`0;Ool00`00
Oomoo`02Ool00`00Ool00005Ool00`00Oomoo`0WOol00`00Oomoo`0>Ool00`00Oomoo`07Ool00`00
Ool00006Ool00`00Oomoo`0;Ool01P00Oomoo`00Ool000Qoo`03001oogoo02Aoo`8000ioo`03001o
ogoo00Aoo`03001oogoo01=oo`8000Eoo`04001oogoo0002Ool100000007001oogooOol007oo0000
0Woo00D007ooOomoo`00009oo`03001oogoo00Eoo`04001oogooOol20006Ool00`00Oomoo`03Ool0
1000Ool000002Woo00<007ooOol01Goo00D007ooOomoo`0000Uoo`03001oo`0000<00003Ool007oo
00Uoo`03001oogoo00Yoo`03001oo`0000Yoo`06001oogoo001oo`000goo00<007ooOol01Goo00<0
07ooOol057oo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00800005Ool007ooOol0
000:Ool2000>Ool01000Oomoo`0017oo00<007oo00001Woo00<007ooOol00Woo00<007ooOol00P00
2Woo00D007ooOomoo`0000Yoo`8000=oo`8000Moo`@00003Ool0000000=oo`40000000<007ooOol0
0goo00<007oo00002Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol037oo00<007oo0000
1Woo00@007ooOol0009oo`04001oo`00000:Ool3000=Ool00`00Oomoo`09Ool20003Ool01P00Oomo
o`00Ool000Uoo`05001oogooOol00008Ool00`00Oomoo`02Ool00`00Ool00003Ool00`00Oomoo`0>
Ool2000:Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool01000Oomoo`0017oo00D0
07oo001oo`0000=oo`03001oogoo00=oo`03001oogoo00Ioo`05001oogooOol00005Ool01000Oomo
o`001goo00<007ooOol01Woo0P001Goo0@0000000`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomo
o`02Ool300000goo001oo`0AOol00`00Oomoo`07Ool00`00Oomoo`0>Ool00`00Ool0000;Ool00`00
Oomoo`0>Ool2000FOol01@00Oomoogoo00001goo00<007ooOol01goo00D007ooOomoo`0000Moo`03
001oogoo00aoo`03001oo`0000Ioo`<000Ioo`05001oo`00Ool00004Ool01000Oomoogoo0P001Goo
00<007ooOol00Woo00@007ooOol000Eoo`03001oogoo00Aoo`03001oogoo019oo`03001oogoo00Yo
o`03001oogoo00Ioo`03001oogoo009oo`40000000@007ooOol000Aoo`80019oo`05001oo`00Ool0
0005Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol027oo00<0
07ooOol00goo00<007ooOol01Goo00<007ooOol00Woo0P0017oo00<007ooOol03Goo00<007ooOol0
0Woo0`001Goo00<007oo00002Goo0P0017oo0P001Goo00<007ooOol01Goo00D007ooOomoo`0000Uo
o`03001oogoo00Aoo`8000Moo`03001oogoo00Yoo`03001oogoo00Moo`04001oogoo0003Ool00`00
Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool01000
Oomoo`003goo0@0000001@00Ool007oo00002Goo00L007oo001oo`00Ool00002Ool00`00Oomoo`02
Ool01000Oomoo`000goo00<007ooOol02Woo00<007ooOol00Woo00<007ooOol00Woo00L007ooOomo
o`00Ool00006Ool20006Ool00`00Ool00004Ool01000Oomoo`004Goo00<007ooOol00Woo0P0057oo
00<007oo00000goo00<007ooOol01goo0P0000=oo`00Ool01goo00<007ooOol01Woo00<007ooOol0
0P002Woo00@007ooOol000Ioo`03001oogoo01Ioo`03001oogoo00Ioo`8000Eoo`04001oogoo0002
Ool00`00Ool00005Ool00`00Ool00002Ool00`00Oomoo`03Ool00`00Oomoo`05Ool2000017oo0000
07oo0P0000=oo`00Ool00Woo00@007ooOomoo`40000000<007ooOol00Woo00D007oo001oo`0002Uo
o`03001oogoo01=oo`03001oogoo00=oo`03001oogoo01=oo`03001oogoo00Uoo`8000]oo`8000Yo
o`03001oogoo00Moo`03001oogoo00aoo`04001oogoo0002Ool00`00Ool00004Ool00`00Oomoo`06
Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool00`00Oomoo`05Ool00`00Ool00007Ool01000Oomoo`00
1goo00@007ooOol000aoo`03001oogoo00Qoo`03001oo`00019oo`40000000@007ooOol000=oo`03
001oogoo00Aoo`06001oo`00001oo`0037oo00<007ooOol00Woo00<007ooOol017oo00<007oo0000
0P0017oo00D007ooOomoo`0001Ioo`8000Ioo`03001oo`0000Eoo`05001oogooOol00008Ool00`00
Oomoo`07Ool01000Oomoogoo0P001Goo00H007oo000007oo000<Ool01`00Oomoogoo001oo`00009o
o`03001oogoo00=oo`03001oogoo00Ioo`80009oo`03001oogoo00]oo`06001oo`00001oo`0027oo
0P0000=oo`00Ool00goo00<007oo00001goo00@007oo001oo`8000eoo`03001oogoo00Aoo`03001o
o`0000moo`05001oogooOol0000:Ool00`00Oomoo`03Ool100000005001oogooOol00005Ool00`00
Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`03Ool01000Oomoo`0017oo0P0000=oo`00Ool017oo
00<007ooOol02goo00P007ooOol007oo001oo`0067oo00<007ooOol00goo00P007ooOol007oo001o
o`002Goo0`000Woo00<007ooOol027oo00@007oo000000Aoo`03001oo`0000Moo`03001oogoo00io
o`8000Ioo`03001oogoo009oo`03001oogoo00Aoo`04001oo`00Ool300001Goo001oogoo00002goo
0`001Goo00<007ooOol06goo00<007oo000017oo00@007ooOomoo`8000Ioo`03001oogoo00Aoo`04
001oogoo0004Ool100000003001oogoo01Aoo`03001oogoo00Qoo`03001oogoo009oo`05001oogoo
Ool0000;Ool01@00Oomoogoo000017oo00<007ooOol02Goo00@007ooOomoo`8000=oo`<000Uoo`03
001oogoo0080009oo`03001oogoo00Qoo`03001oo`0000=oo`03001oogoo009oo`03001oogoo00Uo
o`03001oogoo00Aoo`03001oogoo015oo`03001oogoo00Ioo`8001Uoo`03001oogoo00Ioo`80011o
o`03001oogoo00]oo`80009oo`03001oo`0000ioo`03001oogoo00Ioo`04001oogoo000;Ool10000
0003001oogoo00moo`04001oogooOol200000goo00000005Ool00`00Ool0000@Ool20009Ool01`00
Oomoogoo001oo`00009oo`<000moo`03001oo`0000Aoo`03001oogoo00Eoo`<00005Ool007ooOol0
000?Ool00`00Ool00004Ool01000Oomoo`002Goo0`0000=oo`00Ool00Woo0P001Goo00D007ooOol0
07oo008000=oo`03001oo`0000=oo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Yoo`80
00Uoo`03001oogoo00Ioo`03001oo`0000Moo`03001oogoo00Moo`03001oo`00009oo`04001oogoo
0007Ool30002Ool20009Ool01000Oomoo`000goo00@007ooOomoo`40000000@007oo000000Ioo`06
001oogoo001oo`000goo00D007ooOol007oo008000Moo`03001oogoo00=oo`03001oogoo00Aoo`80
00Ioo`03001oogoo00Eoo`03001oogoo00]oo`04001oogoo0002Ool00`00Ool00006Ool00`00Oomo
o`04Ool300001Goo001oogoo00002Goo00@007oo000000Moo`07001oogooOol007oo00000Woo00L0
07oo001oo`00Ool0000?Ool00`00Oomoo`07Ool01000Oomoo`0017oo00<007ooOol037oo00@007oo
0000009oo`06001oo`00001oo`001Goo00<007ooOol017oo00<007ooOol00Woo00@007ooOol000Ao
o`03001oo`00009oo`03001oogoo00Eoo`800003Ool007oo009oo`03001oogoo009oo`05001oo`00
Ool0000:Ool01@00Oomoogoo00000Woo0`001Goo00<007ooOol00Woo0@0000000`00Oomoo`0ZOol0
1000Oomoo`001Goo00<007ooOol01Woo00<007ooOol05Goo00@007ooOol000Yoo`03001oogoo029o
o`05001oogooOol0000:Ool00`00Oomoo`07Ool20004Ool00`00Oomoo`05Ool01P00Oomoo`00Ool0
00=oo`04001oogoo0003Ool00`00Oomoo`09Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`0>Ool20003Ool00`00Ool00003Ool00`00Oomoo`0;Ool00`00Oomoo`0BOol2
0001Ool100000003001oogoo009oo`03001oogoo00Eoo`04001oogooOol20002Ool01000Oomoogoo
0P000goo0P001Goo00<007ooOol017oo00<007ooOol01Goo00H007ooOol007oo0006Ool200000goo
00000008Ool00`00Oomoo`08Ool00`00Oomoo`05Ool200000goo001oo`03000<Ool00`00Ool00009
Ool20004Ool200000goo001oo`0DOol00`00Ool00004Ool200000goo001oo`0LOol01000Oomoo`00
37oo00D007ooOomoo`0000=oo`800004Ool007ooOol200000goo001oo`02Ool20006Ool02000Oomo
o`00Ool007oo000<Ool5000017oo001oogoo0P001Goo00L007ooOol007oo001oo`0100000003001o
ogoo00]oo`8000=oo`8000Qoo`8000=oo`04001oogoo0005Ool00`00Oomoo`0<Ool2000>Ool00`00
Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool01000Oomoo`000Woo00<007ooOol00goo0P00
17oo00<007ooOol00goo00<007ooOol00goo00<007ooOol017oo0P0000Aoo`00Oomoo`<00005Ool0
07ooOol00003Ool01000Ool000000Woo00<007ooOol00Woo00@007ooOol000Eoo`03001oo`0000Ao
o`03001oo`0000Aoo`03001oogoo00Aoo`80009oo`03001oo`0000Eoo`06001oo`00Ool007oo0`00
0goo00<007ooOol00goo00<007ooOol02Goo00D007ooOomoo`00009oo`07001oo`00Ool007oo0000
6Goo00<007ooOol00Woo00<007ooOol00@0000000`00Ool00005Ool00`00Oomoo`07Ool00`00Oomo
o`09Ool01000Oomoo`000Woo00<007ooOol02Goo00@007ooOol000Ioo`05001oogooOol00002Ool0
1000Oomoogoo0P000Woo00<007ooOol01Woo00<007ooOol00P0000Eoo`00Oomoo`0000]oo`03001o
ogoo00Ioo`03001oogoo00Yoo`03001oogoo00Eoo`04001oogooOol2000>Ool01000Oomoo`000Woo
0P005goo00<007ooOol01goo00D007ooOomoo`0000Ioo`03001oogoo00eoo`06001oogoo001oo`00
1Woo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol00goo00<007oo00000Woo00<007ooOol0
27oo00<007ooOol00Woo00<007ooOol00goo0@0000001@00Ool007oo00000Woo00<007oo000017oo
0P000Woo0P000Woo0P000Woo00<007ooOol00goo00H007ooOomoo`00Ool20007Ool00`00Oomoo`02
Ool20008Ool00`00Oomoo`02Ool20007Ool200000goo001oo`05Ool20002Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool00`00Ool00002Ool02000Oomoo`00Ool007oo0005Ool00`00Oomoo`06Ool01000
Ool000000Woo00<007oo00000goo0P000goo00D007ooOomoo`00009oo`8000=oo`<000Qoo`04001o
ogooOol30002Ool00`00Oomoo`07Ool00`00Oomoo`05Ool30002Ool2000017oo001oo`000Woo00<0
07ooOol01Woo0P001Woo0P000goo0P000goo0P002goo00<007ooOol00Woo0P000goo00<007ooOol0
0goo00<007ooOol00Woo00H007oo000007oo0008Ool10001Ool100000003001oo`0000Aoo`8000ao
o`D000Ioo`800003Ool007oo00Ioo`@000Ioo`04001oogoo0007Ool01@00Oomoogoo000057oo00<0
07oo000017oo00@007ooOol000aoo`07001oo`00Ool007oo000017oo0P0000Aoo`00Ool000Moo`80
009oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00Aoo`80009oo`07001oogoo001oo`00
Ool00P0000=oo`0000001Goo00<007ooOol00Woo00H007oo000007oo0003Ool300000goo00000004
Ool01@00Ool007oo000017oo00<007oo00001goo0P0000=oo`00Ool00Woo0P001Woo00@007oo0000
00ioo`03001oogoo00Aoo`04001oogoo000>Ool00`00Oomoo`03Ool100000003001oogoo00Moo`03
001oogoo00Qoo`03001oogoo00moo`03001oogoo00Uoo`03001oogoo009oo`8000aoo`03001oogoo
00=oo`03001oo`0000Aoo`03001oogoo00]oo`8000Yoo`03001oogoo00Yoo`04001oogoo0004Ool0
0`00Oomoo`07Ool20008Ool20005Ool01000Ool000005Goo00<007ooOol027oo00<007ooOol00Woo
0P0000Aoo`00Ool000Qoo`8000Eoo`8000eoo`03001oogoo009oo`04001oogoo0008Ool01@00Oomo
ogoo00006Goo00@007ooOol0009oo`40000000@007ooOol000Aoo`800004Ool000000002Ool01000
Oomoogoo0P003Goo00@007ooOol000Uoo`03001oogoo009oo`800005Ool007ooOol00002Ool00`00
Oomoo`02Ool00`00Ool0000300000goo001oo`08Ool01@00Oomoogoo00000goo00<007ooOol02Woo
0P000goo00<007ooOol017oo0P000Woo00<007ooOol03goo00D007ooOol007oo00@0009oo`03001o
o`0000=oo`03001oogoo00<00004Ool000000004Ool00`00Ool00005Ool00`00Oomoo`04Ool00`00
Oomoo`09Ool300000goo001oo`0:Ool00`00Oomoo`020004Ool01@00Ool007oo000017oo00@007oo
000000=oo`05001oogooOol00002Ool02000Oomoo`00Ool007oo0008Ool30004Ool01P00Ool007oo
001oo`8000=oo`03001oogoo009oo`03001oogoo0040000000@007oo001oo`8000Eoo`03001oogoo
00800005Ool007ooOol00005Ool01000Oomoo`001Woo00<007ooOol01Goo00<007oo00000P002Woo
00@007ooOomoo`800003Ool007oo009oo`06001oo`00001oo`000Woo0P000goo00<007oo00000goo
0P000Woo0P000Woo00<007ooOol00Woo00<007ooOol01goo00<007ooOol01Woo00<007oo00000goo
00<007ooOol00Woo00<007ooOol01goo00<007ooOol017oo00<007ooOol01Goo10000goo00<007oo
Ool00Woo00D007ooOomoo`0000Yoo`05001oogoo001oo`030004Ool01000Oomoo`001Woo00X007oo
Ool007oo001oo`00Ool0009oo`04001oogooOol3000027oo000007oo001oo`00Ool200000goo001o
o`08Ool00`00Oomoo`02Ool30002Ool00`00Oomoo`020003Ool01`00Oomoogoo001oo`0000Aoo`80
00Aoo`03001oogoo00=oo`40000000<007ooOol02Goo00<007oo00000Woo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol00P001Goo0P004goo00<007ooOol00Woo00<007oo00000goo00<007oo
Ool03goo0`0027oo00@007oo0000009oo`04001oogoo000:Ool20003Ool00`00Oomoo`06Ool00`00
Oomoo`0COol00`00Oomoo`04Ool00`00Oomoo`0:Ool01000Oomoo`000goo0P001Woo00<007ooOol0
2Woo00<007ooOol00goo00<007ooOol02goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0
4goo00<007oo00001Woo00<007ooOol01Woo00<007ooOol00Woo0@000Goo0@0000000`00Oomoo`02
00002Goo001oogoo001oo`00Ool0000;Ool20004Ool00`00Ool00003Ool00`00Ool00003Ool20004
Ool01P00Oomoo`00Ool000=oo`8000=oo`03001oogoo009oo`07001oogooOol007oo00001Goo00<0
07ooOol01@000goo00L007oo000007oo001oo`030003Ool00`00Oomoo`0200000goo001oo`02Ool0
1@00Ool007oo00001Goo00@007ooOol0009oo`07001oo`00Ool007oo00000Woo00@007oo001oo`<0
009oo`05001oogoo001oo`030002Ool01P00Ool00000Ool0009oo`03001oogoo009oo`<000Moo`03
001oo`0000D0009oo`04001oo`000003Ool00`00Ool00009Ool01000Oomoogoo0P0000=oo`000000
0Woo00L007ooOol007oo001oo`020005Ool01`00Oomoogoo001oo`0000Aoo`03001oo`0000Eoo`03
001oo`0000Eoo`03001oogoo009oo`D00003Ool007oo00Aoo`05001oogooOol00003Ool100000004
001oo`000002Ool3000017oo001oo`004goo00<007oo000017oo00<007ooOol027oo0P001Goo00<0
07ooOol00Woo00T007ooOomoo`00Ool007oo00000Woo0`0017oo0`001goo00<007oo00000P0017oo
0P0000Eoo`00Oomoo`0000Eoo`04001oogoo0003Ool00`00Oomoo`05Ool01000Oomoo`001Goo00<0
07ooOol017oo00<007ooOol00goo00<007ooOol01Goo0`0000=oo`00Ool01Goo0P000Woo00<007oo
Ool00goo0P0000=oo`0000000P000goo0P0000=oo`00Ool00Woo00<007oo00001Goo0P000goo0`00
2Goo00<007oo00000goo00<007oo00000Woo00<007ooOol00Woo0`000goo00<007ooOol01Goo00L0
07ooOomoo`00Ool00003Ool00`00Oomoo`0;Ool20004Ool00`00Oomoo`040001Ool100000005001o
ogooOol00003Ool01000Oomoo`003Goo00<007ooOol00Woo0P001Woo00<007ooOol017oo00D007oo
Oomoo`0000Eoo`05001oogooOol00005Ool20007Ool200000goo001oo`020003Ool00`00Ool00002
0004Ool3000017oo001oogoo0P0017oo00<007oo000017oo0P001Woo0P000Woo00<007ooOol00Woo
00<007ooOol010000goo0P0000Aoo`000000009oo`8000Qoo`05001oo`00001oo`0200000goo001o
o`02Ool00`00Ool00003Ool30002Ool00`00Oomoo`03Ool300000goo001oo`05Ool00`00Ool00002
000017oo001oogoo1P0017oo00<007oo00000Woo0P0000=oo`00Ool02Woo00H007ooOol007oo0002
Ool00`00Oomoo`020004Ool00`00Ool00006Ool00`00Oomoo`03Ool00`00Oomoo`04Ool20003Ool0
1P00Ool007oo001oo`40000000<007ooOol00Woo00D007ooOomoo`0000Yoo`07001oogooOol007oo
00000Woo00@007oo001oo`8000Uoo`8000=oo`D00003Ool007oo00Eoo`03001oogoo00Aoo`03001o
ogoo009oo`800003Ool007oo009oo`03001oo`0000Eoo`8000=oo`03001oogoo00Qoo`<000Aoo`03
001oogoo0080009oo`04001oogoo0009Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00<007oo
Ool00Woo00D007ooOol007oo00800004Ool007ooOol30002Ool20003Ool00`00Ool00006Ool00`00
Oomoo`02Ool20008Ool00`00Oomoo`02Ool00`00Ool00003Ool20004Ool00`00Oomoo`03Ool00`00
Ool00002Ool00`00Oomoo`02Ool00`00Ool0000<Ool00`00Oomoo`02Ool00`00Ool000030004Ool2
0002Ool01000Oomoo`001Woo00<007ooOol00Woo00@007ooOol000Aoo`40000000@007ooOol000=o
o`04001oo`00Ool20004Ool00`00Oomoo`050005Ool01000Ool007oo0P0000Aoo`000000009oo`80
009oo`800003Ool0000000Aoo`03001oo`00009oo`06001oogoo001oo`001Goo00<007ooOol00P00
00Aoo`00Ool0009oo`800004Ool007ooOol200000goo0000000700000goo00000009Ool00`00Oomo
o`030003Ool00`00Ool00002Ool300001Goo001oo`00Ool00P000goo00<007ooOol00P0000=oo`00
Ool00goo00<007oo000017oo0P0000=oo`0000000goo00<007ooOol017oo10000goo00<007oo0000
17oo0P000goo00<007oo00000Woo00<007oo00000Woo00@007oo001oo`800003Ool00000009oo`09
001oogooOol007oo001oo`0000Ioo`<00003Ool007oo00=oo`04001oogoo0007Ool01000Oomoogoo
0P000goo0P0000Eoo`00Ool007oo0080009oo`04001oogooOol3000017oo001oo`002Goo0@000000
1P00Oomoo`00Ool0009oo`03001oo`00009oo`@000Aoo`<00003Ool0000000Eoo`04001oogoo0003
Ool00`00Oomoo`04Ool50002Ool2000017oo000000000goo00<007oo00000Woo0`0000Aoo`00Ool0
009oo`03001oogoo00<0009oo`03001oo`00008000=oo`<000Moo`03001oo`0000=oo`03001oo`00
009oo`03001oo`00009oo`80009oo`03001oo`00009oo`800003Ool007oo009oo`<0009oo`03001o
ogoo00=oo`05001oogoo001oo`0500001Goo001oo`00Ool00P0000=oo`00Ool00goo00@007oo0000
009oo`04001oo`00Ool300000goo000000020002Ool20002Ool01000Ool0000017oo00@007ooOomo
o`<00003Ool0000000Aoo`@000=oo`03001oo`0000Ioo`05001oo`00Ool00002Ool00`00Ool00002
0005Ool200000goo001oo`03Ool00`00Oomoo`03Ool2000017oo000000000Woo0P0000Eoo`00Ool0
07oo00P000=oo`40000000<007ooOol00goo100000Aoo`00000000Aoo`8000Aoo`<0009oo`03001o
o`0000Aoo`03001oogoo009oo`03001oogoo0080009oo`<000Aoo`8000=oo`03001oo`0000Uoo`03
001oo`0000Ioo`04001oogooOol20003Ool00`00Oomoo`02Ool01000Oomoo`0017oo0P001Goo00@0
07oo000000Moo`03001oo`00009oo`04001oogoo0006Ool01000Oomoo`001Woo00D007ooOomoo`00
00Aoo`04001oo`000002Ool01@00Ool00000Ool00P0000=oo`00Ool017oo0P0000Aoo`00001oo`@0
0003Ool007oo00Aoo`80009oo`8000=oo`03001oo`0000Ioo`03001oo`00009oo`800003Ool007oo
009oo`03001oogoo00Aoo`03001oogoo008000=oo`05001oogooOol00004Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007oo0000009oo`04001oo`00Ool40002Ool00`00Oomoo`02Ool00`00Oomo
o`020004Ool100000003001oo`0000800003Ool007oo009oo`<00004Ool00000Ool7000037oo001o
ogoo001oo`00Ool007oo001oo`<00003Ool0000000H000=oo`8000Aoo`03001oogoo00800003Ool0
07oo00@0009oo`<0009oo`04001oo`00Ool30004Ool00`00Oomoo`030002Ool50003Ool300001Goo
00000000Ool00P000Woo0P0000Aoo`00001oo`800003Ool0000000800004Ool00000Ool20006Ool0
0`00Ool00003Ool2000017oo0000000017oo0`000Woo00<007oo000020000goo00<007ooOol00Woo
0P0000Aoo`00Ool0009oo`D00005Ool00000Ool00002Ool20002Ool200000goo0000000400000goo
00000002Ool01P00Oomoo`00Ool000=oo`D00003Ool007oo00Aoo`800003Ool0000000<00005Ool0
07oo001oo`0200001goo00000000Ool007oo0080009oo`800005Ool00000Ool00002Ool00`00Oomo
o`020004Ool20002Ool100000003001oo`0000<00003Ool000000080009ooa`00003Ool0000000H0
0003Ool0000000H00004Ool00000Ool400000goo0000000500000goo0000000=00001Woo001oogoo
001oo`H00003Ool0000000@00003Ool0000000P00003Ool0000002400006Ool007ooOol007oo4P00
00=oo`0000000`000Woo0`0000=oo`0000000`000Woo2@0000=oo`00000030000goo7@0000=oo`00
00002P0000=oo`0000003P000Goo0@0000000`00Oomoo`3oOolMOol100000?l002400000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0263022, -0.0250053, 
  0.00366761, 0.00593432}},
  ImageSoundCache->{{{0, 287}, {176.938, 0}} -> GraphicsData["WindowsSound", "\<\
DTU6AS@W001G@EI5IVed810000010040R1<008PC000100P0I65dHA0W003WYePH
01UIZNSoiJ=C5@0LH;3]omnJBPl19FbllogDRS/8139oc?[ga7DZ0Pe6Umkok:aJ
5`0LH[C`o]N<?0P5=XGBoO>iIQl05eZ]kOoJSch81CN8eOk`/UhI01iV^_ClcGd^
0Pe:WnKohIQ32P@eQmKnkZeG500VM<Ojm[aW7@0LI[_fn/Mc9@0FG;?bo<ej:@4C
Ejo`oLml:`4BEjo`oLij:@0DFk?cnlUc900II;cgn<1X700RLLSkl[9H4P4_PmKo
j9i520M1V^Kof8D_0A9J]OCj`FPJ02Iid?k[XTL91d>NjOkCO2L06VW4no:^DPd4
?9KUomJ0:@0JJ/GklJY=2PI3Wn_ncG8O02EkdooVUST345ZhmoJdE@h5?icZo/a`
7@0ZPm[ogXP]01Y]b_gZVcd445^knO>[B`P:CZkdn;MF3@I4YO3k_ehA13jNkOc3
Ha<3>i_[o<AT4`<kW>cl`V4B0cnQko^mF`h5AZScn;EA2PU@]?ScZ4D545k1o>^H
=P4JLM7ogX<V02V8h_o=JaH2?J7`nKE@20aH_O_/Uc@07GWHomEd6`4hWNoi]Dl7
3Eg3oNJ=:`0WR>CnaV0>1dnfn^fI<`0QP=oobV@@1Tfen^fG<P0TQN?na5`<2UNo
oNJ99P0`Ungi/TP456kDomA^50A:]?[[TR`0;9?/n[9711Mcf?o=I0h9El;nhGlM
0CnZmnnG;`0/U>gh[4027H3RoKiA1Q=_eoo;H0`<H<coeFdB1eG2o]eg5`A=^ogR
OQ/3B;KliH8M0TFdnnJ47P94]?_VPQd2AkKlhghJ0dblo]mg5PIC`ooHKA09G/co
cf4:3f_Gol=B1AQlhobc@@4TSnkfWc00=JGhjhPO0TZmo]Y^3`]Te?o4D@@KPnSi
YcD0<ZChjXDL1574om5P2A=gh_b_>`0^X?O[QQ/4E<Soc5T66H;Yn:8_03fboMi_
3Pe]g?fc?@0_XoWWO1D9H]Gn^T@0:ikgjH0F267Eo[U202fRnNIi4P]Zg?f_>00h
[ogKJ@XDONSgW2L1C<Gob5029IWfjGdC2f_NnjTa04>loliF0b:FmNUm4`a_hOZR
:`5<a_o3B00^YocMJ0PHR?3_QaL9J]okXbX1Cl[o_400>;CndEH39IgihF`:5hSa
kH4C3GGWmY<N1VCLnj<Y0UGAo[0c04W7ok/m03nnolA603Nfol]<03:`o/mB0Bj/
o]9E0RbYoMAF0R^YoM=E0Rb[o]5C0Bn^o/i>03BdolU803Zkol5004;4okPf04g>
oZ`/0U[InihQ1VWTmXdF3G_^kGX<693ghFD59ZGmdDh0>;co_3P0Cm;mXb<6J^Gd
QQ4CROGSI`DWZ?k<A`12aon]:PATh_F94Q>:m^5R0bbaol8l053EniXK2g_`j6d6
9ZWnad00CM?lVQ/<O_;VJ0@[/Onn=`5IgON:4AFAnMQB03k7oZHR27O_j6X4;;?o
^C43I>GaN`XPYOk5?01Hg_J53Q^MoL]105CKmhP?6Ycmbd00E]cfQ0dMX_k5>P5N
ho9i22F^okT^16k/jFL3=<3oYAh<QOOIC`1:eOV:3QbRo/0d0f[[jFL2=lCnWAPB
T__=?`5NiNm`132noj8K493kcCl1H>O]J`<faOfH51NLo/4b177`hEL0BMOgP0PX
]_nV712Ao<Ph0fc_heT0B]WeN`H]__jL5ANPokXZ287hdd81Hn_WG@19fOEh1C;4
oI8?7jkoZA`AUojn;0R1n=0m0Vg`gdl0F^KZH019fo=a0c_?nH07;l?lSP`U]onK
4Qf]ojHH5j?o[ahBV_nf8`jCo[`X2hgm`B`9ROc4;PR6nlH`1hCkac47Q?_7<0R5
nlD^28Sl`R`:S?fn:0bBo[TS3iWo/QhDXOnY61V[oilB8;KnT``Y`Ob61cC=mgL3
@MWaIP1@i>QE06;_fd@2M_O<<PR;oKTR4Z7oY1<P^?f<23?>mW41B^7YEP1UlMLl
1H;l_R@AXOnQ4BFonh04?m[^GP1PkmPm1HCl^R0EZOnF2bo<mVh0DnWPAP=lnklT
4jOoUP/ac_AY05W]fSd5R?jb6AfgoH84@moXD05enL8U4jWoT0PieniI06cgb2T@
YOnC23SGkUP0KoS49AB/oXX5@MoWC09no;HJ7[cjMP5Dk=Pg2IOoW0/ceNiG07Cj
_1dL^_]f05O^e38=X?n@1T3PiDH4R_nV3bkAl5P1Mo^f62?5mVH0J_S17a^knW00
HOC891NfngD0GO?:9QJdngH0G_?99ANgng40HoK481bnn6T0K?Vj6BC9le/0Nof/
433FjTX4S_nH1d;Ug3L<Y_j00E[cb28L`?IR07Sm[0lcf^I229_oR09DlL/S6l3f
G`1moZ@;?>;M=Pj[o7@0JOZe4bkGid88W_n00Eof_APXd^]71i_oPP5Om[`G:]CX
@`VQoW/0J?Zc4CCNh3H?/?YY07[nW`Q6k<lT7LO`C`FGoh40I?Vb43OQfblE^oIJ
0XkoR@5On;HA=N7K;QJnm5D4UOn006[kZ@Y2jlhQ8/oZ@@^/nfH1Q_n<0F3i/@dn
j=0R8M3Y?PfanEh2T?n006omX0I@lkhD=>;G9ak<jSl=/oQJ0iOnM@1loi02H_ZZ
2DWa`ADdhmDT8]?U=QC0lDT:[?UM0iSnL@24oh@0LOjG0eojZ0M?m;L>@Ng55SCT
dAlXfm/Y7m7T<aO7jcdA__563;CeC`R[n5P5Xo]P0icmI`:EoVd1Somb08[oM`26
ogX0Pomm087oO`20ogl0P?mo083oOP22og`0Q?mi08SoM@2<og41TOi[0IOmI0>N
ned5Y_UE2:kfC0^glT<@`N`i5/_U;akEgBHWg]<L<^O74ck`^Pa=mj/6GObJ0Fko
Q`21og@1UOeP1JWgC0fmkCTHd>0W:>7>5c__^P]AnJ83J_n808GoK0:QnE4;^ndg
6mCK833X`Pi;mjD3JOn508_nI0F/m4<Cbn8W:^G744SgY@=/oh00ToaI2KS]=AgI
daPll[05Hoj708kmG0RhkC@Og=0E@_FW0fkoN@6MnD/@bN4S<>^j25cmRP2?o5L;
_nLZ:NO02eOmSP2=oEL;`NHX;>Vk25knQ02HnT`AcM`M>_:Z0g;oKPB_l3DQhLH=
EOf;09CjC1;?fAU0mZ41OoiN2L3U9C;_[`=bof/5]^//:n^f1F_oL0BbkBhZj[L5
Jom^1KG[:bg]/@AcofH7_NDS=o>U0H7nE`k<fAM7nY80U_Q26mg62eooM`>ak2X`
kjX1OoiE4=3D4e3mQ06VlC4Yk;02NoiG3loD4U?mO`:]kBXalJ@0RO]86=g426So
I`W4g1Q:o8H1Z^h[<_:Q093i@1oU^0AhoUDBe//;HomX2LOI55;nN@Bii1e4nhP1
[>`V>OND0:;a;C7cW02Jm3</l:80UOHf:NnU09;g>2S^Y@2CmSLYkj<0U_Dc;O:N
09cb;S;eUP2UkRLknH/1/>LNA_am1;gN5EGoK@W<d@aWoeXBfl04O?a58>ZZ09Cd
<3?fT@2_iaa;oW@7bM8<JOmD5^6f0H_h=BkdU02_iQY?ofd:dLT7Moe58^fR0:;]
8TGmM@S<cPQcoDHQkJ40YNXNBoi]2mC41H3j>BgeS`6hgQ5QoeDHiZ/0W^hQB?i]
3=K00hSg<3OjP0G8cPQho3`/mHd2_]L<K_i49O:D0KSK3VWnAb?aUP6hf`i[oTDV
lY42_ML;L_dn;?J81<K>1goi<SSkN0WD_`:AlRA9of8ChjX0ZN@DH_m99O>>0lC>
1X;g;ComJ`oO[`2WiA=ToTDYmXH5cL@2TO4PD?mF7>jF0/7@1XCf:4OoGaOZW@6l
d`N1mbU6oehHjiX1`=05R?@SC_mD7o6=1<c30YS[663n@RkiM`cN[@2af`Yln2U8
oeLNlH`5d;d0X^DAKo/b?oiP6NjB1<g00J7U473k<4;oFQgaR@KE]P2]f`V0mB9D
odH]nW4AiYd2alD1Wn@?MOTYC?m<:OUd4>JL0/W20:GP2gke8ESo?cGmHQ[aQ`SK
Z`2nb`:Li@ihmb=FochgoUdNm7l<hZ02b[h0[]P6Sn`CL?TWD_lo=oiK8OIh4>RD
1MF`0;o80JKM28_]577h95On>43oCRckIA_cO@kWU0GHZP37_`2cd@>Oh0V:kA9e
mQiRo2a?oc/nod`_oEdRn6hGlGl>jI07gil3djh0ak`0^lP0[]<3XMd6U>D;R>`A
O?8GL?LNI_XUFod/D_hdBOlk@Om3>_m:=?iA;_eG:OaM9?YS8?UX7OM]6_Eb5oAf
5O9i5?5l4^mn4Nj04>j14>f23nf23nf24>j14>j04Nmn4_1k4o5h5O=e5oAa6OI]
7?QX8?UR9?]L:?eF;Oi?<om9>Om1@?ljB?lbDOh[F_/TI?PLKo@FN^l?Q^T:T^46
WmP2[<h0^L80aKD1dZL4gIL8ihL@l7LImfDTo5@bod=1oc=BoBEUmaQikPf>hPFR
d`6g`P3:[P;KV0WZPACeJB?lDCKo>dcn9fCg5WkZ2IWI0[?40<^[0mn?3_1c7_]F
<olkCOdSJo<AR^84ZL/0aZl3ghl>lFhRoDdloc1Ln1Qoj0NRd033/@?OSA3dJ2On
A4Kn9F_b3Y;K0KRl0MRF3O5]9?i5A_hTK_0<V=H0`K43hXLEn5/coc=Kn1B8h0:e
_@7KT13eHBoo=UWh58WO0[Ri0]n95?QG>?l[I_8<V]<0bJD8kG4ToSm@nQN5h@:j
]@?TP1_lBTKm7GcV1;>k0^636O];AOdMO^@3]kH3iG`OoD9?nQF;f`35YPS_JBgo
<6Ga2ZC70=Z;5_]<Ao`IQ]d1aJH9lF@bobU_j`Fb^@?WMRCo=V3c2ZG50Mn27Ohn
EoH=W/X0g8HJoD1EmPjNb@3MQ1cn?5[d2jC30N=j8olcI^l6/[H5k6X`obEhh`74
XPgfDdCl5I;A0=Z67OhhHO07/[@6kf<goQb7f@3DSAWm>eka1k:c1o5N??dHT=40
gH0Robi`i`;5WQ3jAUCe2Jfg1_1M?_`EUlX1i78]ob63f@3HQ23o;G?S0<fB6?hg
InX2a9`Bo3iOk`BnX`oj@e[a1K^V3_Y4FO45^jD?nT=Ll0BoXA7k?F;/0lFI5_df
JnH1cXdMob]ig@3JORSo7h[@0>I[=odCWkh5lUA<mPRfY`ok?6GY0Ln;8?lUQ=@0
iFXio12V]`SgB5[^0lRB7?lWP]@0iVLln`f][Pgj?FOV0=Io:_lHVL05m4aGk`;:
SB7o88o90o1DD?84aY4Nob6>b@?aDU?`0lZ;8olLU/46mDMOj@3FO2on4ZR`3O`e
MM/0iV=4mPK2U1ko7YC11_M2I^@0gfhln@VlVQ_o7i?11oM0JN40hfI4mPG6SBCo
5ZBa3_d^P=02lDaMj03NKCkg1/F=9OlDZJ/BoRN;aPKg?FoK0>]FEN`0fflnm`G8
Qb[m3[BN6olJWk8?oRR;a0Oi=gWC0_=6Iml0jeEHj@3RHd[`0MQa?oH4cg`enPO6
Qbgl2[j@9_h>]iLQoa6bWAko5:fR6olFZZDIoaNXYaSo6:NW6?lHZ:HIoaJZY1_o
5JfP7OlB/YXQo`nhU2Km2kn;;?/8ah4dn0C@MSkd0]UZBNh0heaGiP3/CFKK0O@n
Mlh6nRn:_Pgn89j/5olD/iLVo@W7P3Sf0]YWC^X0jTiXf@;g=XC23?hPXJLKo`jm
RC;h0mMXC^T0kDQ_dPGk:i>c5OlC]hl^n@CGJ53X0>m2Ml/9oB6QYAon2/Qi@O00
j4e/d`Gl9i^Z7?h;agY1k`3ZBG7>2?dPYIlTo0KCJU7U0?@gQk/Boa6mQ3[b0>Q;
L/`9oQb]UBgh0]mHI=H5o2:TWROk0m]MH=T4nbBRWbOj0maJHmH6oB2YUbgh0N=@
K/d:oaNgR3[a0>hoP[/Do`_;Ke3R0_TYWZ0Wn@;RD73:3?lB`7]6j03g;IZT9OX2
hTmca`oo3/MbD>42nb:YTc?c0>lkR[4Mo@CME6k93_l>bViEg0Gm6kF5@NX0mbVR
VC3d0?0gT:XTnP7WA86g6_d4ge1e`ACo1mQIK<T?o`[CH6K>3Ol<cfARd0co3LiU
HM4<o`g?Hf??3Ol;dUmXbPoo2=MHL<@DoPGNCWZj6_`2iT>8[RCh0>heV9h`l@3f
9jZ;@NL2oAVnM5GG2Ol<dUa^`aKm0nE2RZTYm@3e:JV:@n@4oQ?7J6?;4Oh5hTF9
ZB[d0?LT/85<g@So3=EFMkTNn@3a;ZF<@n85o`oAFWBk7OX0lRbXR4SN1ol;f51o
/2Kd0?PP^GEJca3n0nPiVIHmiPCo3]ADOK4Wm03j7<1/ILHHn`3a:Zf0D]D>o`?Y
=ij?A=l8o`OQ@I>I?>D5o`[LAhfO=nP4o`_JBH^P=^P4o`_KAhjM>^D6o`SP@IFE
@N09o`GW=j68CMH?oP7_:[5gG/LIn@3h7<AQM;<Yl0;n3]U8T9U0g`[o0n`][gQO
aAcg0?/EcUB4XcST1ol4jRn]N6347_H0o17EBXnFA=X>oP7d8<5QMjdaj@Ko1NX^
/G=W_2G`0_l9hcNVOUg47o@1oPcO?::1F/HNm07n2n0jYGiN`R7b0_l8iS:^LfRh
:^`5o`C^9[eRNZLih0cm0?PGdD^CSU7<6oD1o`WV<;9]LJhdh`_n0?PFddNIQUW4
8_04o`C`8/AGRII;ca[e0Ol7jbRmGX:LA]<GmP7o1n/X_eb5V4[?6o@2o`C`8<QA
TX]H`RK/1ol0n1CI?JQcKj`jfa;i0?l7k2C5Di6:F[lZj0[m0?`<i2jkGXNCD/DU
j`Sn0?/=i2jkG8V@E/4Yi`_l0?d9jbC7CYR0I[4hfQGf0_l2mQCL=[ARQ9=E`2_T
3_X0o`Cb6MHk[fN1UE?1;><?n@7o0oDDgC>iFhj7H[8ieaWa1Oh0o@W]7m10ZfR1
TeRk<]`Fm0Co0?d8kAgC?;5QRXYR/3gB7n`:o03o0_L@i2S8AjI[PI5K]CWE7^`:
n`3o0OT<jR3B?;=LTH1^XTc2;]dGl@Om0?l2n@cZ7mDh^EFJMGZFF[@ld2CV4?H4
oP3o0_P=jagG<km=Y6Z6R6VTCKldeakY3_L4oP3o0OX9l1KP:<`n]EJLL8::J:A?
_3SA9N<El@Wj0_l0o`;j2O4CiB;E<l97[EfGLh69JYmE]477;mPPiQ?a2OT3oP3o
0?h3n@[a4nLNfRc<>ka;ZefIKXR0MY9TXe>dA<<ed2SM7NLCl0cf1_/2oP3o0?l1
o@Ci2O<?k1KU7m`XdS;7?Ka8/EBUH9U/SWN2PgJ>JiUPY5J^C;Q3`C[9<]4Zf2CO
7N@HjQ?^3o8;mPSh1O/3o@;n0Ol0o`3o0?l0o`3n0Od2o0?k1OT6n0Sf2OD;l`ga
3_0@kQ;]4n/EjQKX5nLIiQ[U6n@KhacS7N8MhQgR7N8MhQgR7N8LhacT6n@JiAWV
6>PGjAGZ5>`BkA7_3o4>lPcd2_H9m`Oi1_X4n`?m0_h1o`3o0?l0o`3o0?h1o@;l
1?X6m`Wd3O4Ak1GW6^8Pg2OE;/heaSjmAkA@ZUZOIIE`RG]nQg:CIYmJZTnf@l4h
c2kF9>0Kj1?`3?H7n`?n0?l0o`7m0oT8m0o/5n<Rebk:?;a;[5^LK8YnN91WXEFc
A<<ddbGP6N`>m@Ok0Ol0o`7l1OH=kASP9]4g_dZ[GYIdP8]YXE>g?//[g1_[3_H5
o@3o0?d4m`k[6m/]b4:aFYUcOhiTZ4_0==HPj13e1Od0o`7k2?4EhRO=?[AIV7Ij
Tef`@LXYhAGb1o`0o`7k2NlHgBk4BJMXQhQWZ4O6;=lFlPOm0?l2n@gY8M8k]E^C
OW2QC/4_gAKb1_d0o`?f4^<YadRVK82AFkHheQc^2O`0o`?f4^8[a4fPLgRKD<4]
h1?f0ol0n`[[8Li2ZVZ0U5Jm<MhDm@?o0?X<ibK8BZ1eLj98bRCY2o`0o`Ga6]Dl
[VN1UU?1:n@>nP3o1?8IeSb]JGfJC/LUj@[m0?h8k2?9C9]mJJhjfAKe0_l2mAKH
?:a/NJ16cag`1Ol1n1;L=k1YNii7caga1?l1mQKG?ZQbLJTmfAGg0Ol5kR;8D9>9
F[lYj@Sn0?TBfcZ[LG2[>M`AnP3n2^H^^6AmX4?E5_L0o`OY:[aPPIe5e1Kg0?h8
ibfhIGZT?]/An`3l3]lhZWEZ]2oW2Ol1mQ[>CI:>DL`Km@7o2>H`/Vi`/37V2Ol1
m1g9EHVIAMHCnP3k4MQ4VXQEbAce0?h;h3ZUOEk28O82o`WT=ZUjHL0RlP;o2N<h
YWeMa1od0Oh=gCnMR5;>5oT0naCBCXbI@]`=oP7c8[mTM;4]k0Co2>@hY89Fc1Oj
0?THbeR0YcCW1_l6iSJUPUG>5O/0mag3HWBc:Nl2oPgIB8nI?n09o`CY=:J3D]4B
o@3b9[IbH/@Kn@3h7<9UKkXRm@3k5lUMM[<WlP3l5<eJNK4Xl@3l5<aKMk<Vl`3k
5lQQLKXQmP3i7Km[I/@InP3c9k9jEm4@oP;Z=In>A>07o`WLBHRV;nl1o1K7I6_1
6_/0lBbZQD_L2Ol8g4Z5ZR_b0?XM_79Lca3o1>DoTJ0ckP7k6L5^GldAoPCT@HjT
;o40nAnhN5CF2ol9fU1l]B3i0?4`XI8mj0;m5l5_G=8=o`SJDGZh7_X1k3NGWS7`
0?PS[hE6h`Cn5L=^Fm@;o`_CFfg55?h5h4an]agk0NPoRj/Un03^=YJQ;O@0lS2M
VS;a0?D[XYHek`3f:ZBD=^l0mRZSUCG`0?D/X9TalP3c<IVP;?D0kcR@ZBCi0NU2
Q;DLo@CPCgG24ol9e61Td@[o4LAdD>03o1j`Rc_^0?@`V:@Vn@7VB7^n5?l9dFEM
f0Kn6[F6?^d0lc>CZR7l0miDK<`;oa>oODGY0?D`UZPRo0CMF6SA2?hH]XPjl03^
?XBj5Ol;bg1?i07h;IRX8O`5f61MfPCk9:>M:?X3gUUTePKm8JNK:OX3gUYSe`Gl
9::P9O/4f6=Ig`;h;IF]6oh:bgA8jP3`?X313olE]Hdbm`7PF6;I0oX[UZhIo`c4
OCoa0>Q>K=<6o2JKZQco3<En?O80iE=Vf0?i;Y2f5?lC]hl^n@?GJ53X0>m4M<h7
o2NH[aOo4[R>;_X4e6i9k@3YD6KJ0_LfQ<<;oR2OZQ[o4KR@:o/6cWLol`7OH5CW
0>a;JMT2mSUmb@Sl:Y2i3olNXJXHoaB`Vb;n3Kf=;?/8b80fn0CAMCod0]U[Ao00
gf=?k03TG5GX0>MGF^D0jU=Mh`3[DF3R0>a@HN80k51PhP3[DUkT0>YEFnH0ieUF
j@3TGe3]0=mVBO41fFm1m@?ANCOi1/R5;_`;_I<Toa6`XA[o6Z6`4OhUT<09nc=m
d0?dA6WO0>YHE>`0ffhom`G9QR_m3[>P6OlMVKT;o35md@;bBf3V0>5X@oH5bHTX
oQ:[ZQ?n:8W91?E5I>@0hFU1m`K4T2;o69nf2o/eM]T0jUa<lP?;R2Oo5J>d3?/f
M=X0if56m@G4TQoo7IC21_I6HNP0f7TaoA2Z[`kl=G?M0>=Y?OX:]Z<CoRile`3W
I47h2KRQ5?h^NmP0iFPmnP^bZA3l=W3P0=ef<OhCX[T8mdMLk@;;SAoo8hS@0NUS
@?X<[jh=nSmSj@7?RR7o98KB0>IY>O`AY;T7mDiBl`JmX1;m=f[V0=6:8?lWP=P0
ggH]oa^Ab`7YIc[l4ik01>mK@oX=Z;P7leA:m`^^/PWeCdkf2K2`2OI?C_H:[k88
mE5;m`^[]`ObF4Gj3j>o1>eR>odEUlT1iVl`oaj7eP3KPB;o;7CT0L^F5O`nGO46
]Jl9m5I4na:Kb07TM2_o9G_P0<fF5?a2Eo@9[;T4kFHdoaj4f`3ATAKl@5Sd2ZVm
0nY];_lUN><1aJ0>me95naFCd@3HRA[m?UWd2jG20NAi9?lbI^h6/KP4jVl[oba]
j`Fe]0G/KBco;6g[1K>f1>Ua:?l`I^l8Zkl2hg`PoS]ImPjLc@3GSaCjCDGl6XGN
0L>X2?1X;_l^Io09Y/D0g8XFnde5oAb0hP:k/PCXMb;n?U?i58kJ0<FX1ne_9oli
F?PBT=T0a:T7k78ToSiAnQN7h0:j]@?SPAWkCT7n8g;/2:G90=:K3?5Y:OlkDoXG
Pn<3/kh1fY4@mF8^ocMFnAN4h`B``@3FU`caJbKn@T[m87C]2IkA0<F]1>B55OQL
<OlhE?/KNnX8XM00aJl3hHXBmF@Yod98oREZl`n>g`>`a03>Y@KVQ1CfHR[oA4Gn
:F?f58?W1j;B0;jh0MJL2>Yo5_MR:Oi7@?l`FOXLM?0>Sn04Z<d0`;P1e:06iHP@
lW0NnUX^odA1oc9Eo25ZmAB0j`ZDgPBXd02j`03:[`;HW@OTS0k^NQOfJB7kFRgn
BcWo?DKo<E?m9V7i7Fkd5G_^3hSX2Y?Q1IoI0jWA0K?90;c10<Bh0<^a0M:Y0]NR
1=fK1^6D2>F>2nR93N^43nio4O1k4o5h5O=e5oAc6?Ea6OE_6_I_6_I^6_I^6_I_
6_E`6OEb6?Ad5_=g5?5j4o1n4Nj33^^83>R=2^FC2>6I1MbP0mNW0]6_0<Zf0<>o
0;_70;;?0JSG19kO1i;V38K]4G[c66gh8F3l:e;o=TGo@cSoDB_lH23gL1K`P@gW
T`KKY@;>]P2na`2/ePBIi0^5kaE`n2=KoS=6odHcoE/Rmg8CkHX8gZ<2c;X0]/l2
W^8;Q?4HJO/ZCom1=_iK8OIg4>RE1=Ba0;c<0YoR383c767m=4;oD2SiL1?[TPGD
/`2hd0>Gj15cn2M@odD`o6PGkXd6e[80]]85TN`EJ_/`A?mC9?Ik3>6T0L;90Y_W
4G3j;DOoDRCfOP_NZ@2jd@F?kQUQoS/goFHFjiD3bl81WnHAKo/a@?mM6nn?1<jo
0J7U4Fkl<cgnHaO[U`;6b0>DkAUNod8^nGL<gJh0[m`;N?T^@_iQ5nZJ0L3?1HWc
8dkoEAk`T0?8b0>?lAmCoe8PlHl3alT4S?8RC_mH6nfH0KkB1h3h;D3nJ17RZP2/
hA5YoT4/mh86c/@3So8TB_mP5NJV0:kQ4FOnABOdR`?5cPMonC4ingH:eKh2T_8T
B?mV4N2a09o[75;oG1KUZ@2Vj1QGoePHijL0YnLHEomJ5nFZ0:?Z757oHA;P/`2I
l2=6oVh<e/03ROL`=oZ01LKA2G?m@bG`V@2`haIHoehCgkH1TO@/>_Z01LCD36cn
CAgYZ02NkbA3oGP7bM0:Koi;7NVY09_a:3gkP0C1f0mRoeTDg[X2QoTi:o:I0:SZ
84KmN@K4ePiRoe`Afl04OOa48N^Y09Kd<3;eT`2ZjR53o803^mlFDom_2<WD3V7o
H@kCbPU]oeLCfl86M_i?5n2l17cmBQ[S^0=oo4PLi;L3P?a86n>h0ggmBaWQ_0Ah
oU0Eg<87L?mI4=G:2VKoI0_<eA1Hog86_n0IBOb40Jk[9SSfV02JmCHWk:h1Poa<
5mc526SoIPW6faI<o8@1Z^h[<?6U08WkB1SLa@UUof`7_^8N@?RD09Sg?AoS_@I/
ofL8`N4M@?RF09Ci@a_Na@YQog@4/n/Y<?2[0WgnFPg:faU4nID0T_Y75mS=3eCm
Q@2PmC`Nh<@:GOml0JOb=b;S`0UPog/2Z?8g8N;32UcnP06QmChKg</?D_b<09Cj
Ba;@f1Q1mYl1P?iP2;gW:Bg[^0MTog`1XOI25mGD5TCgX05lofH6]>hb8n773U7k
T`27oUd9^nX^9^C43E;kU025oV47]^dc8Mk<4TShX05fog42YOI45<kM83?/^@UK
oHl0Q_iS1K3b?1WDfAdfk[L8F_fA087oJP>WmTHBbN<X:NC84DKfZ0AXohH0R_iU
1:[eAQ77iB/TgllG??2e25OkVP5dogd0SoeR1J[fB@o1jS<Me]XQ;^K84d7b/`QF
nYh2Jon9083oM@2DoF84Y_Q@2[Oa@A;6j3<LdmhW9]kD7C7WbA@lk[d>AoBb2E;h
Z0ELnih3I_fE0FooS01gohD0O_mn08CoN029og<0S_m`0I7nK@6DoV/1UOiY0IKn
J@6EoVX1U?i/0I;nKP6?og80Romf08KoO020oh80N_n907;oT@5YoIX3H?^T1UKh
[PU;lkT?@>g45CGVcahZg=XX8=7U=1K4kT8=]OIB1ZCkI0:AogL0O_n<0FWlX@ED
m[H>?n_:6bcLg2`Kb^]03K?gF0BJoW<0Oon?0F;jZ`Y7klHI;McM;QS4l4T8YoaX
08KoRP5TnZ`;@nc;7RKDiCX?]OML0Y3oPP1YnjT:A>_=82?@jD0;[?]X087oT`=F
mKdE;m_P=A6fn5l1ROn>0UWf_1D_f^8h3k7jIP20oiT5CNo97b;=kDT6W?mn06Ki
]14cgN4g3ZkkK01foJH;?^GI;a>gnFD0O?jR2D7WebhD]_UW07SmYP/kh]de3jgl
LP1[n[@C;]KXA@NJohP2EO798Qc1mUl0O?jW33SNhSd9Won50UGabbDI_?QW077k
/a@[d^e?0hWoW@TmhN4m2IcoR`A<jmH`4:[mOP5HlLdX5KCkM@1Om<LS6;SjL@1R
mLHR6KWjL@1Qm<PT5kGkMP1KlLhZ4ZgmP09@k=Ld3:3oS`I2h^921XkoXPdae>iF
0GOk^1XO_oU`05cad2h>Xon?1SoNid/3POfb5b;2n700F^oD<`^Koi/;<m?`G01/
mlLW4ZWoSPLlfn]D0G?i`R@DZon=1ScJk5H0KoO7:12ToiH:<]7bI01PlM@f293o
ZaDQ_O]m0dKQie01L_S8:`jMoj4@9lCiN099h^MA06ofc2l;UOn[5QnhoHP6>MGb
I@1Hjmm60WSiab`<Uon[5abcoXl9<LcgM098gn]J063^fd<2N?S:;`V>o[HP4j?o
Xa<P]_j@2Rg6nWh4>mCdKP59gneO05KWiE80H^kMA`5^m=Dn0gSgcSH6P?[8<0R8
o<8[2Xgm_RP<TOjj9@jDo[PT3YKn^2<>U_jh90jDo[XV3I7m_BT;SOc2;@V7nlLb
1X3icCP4MoKE@@9]lMa;067[i5H0EN?/I017fO=c0cW=nH@8:kknUQ0N[OnY71:I
o[`[28?iccd2K>oQD`1ChNm/0Sc>nXL:9[KoXaTCV_jo;PIkmMQ905_UkFT2?<ck
R`dQ[On_8Pb9n/lo0F?YjV@1?/gkS@hNZOne:0Qnm]U<05?NlgP6:kWoYah>Ro[A
@`1Jh_1c1BjkojHN3HWie4P0E=gdO0TV/?nc:0Mhl^5J047=o9DD5IKlc400FN3c
O0TT[?nj;`A]k>YZ0c2koj`T27Wbhel1><?nYAl;OoCPF`4jaOjT7`]nln9N0CO1
ojXT27K_ifP4;[Ko\>"]},
  ImageCacheContents->"Sound"]
}, Open  ]],

Cell[TextData[{
  "To deepen understanding and further promote active learning, \"take-home\" \
assignments and computer projects complement such simple exercises. It has \
been our experience that projects are an important learning instrument. Given \
a capable computational tool that makes mathematics more accessible and \
programming easier, projects help to motivate the student, they reward \
initiative and creativity, and prepare for independent, unassisted learning. \
Examples of recent projects include:\n\[FilledSmallSquare] implementation of \
the fast DCT (image processing)\n\[FilledSmallSquare] comparison of \
differential, transform and sub-band compression methods (image processing)\n\
\[FilledSmallSquare] ",
  ButtonBox["implementation of a spectrogram plot",
    ButtonData:>{"Projects.Spectrogram.nb", None},
    ButtonStyle->"Hyperlink"],
  " (signals and systems)\n\[FilledSmallSquare] implementation of an ADPCM \
system for speech signals (communications)\n\[FilledSmallSquare] Schur-Cohn \
stability test (dsp)\n\[FilledSmallSquare] ",
  ButtonBox[
  "comparison of design methods for a FIR half-band differentiator",
    ButtonData:>{"Projects.Differentiator.nb", None},
    ButtonStyle->"Hyperlink"],
  " (dsp)\nSystematic use of writing and revision is also an important \
cognition tool, so an essential component of these projects is the \
requirement that results be presented in clear, coherent prose."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Courseware Development", "Section"],

Cell[TextData[{
  "To date, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has been integrated into four upper-level electrical engineering courses \
in the signal processing area, including junior-level ",
  ButtonBox["Signals and Systems",
    ButtonData:>{
      URL[ "http://www.ee.usm.maine.edu/ee/faculty/mjkcc/docs/ele314/"], 
      None},
    ButtonStyle->"Hyperlink"],
  ", and three senior-level courses: ",
  ButtonBox["Communications Engineering",
    ButtonData:>{
      URL[ "http://www.ee.usm.maine.edu/ee/faculty/mjkcc/docs/ele483/"], 
      None},
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["Digital Signal Processing",
    ButtonData:>{
      URL[ "http://www.ee.usm.maine.edu/ee/faculty/mjkcc/docs/ele486/"], 
      None},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["Digital Image Processing",
    ButtonData:>{
      URL[ "http://www.ee.usm.maine.edu/ee/faculty/mjkcc/docs/ele489/"], 
      None},
    ButtonStyle->"Hyperlink"],
  ". A large number of supporting notebooks has been developed that accompany \
and extend the traditional, well-known and widely used textbooks:"
}], "Text"],

Cell[TextData[{
  "[1]\tOppenheim, A.V., Willsky, A.S. and Navab, S.H., ",
  StyleBox["Signals and Systems",
    FontSlant->"Italic"],
  ", 2nd Edition, Prentice Hall, 1997.\n[2]\tProakis, J.G. and Manolakis, \
D.G., ",
  StyleBox["Digital Signal Processing",
    FontSlant->"Italic"],
  ", 3rd Edition, Prentice Hall, 1996.\n[3]\tGonzalez, R.C. and Woods, R.E. ",
  
  StyleBox["Digital Image Processing",
    FontSlant->"Italic"],
  ", Addison-Wesley, 1992.\n[4]\tLathi, B.P. ",
  StyleBox["Modern Digital and Analog Communication Systems",
    FontSlant->"Italic"],
  ", 3rd Edition, Oxford Press, 1998."
}], "Text"],

Cell["\<\
A few simple principles govern the organization of each notebook. A notebook \
typically deals with a single important course topic. It includes moderate \
levels of introductory and explanatory text to allow some degree of \
independent study. The notebooks have examples of typical calculations that \
demonstrate solutions to standard problems. Additionally, each notebook \
includes \"discussion problems\" that students answer during the lecture \
session. This activity promotes self-discovery, and allows the student to \
actively participate during the lecture. Finally, a set of basic and extended \
computer-based homework problems/projects are attached to each notebook.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example Notebooks", "Section"],

Cell[TextData[{
  "\[FilledSmallSquare]\t",
  ButtonBox["ELE314",
    ButtonData:>{"ele314.nb", None},
    ButtonStyle->"Hyperlink"],
  ": Signals and Systems\n\[FilledSmallSquare]\t",
  ButtonBox["ELE483",
    ButtonData:>{"ele483.nb", None},
    ButtonStyle->"Hyperlink"],
  ": Communication Engineering\n\[FilledSmallSquare]\t",
  ButtonBox["ELE486",
    ButtonData:>{"ele486.nb", None},
    ButtonStyle->"Hyperlink"],
  ": Digital Signal Processing\n\[FilledSmallSquare]\t",
  ButtonBox["ELE489",
    ButtonData:>{"ele489.nb", None},
    ButtonStyle->"Hyperlink"],
  ": Digital Image Processing"
}], "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->"EditBar",
WindowSize->{639, 526},
WindowMargins->{{113, Automatic}, {Automatic, 45}},
PrintingCopies->1,
PrintingPageRange->{6, 6},
StyleDefinitions -> "ArticleClassic.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 54, 0, 40, "Title"],
Cell[1788, 53, 60, 0, 30, "Subtitle"],
Cell[1851, 55, 72, 3, 61, "Author"],

Cell[CellGroupData[{
Cell[1948, 62, 31, 0, 50, "Section"],
Cell[1982, 64, 946, 15, 179, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2965, 84, 44, 0, 50, "Section"],
Cell[3012, 86, 694, 15, 79, "Text"],
Cell[3709, 103, 783424, 10780, 231, 604358, 8564, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[787170, 10888, 27, 0, 50, "Section"],
Cell[787200, 10890, 1316, 27, 150, "Text"],
Cell[788519, 10919, 126, 2, 22, "Text"],

Cell[CellGroupData[{
Cell[788670, 10925, 160, 3, 40, "Input"],
Cell[788833, 10930, 105, 2, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[788975, 10937, 242, 4, 40, "Input"],
Cell[789220, 10943, 136, 3, 41, "Output"]
}, Open  ]],
Cell[789371, 10949, 113, 2, 22, "Text"],

Cell[CellGroupData[{
Cell[789509, 10955, 168, 3, 62, "Input"],
Cell[789680, 10960, 345, 7, 41, "Output"]
}, Open  ]],
Cell[790040, 10970, 154, 4, 22, "Text"],
Cell[790197, 10976, 77, 2, 23, "Input"],

Cell[CellGroupData[{
Cell[790299, 10982, 222, 4, 64, "Input"],
Cell[790524, 10988, 458, 8, 58, "Output"]
}, Open  ]],
Cell[790997, 10999, 94, 1, 22, "Text"],

Cell[CellGroupData[{
Cell[791116, 11004, 444, 9, 70, "Input"],
Cell[791563, 11015, 214, 4, 62, "Output"]
}, Open  ]],
Cell[791792, 11022, 418, 10, 50, "Text"],
Cell[792213, 11034, 173, 5, 22, "Text"],

Cell[CellGroupData[{
Cell[792411, 11043, 228, 4, 36, "Input"],
Cell[792642, 11049, 63683, 1382, 254, 21954, 862, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[856340, 12434, 191, 6, 22, "Text"],

Cell[CellGroupData[{
Cell[856556, 12444, 183, 4, 23, "Input"],
Cell[856742, 12450, 20314, 592, 192, 5708, 407, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[877071, 13045, 244, 4, 36, "Text"],

Cell[CellGroupData[{
Cell[877340, 13053, 154, 3, 23, "Input"],
Cell[877497, 13058, 143356, 1900, 192, 33936, 475, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1020890, 14963, 154, 3, 23, "Input"],
Cell[1021047, 14968, 110321, 1457, 192, 21000, 307, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[1131383, 16428, 1451, 24, 193, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1132871, 16457, 41, 0, 50, "Section"],
Cell[1132915, 16459, 1138, 31, 65, "Text"],
Cell[1134056, 16492, 619, 16, 65, "Text"],
Cell[1134678, 16510, 705, 10, 112, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1135420, 16525, 36, 0, 56, "Section"],
Cell[1135459, 16527, 611, 18, 78, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

