(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    320329,       8035]*)
(*NotebookOutlinePosition[    321325,       8069]*)
(*  CellTagsIndexPosition[    321281,       8065]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["FOURIER SERIES", "Title"],

Cell["LECTURE 9 ", "Subtitle"],

Cell["ELE314: LINEAR SIGNALS AND SYSTEMS", "Subsubtitle"],

Cell[TextData[
"Mariusz Jankowski \[Copyright]\nDepartment of Electrical Engineering\n\
University of Southern Maine\nmjkcc@usm.maine.edu"], "Subsubtitle"],

Cell[BoxData[
    \(<< SignalPlot`\)], "Input"],

Cell[CellGroupData[{

Cell["INTRODUCTION", "Section"],

Cell["\<\
To start, consider the following important fact about LTI systems: the system \
response to a linear combination of some basic signals is a superposition of \
the individual responses of the system to each basic signal. Furthermore, the \
response of an LTI system to a sinusoidal signal is sinusoidal in form! \
Formally, the family of sinusoids is an eigenfunction of linear time \
invariant systems. Sinusoidal signals are therefore extremely useful in the \
analysis of LTI systems. In the early 19th century, the French mathematician \
Jean Baptiste Fourier showed that a large class of interesting functions \
could be represented by linear combinations of harmonically related \
sinusoids. \
\>", "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
MathPictureStart % Start of picture
% Scaling calculations
0 1 0 1
[
[ 0.000000 0.000000 0 0 ]
[ 1.000000 0.992248 0 0 ]
] MathScale
% Start of Graphics
0 setgray
0 setlinewidth
gsave
0.000000 0.000000 translate
1.000000 0.992248 scale
1 string
129 128 8 [129 0 0 128 0 0] {
 currentfile
 1 index
 readhexstring
 pop
} false 3 colorimage
FCFCFCF4F4F4F9F9F9F6F6F6F5F5F5F4F4F4F6F6F6F3F3F3F5F5F5F3F3F3
F5F5F5F3F3F3F8F8F8F5F5F5F5F5F5F6F6F6F9F9F9F7F7F7F6F6F6F3F3F3
F3F3F3F1F1F1F5F5F5F3F3F3F5F5F5F4F4F4F4F4F4F3F3F3F3F3F3F5F5F5
EFEFEFF5F5F5EFEFEFF3F3F3F3F3F3F5F5F5F1F1F1F1F1F1F1F1F1F4F4F4
F1F1F1ECECECF5F5F5F3F3F3F4F4F4F3F3F3F8F8F8F3F3F3F1F1F1FCFCFC
F6F6F6ECECECEFEFEFF3F3F3EDEDEDF1F1F1F3F3F3F1F1F1ECECECEDEDED
F4F4F4F5F5F5F6F6F6F3F3F3F8F8F8F3F3F3F3F3F3F8F8F8F4F4F4F1F1F1
F5F5F5F0F0F0EEEEEEF4F4F4EBEBEBF5F5F5EDEDEDF3F3F3F3F3F3F3F3F3
FAFAFAF7F7F7F5F5F5EDEDEDECECECF3F3F3F3F3F3F9F9F9FBFBFBFBFBFB
ECECECF4F4F4F8F8F8ECECECEFEFEFF8F8F8F1F1F1F5F5F5F3F3F3FBFBFB
F4F4F4F0F0F0F6F6F6EFEFEFF1F1F1EDEDEDECECECF1F1F1EAEAEAEFEFEF
F8F8F8F7F7F7F0F0F0F0F0F0F5F5F5F5F5F5F8F8F8F3F3F3F5F5F5F5F5F5
EEEEEEF6F6F6EEEEEEEDEDEDEDEDEDF5F5F5EFEFEFF7F7F7F1F1F1
F8F8F8F9F9F9F6F6F6F9F9F9F4F4F4F8F8F8F5F5F5F4F4F4F1F1F1F5F5F5
E2E2E2F3F3F3F7F7F7F3F3F3F5F5F5F8F8F8F8F8F8F8F8F8F1F1F1F1F1F1
EDEDEDF5F5F5F4F4F4F4F4F4F7F7F7F8F8F8F3F3F3F3F3F3F5F5F5EFEFEF
F8F8F8F5F5F5F3F3F3F6F6F6F5F5F5F8F8F8F7F7F7F5F5F5EEEEEEF4F4F4
F7F7F7F0F0F0F7F7F7F3F3F3F4F4F4F9F9F9F6F6F6F5F5F5F1F1F1F6F6F6
F8F8F8F1F1F1F0F0F0F4F4F4F1F1F1EEEEEEEEEEEEEDEDEDEEEEEEEDEDED
F7F7F7FBFBFBF4F4F4F5F5F5F9F9F9F3F3F3F3F3F3F8F8F8F6F6F6EFEFEF
F7F7F7E5E5E5F6F6F6F5F5F5E9E9E9EEEEEEF6F6F6F3F3F3F5F5F5F5F5F5
F8F8F8F8F8F8F3F3F3F5F5F5F4F4F4F1F1F1F1F1F1FCFCFCFAFAFAF6F6F6
EAEAEAF5F5F5F4F4F4F1F1F1F5F5F5EFEFEFF1F1F1F9F9F9F4F4F4F5F5F5
F4F4F4F6F6F6F5F5F5F1F1F1F7F7F7F5F5F5EEEEEEEEEEEEF1F1F1F3F3F3
F9F9F9F8F8F8F4F4F4F1F1F1F1F1F1F3F3F3FAFAFAF1F1F1E3E3E3F1F1F1
EEEEEEF5F5F5F9F9F9F1F1F1F7F7F7F3F3F3F5F5F5FAFAFAF0F0F0
F8F8F8FAFAFAF5F5F5F8F8F8F5F5F5F8F8F8F7F7F7F5F5F5F1F1F1F1F1F1
F3F3F3F1F1F1F5F5F5F4F4F4F9F9F9F6F6F6F5F5F5F4F4F4F1F1F1F3F3F3
F5F5F5F1F1F1F5F5F5F4F4F4F4F4F4F5F5F5F3F3F3F4F4F4F3F3F3F4F4F4
EDEDEDF3F3F3F1F1F1F6F6F6F6F6F6F7F7F7F8F8F8F3F3F3F0F0F0ECECEC
F7F7F7ECECECFAFAFAF1F1F1F5F5F5F6F6F6F1F1F1F8F8F8EEEEEEFBFBFB
F8F8F8F3F3F3F1F1F1F5F5F5F2F2F2EDEDEDE1E1E1EEEEEEF4F4F4EFEFEF
F8F8F8FDFDFDF5F5F5F6F6F6F5F5F5F1F1F1F9F9F9F6F6F6F4F4F4F1F1F1
F4F4F4F1F1F1F1F1F1F4F4F4F3F3F3F4F4F4EFEFEFE8E8E8F1F1F1F3F3F3
F8F8F8F2F2F2F3F3F3F4F4F4E6E6E6F4F4F4EEEEEEF7F7F7F7F7F7F8F8F8
ECECECF5F5F5F1F1F1E9E9E9EBEBEBF7F7F7F3F3F3F9F9F9F0F0F0FAFAFA
F5F5F5F4F4F4F5F5F5E4E4E4F6F6F6F6F6F6F2F2F2F3F3F3F8F8F8E8E8E8
F7F7F7F4F4F4E9E9E9F5F5F5F3F3F3F0F0F0F8F8F8F1F1F1F1F1F1F6F6F6
EDEDEDF5F5F5F3F3F3EEEEEEF3F3F3EBEBEBF6F6F6F9F9F9F1F1F1
F3F3F3F3F3F3F6F6F6FCFCFCF8F8F8F7F7F7F8F8F8F6F6F6F4F4F4F4F4F4
F4F4F4F3F3F3F5F5F5F7F7F7F6F6F6FAFAFAF3F3F3F4F4F4F5F5F5F7F7F7
F5F5F5F7F7F7F5F5F5F3F3F3F8F8F8F8F8F8F6F6F6F3F3F3F6F6F6F8F8F8
F8F8F8F7F7F7F6F6F6F8F8F8F8F8F8F7F7F7FAFAFAFBFBFBF5F5F5F4F4F4
F0F0F0F6F6F6F8F8F8F9F9F9F8F8F8F8F8F8F6F6F6F5F5F5F9F9F9F8F8F8
F1F1F1F8F8F8F7F7F7F8F8F8EAEAEAEEEEEEF5F5F5F1F1F1F3F3F3E6E6E6
F8F8F8F8F8F8F9F9F9F5F5F5FCFCFCF1F1F1F3F3F3F8F8F8F8F8F8F8F8F8
F6F6F6F5F5F5F8F8F8F7F7F7F7F7F7F4F4F4F5F5F5EEEEEEF1F1F1F1F1F1
F8F8F8F8F8F8FBFBFBF5F5F5F6F6F6F3F3F3F8F8F8F8F8F8F8F8F8FAFAFA
F5F5F5FAFAFAF1F1F1E4E4E4F6F6F6FDFDFDF7F7F7FBFBFBF4F4F4FBFBFB
F6F6F6F8F8F8F8F8F8F7F7F7F9F9F9F5F5F5F8F8F8F5F5F5EDEDEDF9F9F9
F5F5F5F7F7F7F9F9F9F8F8F8F2F2F2ECECECEAEAEAF7F7F7F7F7F7EFEFEF
F5F5F5F3F3F3F4F4F4F8F8F8F9F9F9FBFBFBF3F3F3F5F5F5F8F8F8
F8F8F8F6F6F6F4F4F4FAFAFAFCFCFCF5F5F5F7F7F7F7F7F7F5F5F5F5F5F5
F4F4F4EFEFEFF9F9F9F5F5F5FBFBFBF1F1F1F3F3F3F4F4F4F8F8F8F9F9F9
F8F8F8F8F8F8F5F5F5EDEDEDF8F8F8F5F5F5F8F8F8F4F4F4F9F9F9FBFBFB
F7F7F7F7F7F7F1F1F1F7F7F7F8F8F8FDFDFDF5F5F5F8F8F8FCFCFCF6F6F6
F3F3F3F0F0F0F6F6F6F9F9F9FBFBFBFFFFFFF8F8F8FDFDFDFAFAFAF7F7F7
FAFAFAF8F8F8F8F8F8FAFAFAF1F1F1FCFCFCF8F8F8F8F8F8F3F3F3F4F4F4
F8F8F8FAFAFAF9F9F9F9F9F9FCFCFCF7F7F7FCFCFCF8F8F8F8F8F8F9F9F9
F8F8F8F1F1F1FAFAFAFBFBFBF5F5F5F8F8F8F6F6F6F8F8F8EDEDEDF5F5F5
FAFAFAF8F8F8F8F8F8F5F5F5F7F7F7F8F8F8F8F8F8F8F8F8FAFAFAF9F9F9
F8F8F8F4F4F4EEEEEEFAFAFAF5F5F5FBFBFBF8F8F8FBFBFBF5F5F5FFFFFF
F7F7F7F8F8F8EEEEEEF9F9F9F6F6F6F6F6F6F5F5F5F5F5F5F8F8F8F5F5F5
FCFCFCFEFEFEF9F9F9FDFDFDF5F5F5F8F8F8F1F1F1E6E6E6FCFCFCF8F8F8
F2F2F2FDFDFDF1F1F1F3F3F3F9F9F9FAFAFAF3F3F3F7F7F7F7F7F7
F8F8F8F6F6F6F8F8F8F9F9F9F9F9F9F7F7F7F6F6F6F5F5F5F7F7F7F5F5F5
F5F5F5F6F6F6F8F8F8F5F5F5F1F1F1EDEDEDF5F5F5F6F6F6FAFAFAFBFBFB
F8F8F8F8F8F8F8F8F8F7F7F7FAFAFAFAFAFAF8F8F8F8F8F8F9F9F9FEFEFE
F8F8F8F8F8F8F7F7F7F9F9F9FBFBFBFAFAFAF8F8F8F8F8F8F7F7F7F7F7F7
F9F9F9F8F8F8F1F1F1F4F4F4F9F9F9FAFAFAF3F3F3F7F7F7F7F7F7F8F8F8
F8F8F8FFFFFFF5F5F5F6F6F6FAFAFAF7F7F7F8F8F8FDFDFDF7F7F7F7F7F7
FDFDFDF8F8F8FAFAFAF5F5F5FBFBFBF5F5F5F5F5F5F8F8F8F4F4F4F7F7F7
F2F2F2F8F8F8F7F7F7F7F7F7F7F7F7FAFAFAF8F8F8F5F5F5F8F8F8FFFFFF
EAEAEAF9F9F9FCFCFCFAFAFAF8F8F8F6F6F6F8F8F8F6F6F6F9F9F9F5F5F5
EAEAEAF1F1F1FAFAFAF8F8F8F8F8F8F7F7F7FAFAFAF3F3F3F3F3F3F4F4F4
F9F9F9FAFAFAFAFAFAF8F8F8F5F5F5FDFDFDF8F8F8F6F6F6F9F9F9F9F9F9
F8F8F8F5F5F5F9F9F9F7F7F7F8F8F8F8F8F8F8F8F8FAFAFAEEEEEEF4F4F4
F9F9F9F9F9F9F7F7F7F3F3F3F9F9F9FAFAFAF8F8F8F8F8F8F8F8F8
F6F6F6F2F2F2FCFCFCF3F3F3F5F5F5F9F9F9F7F7F7FBFBFBF8F8F8F5F5F5
F5F5F5F5F5F5F8F8F8F1F1F1F3F3F3F4F4F4F5F5F5F7F7F7FAFAFAF2F2F2
F7F7F7F5F5F5F8F8F8F7F7F7F8F8F8F8F8F8F7F7F7F8F8F8FDFDFDF8F8F8
FAFAFAF5F5F5F5F5F5F7F7F7FCFCFCF7F7F7F8F8F8F9F9F9F6F6F6F5F5F5
F5F5F5F9F9F9F7F7F7F0F0F0F5F5F5F8F8F8F8F8F8F8F8F8F6F6F6F6F6F6
F7F7F7EAEAEAF0F0F0F1F1F1F8F8F8F7F7F7F3F3F3F6F6F6F8F8F8F6F6F6
F3F3F3F5F5F5F9F9F9F8F8F8F3F3F3F4F4F4F3F3F3F8F8F8FBFBFBF4F4F4
F7F7F7F8F8F8FAFAFAF8F8F8F2F2F2F3F3F3F8F8F8F3F3F3FBFBFBFAFAFA
F5F5F5F1F1F1F8F8F8F4F4F4F7F7F7F5F5F5F8F8F8F9F9F9F5F5F5F1F1F1
F1F1F1E8E8E8F1F1F1F6F6F6F8F8F8F9F9F9F6F6F6F8F8F8F6F6F6F9F9F9
F7F7F7F7F7F7F7F7F7F6F6F6EEEEEEF3F3F3F9F9F9F3F3F3F8F8F8F7F7F7
F0F0F0F8F8F8F5F5F5F7F7F7F2F2F2F8F8F8FDFDFDF7F7F7F4F4F4F0F0F0
F5F5F5FBFBFBF5F5F5F3F3F3F8F8F8F9F9F9F3F3F3F9F9F9F9F9F9
F9F9F9F7F7F7F8F8F8F4F4F4F8F8F8F4F4F4F4F4F4F4F4F4F6F6F6F5F5F5
F3F3F3F1F1F1F4F4F4F1F1F1FCFCFCF3F3F3F8F8F8F3F3F3F3F3F3F6F6F6
F3F3F3F5F5F5F5F5F5F4F4F4F5F5F5F4F4F4F9F9F9F1F1F1F4F4F4EEEEEE
F5F5F5F0F0F0F3F3F3F3F3F3F4F4F4F7F7F7F8F8F8F8F8F8F5F5F5F7F7F7
F4F4F4F5F5F5F4F4F4F3F3F3EEEEEEF7F7F7F6F6F6F3F3F3F3F3F3F4F4F4
E9E9E9F0F0F0EFEFEFF5F5F5F3F3F3F0F0F0F3F3F3F1F1F1F0F0F0EEEEEE
F8F8F8F3F3F3F5F5F5F4F4F4E2E2E2F5F5F5F5F5F5ECECECF6F6F6F1F1F1
F6F6F6F8F8F8F9F9F9F3F3F3F1F1F1F9F9F9F7F7F7F5F5F5F8F8F8FDFDFD
F6F6F6E9E9E9EDEDEDEFEFEFECECECF3F3F3F5F5F5F5F5F5F0F0F0F9F9F9
F1F1F1F5F5F5EFEFEFEEEEEEF6F6F6FEFEFEF9F9F9F8F8F8F3F3F3F5F5F5
EFEFEFF8F8F8F3F3F3F3F3F3F5F5F5EDEDEDF6F6F6EBEBEBF3F3F3F0F0F0
F3F3F3F6F6F6F4F4F4FCFCFCEFEFEFF5F5F5F8F8F8EEEEEEF4F4F4F1F1F1
F0F0F0FBFBFBEBEBEBF7F7F7F5F5F5FDFDFDF9F9F9FCFCFCF6F6F6
F8F8F8FAFAFAFBFBFBF8F8F8F5F5F5F8F8F8F2F2F2F5F5F5F6F6F6F1F1F1
F1F1F1F5F5F5EEEEEEEDEDEDF1F1F1F5F5F5F4F4F4F1F1F1F5F5F5F4F4F4
F3F3F3F1F1F1F1F1F1ECECECF3F3F3F1F1F1F1F1F1ECECECF2F2F2F6F6F6
F8F8F8F3F3F3E9E9E9F8F8F8F5F5F5FCFCFCF4F4F4FCFCFCF9F9F9F9F9F9
F8F8F8EDEDEDFFFFFFFDFDFDF4F4F4EFEFEFF9F9F9F6F6F6F4F4F4F1F1F1
EFEFEFEDEDEDFDFDFDF1F1F1F0F0F0F7F7F7F5F5F5F2F2F2FAFAFAF5F5F5
F6F6F6FFFFFFFBFBFBF4F4F4F8F8F8FCFCFCFBFBFBF6F6F6F6F6F6F3F3F3
F2F2F2F9F9F9F7F7F7F3F3F3F5F5F5FDFDFDF4F4F4F6F6F6FFFFFFF4F4F4
ECECECF3F3F3F0F0F0EBEBEBF1F1F1EDEDEDF5F5F5EBEBEBE9E9E9F0F0F0
EEEEEEF5F5F5FFFFFFF6F6F6F3F3F3FBFBFBF1F1F1F3F3F3ECECECEEEEEE
E7E7E7F3F3F3F0F0F0EFEFEFE6E6E6F5F5F5F4F4F4F1F1F1EFEFEFF0F0F0
F0F0F0F5F5F5EBEBEBF1F1F1F5F5F5F6F6F6F1F1F1F5F5F5EDEDEDF1F1F1
E8E8E8EBEBEBEFEFEFEAEAEAF4F4F4F6F6F6EEEEEEF8F8F8F4F4F4
F5F5F5FAFAFAF5F5F5F5F5F5F3F3F3EBEBEBEAEAEAE8E8E8EAEAEAE7E7E7
E1E1E1E5E5E5E6E6E6DEDEDEE9E9E9E7E7E7E6E6E6DFDFDFEAEAEADDDDDD
D8D8D87676761E1E1E0000001515151F1F1F0000003737371E1E1E000000
0000000707070F0F0F1616161F1F1F2B2B2B0505050A0A0A1E1E1E161616
0A0A0A1D1D1D2121211616161C1C1C1515150404042C2C2C000000313131
3434341A1A1A0E0E0E0000003838381C1C1C4A4A4A2D2D2D000000070707
2424241313130505052626263D3D3D0101010F0F0F0D0D0D2929291E1E1E
3C3C3C2323231919191313130F0F0F212121181818313131202020F4F4F4
E8E8E8E8E8E8EBEBEBDCDCDC979797E4E4E4E0E0E0161616111111232323
161616606060F1F1F1FCFCFC1515150B0B0B0000000707072B2B2B292929
2D2D2D0000001111110202020202020606060D0D0D1515151A1A1A161616
0F0F0F2B2B2B0A0A0A171717EAEAEAE3E3E3CACACAD9D9D9DADADAD2D2D2
D1D1D1E8E8E8DFDFDFCBCBCBE2E2E2F5F5F5F5F5F5F3F3F3F6F6F6
F8F8F8FAFAFAF9F9F9FAFAFAF0F0F0EBEBEBE8E8E8ECECECD4D4D4E2E2E2
E6E6E6E3E3E3EAEAEAE7E7E7EEEEEED9D9D9E4E4E4EBEBEBE8E8E8E2E2E2
E1E1E1A6A6A61C1C1C0F0F0F1919191F1F1F0000002222221B1B1B0E0E0E
0303031D1D1D111111151515212121212121000000000000171717151515
0000001111113636361F1F1F151515212121262626151515000000131313
1515150E0E0E0B0B0B272727181818151515282828383838070707060606
2424242222220303033131311C1C1C0202020000002E2E2E0B0B0B232323
3030303232320000000606062929291515151818189A9A9A0A0A0AEBEBEB
EEEEEEE3E3E3EAEAEABEBEBEDEDEDED0D0D0DFDFDF6A6A6A2929292B2B2B
222222000000E0E0E0E8E8E80000000000000F0F0F060606181818272727
2A2A2A000000000000000000000000131313080808000000000000252525
151515151515121212717171DCDCDCB7B7B7BCBCBCBDBDBDD9D9D9DDDDDD
D2D2D2F1F1F1EBEBEBDFDFDFE6E6E6F5F5F5F4F4F4F9F9F9EFEFEF
F8F8F8FAFAFAF8F8F8F7F7F7EFEFEFEFEFEFEDEDEDEAEAEAE6E6E6F3F3F3
E5E5E5DEDEDEEDEDEDEBEBEBEDEDEDE3E3E3EDEDEDEAEAEAE7E7E7E0E0E0
ECECECC0C0C0090909121212121212131313111111181818151515151515
0C0C0C272727151515161616151515282828000000181818161616151515
0000002020202E2E2E0000000404042C2C2C060606020202232323000000
0000000000001515151515151515151A1A1A0303031515152F2F2F181818
2424242222221616162222222525250F0F0F141414292929151515333333
333333A5A5A50909090E0E0E1F1F1F050505E6E6E6C4C4C4000000E9E9E9
ECECECEFEFEFE9E9E9E1E1E1EDEDED4C4C4CD0D0D06C6C6C0E0E0E191919
737373252525050505EDEDED787878060606040404111111080808171717
111111000000080808111111000000151515202020000000000000111111
000000151515323232D6D6D6909090595959B7B7B7A1A1A1DEDEDEE7E7E7
E2E2E2E4E4E4D9D9D9DDDDDDD1D1D1F4F4F4F8F8F8F6F6F6F5F5F5
F8F8F8F8F8F8F8F8F8E7E7E7EEEEEEF2F2F2EAEAEAEDEDEDF9F9F9E4E4E4
E4E4E4E6E6E6EBEBEBE7E7E7E7E7E7F3F3F3DFDFDFE9E9E9EFEFEFE8E8E8
DADADAF0F0F01616160000001616161A1A1A111111111111111111181818
0202020707071616161111110606061D1D1D3232321D1D1D0505050B0B0B
2828281D1D1D0A0A0A2323231313130000001111112A2A2A0101012B2B2B
2B2B2B1A1A1A0A0A0A1A1A1A1515150000002828281818180000001C1C1C
1F1F1F1717171616160A0A0A1616161D1D1D1919190C0C0C0E0E0E070707
1A1A1AC3C3C3CBCBCB161616131313171717939393050505EAEAEAB2B2B2
E5E5E5E0E0E0DCDCDCD3D3D3B2B2B2BFBFBFD7D7D7AAAAAAC8C8C82E2E2E
050505101010000000313131B2B2B20B0B0B1C1C1C0808080D0D0D050505
1313130909090202020404042424240000000101010F0F0F020202161616
171717242424000000A6A6A69090909696966464648F8F8FD4D4D4D5D5D5
DFDFDFD3D3D3DCDCDCDADADADADADAF9F9F9F6F6F6F5F5F5F7F7F7
F4F4F4F1F1F1F7F7F7EFEFEFEDEDEDE6E6E6ECECECE9E9E9EAEAEAE5E5E5
E7E7E7DCDCDCEBEBEBE0E0E0EDEDEDF5F5F5D7D7D7EAEAEAE6E6E6E3E3E3
E1E1E1E8E8E82A2A2A1616161B1B1B1111110000000101011E1E1E000000
0D0D0D2222221515151818182525253030301111111515150E0E0E151515
2323231515151212123939392020200606060606060D0D0D0F0F0F252525
1E1E1E1717170B0B0B1B1B1B0B0B0B0000002A2A2A3434340B0B0B090909
1C1C1C0B0B0B0000001313131C1C1C1515151515151D1D1D111111181818
636363E4E4E43C3C3C3A3A3A070707181818787878000000F3F3F3ECECEC
EEEEEEE1E1E1E4E4E4D2D2D2C4C4C4E4E4E4EDEDEDD9D9D9C6C6C64A4A4A
0000006565656868681D1D1DC4C4C4131313080808080808242424111111
0B0B0B0F0F0F1414140404040404040000000101010000000909090B0B0B
1717172424240000008F8F8F7373735858587B7B7BB8B8B8D1D1D1D1D1D1
D2D2D2F0F0F0DFDFDFE3E3E3E8E8E8F8F8F8F8F8F8F5F5F5F8F8F8
F5F5F5F9F9F9F5F5F5EFEFEFECECECEFEFEFEAEAEAEAEAEAEAEAEAE9E9E9
E7E7E7DEDEDEEAEAEAE2E2E2E6E6E6D5D5D5F5F5F5E6E6E6E6E6E6E7E7E7
EBEBEBD1D1D10F0F0F1717170808080101012828281111110B0B0B363636
2929291616162121212929291C1C1C1C1C1C1111110D0D0D0D0D0D111111
0D0D0D1E1E1E2E2E2E0000000000001111110000000E0E0E232323000000
0000000606062B2B2B1111111C1C1C1C1C1C000000070707323232292929
0000001313132F2F2F0808081717171111111A1A1A1818180A0A0A0F0F0F
5A5A5A606060D2D2D2E6E6E62525250B0B0B101010606060525252E1E1E1
EAEAEAC8C8C8CECECEEBEBEBECECEC414141565656F1F1F1B4B4B49F9F9F
515151BEBEBE6D6D6D000000D0D0D00C0C0C0000002B2B2B000000010101
0D0D0D0E0E0E0505050404040D0D0D040404000000000000020202000000
0000000000003A3A3A3434340000003636367E7E7E767676E4E4E4E5E5E5
E1E1E1DCDCDCDCDCDCD7D7D7D0D0D0F9F9F9F5F5F5F6F6F6F6F6F6
F4F4F4F8F8F8E7E7E7E9E9E9EBEBEBE5E5E5E7E7E7F3F3F3E9E9E9E3E3E3
E4E4E4ECECECE7E7E7E2E2E2DEDEDEE1E1E1E4E4E4E1E1E1E5E5E5E5E5E5
E7E7E7C6C6C6292929080808080808080808090909080808030303242424
0D0D0D0000001E1E1E1A1A1A0505050000002929291818180000000A0A0A
0F0F0F0505051313131313130B0B0B020202050505141414222222181818
0505050808080606060505050808082525250000000000001E1E1E1D1D1D
0000001717171919190000000606061C1C1C0A0A0A000000181818000000
0404049D9D9DABABABD3D3D32A2A2A6F6F6F1F1F1FB0B0B0909090E2E2E2
E8E8E8B3B3B3DEDEDEA6A6A6E4E4E4888888282828606060303030CFCFCF
4F4F4FE6E6E69C9C9C000000D5D5D50000001616161D1D1D000000000000
0202020000000000000505050101010000000909090A0A0A171717020202
0404040505054444443232324E4E4E5C5C5C5F5F5F828282DCDCDCE0E0E0
D8D8D8DDDDDDD5D5D5D1D1D1CECECEF5F5F5F3F3F3F5F5F5F4F4F4
F5F5F5F7F7F7F8F8F8EBEBEBECECECEEEEEEEFEFEFEAEAEAE8E8E8E9E9E9
E1E1E1E6E6E6CFCFCFE4E4E4E9E9E9E1E1E1E6E6E6E3E3E3EAEAEADCDCDC
DCDCDCDADADACCCCCC0505050A0A0A131313000000222222252525000000
111111171717000000000000313131434343000000000000121212121212
0707072323232929290000000D0D0D0202020000000D0D0D0D0D0D1A1A1A
0808081616160606061818181313130000002A2A2A3434340000001E1E1E
2222220000000000001A1A1A1717170000001F1F1F1313130000002F2F2F
0808080505052D2D2D191919040404181818313131E9E9E9D0D0D0E3E3E3
C7C7C7EBEBEBE4E4E4C7C7C7C8C8C82222228585852C2C2C2D2D2DD0D0D0
ABABABCACACAE3E3E3111111949494060606000000010101131313141414
0808080000000E0E0E0000000000000101011A1A1A000000000000020202
0D0D0D0202024949491414147272726464649E9E9EA3A3A3C4C4C4B1B1B1
C8C8C8F5F5F5D1D1D1EEEEEEECECECF9F9F9EEEEEEF6F6F6F5F5F5
F5F5F5F4F4F4F9F9F9EDEDEDE9E9E9EFEFEFEEEEEEDFDFDFE2E2E2F3F3F3
E2E2E2DFDFDFE6E6E6E7E7E7D7D7D7D7D7D7DFDFDFDEDEDEE7E7E7E1E1E1
DFDFDFD4D4D4B1B1B11212120000000909090606061F1F1F222222010101
1515151313130000001111112020201A1A1A1717170606060D0D0D000000
0000001515151E1E1E0606061515151F1F1F0000001717170D0D0D010101
060606131313121212000000151515131313060606222222000000020202
2727270D0D0D0707071313130A0A0A1111110D0D0D1515150000002F2F2F
0F0F0F0D0D0D0000001313132323230E0E0E3C3C3CEFEFEFE4E4E4E2E2E2
878787D8D8D8B8B8B8DDDDDDD6D6D64545455C5C5C6363636A6A6AC0C0C0
D9D9D9DEDEDE6D6D6D1A1A1AA6A6A60000000000000707070F0F0F272727
1313130101010404040000000000000A0A0A1717170000001414140D0D0D
0000000000006868683B3B3B5858587474747474745B5B5BCBCBCBDADADA
E0E0E0DADADAE0E0E0D9D9D9EAEAEAF1F1F1F0F0F0E8E8E8F5F5F5
F5F5F5F7F7F7F1F1F1F3F3F3EDEDEDEAEAEAE4E4E4ECECECF2F2F2E1E1E1
E4E4E4ECECECE7E7E7DEDEDEF0F0F0E8E8E8E6E6E6E6E6E6E1E1E1DFDFDF
D5D5D5B9B9B9AAAAAA3636360606060606060808080D0D0D0000001E1E1E
0B0B0B0B0B0B2828281F1F1F0000000000001717170000001212122A2A2A
2828280000000000000F0F0F1111110B0B0B2424240D0D0D0000001A1A1A
0A0A0A0F0F0F0808081717171A1A1A0E0E0E262626313131202020000000
0B0B0B2121211E1E1E0B0B0B0707070E0E0E000000060606232323000000
0000007A7A7A1111110B0B0B2727272C2C2C474747EAEAEAEEEEEEE5E5E5
878787E1E1E1E8E8E8D2D2D2DFDFDF0909090F0F0F444444626262A5A5A5
D8D8D8DDDDDDB0B0B00F0F0F9494940202020808080A0A0A080808111111
1212120101010404041A1A1A0505050E0E0E0000001010100404040D0D0D
3434341E1E1E0404042525256262624949497676769F9F9FCECECED0D0D0
DFDFDFD2D2D2D7D7D7D0D0D0D1D1D1F5F5F5F7F7F7F8F8F8F6F6F6
F7F7F7F9F9F9F4F4F4EBEBEBF0F0F0E7E7E7E6E6E6EAEAEAECECECE6E6E6
E6E6E6E9E9E9E4E4E4E1E1E1F2F2F2F5F5F5E2E2E2EBEBEBE2E2E2D7D7D7
C6C6C6E7E7E7D0D0D05F5F5F1111110000000808081313131111110E0E0E
0D0D0D0D0D0D0B0B0B2121211111111111111919190000001111112D2D2D
2929290000000303031818180404040000001B1B1B0A0A0A000000262626
0000000000000E0E0E2525250000000000001F1F1F1919190606060D0D0D
1919190000000A0A0A1111111B1B1B0B0B0B131313242424141414000000
1313130000001414140C0C0C2F2F2FBEBEBE646464DFDFDFF1F1F15B5B5B
BEBEBED7D7D7EEEEEED4D4D4B0B0B0CFCFCF3C3C3C2D2D2D6B6B6B606060
898989DDDDDDBCBCBC4E4E4E6A6A6A0808080606060505050D0D0D060606
0D0D0D1313130000000F0F0F181818000000040404181818060606262626
2929292B2B2B000000313131686868777777ACACACD5D5D5C8C8C8DADADA
DDDDDDE1E1E1DFDFDFDEDEDEDFDFDFF9F9F9F5F5F5F7F7F7F5F5F5
F5F5F5F6F6F6F7F7F7EAEAEAE7E7E7E8E8E8E7E7E7E6E6E6EAEAEAE7E7E7
E7E7E7E9E9E9E8E8E8DCDCDCEEEEEEE8E8E8E6E6E6EBEBEBE1E1E1C5C5C5
C8C8C8D2D2D29B9B9B6767672F2F2F0202020B0B0B1A1A1A1E1E1E050505
0D0D0D1D1D1D1111110A0A0A3A3A3A1F1F1F0000000D0D0D0D0D0D151515
0707071111110000001111111515152525252E2E2E000000000000141414
0000000000000808081515150000000606061F1F1F0E0E0E0000001F1F1F
1F1F1F0000000000001C1C1C0000001111111717170606060B0B0B151515
0D0D0D202020252525171717313131DDDDDDDCDCDCE6E6E6F5F5F54D4D4D
E6E6E6ECECECEFEFEFDADADAD3D3D3E7E7E7252525D7D7D78B8B8B000000
333333D9D9D92E2E2E7A7A7A5E5E5E0F0F0F000000050505232323151515
0000000D0D0D0E0E0E0808080A0A0A0808080000000404040D0D0D1F1F1F
1E1E1E6464642222223030307575757A7A7ADEDEDEDFDFDFC3C3C3D2D2D2
E5E5E5ECECECDDDDDDE9E9E9ECECECF5F5F5F6F6F6F4F4F4F5F5F5
F3F3F3F5F5F5F5F5F5EEEEEEF1F1F1EFEFEFE8E8E8EBEBEBE4E4E4E6E6E6
EAEAEAE8E8E8EBEBEBDFDFDFE1E1E1DADADAE7E7E7DEDEDEE8E8E8EAEAEA
DDDDDD727272B8B8B8D7D7D72222222323232525250A0A0A000000131313
0D0D0D0101011E1E1E2929290808080505052121210D0D0D0F0F0F212121
2020200606060B0B0B050505171717111111060606202020242424111111
0D0D0D0F0F0F0000000000003535352727270000000B0B0B000000000000
0000003434342E2E2E0909091717170A0A0A0000001111111B1B1B161616
0F0F0F1C1C1C7B7B7B111111494949DBDBDBE5E5E5E5E5E5323232E8E8E8
ECECECE4E4E4E0E0E0EAEAEAD8D8D8909090DCDCDCE5E5E5DBDBDB2D2D2D
7C7C7CD2D2D23C3C3CEFEFEF1C1C1C0000001D1D1D0F0F0F0D0D0D010101
1515150A0A0A0808080D0D0D0808080404040F0F0F0000000E0E0E111111
0000002C2C2C717171575757838383D4D4D4929292C6C6C6E7E7E7E4E4E4
E1E1E1D2D2D2E4E4E4CCCCCCC4C4C4F4F4F4F6F6F6F8F8F8F6F6F6
F9F9F9F8F8F8F8F8F8EFEFEFF6F6F6E8E8E8E7E7E7ECECECEEEEEEEAEAEA
E6E6E6E8E8E8EAEAEAE6E6E6EAEAEAE6E6E6E5E5E5E3E3E3E4E4E4DFDFDF
D0D0D0AFAFAFB9B9B9CECECE606060151515181818000000060606121212
0F0F0F0000001C1C1C242424010101000000000000000000171717212121
1818181111110F0F0F1111111919190B0B0B0000001515151111111F1F1F
0E0E0E1D1D1D0D0D0D000000333333202020030303373737000000000000
0000003030303D3D3D0B0B0B2828281111110000002B2B2B222222000000
0B0B0B2424246F6F6F020202606060E7E7E7E3E3E3E7E7E71A1A1ACECECE
E6E6E6DDDDDDDCDCDCE1E1E1E5E5E5434343D4D4D4D9D9D9DADADAD1D1D1
7B7B7B7F7F7F282828E4E4E4000000000000232323131313000000090909
0303030B0B0B0000000000000D0D0D1313130505050808080E0E0E0F0F0F
5B5B5B7272726565655B5B5B969696BBBBBBCFCFCFABABABE6E6E6E1E1E1
DFDFDFDFDFDFEEEEEED4D4D4D0D0D0EFEFEFEFEFEFF6F6F6F5F5F5
F9F9F9F3F3F3F5F5F5E8E8E8E5E5E5F7F7F7EFEFEFE1E1E1E4E4E4E7E7E7
D8D8D8E3E3E3F4F4F4E6E6E6EAEAEAE9E9E9E9E9E9DFDFDFE0E0E0D7D7D7
C8C8C8E5E5E5D4D4D4CFCFCFD7D7D71D1D1D1111111515151111110F0F0F
131313222222000000000000303030202020181818212121171717060606
0000001C1C1C2C2C2C1111112F2F2F000000050505171717111111222222
1111111515150B0B0B1B1B1B1515150303032121210000000A0A0A171717
2020200000000000000E0E0E0000001F1F1F313131060606000000313131
131313505050272727494949B6B6B6C5C5C5E5E5E5BCBCBC373737E7E7E7
E1E1E1E2E2E2E7E7E7DEDEDE3636366A6A6AD3D3D3E2E2E2D9D9D9A9A9A9
A9A9A94C4C4CC7C7C7D8D8D80707071F1F1F171717000000212121111111
1A1A1A1919192222220000000000001C1C1C1F1F1F1717171C1C1C4D4D4D
838383676767616161757575A5A5A5CDCDCDE3E3E3DEDEDECCCCCCD8D8D8
DCDCDCE6E6E6DCDCDCEFEFEFEBEBEBF6F6F6EEEEEEFBFBFBF5F5F5
F5F5F5F4F4F4F7F7F7E8E8E8E8E8E8F1F1F1F2F2F2E3E3E3E9E9E9EAEAEA
E3E3E3DDDDDDECECECEEEEEEE9E9E9E5E5E5E7E7E7E4E4E4ECECECE8E8E8
D6D6D6D8D8D8D4D4D4D7D7D7DCDCDC1313130D0D0D0F0F0F0A0A0A0B0B0B
2323231F1F1F0000000000003737371E1E1E1A1A1A3D3D3D040404000000
0000002A2A2A2626260F0F0F2A2A2A000000000000131313212121000000
1717171818181818180606061616161F1F1F0D0D0D1616161818183F3F3F
0B0B0B0707070E0E0E0808080606060D0D0D1C1C1C000000000000232323
3131315A5A5A0D0D0D7A7A7AE1E1E1DFDFDFE9E9E9232323E2E2E2E9E9E9
EEEEEEDFDFDFDFDFDFC5C5C5363636E7E7E7D4D4D4E1E1E1DCDCDC818181
AFAFAFB7B7B7E0E0E0DDDDDD000000040404000000000000222222070707
0C0C0C1414142121210000000606061515151111110F0F0F313131323232
6767674A4A4A939393898989C6C6C6D8D8D8DADADAD9D9D9D8D8D8D9D9D9
DDDDDDE6E6E6DBDBDBE2E2E2E1E1E1F4F4F4F1F1F1EFEFEFEDEDED
F6F6F6F4F4F4F7F7F7FAFAFAF8F8F8E8E8E8DEDEDEF3F3F3EAEAEAEDEDED
EAEAEAEDEDEDE3E3E3E2E2E2E8E8E8EFEFEFE9E9E9EFEFEFE2E2E2D2D2D2
DFDFDFD5D5D5C5C5C5DEDEDEDFDFDF8C8C8C1F1F1F0F0F0F0B0B0B0D0D0D
1616160505053A3A3A1111110909090000000B0B0B0000001C1C1C313131
2222220000000000000000000000001D1D1D2424240000000A0A0A2F2F2F
0000000000001313132222220606060E0E0E1717170000001616160E0E0E
0F0F0F1515151F1F1F000000212121000000000000353535222222040404
BCBCBC828282ADADAD333333EEEEEEF0F0F00A0A0AEBEBEBF3F3F3E4E4E4
D8D8D8EBEBEBC2C2C2CECECEE8E8E8D9D9D9CFCFCFD5D5D5E1E1E1929292
818181B3B3B3E1E1E1E3E3E30505050A0A0A1313131B1B1B1313130E0E0E
2727270A0A0A0404042E2E2E1F1F1F2929291A1A1A6C6C6C8B8B8B969696
8E8E8E616161ABABABD4D4D4D6D6D6CBCBCBDFDFDFDDDDDDDFDFDFE1E1E1
DEDEDEDDDDDDE6E6E6DBDBDBD7D7D7F5F5F5F1F1F1F6F6F6EFEFEF
F8F8F8F5F5F5F9F9F9EEEEEEEDEDEDE5E5E5E4E4E4F4F4F4EFEFEFEAEAEA
ECECECEFEFEFDCDCDCE6E6E6F8F8F8EAEAEAECECECEEEEEEE5E5E5D8D8D8
DDDDDDDBDBDBDADADAE1E1E1EEEEEEC6C6C66969691E1E1E000000121212
2626261515150000001717171515150D0D0D0000001515151111111C1C1C
171717050505000000020202000000111111373737000000000000171717
0000000000004444445353530606060000000E0E0E0707071A1A1A1F1F1F
1515151313131212121717172323231818181A1A1A1E1E1E2828280F0F0F
BABABA252525D4D4D43E3E3EECECECCBCBCBCECECEECECECECECECE2E2E2
E5E5E5EDEDEDF1F1F1DCDCDCD6D6D6E0E0E0D3D3D3EFEFEFE6E6E6727272
BCBCBCDCDCDCE5E5E5E1E1E10808080606060505050F0F0F0D0D0D131313
2E2E2E0303030E0E0E3939391111110F0F0F090909858585424242848484
767676A8A8A8C6C6C6EBEBEBDCDCDCD0D0D0F1F1F1E7E7E7DDDDDDE3E3E3
E5E5E5DADADAD1D1D1E0E0E0E1E1E1F7F7F7F5F5F5F7F7F7F6F6F6
F8F8F8F6F6F6F8F8F8E8E8E8ECECECE6E6E6EDEDEDE2E2E2E4E4E4E7E7E7
E4E4E4DFDFDFEFEFEFE9E9E9E0E0E0E3E3E3E1E1E1D1D1D1F6F6F6F5F5F5
E6E6E6D4D4D4DADADACCCCCCD0D0D0EBEBEBBEBEBE0404041818180E0E0E
0101010D0D0D1212121111111818181313131A1A1A2020201818180B0B0B
0E0E0E3434341F1F1F282828202020000000000000191919424242000000
131313383838040404000000424242383838131313373737000000151515
0000002323231F1F1F515151262626181818151515181818181818D3D3D3
5C5C5CB8B8B8D3D3D3A1A1A19C9C9C0D0D0DE7E7E7E6E6E6EAEAEAF1F1F1
F3F3F3D8D8D8C9C9C9DADADAD6D6D66363638A8A8A2E2E2EBBBBBBC9C9C9
D6D6D6D7D7D7DFDFDFC3C3C31D1D1D0000000D0D0D1111110A0A0A0D0D0D
1515150F0F0F3636360505050000002828283E3E3E6F6F6F838383444444
878787C0C0C0D7D7D7CECECED7D7D7F1F1F1CCCCCCD5D5D5E8E8E8DDDDDD
DFDFDFE1E1E1EFEFEFC4C4C4DEDEDEF5F5F5F7F7F7F8F8F8F8F8F8
F9F9F9F6F6F6F4F4F4EDEDEDEEEEEEE9E9E9EBEBEBEAEAEAE8E8E8E7E7E7
E6E6E6E6E6E6EAEAEAE3E3E3E4E4E4E2E2E2E1E1E1D8D8D8F2F2F2ECECEC
E8E8E8D6D6D6DADADAC9C9C9D6D6D6E8E8E8F0F0F01010100505050E0E0E
0000000505050F0F0F5353531010102D2D2D0D0D0D0606062323231E1E1E
2F2F2F0B0B0B111111151515050505050505181818151515171717171717
2C2C2C0D0D0D0101010F0F0F2E2E2E3535351515153C3C3C000000000000
0000001E1E1E676767646464828282030303050505373737656565D1D1D1
333333E9E9E9E1E1E1CDCDCD7A7A7A9E9E9EE6E6E6E1E1E1EAEAEAE8E8E8
ECECECDEDEDEDFDFDFE1E1E1DCDCDC7979796464642E2E2E8F8F8FE4E4E4
E4E4E4E7E7E7EDEDED7272720000000606061F1F1F080808020202181818
1E1E1E0000001C1C1C1717171B1B1B4141413333335151519797977E7E7E
B3B3B3DDDDDDDADADAD9D9D9D6D6D6ECECECD3D3D3D5D5D5E6E6E6E1E1E1
D1D1D1E8E8E8F0F0F0C9C9C9D8D8D8F5F5F5F6F6F6F4F4F4F5F5F5
F7F7F7F8F8F8EFEFEFFBFBFBF7F7F7E0E0E0DBDBDBE9E9E9E7E7E7E9E9E9
EAEAEAEAEAEADFDFDFE3E3E3E6E6E6E6E6E6DFDFDFE7E7E7EAEAEAEAEAEA
E3E3E3DADADADEDEDEDADADAD0D0D0EAEAEADADADA5151511818180B0B0B
0000000000002525251B1B1B000000000000060606000000272727202020
2424240404041717171515151C1C1C131313202020020202111111000000
2424240000001515150B0B0B1D1D1D121212070707282828000000000000
0000001B1B1B333333ADADAD6C6C6C6565651A1A1A3A3A3AD3D3D3797979
838383E7E7E7E5E5E5DADADA5E5E5EEFEFEFE5E5E5E5E5E5E2E2E2DFDFDF
D4D4D4E2E2E2E1E1E1E5E5E5D7D7D7747474181818959595C7C7C7ECECEC
E4E4E4D9D9D9E2E2E21C1C1C0000000000002D2D2D1D1D1D0000001B1B1B
3939390000000000001818180A0A0A6767676767677272728B8B8BBBBBBB
B7B7B7CCCCCCD6D6D6D3D3D3D0D0D0D0D0D0D4D4D4E1E1E1E9E9E9DCDCDC
DFDFDFEDEDEDEFEFEFD3D3D3D9D9D9FCFCFCF8F8F8F3F3F3F7F7F7
F8F8F8F8F8F8F8F8F8EBEBEBDDDDDDF4F4F4EAEAEAE1E1E1E0E0E0D6D6D6
DCDCDCE0E0E0EAEAEAE4E4E4E7E7E7E6E6E6DDDDDDE3E3E3E6E6E6E5E5E5
DFDFDFDFDFDFD8D8D8E3E3E3E0E0E0CDCDCDDADADADCDCDCE5E5E5E7E7E7
2F2F2F2020200000000000000808081F1F1F232323262626000000000000
0000003E3E3E0B0B0B1C1C1C0D0D0D0000001515151717171D1D1D111111
0D0D0D1111111111110B0B0B0202021919190F0F0F0000001E1E1E3A3A3A
1E1E1E0F0F0F060606000000333333ACACACCDCDCD010101B6B6B6292929
DADADAC9C9C9EAEAEAD5D5D5D7D7D7DBDBDBE5E5E5DDDDDDE1E1E1E2E2E2
E1E1E1DCDCDCE2E2E2D7D7D7DADADA4A4A4A111111ABABABDEDEDEE3E3E3
E1E1E1E5E5E5E3E3E30000002323231D1D1D0A0A0A1F1F1F222222000000
0000003636363737372525251C1C1C8C8C8C2A2A2AC0C0C0BABABAB8B8B8
D3D3D3DFDFDFD3D3D3D3D3D3B7B7B7D9D9D9DADADAE3E3E3E2E2E2E3E3E3
E2E2E2DDDDDDD6D6D6F4F4F4E2E2E2FCFCFCF5F5F5F8F8F8F9F9F9
F5F5F5F3F3F3F8F8F8E3E3E3E1E1E1EDEDEDEBEBEBD5D5D5DFDFDFE3E3E3
DADADAD7D7D7E6E6E6E3E3E3DDDDDDE8E8E8D4D4D4D4D4D4F6F6F6E5E5E5
E6E6E6E3E3E3DFDFDFDFDFDFDFDFDFD8D8D8DCDCDCDFDFDFE5E5E5DBDBDB
7171710D0D0D0000000000002323230808081B1B1B181818050505040404
0D0D0D2B2B2B1515152E2E2E2020200000000000000F0F0F262626181818
2020201C1C1C0B0B0B0F0F0F2525251818181717170D0D0D1111110B0B0B
1111110303031A1A1AB3B3B3BCBCBCA8A8A8242424AFAFAF696969CCCCCC
CCCCCC000000CACACAE2E2E2E1E1E1D9D9D9E7E7E7D1D1D1E6E6E6F1F1F1
DFDFDFD7D7D7DDDDDDDFDFDFD4D4D4CFCFCF787878B2B2B2E1E1E1DADADA
DEDEDEE2E2E2D2D2D20000000909092222220000000B0B0B131313000000
0202022E2E2E3C3C3C0B0B0B929292A6A6A6575757B7B7B7D9D9D9ABABAB
D3D3D3DBDBDBD1D1D1D8D8D8D7D7D7DCDCDCDADADAE6E6E6E4E4E4E3E3E3
E4E4E4E2E2E2DFDFDFE4E4E4E7E7E7F5F5F5F5F5F5F8F8F8F6F6F6
F5F5F5F9F9F9F6F6F6EEEEEEEBEBEBE3E3E3E9E9E9EDEDEDEAEAEAF0F0F0
E8E8E8EFEFEFDADADAE4E4E4F0F0F0E5E5E5F0F0F0EFEFEFD6D6D6DFDFDF
DFDFDFE3E3E3E5E5E5E4E4E4E6E6E6DCDCDCE1E1E1D9D9D9DDDDDDDADADA
4646463030301717170000000202021B1B1B0505050000001717171B1B1B
0D0D0D0000000D0D0D0000000000000E0E0E111111050505000000000000
0000000000000808081818180505050B0B0B1515151515151F1F1F131313
0D0D0D252525151515121212272727040404555555CACACA272727E5E5E5
444444A9A9A9E6E6E6E2E2E2F0F0F0E4E4E4E7E7E7E5E5E5E1E1E1D7D7D7
C6C6C6E2E2E2F1F1F1E2E2E2E8E8E8E1E1E1CACACADFDFDFE5E5E5D3D3D3
DFDFDFE2E2E2C9C9C91212121111110606060000001111111717171E1E1E
3E3E3E1111110000005D5D5D8F8F8FABABABB5B5B5838383696969D9D9D9
E6E6E6C2C2C2E7E7E7E3E3E3DADADAC3C3C3EAEAEAE5E5E5E1E1E1E8E8E8
E6E6E6DDDDDDE1E1E1DBDBDBDADADAF7F7F7F1F1F1F7F7F7F6F6F6
F9F9F9F5F5F5F7F7F7ECECECE8E8E8EBEBEBE4E4E4E3E3E3EAEAEAE7E7E7
E7E7E7E8E8E8E2E2E2E3E3E3E9E9E9E3E3E3F2F2F2ECECECD9D9D9E2E2E2
E7E7E7E7E7E7DCDCDCEEEEEEF5F5F5D8D8D8DFDFDFE3E3E3E1E1E1D8D8D8
E7E7E73939390F0F0F0000001B1B1B1111110000000101011717171D1D1D
1616160D0D0D2525250404040000002A2A2A2A2A2A000000000000050505
0000000000002828280F0F0F050505111111000000000000292929202020
1717170A0A0A0D0D0D0F0F0F0F0F0F1F1F1F7070701C1C1C6A6A6ACACACA
434343D8D8D8E7E7E7DFDFDFE3E3E3EAEAEAE6E6E6E8E8E8E1E1E1CBCBCB
B8B8B8EDEDEDEBEBEBE7E7E7EDEDEDD9D9D9D3D3D3F4F4F4E8E8E8D7D7D7
E9E9E9E1E1E1858585000000171717171717373737151515000000686868
2121210E0E0E151515717171AAAAAAB9B9B9A9A9A9828282898989DEDEDE
DADADACFCFCFDFDFDFEEEEEECDCDCDC6C6C6F2F2F2DFDFDFE6E6E6E8E8E8
F1F1F1D2D2D2D6D6D6E3E3E3D8D8D8F7F7F7F5F5F5F5F5F5F7F7F7
F8F8F8F5F5F5F8F8F8EDEDEDEDEDEDEAEAEAE9E9E9E5E5E5EAEAEAE1E1E1
E0E0E0E7E7E7E7E7E7E8E8E8E9E9E9E9E9E9E2E2E2DCDCDCF4F4F4E9E9E9
E2E2E2E6E6E6E8E8E8CCCCCCE1E1E1E8E8E8E6E6E6DBDBDBE5E5E5CCCCCC
D6D6D6D6D6D61818180000000808080000000A0A0A020202000000060606
1919191111111919192020201313130000000000000F0F0F1B1B1B171717
1B1B1B4545450404040F0F0F353535181818212121373737000000000000
0F0F0F2525251313132020202C2C2C0D0D0D2020201E1E1EE8E8E8434343
DBDBDBE6E6E6E8E8E8E4E4E4E8E8E8EAEAEAE2E2E2E3E3E3E9E9E9F0F0F0
EDEDEDD7D7D7E6E6E6DADADA959595F9F9F9EEEEEEE1E1E1D6D6D6E7E7E7
D5D5D58888882121212525250D0D0D1717171111110B0B0B141414646464
3131311F1F1F858585B5B5B5A4A4A4929292929292C8C8C8E3E3E3CBCBCB
DEDEDEEDEDEDDADADAD0D0D0DCDCDCEDEDEDE0E0E0EAEAEAE6E6E6DDDDDD
D3D3D3EAEAEAF0F0F0D0D0D0DFDFDFF9F9F9F7F7F7F5F5F5F6F6F6
F5F5F5F8F8F8F9F9F9F3F3F3EEEEEEEDEDEDEBEBEBE7E7E7ECECECE3E3E3
E6E6E6E4E4E4E3E3E3E6E6E6E6E6E6E5E5E5E6E6E6E5E5E5EBEBEBE6E6E6
E3E3E3DFDFDFEEEEEEDBDBDBE4E4E4F0F0F0E1E1E1DDDDDDF1F1F1DCDCDC
D3D3D3D6D6D6F1F1F12323230A0A0A1717170000000707071E1E1E121212
1515150D0D0D2F2F2F2424241919191111110808080D0D0D010101131313
1919192D2D2D000000111111242424151515131313323232010101090909
0101011111111515153131314F4F4F7B7B7B0F0F0FE7E7E7E3E3E3666666
D9D9D9DCDCDCE2E2E2E9E9E9E0E0E0E7E7E7E5E5E5E4E4E4E5E5E5E7E7E7
E9E9E9DEDEDEDCDCDCD3D3D3A0A0A0E2E2E2E1E1E1D7D7D7DCDCDCE4E4E4
4545450202020808081111110000000B0B0B1616160505052626262C2C2C
2F2F2F4F4F4F777777AFAFAF9F9F9F9F9F9FC3C3C3D3D3D3DEDEDECECECE
DFDFDFE4E4E4D1D1D1CDCDCDE7E7E7F5F5F5E1E1E1ECECECEAEAEADFDFDF
CDCDCDF6F6F6EFEFEFD6D6D6E8E8E8FCFCFCF5F5F5F8F8F8F6F6F6
F9F9F9F8F8F8F6F6F6E4E4E4EBEBEBEDEDEDE7E7E7DCDCDCEBEBEBDCDCDC
DCDCDCE1E1E1E6E6E6E4E4E4E7E7E7DEDEDEE7E7E7E5E5E5DBDBDBE6E6E6
E2E2E2E4E4E4D7D7D7E4E4E4EEEEEED4D4D4DDDDDDE3E3E3DCDCDCF1F1F1
EFEFEFDDDDDDCACACACDCDCD2323230101010A0A0A1C1C1C0000000B0B0B
0D0D0D1B1B1B1111111717172727271A1A1A1717170D0D0D151515000000
0B0B0B1C1C1C0B0B0B4B4B4BB0B0B01A1A1A060606050505717171282828
0F0F0F1111113C3C3C0000007B7B7BB6B6B63E3E3ED6D6D64646468D8D8D
BEBEBEDFDFDFEEEEEEE9E9E9E3E3E3DDDDDDDEDEDEDEDEDEE1E1E1E5E5E5
E7E7E7D5D5D5B7B7B7797979ACACACDDDDDDD4D4D4E9E9E9DEDEDE131313
2121211212120000000F0F0F2323233131311313132828280C0C0C050505
000000D4D4D4A5A5A5CFCFCF949494B0B0B0C0C0C0D5D5D5DFDFDFDFDFDF
E9E9E9CFCFCFDEDEDEEDEDEDDBDBDBCDCDCDE9E9E9CFCFCFDFDFDFE1E1E1
F0F0F0D7D7D7D3D3D3E9E9E9D3D3D3F4F4F4F6F6F6F1F1F1F5F5F5
F3F3F3F8F8F8F6F6F6E7E7E7EDEDEDEFEFEFE4E4E4E6E6E6F3F3F3D4D4D4
D4D4D4EBEBEBECECECDEDEDEE8E8E8E8E8E8DFDFDFDCDCDCEAEAEAE3E3E3
E1E1E1DFDFDFE1E1E1DDDDDDEAEAEAD2D2D2DFDFDFE4E4E4DFDFDFEFEFEF
E8E8E8DFDFDFC3C3C3CECECE3131310000000F0F0F1C1C1C0606060B0B0B
2222220F0F0F0000001C1C1C1717170000000B0B0B1212121313131F1F1F
1C1C1C3030300A0A0A0000002727272424240B0B0B1515152D2D2D1C1C1C
1515151818183131310404040B0B0BB9B9B9EBEBEBA6A6A64C4C4C7A7A7A
D1D1D1DDDDDDF2F2F2E9E9E9E3E3E3E2E2E2E1E1E1E0E0E0E8E8E8E7E7E7
E6E6E6B3B3B3D2D2D2D4D4D4CFCFCFD3D3D3D7D7D7E0E0E01F1F1F171717
1111111D1D1D0000000000002727273535351515152828280B0B0B000000
646464EDEDEDC7C7C78F8F8FDFDFDFBBBBBBD2D2D2ECECECE0E0E0D9D9D9
E3E3E3DEDEDED7D7D7E1E1E1D9D9D9DCDCDCE1E1E1DFDFDFE6E6E6DADADA
E1E1E1D8D8D8D1D1D1DCDCDCCBCBCBEFEFEFF5F5F5F1F1F1EBEBEB
F5F5F5FCFCFCF5F5F5EDEDEDE3E3E3EEEEEEE6E6E6E5E5E5F0F0F0E2E2E2
D6D6D6E8E8E8E6E6E6DFDFDFE3E3E3F5F5F5D0D0D0DFDFDFF1F1F1E7E7E7
DFDFDFE4E4E4EFEFEFDFDFDFE2E2E2E8E8E8D7D7D7E1E1E1E1E1E1E3E3E3
E3E3E3DADADAD0D0D0CDCDCDD7D7D70D0D0D1C1C1C1D1D1D0101010D0D0D
0808081717170000003333332020200000001111111D1D1D1717172E2E2E
2A2A2A2929290A0A0A0000001C1C1C0F0F0F2F2F2F1717171313130A0A0A
1111112525250F0F0F040404111111E3E3E3EAEAEA7777772525251D1D1D
3B3B3BADADADD4D4D4E4E4E4DADADAD6D6D6E3E3E3DBDBDBF2F2F2F1F1F1
D9D9D9616161DEDEDED6D6D6DADADADEDEDEDCDCDC2F2F2F161616000000
0000001111111F1F1F0B0B0B0707071E1E1E181818282828060606212121
939393B7B7B7BDBDBDC6C6C6DDDDDDCCCCCCC8C8C8F1F1F1E7E7E7D8D8D8
EDEDEDECECECD4D4D4D7D7D7E1E1E1E5E5E5E2E2E2DCDCDCDDDDDDD6D6D6
D9D9D9DCDCDCDCDCDCD8D8D8D0D0D0E9E9E9F5F5F5F3F3F3E9E9E9
F8F8F8FAFAFAF4F4F4F0F0F0EAEAEAEAEAEAEDEDEDE8E8E8E0E0E0ECECEC
E7E7E7E0E0E0EAEAEAEFEFEFCCCCCCE0E0E0F8F8F8E9E9E9DFDFDFE3E3E3
ECECECE2E2E2DFDFDFE6E6E6E6E6E6D8D8D8E1E1E1DBDBDBDFDFDFD7D7D7
DADADAE0E0E0D5D5D5D8D8D8DBDBDBD2D2D21A1A1A0000003535351D1D1D
0000000101014242420000000000001C1C1C0D0D0D000000060606070707
0000000707073535350000000F0F0F1D1D1D0505050000003B3B3B0B0B0B
1818181515152A2A2A0E0E0E222222E6E6E6E1E1E11818181A1A1A222222
2E2E2E0C0C0C3434343B3B3B636363616161BEBEBEE4E4E4AFAFAF5A5A5A
282828E7E7E7E6E6E6EBEBEBE3E3E3C9C9C9D2D2D2151515000000060606
0F0F0F3030302A2A2A0A0A0A1515151515151C1C1C0F0F0F2A2A2A838383
9D9D9D808080797979A5A5A5B3B3B3EDEDEDE7E7E7C7C7C7C7C7C7E9E9E9
E4E4E4C6C6C6EFEFEFF4F4F4CECECED1D1D1DFDFDFD7D7D7EDEDEDE8E8E8
E2E2E2DCDCDCD7D7D7DCDCDCDDDDDDF3F3F3F4F4F4F5F5F5FAFAFA
F8F8F8F5F5F5F5F5F5EDEDEDEEEEEEEBEBEBE7E7E7EAEAEAEBEBEBE8E8E8
E6E6E6E6E6E6E4E4E4EAEAEAE6E6E6D9D9D9F0F0F0EAEAEAE9E9E9EAEAEA
E5E5E5EAEAEADDDDDDF4F4F4EFEFEFDEDEDEE4E4E4E0E0E0D1D1D1EFEFEF
EBEBEBE1E1E1D3D3D3E3E3E3DCDCDCDCDCDCB4B4B41E1E1E010101111111
1919190D0D0D2B2B2B0000000808081B1B1B0D0D0D000000222222000000
0000000000004747470B0B0B1E1E1E2929290B0B0B000000292929242424
0F0F0F0F0F0F4C4C4C000000393939E8E8E85C5C5C2A2A2A212121595959
4848481010103A3A3A1919192B2B2B1E1E1E3333333030300C0C0C141414
151515EDEDEDE4E4E4E6E6E6E7E7E7C9C9C9D3D3D31616161313131D1D1D
2222222727271616160606063131311A1A1A272727565656787878B5B5B5
C3C3C3B7B7B7BFBFBFCDCDCDD6D6D6D3D3D3ECECECDADADACCCCCCE7E7E7
E1E1E1D0D0D0F0F0F0E5E5E5CBCBCBD8D8D8E4E4E4DDDDDDE8E8E8ECECEC
F0F0F0C2C2C2CECECEE1E1E1D8D8D8F7F7F7F5F5F5F5F5F5F3F3F3
F6F6F6F8F8F8F2F2F2F3F3F3ECECECECECECEFEFEFE8E8E8F0F0F0E6E6E6
E6E6E6E7E7E7E9E9E9DCDCDCE6E6E6E9E9E9E2E2E2E7E7E7F3F3F3E3E3E3
E4E4E4F6F6F6F4F4F4D6D6D6DDDDDDE1E1E1D9D9D9E9E9E9F1F1F1D9D9D9
D7D7D7E7E7E7E1E1E1DADADAE3E3E3EDEDEDD5D5D54343430B0B0B0D0D0D
0808081212120A0A0A0A0A0A1717170000004444446262620D0D0D3A3A3A
1D1D1D0202020606061C1C1C1111110D0D0D2C2C2C2020200000000C0C0C
151515080808060606303030E8E8E8C2C2C2272727B3B3B3C6C6C68C8C8C
3636361515150F0F0F0C0C0C1818181C1C1C0F0F0F0808082121212C2C2C
929292E5E5E5DFDFDFE1E1E1DBDBDBE2E2E2F3F3F3000000000000030303
0E0E0E0000003636362121210000002424245151517C7C7CB4B4B4C8C8C8
BDBDBDBFBFBFD6D6D6DADADADFDFDFD9D9D9D6D6D6DADADAE1E1E1E3E3E3
E7E7E7E9E9E9DFDFDFD3D3D3F0F0F0EDEDEDDFDFDFEFEFEFDDDDDDDFDFDF
D9D9D9F6F6F6EDEDEDE4E4E4F4F4F4F5F5F5F7F7F7F6F6F6F6F6F6
F8F8F8F9F9F9F5F5F5FAFAFAEEEEEEEDEDEDEFEFEFE7E7E7E8E8E8E6E6E6
E6E6E6E6E6E6EEEEEEE6E6E6E6E6E6E6E6E6E7E7E7E7E7E7E9E9E9E8E8E8
E3E3E3E7E7E7F2F2F2DCDCDCE6E6E6EAEAEAE2E2E2E4E4E4F4F4F4E0E0E0
DFDFDFEFEFEFE2E2E2DBDBDBEFEFEFE8E8E8CACACA9E9E9E2222220F0F0F
0000000808082C2C2C1313130E0E0E1515151F1F1F1515151313131D1D1D
1C1C1C1111110D0D0D121212151515151515393939292929090909020202
2B2B2B0909090B0B0BA2A2A2ECECEC5E5E5E383838E9E9E9E8E8E8E9E9E9
EEEEEE3F3F3F0000003D3D3D111111131313494949626262121212131313
D6D6D6E6E6E6ECECECE6E6E6E6E6E6E2E2E26363630F0F0F1515150F0F0F
0000000000002020207D7D7D0A0A0A707070434343858585B6B6B6DADADA
C1C1C1CDCDCDDCDCDCD8D8D8D8D8D8E9E9E9F1F1F1E1E1E1D4D4D4D5D5D5
E1E1E1E3E3E3D7D7D7DADADAE1E1E1E5E5E5E3E3E3DFDFDFDFDFDFD9D9D9
CCCCCCF3F3F3EDEDEDE2E2E2E5E5E5F9F9F9F7F7F7FAFAFAF8F8F8
F7F7F7F9F9F9F8F8F8EDEDEDF0F0F0EAEAEAE6E6E6EDEDEDF4F4F4E2E2E2
EAEAEAE6E6E6E5E5E5DADADAEDEDEDE4E4E4E6E6E6E1E1E1E6E6E6E4E4E4
E2E2E2DCDCDCE1E1E1E6E6E6E2E2E2E5E5E5EAEAEADEDEDEDADADAF4F4F4
E8E8E8E3E3E3E1E1E1EAEAEADCDCDCCFCFCFEBEBEBCECECE454545131313
1A1A1A0000001313131919190808080505050707071111110F0F0F222222
1111111313131313131919191313131515150505050F0F0F0F0F0F0F0F0F
060606363636404040E5E5E5DBDBDB1F1F1F1D1D1DE1E1E1EFEFEFDADADA
D0D0D0D4D4D42929291A1A1A1212121B1B1B2F2F2F2F2F2F444444232323
BFBFBFE8E8E8E6E6E6E1E1E1DFDFDFD0D0D0141414262626242424151515
2B2B2B393939555555747474ADADAD5C5C5C949494CCCCCC4D4D4DAAAAAA
C6C6C6E9E9E9DDDDDDE5E5E5F2F2F2D3D3D3DEDEDEE5E5E5DFDFDFE4E4E4
E1E1E1DDDDDDDADADAE1E1E1E5E5E5DBDBDBDDDDDDD6D6D6E9E9E9DFDFDF
E8E8E8E3E3E3DADADAE2E2E2C9C9C9F8F8F8F8F8F8FDFDFDF8F8F8
F8F8F8F6F6F6F8F8F8EFEFEFEFEFEFE9E9E9E4E4E4EDEDEDF4F4F4DDDDDD
E6E6E6EBEBEBE0E0E0D4D4D4F2F2F2F1F1F1E1E1E1E4E4E4E9E9E9DFDFDF
D2D2D2E8E8E8E6E6E6E1E1E1E3E3E3E2E2E2E8E8E8E3E3E3E1E1E1E4E4E4
E4E4E4E1E1E1DDDDDDEAEAEAD5D5D5DBDBDBE9E9E9DEDEDED0D0D05E5E5E
0D0D0D000000000000232323080808010101171717111111000000343434
2020200000001616161616160A0A0A0101011111110A0A0A181818111111
2828281F1F1F757575DADADA949494252525464646AAAAAA9797971F1F1F
0C0C0C6A6A6AB5B5B52B2B2B0D0D0D202020000000575757363636484848
AFAFAFE2E2E2ECECECD6D6D6E1E1E1DBDBDB1313131515151919190F0F0F
2222225353538B8B8B989898A4A4A48989899D9D9D8D8D8D646464878787
D0D0D0EBEBEBD8D8D8EDEDEDF2F2F2D8D8D8D7D7D7EBEBEBE3E3E3E7E7E7
E9E9E9E9E9E9D1D1D1D3D3D3DEDEDEDEDEDED7D7D7E7E7E7E3E3E3D8D8D8
DFDFDFDADADACDCDCDD9D9D9D5D5D5F7F7F7F7F7F7FAFAFAEBEBEB
F8F8F8F8F8F8F6F6F6ECECECEAEAEAECECECEFEFEFE1E1E1E3E3E3E9E9E9
E5E5E5DCDCDCF2F2F2F0F0F0E6E6E6D6D6D6EAEAEADADADAE4E4E4E9E9E9
F1F1F1E3E3E3DDDDDDE7E7E7E1E1E1E3E3E3E8E8E8DBDBDBE4E4E4E2E2E2
E3E3E3E2E2E2DADADAE2E2E2E8E8E8EBEBEBCDCDCDD9D9D9DEDEDE949494
1212120F0F0F1A1A1A1717171B1B1B191919111111222222181818000000
0000001212123333330000000D0D0D4040400000001A1A1A1A1A1A272727
292929252525EDEDEDD2D2D2292929515151E7E7E7E7E7E7DADADADEDEDE
E6E6E66868682020206C6C6C0000000303034141419D9D9D000000191919
F1F1F1E1E1E1E4E4E4E4E4E4E3E3E33F3F3F1515151818181515151C1C1C
232323BCBCBCB8B8B89F9F9F8787877D7D7D939393A8A8A8A6A6A6E5E5E5
DDDDDDE1E1E1DFDFDFD3D3D3D2D2D2F3F3F3E8E8E8BFBFBFE1E1E1DEDEDE
CCCCCCC8C8C8EEEEEEEFEFEFC3C3C3D7D7D7D1D1D1CDCDCDDFDFDFDEDEDE
DFDFDFDADADADADADADDDDDDDADADAF7F7F7F8F8F8F6F6F6F4F4F4
F7F7F7F8F8F8F5F5F5EDEDEDE9E9E9E9E9E9E8E8E8E8E8E8DADADAE8E8E8
E6E6E6DEDEDEEBEBEBF0F0F0E0E0E0DFDFDFEAEAEAE1E1E1E8E8E8E7E7E7
F0F0F0D4D4D4D3D3D3DFDFDFDDDDDDEAEAEAF3F3F3C6C6C6D3D3D3ECECEC
E3E3E3E6E6E6DFDFDFE3E3E3E1E1E1DADADADBDBDBDEDEDEDFDFDFD9D9D9
8181810B0B0B1A1A1A1111111111110505050D0D0D1B1B1B343434000000
0000001212121616160000002A2A2A202020101010070707131313030303
020202DFDFDFDFDFDF2B2B2B0C0C0CD4D4D4D3D3D38C8C8C8E8E8EDEDEDE
E0E0E0D3D3D34F4F4F2626261212122929293131316C6C6C080808202020
EAEAEAE3E3E3E3E3E3E1E1E1EBEBEB0C0C0C0E0E0E111111181818353535
B2B2B2BDBDBD8E8E8E7F7F7FAFAFAFC1C1C1DDDDDDDBDBDBCECECEDEDEDE
DADADADCDCDCDFDFDFD3D3D3DBDBDBE7E7E7E6E6E6D5D5D5DCDCDCD6D6D6
D0D0D0CCCCCCF2F2F2E8E8E8CFCFCFD3D3D3D0D0D0C9C9C9E9E9E9DCDCDC
DCDCDCDFDFDFDEDEDECECECEC3C3C3F1F1F1F5F5F5F9F9F9F4F4F4
F6F6F6F8F8F8F6F6F6EDEDEDF5F5F5EBEBEBE0E0E0ECECECF2F2F2E6E6E6
E3E3E3E3E3E3E1E1E1E2E2E2E1E1E1DFDFDFE4E4E4E0E0E0ECECECE9E9E9
E7E7E7E1E1E1E0E0E0EBEBEBE3E3E3ECECECF9F9F9D8D8D8DBDBDBF2F2F2
E1E1E1E1E1E1E8E8E8F1F1F1D4D4D4D5D5D5EAEAEAE8E8E8DFDFDFE2E2E2
E5E5E50F0F0F1111110404040808080000001B1B1B0B0B0B1A1A1A151515
1515151616160F0F0F1515152E2E2E2424240000000E0E0E404040131313
070707F9F9F9F5F5F50B0B0BB8B8B8DADADADEDEDEDFDFDFC2C2C2515151
3737377373737979795454542D2D2D4545451616163C3C3C1E1E1E353535
E0E0E0E6E6E6E1E1E1DCDCDCE2E2E20000001515151919190C0C0C3D3D3D
E9E9E9C9C9C9656565ACACACD2D2D2DADADAEDEDEDE7E7E7CACACAD6D6D6
E2E2E2EBEBEBE0E0E0E8E8E8EDEDEDE1E1E1E0E0E0D8D8D8E3E3E3E2E2E2
D9D9D9DFDFDFEEEEEEEAEAEADCDCDCE2E2E2D5D5D5C2C2C2F7F7F7EBEBEB
E3E3E3D3D3D3DDDDDDC4C4C4CACACAF3F3F3F7F7F7FCFCFCF5F5F5
F8F8F8F7F7F7F5F5F5EAEAEAE8E8E8EDEDEDEFEFEFE3E3E3DFDFDFE7E7E7
E3E3E3E0E0E0E6E6E6DFDFDFE6E6E6E3E3E3E5E5E5E6E6E6E8E8E8E6E6E6
E1E1E1E6E6E6E5E5E5E6E6E6F1F1F1E6E6E6DFDFDFEAEAEAF7F7F7E9E9E9
E8E8E8F3F3F3D9D9D9D6D6D6EEEEEEF6F6F6D8D8D8E1E1E1DDDDDDDCDCDC
DADADA5555551111110E0E0E171717020202030303111111151515151515
1111110000001111113030301616160F0F0F3939390A0A0A1616162C2C2C
6E6E6EDADADA292929D8D8D8EBEBEBEAEAEAE7E7E7E1E1E1D2D2D2E8E8E8
D6D6D67171711919191111111D1D1D2A2A2A1E1E1E1111111E1E1E595959
E1E1E1E1E1E1E6E6E6DEDEDEC6C6C61C1C1C1111111515153D3D3D8C8C8C
C8C8C8C5C5C5D8D8D8D8D8D8AAAAAAF0F0F0B2B2B2CECECEEDEDEDF0F0F0
E5E5E5DDDDDDE5E5E5DEDEDEE4E4E4E4E4E4E1E1E1E1E1E1E5E5E5D9D9D9
ECECECE1E1E1E5E5E5DDDDDDDFDFDFDFDFDFDFDFDFEEEEEEC3C3C3D7D7D7
DEDEDEF0F0F0D7D7D7EDEDEDEFEFEFF5F5F5F5F5F5F5F5F5F5F5F5
FAFAFAF6F6F6F5F5F5E6E6E6E1E1E1F6F6F6EFEFEFE0E0E0E4E4E4E6E6E6
CFCFCFD3D3D3EEEEEED8D8D8D9D9D9E0E0E0E5E5E5E4E4E4E6E6E6E8E8E8
E6E6E6E3E3E3E5E5E5E4E4E4E6E6E6E6E6E6E9E9E9E4E4E4EDEDEDE1E1E1
E5E5E5E9E9E9D2D2D2DBDBDBF5F5F5F2F2F2E2E2E2ECECECE2E2E2D4D4D4
D1D1D1EBEBEB4343431515151B1B1B1E1E1E0000001B1B1B2323230B0B0B
1111112B2B2B0606061818182828281515151E1E1E151515161616141414
E7E7E78F8F8FBDBDBDDCDCDCE1E1E1E4E4E4E4E4E4BEBEBE8686869A9A9A
6464648383839898989D9D9D0404040707073535350F0F0F1515154A4A4A
EBEBEBE1E1E1DFDFDFE1E1E1AEAEAE1111111A1A1A1C1C1C0F0F0FE2E2E2
D2D2D2D6D6D6E4E4E4CECECECCCCCCDBDBDBCCCCCCE1E1E1E3E3E3E7E7E7
D8D8D8E4E4E4F2F2F2D1D1D1E2E2E2EEEEEEE5E5E5CCCCCCEBEBEBD1D1D1
D4D4D4E1E1E1ECECECE3E3E3DDDDDDE1E1E1DCDCDCDDDDDDD8D8D8D3D3D3
D8D8D8E4E4E4DDDDDDDCDCDCE6E6E6F9F9F9F3F3F3F5F5F5F4F4F4
F8F8F8F8F8F8F5F5F5EFEFEFF6F6F6EAEAEAF3F3F3F4F4F4ECECECE6E6E6
E8E8E8E1E1E1E0E0E0C7C7C7E4E4E4EAEAEAE6E6E6E7E7E7E5E5E5E3E3E3
D8D8D8E5E5E5E2E2E2E7E7E7E6E6E6E6E6E6E7E7E7DFDFDFE0E0E0E8E8E8
E4E4E4E0E0E0E8E8E8EFEFEFDBDBDBDADADAE2E2E2E1E1E1E5E5E5DFDFDF
EEEEEEDEDEDED9D9D9A6A6A61111110F0F0F1717171515150E0E0E404040
1111110A0A0A1515151C1C1C1212120E0E0E2F2F2F1313130C0C0C313131
EDEDEDDFDFDFE2E2E2C8C8C8CECECED9D9D9B5B5B52A2A2A141414000000
1818182121210000000000003D3D3D1C1C1C000000171717212121191919
E4E4E4E7E7E7F2F2F2D2D2D22323232222221C1C1C212121888888E9E9E9
E0E0E0E0E0E0D5D5D5D7D7D7DFDFDFE3E3E3E4E4E4E8E8E8D6D6D6E8E8E8
EAEAEAEBEBEBDADADAF4F4F4F0F0F0D9D9D9DFDFDFE8E8E8E6E6E6EAEAEA
EDEDEDECECECD5D5D5E4E4E4DEDEDEDFDFDFE8E8E8DDDDDDDCDCDCDDDDDD
DADADAD3D3D3DFDFDFDCDCDCD0D0D0F8F8F8F3F3F3F8F8F8F6F6F6
F8F8F8F9F9F9F7F7F7EAEAEAEAEAEAE9E9E9E3E3E3E7E7E7F0F0F0E5E5E5
E3E3E3E6E6E6D9D9D9CFCFCFF5F5F5F2F2F2E9E9E9EFEFEFE3E3E3D5D5D5
E1E1E1ECECECE5E5E5E6E6E6EBEBEBE0E0E0DFDFDFECECECE6E6E6E5E5E5
E2E2E2DFDFDFDFDFDFDFDFDFDADADADBDBDBDFDFDFDADADADEDEDEECECEC
E4E4E4D5D5D5DDDDDDDEDEDE1313130808080808080E0E0E040404131313
0202020000002424241717170505050606060F0F0F1313130D0D0DCCCCCC
DCDCDCC9C9C99A9A9A6B6B6B2626262525251C1C1C1111110D0D0D0E0E0E
2323231E1E1E1A1A1A0F0F0F1212122323230808081111111111110B0B0B
CACACAE3E3E3E4E4E4C0C0C0151515282828161616141414EEEEEEE0E0E0
D9D9D9DEDEDED5D5D5CECECEDCDCDCE8E8E8DADADAE3E3E3E1E1E1DDDDDD
E1E1E1E5E5E5DADADAE7E7E7E6E6E6DCDCDCDDDDDDF1F1F1DADADAEFEFEF
E9E9E9E9E9E9D2D2D2DEDEDEDDDDDDDEDEDEE9E9E9F2F2F2D2D2D2CACACA
DCDCDCD7D7D7D8D8D8DEDEDEDEDEDEF5F5F5F8F8F8F1F1F1F6F6F6
F9F9F9FBFBFBFAFAFAEAEAEAEAEAEAEAEAEAE6E6E6E4E4E4D6D6D6E8E8E8
DFDFDFD5D5D5EEEEEEE8E8E8DBDBDBE5E5E5E4E4E4CDCDCDF2F2F2F5F5F5
F2F2F2CFCFCFE0E0E0DCDCDCDFDFDFE8E8E8F1F1F1DBDBDBDDDDDDE1E1E1
E4E4E4E1E1E1E2E2E2D9D9D9E1E1E1E2E2E2E6E6E6E5E5E5E1E1E1D6D6D6
DDDDDDE6E6E6DFDFDFE3E3E35C5C5C1616160000002D2D2D1F1F1F000000
1717173333330101010000003C3C3C3C3C3C2222227C7C7C202020858585
D4D4D4EBEBEBE7E7E7C5C5C5606060D2D2D2CBCBCB767676363636131313
0C0C0C1A1A1A1818184040400505050A0A0A1717170505050B0B0B121212
3B3B3BD8D8D8D5D5D58B8B8B1515151313131F1F1F474747E6E6E6E6E6E6
EEEEEEE3E3E3E1E1E1E3E3E3E5E5E5E6E6E6DFDFDFECECECE6E6E6E3E3E3
E1E1E1E5E5E5E4E4E4E3E3E3E5E5E5DFDFDFE2E2E2E3E3E3EDEDEDD3D3D3
D1D1D1E2E2E2ECECECE1E1E1DCDCDCDCDCDCCACACAD1D1D1F5F5F5E3E3E3
E1E1E1E1E1E1E4E4E4DCDCDCDEDEDEF7F7F7F6F6F6EDEDEDF8F8F8
F8F8F8F8F8F8F7F7F7F1F1F1F0F0F0E8E8E8E4E4E4EFEFEFDFDFDFDBDBDB
E1E1E1DADADAE1E1E1E1E1E1DFDFDFDCDCDCE2E2E2DCDCDCEEEEEEF1F1F1
E7E7E7E1E1E1E5E5E5DFDFDFE1E1E1F3F3F3EBEBEBD5D5D5D8D8D8E6E6E6
DBDBDBCFCFCFEDEDEDE7E7E7D6D6D6E3E3E3E2E2E2DFDFDFE7E7E7DFDFDF
E1E1E1DFDFDFDFDFDFD5D5D5989898151515121212202020080808000000
2929291B1B1B0E0E0E0000007777772525252B2B2B2E2E2EB7B7B7DDDDDD
DCDCDCF0F0F0F1F1F1DCDCDCECECECD8D8D8C7C7C7E0E0E0D1D1D1CECECE
E6E6E6CECECE5959591111110F0F0F181818171717111111111111191919
353535B6B6B6E6E6E6272727151515181818303030E2E2E2D5D5D5E8E8E8
E8E8E8DCDCDCE3E3E3E6E6E6E0E0E0DEDEDEE1E1E1E1E1E1DDDDDDDCDCDC
E5E5E5E0E0E0CCCCCCE3E3E3E4E4E4DDDDDDE9E9E9E2E2E2E1E1E1D5D5D5
DCDCDCE1E1E1DCDCDCDCDCDCD8D8D8E2E2E2D1D1D1D1D1D1F0F0F0E3E3E3
DEDEDED9D9D9EBEBEBCBCBCBCACACAF5F5F5F5F5F5F6F6F6F6F6F6
F6F6F6F9F9F9F9F9F9EBEBEBE8E8E8EFEFEFF4F4F4E3E3E3D7D7D7E3E3E3
D9D9D9E5E5E5E3E3E3E3E3E3E7E7E7E2E2E2E8E8E8E1E1E1DFDFDFDFDFDF
E3E3E3F2F2F2E6E6E6ECECECF2F2F2DCDCDCDADADAF5F5F5EAEAEAEBEBEB
F1F1F1F5F5F5DEDEDEE4E4E4EFEFEFEAEAEAE3E3E3E7E7E7DFDFDFD8D8D8
E4E4E4E2E2E2E5E5E5E2E2E2E3E3E31818182A2A2A060606111111171717
1F1F1F0E0E0E4444443939390E0E0E0E0E0E1C1C1C1C1C1CEFEFEFE6E6E6
E7E7E7DADADAE0E0E0CECECEC6C6C6E4E4E4EDEDEDD0D0D0535353121212
000000010101414141C0C0C0A8A8A83E3E3E3333331515151111111C1C1C
0D0D0D5A5A5AE5E5E51616162222220E0E0E161616F0F0F0EAEAEAE2E2E2
EBEBEBEDEDEDE2E2E2E0E0E0F3F3F3F1F1F1DFDFDFEAEAEAE5E5E5E6E6E6
DEDEDEF0F0F0EBEBEBE5E5E5E6E6E6E6E6E6E5E5E5E1E1E1E3E3E3E1E1E1
E8E8E8E8E8E8E8E8E8E8E8E8E3E3E3DFDFDFF1F1F1E2E2E2D1D1D1DFDFDF
DADADADADADACACACAEDEDEDE3E3E3F9F9F9FAFAFAF4F4F4FBFBFB
F8F8F8F9F9F9F6F6F6EBEBEBDDDDDDF4F4F4F4F4F4DBDBDBEAEAEAE3E3E3
D7D7D7E1E1E1EBEBEBE6E6E6DADADAE8E8E8DADADAE3E3E3E7E7E7E7E7E7
E7E7E7E5E5E5E5E5E5E3E3E3F2F2F2E3E3E3E5E5E5EFEFEFEBEBEBEBEBEB
E9E9E9F3F3F3D7D7D7E5E5E5EFEFEFEAEAEAE7E7E7EFEFEFD8D8D8E5E5E5
DEDEDEE8E8E8E1E1E1E1E1E1F1F1F10B0B0B0B0B0B2B2B2B1B1B1B0B0B0B
0A0A0A2828282626261919191F1F1F0F0F0F787878E7E7E7E5E5E5E7E7E7
E6E6E6CDCDCDDEDEDED5D5D5D8D8D8BFBFBFE2E2E2000000060606181818
1111110000001111113333330000006F6F6F272727636363282828111111
212121333333D7D7D71111110B0B0B1C1C1C434343EDEDEDEEEEEEE4E4E4
E4E4E4E9E9E9E6E6E6E2E2E2E6E6E6F1F1F1D9D9D9EAEAEAE6E6E6E6E6E6
DCDCDCF2F2F2F1F1F1D7D7D7E6E6E6ECECECE3E3E3E1E1E1E4E4E4D7D7D7
D8D8D8E7E7E7E3E3E3E0E0E0E6E6E6E7E7E7E1E1E1DFDFDFDADADAD4D4D4
DDDDDDDFDFDFD5D5D5E5E5E5E4E4E4FCFCFCF9F9F9F3F3F3F5F5F5
F6F6F6F8F8F8F8F8F8E5E5E5EDEDEDEAEAEAEEEEEEE3E3E3E5E5E5E0E0E0
DADADAD4D4D4F3F3F3E9E9E9D6D6D6DEDEDED8D8D8D0D0D0F2F2F2EFEFEF
E8E8E8E6E6E6E3E3E3DFDFDFE0E0E0E6E6E6E7E7E7D9D9D9E6E6E6E3E3E3
E7E7E7E6E6E6E4E4E4E5E5E5E7E7E7E3E3E3EAEAEAEFEFEFDCDCDCDBDBDB
D6D6D6EEEEEEE3E3E3E5E5E5EEEEEE0808080A0A0A0E0E0E191919050505
1212124545450000001616162A2A2AE2E2E2E4E4E4E6E6E6E7E7E7DDDDDD
D4D4D4DCDCDCDEDEDEC7C7C76D6D6D6969696666660F0F0F1818181A1A1A
1515151515152E2E2E191919070707050505C8C8C8848484111111292929
3C3C3C3333330000001C1C1C0B0B0B1A1A1AE9E9E9ECECECE7E7E7EEEEEE
E4E4E4E8E8E8EBEBEBE6E6E6E5E5E5E5E5E5E3E3E3EFEFEFEBEBEBE6E6E6
E6E6E6E8E8E8F0F0F0D7D7D7E7E7E7E7E7E7DBDBDBE3E3E3E9E9E9D0D0D0
D9D9D9EBEBEBE8E8E8D9D9D9DFDFDFF5F5F5D9D9D9D8D8D8DEDEDED4D4D4
DCDCDCDFDFDFE1E1E1DCDCDCE4E4E4F8F8F8F6F6F6F8F8F8F3F3F3
F7F7F7F7F7F7F6F6F6F6F6F6EFEFEFD9D9D9E4E4E4ECECECEBEBEBEEEEEE
E8E8E8F1F1F1D8D8D8E1E1E1F4F4F4E7E7E7EEEEEEE1E1E1D6D6D6D8D8D8
E6E6E6E7E7E7E2E2E2E9E9E9E9E9E9E1E1E1E8E8E8E6E6E6E6E6E6E4E4E4
E3E3E3DFDFDFE6E6E6EBEBEBE6E6E6E6E6E6E4E4E4D9D9D9E9E9E9E8E8E8
EBEBEBE3E3E3E6E6E6CACACAD3D3D31616160D0D0D0000000909090E0E0E
0A0A0A1C1C1C333333EDEDEDDCDCDCD0D0D0E2E2E2E1E1E1E3E3E3E4E4E4
D3D3D3C4C4C4585858606060373737303030313131404040666666333333
3E3E3E343434060606000000353535454545393939D4D4D4101010000000
0606063B3B3B323232202020434343E2E2E2E6E6E6E6E6E6F1F1F1E6E6E6
E1E1E1E6E6E6E4E4E4E6E6E6E6E6E6E7E7E7EAEAEAE3E3E3DFDFDFDFDFDF
E7E7E7DEDEDEDFDFDFEDEDEDE5E5E5DFDFDFEDEDEDE6E6E6CECECEEEEEEE
F1F1F1E1E1E1E3E3E3F0F0F0DDDDDDE2E2E2E3E3E3DDDDDDDEDEDED4D4D4
E2E2E2D6D6D6DFDFDFD7D7D7DCDCDCEFEFEFF5F5F5F6F6F6F7F7F7
F5F5F5F5F5F5F5F5F5E9E9E9DCDCDCEAEAEAEAEAEAEBEBEBE6E6E6E7E7E7
E7E7E7E7E7E7D7D7D7E3E3E3EBEBEBEBEBEBE9E9E9F1F1F1CDCDCDD8D8D8
E4E4E4E8E8E8DEDEDEF2F2F2F5F5F5D7D7D7E5E5E5E5E5E5E4E4E4F0F0F0
F2F2F2F1F1F1DCDCDCE2E2E2E7E7E7E2E2E2E5E5E5E3E3E3DFDFDFE9E9E9
E6E6E6E3E3E3E4E4E4D3D3D3DFDFDF0A0A0A1111110000000F0F0F0F0F0F
000000000000F4F4F4E8E8E8DFDFDFE1E1E1E1E1E1D8D8D8D9D9D9CACACA
A0A0A02121213535353737373B3B3B9D9D9DC8C8C8B0B0B0C1C1C1B8B8B8
7878785050504444443C3C3C3E3E3E1616160B0B0B1414146B6B6B090909
151515232323333333DCDCDCE8E8E8E6E6E6E3E3E3F1F1F1EFEFEFD5D5D5
EDEDEDF7F7F7E6E6E6DFDFDFEFEFEFF3F3F3D8D8D8E7E7E7E3E3E3E2E2E2
E1E1E1DFDFDFE2E2E2E1E1E1E1E1E1DFDFDFE6E6E6E2E2E2D4D4D4F0F0F0
EAEAEADADADAEAEAEAE9E9E9D2D2D2D2D2D2F9F9F9E4E4E4CECECED7D7D7
EEEEEED7D7D7CCCCCCEAEAEADDDDDDF3F3F3F8F8F8F1F1F1F6F6F6
F7F7F7F9F9F9F6F6F6E9E9E9EAEAEAEEEEEEEAEAEAE3E3E3E6E6E6E3E3E3
DEDEDEE2E2E2E9E9E9E7E7E7E5E5E5E7E7E7DEDEDEDBDBDBF3F3F3ECECEC
DCDCDCE2E2E2EAEAEAD6D6D6DEDEDEEDEDEDEAEAEAD9D9D9DDDDDDE4E4E4
CFCFCFE5E5E5E6E6E6EAEAEAE1E1E1E1E1E1DDDDDDDEDEDEDFDFDFE5E5E5
E3E3E3E3E3E3E3E3E3E0E0E0F1F1F11818180606061A1A1A3030301C1C1C
8D8D8DF2F2F2CACACAADADADEAEAEADADADAE2E2E2E0E0E0262626303030
5858587777779B9B9BA8A8A8D2D2D2D5D5D5CACACAE9E9E9DFDFDFDEDEDE
D2D2D2D6D6D6C1C1C1A9A9A96262620909090D0D0D050505414141727272
434343121212EDEDEDE9E9E9E2E2E2E9E9E9F5F5F5E9E9E9D8D8D8EDEDED
E0E0E0D7D7D7EEEEEEF0F0F0DCDCDCD7D7D7E5E5E5E3E3E3E7E7E7E3E3E3
DFDFDFE3E3E3E2E2E2D8D8D8E1E1E1DFDFDFDADADAE2E2E2E8E8E8CDCDCD
DFDFDFE5E5E5D8D8D8DFDFDFE5E5E5E4E4E4D7D7D7E5E5E5EBEBEBD7D7D7
D3D3D3EEEEEEE3E3E3D7D7D7DDDDDDF3F3F3F9F9F9F8F8F8F9F9F9
F5F5F5F5F5F5F5F5F5F1F1F1F4F4F4E2E2E2E8E8E8E7E7E7E3E3E3E6E6E6
E7E7E7E5E5E5E2E2E2E1E1E1E8E8E8E3E3E3D7D7D7D6D6D6E8E8E8E6E6E6
DEDEDEDEDEDEDFDFDFD2D2D2DCDCDCEDEDEDEEEEEED3D3D3E2E2E2D8D8D8
D4D4D4D5D5D5E7E7E7ECECECDFDFDFE2E2E2E3E3E3D4D4D4E1E1E1EFEFEF
DFDFDFD9D9D9E2E2E2D3D3D3DADADA0B0B0B151515363636494949202020
E3E3E3EAEAEA6B6B6B7E7E7ED7D7D7D4D4D4636363626262646464373737
717171D7D7D7D1D1D1CCCCCCEBEBEBD2D2D2CFCFCFEEEEEEE3E3E3DADADA
EAEAEAEBEBEBC4C4C4C7C7C76A6A6A0E0E0E2626261313131818183C3C3C
555555EBEBEBE9E9E9E7E7E7DFDFDFE4E4E4E8E8E8E3E3E3D9D9D9E1E1E1
E0E0E0D6D6D6EFEFEFF5F5F5D4D4D4D8D8D8ECECECDCDCDCE6E6E6DDDDDD
F3F3F3D6D6D6DADADADFDFDFDADADAE1E1E1DFDFDFDFDFDFDADADAD8D8D8
E1E1E1D8D8D8D5D5D5D4D4D4DDDDDDE1E1E1D7D7D7DDDDDDE9E9E9D8D8D8
D1D1D1E7E7E7E7E7E7DADADAE5E5E5F3F3F3FAFAFAF8F8F8F8F8F8
F7F7F7F9F9F9F6F6F6E2E2E2E1E1E1F1F1F1EAEAEAE6E6E6E7E7E7E6E6E6
E0E0E0D9D9D9E6E6E6E5E5E5E8E8E8E9E9E9EBEBEBE4E4E4E7E7E7E3E3E3
E7E7E7E7E7E7DFDFDFE8E8E8E3E3E3CFCFCFE6E6E6F1F1F1E7E7E7F5F5F5
F4F4F4ECECECD5D5D5E8E8E8EAEAEAE5E5E5E7E7E7ECECECD9D9D9DFDFDF
E1E1E1E4E4E4E5E5E5E0E0E0E3E3E30606061515151818181C1C1CBEBEBE
9F9F9F3D3D3DDDDDDDE2E2E24747475252528989899C9C9CC9C9C9BBBBBB
919191B8B8B8DADADAC6C6C6D4D4D4DDDDDDEFEFEFCCCCCCC6C6C6E0E0E0
E1E1E1DCDCDCEAEAEADEDEDE4646463A3A3A0D0D0D1F1F1F1D1D1D181818
CECECEE9E9E9E9E9E9EAEAEAE5E5E5E4E4E4E3E3E3EEEEEEEAEAEADFDFDF
E5E5E5F5F5F5D2D2D2E0E0E0F4F4F4F3F3F3DFDFDFE5E5E5E3E3E3E3E3E3
E3E3E3E5E5E5E6E6E6E5E5E5E3E3E3DDDDDDE4E4E4E1E1E1E6E6E6DDDDDD
DFDFDFD5D5D5E5E5E5E3E3E3D6D6D6D3D3D3E6E6E6E6E6E6E4E4E4E4E4E4
EFEFEFD3D3D3C3C3C3E3E3E3D7D7D7F5F5F5F4F4F4F8F8F8F5F5F5
F7F7F7FAFAFAF8F8F8E3E3E3E7E7E7F9F9F9EAEAEAE2E2E2F4F4F4D8D8D8
DADADADDDDDDEDEDEDE8E8E8E8E8E8F0F0F0DCDCDCE4E4E4EAEAEAE2E2E2
E6E6E6E0E0E0E1E1E1E5E5E5E3E3E3D3D3D3E7E7E7E5E5E5E6E6E6F0F0F0
E9E9E9E5E5E5E3E3E3E6E6E6E7E7E7E8E8E8F3F3F3F8F8F8D8D8D8D4D4D4
F0F0F0E7E7E7E0E0E0ECECECF1F1F10E0E0E0303031515152E2E2EC6C6C6
646464E6E6E6E1E1E13B3B3B7171719A9A9AABABAB7D7D7DC9C9C9B6B6B6
979797C3C3C3D0D0D0C5C5C5ADADADECECECE7E7E7747474494949808080
BEBEBEC2C2C2E6E6E6E1E1E10000001515150A0A0A0000001E1E1E2F2F2F
D7D7D7DFDFDFE6E6E6E6E6E6E3E3E3E3E3E3E9E9E9E1E1E1DCDCDCDADADA
DCDCDCDDDDDDE2E2E2E0E0E0F3F3F3F7F7F7E2E2E2E6E6E6E6E6E6D2D2D2
D7D7D7FBFBFBF4F4F4E5E5E5F6F6F6D7D7D7DFDFDFF1F1F1DEDEDED2D2D2
E1E1E1EFEFEFE9E9E9E2E2E2E6E6E6E4E4E4E1E1E1E6E6E6E2E2E2D4D4D4
E1E1E1E6E6E6DADADADFDFDFDEDEDEF8F8F8F6F6F6F4F4F4F8F8F8
F5F5F5F8F8F8F8F8F8FCFCFCEFEFEFE8E8E8EDEDEDEDEDEDE4E4E4F1F1F1
ECECECE7E7E7E9E9E9E8E8E8EAEAEAE4E4E4EBEBEBEBEBEBE6E6E6DFDFDF
E6E6E6E4E4E4E5E5E5DFDFDFE6E6E6E7E7E7DFDFDFDADADAE8E8E8E1E1E1
DFDFDFE6E6E6DDDDDDE9E9E9E6E6E6EBEBEBE5E5E5DEDEDEF1F1F1F0F0F0
E5E5E5E4E4E4F1F1F1D5D5D5D2D2D2282828171717000000111111ADADAD
C7C7C7CECECE1C1C1C4545458A8A8AC6C6C6C1C1C1AFAFAFBDBDBDB0B0B0
B2B2B2BEBEBEDADADACDCDCDDBDBDBDBDBDBDEDEDEDEDEDE5E5E5E111111
1C1C1C3232320909091111115757573B3B3B1A1A1A2828280909094B4B4B
F4F4F4E7E7E7E3E3E3E8E8E8E8E8E8E4E4E4E0E0E0E6E6E6E1E1E1E6E6E6
E1E1E1E1E1E1E3E3E3EBEBEBD9D9D9DFDFDFE2E2E2DADADAE5E5E5F8F8F8
F8F8F8D2D2D2D3D3D3E6E6E6D4D4D4DADADAEEEEEED2D2D2D3D3D3E2E2E2
E6E6E6DFDFDFE8E8E8EDEDEDDADADAE5E5E5DEDEDEDCDCDCE3E3E3DFDFDF
D9D9D9EDEDEDE0E0E0DDDDDDE6E6E6F8F8F8F8F8F8F7F7F7F5F5F5
F8F8F8F9F9F9F5F5F5F1F1F1EDEDEDEEEEEEEAEAEAEDEDEDE4E4E4F2F2F2
EAEAEAE8E8E8DCDCDCECECECEBEBEBE0E0E0F5F5F5F5F5F5D7D7D7E2E2E2
F0F0F0E4E4E4DBDBDBECECECE7E7E7E6E6E6E5E5E5E4E4E4CFCFCFE1E1E1
E2E2E2DBDBDBE7E7E7E6E6E6EAEAEAE7E7E7EAEAEAE9E9E9E8E8E8E9E9E9
E9E9E9E3E3E3F1F1F1D8D8D8D5D5D55757570000000000001515158E8E8E
DADADA3B3B3B272727848484BABABAB8B8B8C6C6C6B9B9B9D0D0D0C1C1C1
B6B6B67B7B7B9C9C9CBBBBBB8B8B8BE3E3E3E5E5E5D4D4D44141411C1C1C
1C1C1C3838380000000000002626263939395050502B2B2B131313111111
F4F4F4ECECECF1F1F1ECECECEEEEEED7D7D7CBCBCBEEEEEEEAEAEAE8E8E8
E5E5E5ECECECE1E1E1E4E4E4E3E3E3E8E8E8E6E6E6E6E6E6E4E4E4E3E3E3
DFDFDFDFDFDFD2D2D2D9D9D9D7D7D7EFEFEFE9E9E9D6D6D6D8D8D8E1E1E1
DCDCDCC9C9C9F1F1F1F2F2F2DADADAD1D1D1E1E1E1DCDCDCDADADAE2E2E2
E2E2E2DFDFDFDCDCDCDFDFDFE0E0E0F4F4F4F6F6F6F8F8F8F5F5F5
F9F9F9F9F9F9F8F8F8EBEBEBEAEAEAEEEEEEEAEAEAEAEAEAE8E8E8E9E9E9
DFDFDFE6E6E6E2E2E2E5E5E5EBEBEBE0E0E0F3F3F3F1F1F1DADADAE7E7E7
F3F3F3E9E9E9DFDFDFF3F3F3EBEBEBDFDFDFE6E6E6E6E6E6E7E7E7F4F4F4
F2F2F2E1E1E1DFDFDFDFDFDFDFDFDFE1E1E1E2E2E2E5E5E5DFDFDFE6E6E6
E4E4E4E3E3E3E3E3E3D9D9D9D8D8D88A8A8A151515111111161616121212
6B6B6B0F0F0F7B7B7BC4C4C4BCBCBCBDBDBDA1A1A1C8C8C8EDEDEDD6D6D6
B3B3B36F6F6FAAAAAA787878272727E1E1E1F0F0F0C8C8C8D2D2D2D6D6D6
E0E0E0B5B5B51E1E1E0707072828281C1C1C4949493838380E0E0E232323
FBFBFBEAEAEAEAEAEAF4F4F4F4F4F4DADADAE3E3E3ECECECE1E1E1DCDCDC
F3F3F3E9E9E9D5D5D5D8D8D8E8E8E8F1F1F1DFDFDFF1F1F1DFDFDFDDDDDD
D5D5D5D3D3D3D8D8D8DCDCDCDFDFDFE7E7E7E5E5E5D5D5D5D1D1D1EDEDED
DBDBDBDFDFDFF3F3F3E0E0E0D4D4D4D8D8D8EBEBEBDFDFDFE1E1E1E4E4E4
F3F3F3D3D3D3CCCCCCDEDEDEDADADAF6F6F6F8F8F8F7F7F7FDFDFD
FAFAFAF5F5F5F8F8F8F0F0F0EAEAEAE7E7E7E7E7E7E9E9E9E4E4E4E1E1E1
E4E4E4E8E8E8E9E9E9D8D8D8ECECECF1F1F1D3D3D3E4E4E4EEEEEEE5E5E5
D6D6D6ECECECF7F7F7D6D6D6E6E6E6ECECECDFDFDFE7E7E7F2F2F2E4E4E4
DADADAE1E1E1E1E1E1E1E1E1E8E8E8E1E1E1E3E3E3DEDEDEDDDDDDDDDDDD
E1E1E1E6E6E6E1E1E1E8E8E8E1E1E1E0E0E09A9A9A0404040D0D0D222222
3030303B3B3B525252CECECEE3E3E3ACACACEDEDEDF2F2F2ACACACBEBEBE
C8C8C8A0A0A0505050DADADA5B5B5B121212262626232323444444515151
2929298D8D8D1717170606060A0A0A2727274E4E4E101010353535434343
EDEDEDE3E3E3ECECECD5D5D5DEDEDEEEEEEEECECECD5D5D5DEDEDEE4E4E4
D6D6D6E0E0E0EEEEEEEFEFEFD6D6D6DDDDDDCCCCCCE1E1E1E0E0E0E4E4E4
D7D7D7DDDDDDDFDFDFDDDDDDE2E2E2DDDDDDD7D7D7DFDFDFEDEDEDE2E2E2
E8E8E8E5E5E5D5D5D5CCCCCCEBEBEBEDEDEDDEDEDEDDDDDDE3E3E3CBCBCB
CDCDCDEBEBEBE5E5E5DCDCDCEFEFEFF7F7F7F8F8F8F4F4F4F5F5F5
F9F9F9F7F7F7EBEBEBF1F1F1EEEEEEEDEDEDEEEEEEEAEAEAE6E6E6E8E8E8
E7E7E7E0E0E0E6E6E6E8E8E8E5E5E5E2E2E2E4E4E4E4E4E4E3E3E3DCDCDC
E1E1E1E8E8E8ECECECDCDCDCE5E5E5E6E6E6DFDFDFDEDEDEECECECDADADA
E1E1E1E3E3E3E5E5E5D6D6D6E1E1E1E8E8E8E6E6E6C5C5C5E8E8E8E5E5E5
E4E4E4DFDFDFE9E9E9DCDCDCDFDFDFE4E4E4C8C8C81818181111111F1F1F
757575696969474747B7B7B7CACACAA8A8A8ECECECE0E0E0CBCBCBCECECE
CDCDCDBFBFBF3E3E3E9B9B9B9C9C9C1F1F1F454545DBDBDB9F9F9F343434
9C9C9C9494940000001111110D0D0D0C0C0C6565655B5B5B1A1A1A161616
BCBCBCE4E4E4E9E9E9DFDFDFE5E5E5E2E2E2EBEBEBDDDDDDE3E3E3E1E1E1
DBDBDBE3E3E3E6E6E6ECECECD6D6D6E6E6E6D9D9D9DCDCDCE1E1E1F3F3F3
EDEDEDDBDBDBE2E2E2DFDFDFD5D5D5E9E9E9EDEDEDDCDCDCD6D6D6DFDFDF
E2E2E2D8D8D8D6D6D6D7D7D7D3D3D3E9E9E9DFDFDFE0E0E0DFDFDFCACACA
DADADAEEEEEEE1E1E1D2D2D2E5E5E5F7F7F7F3F3F3F7F7F7F3F3F3
F8F8F8F7F7F7F8F8F8EAEAEAE6E6E6E9E9E9E8E8E8E7E7E7E4E4E4D9D9D9
D8D8D8EAEAEAE6E6E6E1E1E1E4E4E4EBEBEBDDDDDDE5E5E5E4E4E4E4E4E4
F1F1F1E6E6E6D8D8D8EEEEEEEBEBEBDEDEDEEAEAEADEDEDEDFDFDFF8F8F8
EEEEEEDCDCDCD6D6D6F0F0F0E4E4E4DEDEDEF1F1F1EAEAEAE2E2E2DFDFDF
DEDEDEDEDEDEE5E5E5DFDFDFE2E2E2E1E1E1313131181818141414C7C7C7
C7C7C7D5D5D56868688F8F8FD5D5D5CECECED9D9D9D6D6D6DEDEDEDCDCDC
DEDEDEDFDFDFD2D2D22F2F2F858585DEDEDE9B9B9BD5D5D5E0E0E0D9D9D9
8E8E8EC5C5C50909090D0D0D0202020B0B0B0D0D0D0C0C0C353535232323
989898EFEFEFE4E4E4E6E6E6EBEBEBD4D4D4DFDFDFE8E8E8E1E1E1E4E4E4
E8E8E8F0F0F0E1E1E1DEDEDEF4F4F4ECECECE6E6E6F7F7F7CDCDCDD2D2D2
E2E2E2D9D9D9DCDCDCDDDDDDE7E7E7D6D6D6CDCDCDE3E3E3DADADAE1E1E1
ECECECD7D7D7E4E4E4DEDEDED1D1D1DBDBDBE1E1E1CCCCCCDFDFDFE0E0E0
E0E0E0CDCDCDDADADADADADAC5C5C5F5F5F5F7F7F7EFEFEFFAFAFA
F8F8F8F5F5F5F8F8F8EDEDEDF0F0F0EDEDEDE4E4E4EEEEEEEAEAEAD9D9D9
E6E6E6EBEBEBE5E5E5E1E1E1EEEEEEE9E9E9DFDFDFE6E6E6EAEAEAE5E5E5
D7D7D7E7E7E7EAEAEAE6E6E6E5E5E5E6E6E6DEDEDEE3E3E3E7E7E7EBEBEB
E5E5E5EAEAEAE4E4E4E8E8E8E8E8E8D6D6D6EDEDEDEBEBEBDDDDDDE6E6E6
E2E2E2E1E1E1D8D8D8F3F3F3ECECEC6E6E6E1C1C1C1C1C1CACACACBEBEBE
EAEAEAE0E0E06C6C6CB0B0B0D3D3D3D8D8D8DADADADEDEDEE2E2E2E1E1E1
DADADADCDCDCDEDEDE535353727272E5E5E5D2D2D2E2E2E2E3E3E3C7C7C7
CCCCCC888888303030131313000000111111000000000000333333484848
646464E3E3E3EFEFEFE3E3E3E9E9E9EEEEEEEBEBEBEBEBEBEFEFEFE9E9E9
DFDFDFEAEAEAE7E7E7E5E5E5F0F0F0E8E8E8EBEBEBF4F4F4DCDCDCE7E7E7
E5E5E5F2F2F2E7E7E7E4E4E4F2F2F2DFDFDFC2C2C2ECECECE5E5E5E4E4E4
EFEFEFECECECDBDBDBD7D7D7E1E1E1E2E2E2DEDEDEE4E4E4D9D9D9DADADA
DEDEDEE2E2E2DEDEDEEDEDEDD8D8D8F8F8F8F9F9F9F7F7F7F5F5F5
F7F7F7F8F8F8F8F8F8EDEDEDEEEEEEEAEAEAEFEFEFE3E3E3DCDCDCF5F5F5
E6E6E6E5E5E5E5E5E5F1F1F1E3E3E3DBDBDBEEEEEEE5E5E5E9E9E9E3E3E3
E8E8E8E3E3E3E5E5E5E3E3E3E4E4E4E6E6E6E0E0E0E3E3E3E6E6E6E4E4E4
E3E3E3EEEEEEE6E6E6DCDCDCEAEAEAF1F1F1D7D7D7E4E4E4EDEDEDDFDFDF
DFDFDFEDEDEDF2F2F2CDCDCD8787872525250F0F0F8B8B8BD5D5D5C3C3C3
E2E2E2D7D7D7626262B3B3B3DFDFDFDFDFDFE3E3E3E6E6E6E3E3E3E3E3E3
E3E3E3DCDCDCE4E4E4E1E1E1494949B0B0B0DCDCDC9393939D9D9DEAEAEA
E7E7E71E1E1E0000001F1F1F0A0A0A020202424242424242070707111111
272727EBEBEBEBEBEBE4E4E4EAEAEAE0E0E0E9E9E9E4E4E4E6E6E6E6E6E6
E1E1E1E5E5E5E5E5E5EBEBEBD8D8D8EAEAEAE2E2E2E5E5E5F0F0F0F0F0F0
E6E6E6DBDBDBEAEAEADFDFDFD9D9D9EFEFEFEEEEEECDCDCDDFDFDFDFDFDF
DADADAD7D7D7E9E9E9E3E3E3CECECEDBDBDBE2E2E2E1E1E1E4E4E4E1E1E1
E1E1E1DFDFDFDFDFDFE2E2E2E5E5E5F7F7F7F8F8F8F8F8F8F5F5F5
F7F7F7F8F8F8F9F9F9EDEDEDECECECEEEEEEEFEFEFE3E3E3E4E4E4EAEAEA
E6E6E6E6E6E6ECECECECECECDCDCDCDFDFDFF1F1F1E4E4E4E4E4E4EAEAEA
F4F4F4E0E0E0D4D4D4EBEBEBE7E7E7E8E8E8F6F6F6E3E3E3E3E3E3F3F3F3
E8E8E8E7E7E7EAEAEAE8E8E8E7E7E7E6E6E6E6E6E6E7E7E7EAEAEAE6E6E6
D8D8D8EEEEEEEAEAEACBCBCB2B2B2B2C2C2C0B0B0BDDDDDDEDEDED6D6D6D
D0D0D07A7A7A5B5B5BB4B4B4E4E4E4F3F3F3DCDCDCE0E0E0F1F1F1E8E8E8
DFDFDFEDEDEDE6E6E6CBCBCB7B7B7B595959E6E6E6B9B9B9040404676767
E2E2E24040400707071111111515150808083D3D3D3D3D3D0000000E0E0E
454545F5F5F5E6E6E6EAEAEAF3F3F3E4E4E4EAEAEAEDEDEDEBEBEBEAEAEA
F3F3F3E8E8E8E4E4E4E6E6E6E3E3E3E4E4E4E3E3E3DDDDDDDFDFDFE6E6E6
E7E7E7D7D7D7E8E8E8DDDDDDDBDBDBF1F1F1ECECECCFCFCFE1E1E1DBDBDB
D9D9D9D2D2D2F3F3F3F5F5F5C3C3C3DCDCDCD9D9D9D1D1D1EDEDEDEFEFEF
E2E2E2D1D1D1E2E2E2DDDDDDDCDCDCF8F8F8F8F8F8F6F6F6FAFAFA
FAFAFAFAFAFAFAFAFAF3F3F3ECECECE6E6E6E9E9E9EAEAEAEDEDEDE4E4E4
EDEDEDEBEBEBE3E3E3E6E6E6FBFBFBEDEDEDD9D9D9E9E9E9E5E5E5D7D7D7
D6D6D6EEEEEEF4F4F4DBDBDBE6E6E6E6E6E6E6E6E6EBEBEBE9E9E9EAEAEA
E4E4E4E6E6E6E5E5E5E1E1E1E6E6E6EAEAEAE7E7E7E7E7E7E4E4E4E3E3E3
EAEAEAD4D4D4D9D9D93A3A3A1C1C1C0C0C0C8F8F8FDEDEDE727272E0E0E0
EAEAEA2727273B3B3BC8C8C8E6E6E6E4E4E4F0F0F0ECECECD9D9D9E0E0E0
E1E1E1E5E5E5E3E3E3DCDCDCCFCFCF464646F1F1F1DFDFDFDDDDDD969696
BFBFBFD6D6D62525251111111515153838380000000000002E2E2E2E2E2E
0C0C0CEDEDEDF7F7F7DCDCDCE3E3E3EFEFEFE9E9E9DADADAEAEAEAE6E6E6
D7D7D7D5D5D5EFEFEFEBEBEBE5E5E5E8E8E8E2E2E2E5E5E5D9D9D9E0E0E0
DCDCDCF0F0F0E4E4E4E4E4E4EDEDEDD8D8D8D6D6D6F7F7F7E9E9E9E1E1E1
F1F1F1F5F5F5D7D7D7CCCCCCEEEEEEEDEDEDF3F3F3EEEEEECFCFCFD4D4D4
DEDEDEDFDFDFDFDFDFDCDCDCE2E2E2F5F5F5F8F8F8F6F6F6F4F4F4
F6F6F6F9F9F9F6F6F6EDEDEDEAEAEAEAEAEAEDEDEDEAEAEAE6E6E6E6E6E6
E4E4E4E5E5E5E6E6E6E3E3E3ECECECEBEBEBDFDFDFDBDBDBE4E4E4D1D1D1
D5D5D5EEEEEEE5E5E5DEDEDEEDEDEDE3E3E3DBDBDBE9E9E9F6F6F6E2E2E2
DEDEDEEAEAEAE2E2E2D7D7D7F5F5F5F2F2F2E0E0E0E7E7E7DFDFDFDFDFDF
E1E1E1E1E1E1DADADA1C1C1C1C1C1C171717E5E5E5CCCCCC484848DCDCDC
D7D7D71616163B3B3BE2E2E2E6E6E6D4D4D4E4E4E4EEEEEEDBDBDBE4E4E4
EFEFEFD8D8D8DDDDDDECECECE4E4E4B1B1B1B6B6B6DCDCDCDFDFDFE8E8E8
E3E3E3DEDEDEB1B1B11616161515154A4A4A232323131313252525202020
1F1F1FECECECF1F1F1E1E1E1E1E1E1EAEAEAE8E8E8E1E1E1EEEEEEDBDBDB
D1D1D1DBDBDBF4F4F4E8E8E8DFDFDFE9E9E9D5D5D5D7D7D7E3E3E3E3E3E3
E5E5E5DFDFDFE5E5E5D9D9D9DADADAE6E6E6E6E6E6E6E6E6DEDEDEDDDDDD
E1E1E1E3E3E3E2E2E2D9D9D9EBEBEBECECECE6E6E6E6E6E6CBCBCBCCCCCC
C8C8C8EFEFEFE7E7E7E9E9E9E4E4E4EFEFEFF5F5F5F8F8F8F5F5F5
F6F6F6FAFAFAF5F5F5F3F3F3E8E8E8EFEFEFEFEFEFE4E4E4E3E3E3E3E3E3
E6E6E6D7D7D7EAEAEAE9E9E9E9E9E9DFDFDFE3E3E3E7E7E7E7E7E7E1E1E1
E5E5E5E8E8E8E2E2E2E7E7E7E4E4E4E0E0E0DDDDDDF3F3F3F6F6F6E4E4E4
E8E8E8F3F3F3E2E2E2D9D9D9F4F4F4F4F4F4E6E6E6E6E6E6E6E6E6DFDFDF
E1E1E1F6F6F6E8E8E8111111080808393939D6D6D6E9E9E9656565757575
434343181818545454C7C7C7E4E4E4DFDFDFE8E8E8E1E1E1D4D4D4E6E6E6
EDEDEDDFDFDFDFDFDFEAEAEAE3E3E3D6D6D6E4E4E4DADADAE3E3E3F4F4F4
EEEEEEDEDEDEBDBDBD1515152D2D2D4D4D4D555555212121020202181818
2C2C2CF5F5F5EAEAEAE8E8E8E3E3E3E6E6E6E6E6E6E7E7E7DFDFDFE1E1E1
DBDBDBDCDCDCE8E8E8E1E1E1D9D9D9EBEBEBD7D7D7DADADAF1F1F1E1E1E1
EAEAEADEDEDEF0F0F0DFDFDFD2D2D2F0F0F0E8E8E8CFCFCFDEDEDEDFDFDF
DFDFDFD7D7D7E3E3E3E1E1E1DCDCDCDFDFDFE0E0E0DEDEDED5D5D5DEDEDE
D6D6D6E1E1E1DCDCDCEAEAEAF1F1F1F9F9F9F7F7F7F7F7F7F8F8F8
F7F7F7F7F7F7F6F6F6EBEBEBEBEBEBEAEAEADBDBDBF5F5F5F5F5F5E0E0E0
E5E5E5E6E6E6E8E8E8E2E2E2E6E6E6E9E9E9DFDFDFDFDFDFE6E6E6E2E2E2
E1E1E1DEDEDEE4E4E4E2E2E2DFDFDFE9E9E9EBEBEBDEDEDED3D3D3EFEFEF
DDDDDDD4D4D4E7E7E7EAEAEACFCFCFDDDDDDEEEEEEE4E4E4DFDFDFECECEC
ECECECCFCFCF8686862626261515152020209B9B9BA9A9A93535351E1E1E
1F1F1F2E2E2E373737D7D7D7E3E3E3DCDCDCD8D8D8E3E3E3E3E3E3DFDFDF
DDDDDDDDDDDDF2F2F2D5D5D5E1E1E1EEEEEED9D9D9E3E3E3E8E8E8D4D4D4
E2E2E2E5E5E51D1D1D0B0B0B7272726B6B6B0808080F0F0F3B3B3B121212
0D0D0DEAEAEAECECECEAEAEAE4E4E4E6E6E6D4D4D4E5E5E5E0E0E0EFEFEF
E8E8E8E1E1E1E1E1E1E1E1E1E7E7E7E7E7E7F2F2F2F1F1F1CBCBCBD0D0D0
ECECECE3E3E3DBDBDBDDDDDDEAEAEAD3D3D3E0E0E0E2E2E2D8D8D8DDDDDD
EDEDEDDFDFDFDADADAE1E1E1DADADAD0D0D0DCDCDCDADADADCDCDCDADADA
DEDEDED7D7D7DFDFDFD5D5D5CECECEF7F7F7F6F6F6F9F9F9F4F4F4
F7F7F7F5F5F5F5F5F5F1F1F1EDEDEDE9E9E9E9E9E9F5F5F5F5F5F5E4E4E4
EAEAEAF1F1F1E1E1E1D8D8D8F2F2F2EAEAEAE7E7E7F2F2F2ECECECDADADA
E0E0E0EDEDEDE8E8E8E6E6E6F0F0F0E9E9E9E2E2E2E6E6E6E5E5E5E7E7E7
E3E3E3DCDCDCE4E4E4E6E6E6DBDBDBE5E5E5EAEAEAD9D9D9E2E2E2F2F2F2
E8E8E8DCDCDC9393931E1E1E1515151313137979790404040D0D0D292929
151515212121414141D6D6D6E9E9E9E1E1E1E3E3E3E3E3E3E7E7E7E3E3E3
E6E6E6DDDDDDD6D6D6D5D5D5E4E4E4E9E9E9DFDFDFE2E2E2E5E5E5D6D6D6
E1E1E1C2C2C21515150000009090908A8A8A000000161616191919080808
101010F0F0F0EDEDEDE7E7E7E4E4E4E9E9E9E4E4E4E8E8E8E5E5E5D7D7D7
DCDCDCE9E9E9EBEBEBE8E8E8EAEAEAE9E9E9EBEBEBF1F1F1DFDFDFE5E5E5
E5E5E5EEEEEEDCDCDCF1F1F1EEEEEEDCDCDCE2E2E2EEEEEEEAEAEAECECEC
F2F2F2E7E7E7D9D9D9D6D6D6E3E3E3DFDFDFEEEEEEEDEDEDDDDDDDDADADA
DDDDDDE1E1E1E1E1E1DFDFDFCECECEF6F6F6F8F8F8F4F4F4F3F3F3
F7F7F7F9F9F9F9F9F9ECECECEDEDEDF1F1F1F3F3F3E9E9E9E0E0E0E6E6E6
E1E1E1DADADAF7F7F7F1F1F1E5E5E5DBDBDBE8E8E8DADADAECECECF2F2F2
E8E8E8E3E3E3D5D5D5E2E2E2E4E4E4E6E6E6E9E9E9DBDBDBE7E7E7E7E7E7
E6E6E6E4E4E4DDDDDDE6E6E6F0F0F0E7E7E7E5E5E5E9E9E9E2E2E2DADADA
D4D4D4ECECEC6A6A6A0303031717170F0F0F0000001111112F2F2F000000
1C1C1C4242423D3D3DBDBDBDE6E6E6E6E6E6E3E3E3E3E3E3D9D9D9C8C8C8
D9D9D9B1B1B1656565838383E9E9E9E8E8E8E8E8E8DBDBDBD9D9D9F1F1F1
ECECEC1D1D1D0B0B0B2B2B2B0C0C0C0C0C0C9494943E3E3E000000191919
1E1E1E282828393939D4D4D4EAEAEAECECECEAEAEAEAEAEAEBEBEBEAEAEA
E5E5E5EAEAEAEAEAEAE7E7E7E9E9E9E9E9E9E1E1E1DCDCDCEAEAEAE7E7E7
E5E5E5E4E4E4F1F1F1D0D0D0D3D3D3EFEFEFE9E9E9D6D6D6E2E2E2D3D3D3
DADADADEDEDEEEEEEEE6E6E6DCDCDCE2E2E2E5E5E5D9D9D9E1E1E1DFDFDF
E2E2E2DFDFDFDEDEDED2D2D2E1E1E1F9F9F9F9F9F9F8F8F8F5F5F5
F5F5F5F9F9F9FBFBFBF1F1F1EDEDEDEDEDEDE9E9E9EBEBEBE4E4E4EAEAEA
E1E1E1E0E0E0ECECECECECECE4E4E4E4E4E4E7E7E7E6E6E6F9F9F9F3F3F3
F4F4F4DADADAE4E4E4E6E6E6E3E3E3F1F1F1EFEFEFD9D9D9DEDEDEECECEC
E2E2E2E5E5E5E8E8E8E7E7E7E4E4E4E6E6E6E3E3E3E6E6E6E4E4E4E1E1E1
DBDBDB818181161616111111202020010101020202292929333333000000
1212124A4A4A2C2C2CB4B4B4E9E9E9ECECECCBCBCBAFAFAFBDBDBD9B9B9B
A5A5A5E4E4E4A7A7A74E4E4EE3E3E3E7E7E7DCDCDCDADADAE8E8E8E4E4E4
DBDBDB3D3D3D1515153838381818181515153C3C3C454545151515323232
333333000000060606999999DCDCDCECECECEEEEEEEEEEEEE0E0E0FDFDFD
EAEAEAE4E4E4EAEAEAEBEBEBE8E8E8E6E6E6E8E8E8EDEDEDE4E4E4E1E1E1
E3E3E3E5E5E5E7E7E7DFDFDFE6E6E6E4E4E4DFDFDFD7D7D7E2E2E2D8D8D8
E3E3E3E0E0E0EDEDEDE4E4E4D4D4D4E3E3E3D6D6D6D6D6D6F3F3F3F0F0F0
DDDDDDE3E3E3EBEBEBD2D2D2CCCCCCF8F8F8F8F8F8F8F8F8F7F7F7
F6F6F6F6F6F6F6F6F6E9E9E9EAEAEAECECECEAEAEAEAEAEAEFEFEFE8E8E8
ECECECE9E9E9E4E4E4E4E4E4F7F7F7E5E5E5E9E9E9F4F4F4DEDEDEDFDFDF
E2E2E2F5F5F5EBEBEBEBEBEBF1F1F1E4E4E4D6D6D6EFEFEFEAEAEAEAEAEA
E7E7E7ECECECD8D8D8E6E6E6ECECECE4E4E4DCDCDCE4E4E4E5E5E5E6E6E6
DEDEDE0C0C0C0A0A0A0505050505050D0D0D1A1A1A0E0E0E0D0D0D151515
0E0E0E000000494949E8E8E8DFDFDFC9C9C95757574C4C4C4E4E4ECDCDCD
2424240808088B8B8BB5B5B5E8E8E8E5E5E5D9D9D9DADADAE1E1E1E1E1E1
BBBBBB252525A3A3A3D2D2D26363631D1D1D0000000000002A2A2A1D1D1D
000000303030444444565656979797EEEEEEEBEBEBE6E6E6F0F0F0DBDBDB
E5E5E5E4E4E4ECECECDFDFDFE9E9E9F2F2F2E1E1E1E5E5E5E6E6E6E2E2E2
E6E6E6DDDDDDE5E5E5EAEAEAE3E3E3E0E0E0ECECECE2E2E2D9D9D9F1F1F1
F5F5F5E8E8E8D4D4D4E8E8E8E8E8E8D6D6D6F4F4F4F3F3F3D4D4D4D6D6D6
E1E1E1E1E1E1D6D6D6EFEFEFE3E3E3FBFBFBF8F8F8F7F7F7F7F7F7
F8F8F8FBFBFBF6F6F6EBEBEBE8E8E8EFEFEFF4F4F4D9D9D9E3E3E3E9E9E9
DEDEDEE4E4E4E8E8E8E6E6E6E7E7E7E6E6E6E7E7E7E1E1E1EBEBEBE0E0E0
E7E7E7EDEDEDEBEBEBE8E8E8F3F3F3DBDBDBD2D2D2F1F1F1E9E9E9E6E6E6
EBEBEBF5F5F5E2E2E2D6D6D6F3F3F3E8E8E8DFDFDFEEEEEEDADADACECECE
DBDBDB1616160000000F0F0F1515150D0D0D1B1B1B151515292929212121
1C1C1C1A1A1AA9A9A9DCDCDCD8D8D8B9B9B93F3F3F212121D7D7D75A5A5A
1313131212120303037979797D7D7DD9D9D9DEDEDEDADADAD8D8D8E3E3E3
D1D1D1080808DBDBDBA3A3A3BCBCBC4B4B4B4444441111111313130B0B0B
0B0B0B2C2C2C2A2A2A5353534E4E4EE7E7E7E6E6E6E6E6E6E8E8E8DEDEDE
E4E4E4E2E2E2E4E4E4DEDEDEE4E4E4FAFAFAD1D1D1E1E1E1F1F1F1E7E7E7
D4D4D4EDEDEDEBEBEBD9D9D9DCDCDCE1E1E1E6E6E6E1E1E1DEDEDEDCDCDC
DCDCDCDEDEDEDEDEDEDDDDDDDFDFDFE1E1E1E9E9E9EBEBEBD4D4D4DBDBDB
E3E3E3E1E1E1C9C9C9F2F2F2EEEEEEE9E9E9F5F5F5F8F8F8F6F6F6
F7F7F7F7F7F7F5F5F5FAFAFAF0F0F0E3E3E3E1E1E1EEEEEEE9E9E9E8E8E8
E7E7E7E6E6E6E6E6E6E3E3E3E6E6E6E8E8E8DDDDDDE1E1E1EBEBEBF1F1F1
EDEDEDE4E4E4E6E6E6D6D6D6D7D7D7F3F3F3F2F2F2DCDCDCE3E3E3E6E6E6
E2E2E2D6D6D6EDEDEDE9E9E9D8D8D8E1E1E1DEDEDEDCDCDCCDCDCDE6E6E6
CDCDCD1313130D0D0D0000000F0F0F1C1C1C1818181A1A1A3A3A3A0B0B0B
151515252525A9A9A9B6B6B6DCDCDCEBEBEB8B8B8B2A2A2ADDDDDDDADADA
9E9E9E7E7E7E2121212727276D6D6D2A2A2AD1D1D1F1F1F1EEEEEEE1E1E1
2727272020200000001111112626262828281F1F1F252525181818181818
1C1C1C262626121212464646484848E2E2E2E4E4E4E6E6E6E6E6E6F2F2F2
E8E8E8DFDFDFE3E3E3ECECECD7D7D7D6D6D6F5F5F5E9E9E9D9D9D9EAEAEA
E3E3E3D6D6D6DDDDDDE7E7E7DCDCDCE6E6E6E4E4E4DADADAE2E2E2D7D7D7
DEDEDEDADADAECECECD7D7D7DADADAE1E1E1D6D6D6D6D6D6F4F4F4EAEAEA
D2D2D2E8E8E8E1E1E1CCCCCCCCCCCCFAFAFAF6F6F6F6F6F6F8F8F8
F5F5F5FAFAFAF6F6F6FAFAFAF7F7F7E8E8E8DDDDDDF6F6F6EEEEEEEBEBEB
EDEDEDEDEDEDDFDFDFE7E7E7EFEFEFEAEAEAEEEEEEE7E7E7DFDFDFDFDFDF
E6E6E6E7E7E7EAEAEADCDCDCE4E4E4E3E3E3E1E1E1E4E4E4E2E2E2E1E1E1
E2E2E2D9D9D9E8E8E8E2E2E2D6D6D6E1E1E1E5E5E5D4D4D4E3E3E3E7E7E7
E4E4E40707070D0D0D111111000000202020282828060606161616161616
0B0B0B151515A4A4A4CDCDCDCCCCCCDCDCDCBEBEBE6A6A6A161616B2B2B2
DCDCDCDEDEDE4F4F4F161616232323252525DEDEDEE7E7E7F2F2F2BCBCBC
1818182D2D2D0C0C0C0000002828283C3C3C1818180D0D0D1515151C1C1C
020202353535212121343434525252E8E8E8E4E4E4DFDFDFD7D7D7E4E4E4
D8D8D8DDDDDDE4E4E4E8E8E8E1E1E1D8D8D8E9E9E9E5E5E5CECECEEAEAEA
F0F0F0D5D5D5D6D6D6ECECECE1E1E1DFDFDFEEEEEEE1E1E1D1D1D1EAEAEA
EAEAEADCDCDCE1E1E1DDDDDDD4D4D4DCDCDCE0E0E0DFDFDFDFDFDFE1E1E1
D7D7D7D9D9D9E5E5E5C5C5C5D2D2D2F0F0F0EEEEEEF8F8F8F8F8F8
F5F5F5F9F9F9F8F8F8EEEEEEF3F3F3EEEEEEE8E8E8ECECECE9E9E9E7E7E7
ECECECEBEBEBE2E2E2D8D8D8F8F8F8D9D9D9EDEDEDF2F2F2DBDBDBDADADA
E2E2E2EDEDEDE6E6E6E8E8E8ECECECE7E7E7E1E1E1EAEAEAE8E8E8E7E7E7
E7E7E7E5E5E5E1E1E1E6E6E6E6E6E6E8E8E8E4E4E4DADADADFDFDFDDDDDD
E8E8E80B0B0B1F1F1F0000000000000D0D0D2B2B2B000000000000151515
1C1C1C0F0F0FE6E6E6E8E8E8DCDCDCDBDBDBD8D8D8B8B8B8818181070707
7676764040400A0A0A2929298E8E8E5D5D5DE8E8E8E6E6E6E9E9E97A7A7A
0F0F0F181818BFBFBF3D3D3D3636363030301515151313130B0B0B1C1C1C
000000404040252525555555D0D0D0E0E0E0E5E5E5E8E8E8F1F1F1DFDFDF
E3E3E3DFDFDFDCDCDCDCDCDCE3E3E3E9E9E9D9D9D9E8E8E8DCDCDCE4E4E4
E6E6E6DFDFDFD5D5D5EFEFEFE6E6E6D7D7D7EBEBEBE6E6E6D5D5D5EEEEEE
EFEFEFDFDFDFE1E1E1EFEFEFE3E3E3CFCFCFE0E0E0EEEEEEDBDBDBDADADA
E1E1E1DADADACECECEDEDEDEDCDCDCF5F5F5F1F1F1F9F9F9F9F9F9
F8F8F8F3F3F3F8F8F8E8E8E8EDEDEDEEEEEEEEEEEEE4E4E4E8E8E8E4E4E4
E5E5E5EAEAEAF2F2F2EBEBEBD1D1D1E6E6E6E3E3E3D9D9D9F6F6F6E7E7E7
E8E8E8E3E3E3E8E8E8DBDBDBE2E2E2ECECECEBEBEBE5E5E5E7E7E7E8E8E8
E9E9E9E8E8E8E2E2E2E5E5E5E2E2E2E5E5E5E3E3E3E4E4E4D7D7D7DCDCDC
D3D3D34646460E0E0E2B2B2B2121210000001515152727272B2B2B272727
2121213F3F3F5F5F5FD5D5D5F1F1F1E7E7E7C6C6C6A4A4A4757575434343
1414141111111E1E1E1515154141418E8E8EECECECE6E6E6DEDEDE808080
0F0F0F0000001D1D1D8F8F8F0303030000001C1C1C0000002E2E2E353535
2828280000001010104A4A4A727272EEEEEEEDEDEDE6E6E6D8D8D8ECECEC
E6E6E6E2E2E2ECECECE6E6E6E1E1E1E1E1E1DDDDDDE1E1E1D6D6D6E6E6E6
D8D8D8E7E7E7F0F0F0DDDDDDDFDFDFECECECE6E6E6E4E4E4F2F2F2CECECE
E2E2E2E8E8E8E6E6E6D4D4D4E8E8E8F5F5F5DBDBDBD3D3D3DDDDDDEAEAEA
D9D9D9E3E3E3DDDDDDDCDCDCDCDCDCF5F5F5F7F7F7F8F8F8F6F6F6
F9F9F9F7F7F7F7F7F7F2F2F2EDEDEDE7E7E7EEEEEEEBEBEBECECECE6E6E6
EAEAEAE9E9E9ECECECE5E5E5E6E6E6EBEBEBD9D9D9DFDFDFF3F3F3EBEBEB
E8E8E8E5E5E5E8E8E8D5D5D5DADADAF5F5F5EBEBEBD9D9D9E6E6E6E2E2E2
D5D5D5D3D3D3DFDFDFE4E4E4D5D5D5E1E1E1E1E1E1DFDFDFE5E5E5DFDFDF
CACACA3131311A1A1A1111113131311515150A0A0A3131313030301E1E1E
383838686868AFAFAFD4D4D4F6F6F6ECECECDADADAD3D3D3151515060606
0E0E0E1111113636361616162E2E2E262626D5D5D5EAEAEAE8E8E8656565
0707071111112525251A1A1A1818181C1C1C2E2E2E0303031C1C1C313131
2727270000000C0C0C242424585858EDEDEDF7F7F7E0E0E0DADADAECECEC
DADADADADADAE9E9E9F8F8F8DADADADBDBDBF0F0F0EBEBEBDFDFDFDFDFDF
DADADADADADADDDDDDE6E6E6E5E5E5E6E6E6ECECECE3E3E3E6E6E6DBDBDB
E2E2E2E6E6E6DDDDDDD8D8D8DFDFDFEEEEEED2D2D2BBBBBBF2F2F2DCDCDC
C2C2C2E1E1E1EDEDEDCECECEDBDBDBFBFBFBF9F9F9FEFEFEF7F7F7
F8F8F8FAFAFAF8F8F8EBEBEBE8E8E8EEEEEEEAEAEAEBEBEBE7E7E7DFDFDF
E2E2E2E7E7E7E1E1E1E6E6E6E8E8E8EAEAEAEAEAEAEEEEEEE2E2E2E2E2E2
E8E8E8EAEAEADDDDDDE7E7E7F1F1F1E3E3E3D8D8D8F4F4F4E1E1E1EFEFEF
EFEFEFEFEFEFD9D9D9E6E6E6F2F2F2E5E5E5F1F1F1E7E7E7DDDDDDE1E1E1
5757572A2A2A0A0A0A1E1E1E0F0F0F2525251313131A1A1A121212474747
4B4B4B747474E9E9E9F2F2F2D1D1D1DEDEDEE2E2E2D1D1D1E2E2E2939393
3131311C1C1C0E0E0E000000000000232323404040CCCCCCD9D9D9686868
0E0E0E1D1D1D2323231515151E1E1E0F0F0F1818182727270B0B0B0D0D0D
1D1D1D292929252525CFCFCFE5E5E5DEDEDEE5E5E5F5F5F5EEEEEEDCDCDC
E5E5E5F5F5F5E2E2E2E3E3E3F2F2F2F4F4F4DEDEDEEAEAEAECECECDFDFDF
DEDEDEE4E4E4DFDFDFDCDCDCE0E0E0DCDCDCE3E3E3DFDFDFDCDCDCE9E9E9
E7E7E7DEDEDEEBEBEBF2F2F2D8D8D8CFCFCFF2F2F2DDDDDDD6D6D6E3E3E3
EDEDEDD8D8D8C4C4C4ECECECDFDFDFF7F7F7F7F7F7F3F3F3F0F0F0
FBFBFBF8F8F8FBFBFBEBEBEBEDEDEDEAEAEAEBEBEBDEDEDEE9E9E9D8D8D8
D8D8D8DCDCDCE6E6E6E6E6E6E5E5E5E7E7E7E0E0E0E9E9E9E6E6E6E3E3E3
E1E1E1DFDFDFE0E0E0F0F0F0E8E8E8D3D3D3D4D4D4DCDCDCE5E5E5E8E8E8
F0F0F0F0F0F0D7D7D7E5E5E5E8E8E8E5E5E5F1F1F1F3F3F3CFCFCFD8D8D8
6161614444441111111919191515154545452020201C1C1C1C1C1C5A5A5A
C7C7C7DBDBDBDDDDDDE2E2E2E2E2E2E4E4E4DDDDDDE4E4E4E8E8E8E3E3E3
E4E4E4D3D3D3A0A0A0585858494949B3B3B38383834A4A4AAAAAAA313131
0D0D0D0808082121211111110808080000001F1F1F0E0E0E181818303030
2929291010101616162C2C2CF3F3F3D9D9D9E8E8E8E7E7E7EBEBEBE3E3E3
E1E1E1F0F0F0E4E4E4D5D5D5EEEEEEF4F4F4E4E4E4EBEBEBE8E8E8E0E0E0
D9D9D9F0F0F0F2F2F2DFDFDFE5E5E5D8D8D8D4D4D4D9D9D9E1E1E1DFDFDF
E1E1E1D8D8D8E7E7E7DFDFDFDADADAE3E3E3E3E3E3DCDCDCD8D8D8DEDEDE
E6E6E6D2D2D2D5D5D5E1E1E1DFDFDFF5F5F5F5F5F5EEEEEEEFEFEF
FAFAFAF8F8F8F6F6F6F9F9F9FAFAFAE9E9E9E4E4E4EAEAEAE9E9E9EEEEEE
ECECECE4E4E4E6E6E6E3E3E3E5E5E5E8E8E8E6E6E6E8E8E8E5E5E5E3E3E3
E1E1E1E1E1E1DFDFDFDBDBDBDDDDDDEBEBEBEEEEEED9D9D9E4E4E4D7D7D7
DDDDDDDBDBDBF0F0F0E8E8E8D5D5D5E7E7E7D2D2D2D4D4D4ECECECE8E8E8
4343430D0D0D2121210303035757576565653131312020201F1F1FA2A2A2
B7B7B7BDBDBDBEBEBED7D7D7E1E1E1E4E4E4DDDDDDEDEDEDDBDBDBDFDFDF
DEDEDEE0E0E0DFDFDFE3E3E3ECECECBCBCBC949494C5C5C5C3C3C3C1C1C1
B7B7B7A5A5A50909090909090D0D0D1616160F0F0F313131000000050505
161616323232181818272727585858EFEFEFE7E7E7E4E4E4DFDFDFE7E7E7
E2E2E2DFDFDFE1E1E1EEEEEEDADADADCDCDCE7E7E7DFDFDFE1E1E1F4F4F4
ECECECD4D4D4DADADAE2E2E2DFDFDFE2E2E2EEEEEEDDDDDDD7D7D7DEDEDE
D8D8D8DFDFDFDCDCDCE0E0E0D5D5D5CCCCCCD2D2D2DADADAE7E7E7A9A9A9
D2D2D2E4E4E4E2E2E2D0D0D0DFDFDFF5F5F5F3F3F3F1F1F1EFEFEF
F9F9F9F9F9F9F8F8F8F5F5F5F0F0F0EAEAEAE2E2E2F3F3F3E4E4E4F0F0F0
EAEAEAE8E8E8E5E5E5E3E3E3E6E6E6D4D4D4EAEAEAEBEBEBE4E4E4E1E1E1
DFDFDFDBDBDBE1E1E1E1E1E1EAEAEAE6E6E6E7E7E7E2E2E2E6E6E6E1E1E1
DDDDDDE2E2E2E2E2E2E7E7E7DDDDDDE1E1E1DADADAE4E4E4E9E9E9F3F3F3
5D5D5D1515151717170000005151511616162020200808080B0B0B868686
3939391919195757573E3E3EDCDCDCE4E4E4E2E2E2E4E4E4E4E4E4DFDFDF
E2E2E2DCDCDCDDDDDDDADADAD5D5D5DADADAC2C2C2D9D9D9D2D2D2CFCFCF
DBDBDBA6A6A60F0F0F2626263D3D3D1111111C1C1C0E0E0E0000001C1C1C
0000001A1A1A232323303030343434D7D7D7E5E5E5E6E6E6E6E6E6E2E2E2
E4E4E4DFDFDFE9E9E9DADADAD8D8D8E5E5E5E4E4E4E1E1E1E8E8E8F3F3F3
DDDDDDD3D3D3D6D6D6E1E1E1E4E4E4E3E3E3F2F2F2C6C6C6D0D0D0F2F2F2
DADADACDCDCDDBDBDBE4E4E4D6D6D6C9C9C9E3E3E3DADADADADADAD7D7D7
C8C8C8DCDCDCD1D1D1D1D1D1DFDFDFF6F6F6F3F3F3EDEDEDF1F1F1
F9F9F9F2F2F2F8F8F8EDEDEDE5E5E5EDEDEDE8E8E8E1E1E1E8E8E8DBDBDB
DFDFDFDEDEDEF1F1F1E4E4E4E5E5E5E9E9E9CFCFCFD2D2D2E1E1E1DFDFDF
E4E4E4E6E6E6E8E8E8DBDBDBE6E6E6E1E1E1E4E4E4E4E4E4E8E8E8DFDFDF
E6E6E6E6E6E6E1E1E1E8E8E8E2E2E2E3E3E3DCDCDCEEEEEED4D4D4D5D5D5
6262621616160707073535353B3B3B010101000000303030171717636363
5C5C5C414141C2C2C2797979BABABADFDFDFE4E4E4E6E6E6E3E3E3DBDBDB
DFDFDFDFDFDFE5E5E5DDDDDDDDDDDDE7E7E7E4E4E4DADADAD7D7D7D0D0D0
C6C6C68383838E8E8E5E5E5E0000000B0B0B0000000000001E1E1E282828
303030020202181818101010303030E1E1E1ECECECE4E4E4E7E7E7E3E3E3
E4E4E4E7E7E7E8E8E8E4E4E4E4E4E4E7E7E7E6E6E6E6E6E6E4E4E4DADADA
D2D2D2F0F0F0F3F3F3E5E5E5F6F6F6DCDCDCDDDDDDECECECEEEEEED8D8D8
DFDFDFE8E8E8DADADAC7C7C7E2E2E2D7D7D7CACACAD9D9D9DDDDDDD8D8D8
CDCDCDD9D9D9DADADAD3D3D3E1E1E1F3F3F3EFEFEFF3F3F3EDEDED
F4F4F4EFEFEFF3F3F3F1F1F1EAEAEAE8E8E8E6E6E6E6E6E6E7E7E7E4E4E4
D6D6D6E1E1E1E7E7E7E1E1E1E1E1E1E9E9E9C9C9C9DEDEDEF6F6F6E5E5E5
E6E6E6E8E8E8F7F7F7D7D7D7E6E6E6EBEBEBE7E7E7E3E3E3E9E9E9D4D4D4
E2E2E2E3E3E3E2E2E2E9E9E9E1E1E1E1E1E1DDDDDDE6E6E6E2E2E2DFDFDF
CFCFCF2323231515151717172121211111110808082828284D4D4D777777
1C1C1C9292922121212D2D2D4444447E7E7EE1E1E1F3F3F3DEDEDEDFDFDF
E3E3E3E7E7E7E0E0E0E4E4E4E8E8E8D5D5D5D4D4D4DBDBDBD3D3D3D3D3D3
C1C1C16363634B4B4B0505050F0F0F0101010D0D0D151515282828252525
3030300000000E0E0E1212120D0D0DFAFAFAEDEDEDE1E1E1E1E1E1E7E7E7
E4E4E4DBDBDBF1F1F1E8E8E8D9D9D9E6E6E6E4E4E4E4E4E4E6E6E6E6E6E6
E6E6E6DFDFDFE2E2E2E2E2E2E8E8E8E7E7E7D7D7D7E3E3E3F5F5F5DDDDDD
E7E7E7E9E9E9CDCDCDD3D3D3F4F4F4F1F1F1D3D3D3DADADAD6D6D6CBCBCB
C6C6C6EBEBEBEBEBEBC7C7C7E2E2E2F6F6F6F7F7F7F8F8F8F4F4F4
F9F9F9F3F3F3F8F8F8FBFBFBEAEAEAEAEAEAE6E6E6E9E9E9E6E6E6E5E5E5
DFDFDFE3E3E3DFDFDFDADADADDDDDDE9E9E9DFDFDFE1E1E1ECECECE6E6E6
E4E4E4EAEAEAEDEDEDD1D1D1E2E2E2E6E6E6E3E3E3E1E1E1F0F0F0DEDEDE
DBDBDBE3E3E3E8E8E8E5E5E5E4E4E4ECECECD6D6D6DBDBDBEAEAEAE1E1E1
D7D7D73333332828280B0B0B2626261111110303031515150E0E0E6B6B6B
151515828282080808272727B2B2B2E3E3E3E8E8E8EBEBEBDEDEDEDADADA
C6C6C6DFDFDFC8C8C8E1E1E1E5E5E5838383C6C6C6E1E1E1D6D6D6D8D8D8
B3B3B3CBCBCB3333331515150D0D0D0606060F0F0F0F0F0F4545451A1A1A
2525251212121818180B0B0B171717ECECECEAEAEAE9E9E9D4D4D4E6E6E6
D8D8D8D9D9D9F4F4F4F3F3F3DBDBDBD5D5D5E1E1E1DCDCDCF2F2F2EAEAEA
E1E1E1DFDFDFDCDCDCE5E5E5DDDDDDE7E7E7E8E8E8E3E3E3DDDDDDDCDCDC
DDDDDDEFEFEFD4D4D4DBDBDBECECECF1F1F1E1E1E1E8E8E8DFDFDFBEBEBE
CACACAF1F1F1EDEDEDCBCBCBECECECF5F5F5F5F5F5F6F6F6F3F3F3
F8F8F8FAFAFAF8F8F8EBEBEBEDEDEDEFEFEFE8E8E8E8E8E8EDEDEDDDDDDD
DCDCDCDADADAE6E6E6E5E5E5E9E9E9E2E2E2E7E7E7E9E9E9E6E6E6EAEAEA
EBEBEBE9E9E9E6E6E6E8E8E8F0F0F0DEDEDEE8E8E8E7E7E7E3E3E3F5F5F5
F6F6F6F3F3F3E1E1E1E7E7E7E7E7E7E7E7E7EEEEEEECECECD4D4D4E7E7E7
E1E1E16565650606062323231C1C1C0D0D0D1616161111110808080E0E0E
1010101A1A1A3232322E2E2EE5E5E5ECECECDFDFDFD3D3D3C0C0C0D3D3D3
CDCDCDCFCFCFE0E0E08888881B1B1BE7E7E7989898B8B8B8AEAEAE797979
4747476060601515150000000000001313130F0F0F0000001111111A1A1A
1818183939391212123F3F3F959595E2E2E2E5E5E5E7E7E7E9E9E9E9E9E9
E4E4E4F5F5F5DEDEDEDBDBDBECECECF0F0F0E6E6E6E8E8E8D6D6D6DADADA
DFDFDFE9E9E9E2E2E2E1E1E1EDEDEDDADADADEDEDEDFDFDFDCDCDCD8D8D8
E2E2E2DEDEDEDDDDDDEAEAEAD7D7D7D1D1D1E0E0E0D9D9D9DEDEDEEAEAEA
E4E4E4C2C2C2C3C3C3D8D8D8C2C2C2EFEFEFF5F5F5F3F3F3EFEFEF
F3F3F3F5F5F5FAFAFAEAEAEAF3F3F3EFEFEFE9E9E9E9E9E9F2F2F2CFCFCF
D6D6D6DDDDDDDEDEDEDCDCDCEBEBEBEBEBEBE0E0E0E6E6E6E6E6E6E8E8E8
E3E3E3E7E7E7E4E4E4E6E6E6E9E9E9E6E6E6E6E6E6E7E7E7E6E6E6ECECEC
F1F1F1E8E8E8DFDFDFEBEBEBE6E6E6E2E2E2F5F5F5F3F3F3DCDCDCDDDDDD
E5E5E55C5C5C0C0C0C1111110808080000000909092626261E1E1E151515
0B0B0B1E1E1E0C0C0C525252DCDCDCDEDEDEC4C4C42424245B5B5B2D2D2D
1D1D1D4343439898981616161A1A1AA0A0A0707070AEAEAEA8A8A8000000
0D0D0D1D1D1D1717171212120000001313130F0F0F0000002A2A2A2F2F2F
0505051616163232327E7E7ED6D6D6EAEAEAE9E9E9E5E5E5E3E3E3E6E6E6
E7E7E7EDEDEDE1E1E1E1E1E1E3E3E3ECECECE5E5E5F6F6F6D8D8D8D5D5D5
DDDDDDE8E8E8E9E9E9ECECECF3F3F3D2D2D2D0D0D0EEEEEEE7E7E7DFDFDF
E4E4E4E3E3E3D3D3D3D0D0D0DDDDDDDEDEDEDCDCDCD9D9D9D8D8D8D7D7D7
DBDBDBBEBEBEB6B6B6D0D0D0C1C1C1F5F5F5F1F1F1F5F5F5F1F1F1
FAFAFAF6F6F6F5F5F5F9F9F9EAEAEAE7E7E7E9E9E9EAEAEADBDBDBEEEEEE
EAEAEAE3E3E3E3E3E3E7E7E7E4E4E4CECECEE3E3E3E2E2E2E5E5E5E7E7E7
E5E5E5ECECECE2E2E2E2E2E2E4E4E4E6E6E6E2E2E2E2E2E2E8E8E8D8D8D8
E6E6E6E6E6E6E3E3E3D8D8D8E5E5E5E7E7E7D9D9D9DDDDDDE4E4E4DDDDDD
D3D3D33E3E3E3D3D3D0000000A0A0A1818181212121818183838384E4E4E
0000001616160707071D1D1DC6C6C6B3B3B3212121030303111111010101
2929291C1C1C2525252828283737370B0B0B1616165353531C1C1C4C4C4C
5555552727270000001616163939391111114C4C4C1818180606060B0B0B
080808313131575757B7B7B7E6E6E6D9D9D9E6E6E6E3E3E3E1E1E1E1E1E1
DADADAE3E3E3E9E9E9E5E5E5DDDDDDDFDFDFDCDCDCCECECEF2F2F2F6F6F6
E8E8E8D5D5D5E1E1E1D6D6D6D2D2D2EEEEEEEDEDEDC5C5C5DADADADADADA
DADADAD3D3D3DDDDDDDEDEDECCCCCCD9D9D9D8D8D8D8D8D8D5D5D5CACACA
D1D1D1D8D8D8D8D8D8CACACAE3E3E3F0F0F0F1F1F1F4F4F4F3F3F3
F8F8F8F5F5F5F5F5F5EAEAEAEAEAEAE6E6E6E7E7E7E8E8E8E2E2E2F0F0F0
ECECECE3E3E3E7E7E7E7E7E7E4E4E4D3D3D3EDEDEDE3E3E3E6E6E6ECECEC
E9E9E9DBDBDBE3E3E3E6E6E6E5E5E5E4E4E4E6E6E6EAEAEAD5D5D5E9E9E9
E2E2E2E4E4E4DFDFDFE3E3E3E6E6E6E1E1E1DEDEDED2D2D2E3E3E3DCDCDC
D5D5D5BFBFBF7979790000000B0B0B2323230F0F0F1313131111113E3E3E
000000121212292929000000838383696969131313151515232323171717
1111111111111A1A1A1F1F1F1818181818181C1C1C1C1C1C282828606060
0808081E1E1E0909091212120A0A0A000000282828252525000000000000
111111252525171717DDDDDDDFDFDFD6D6D6D9D9D9E8E8E8EFEFEFE8E8E8
E0E0E0E7E7E7E3E3E3DDDDDDE4E4E4DEDEDEE1E1E1DFDFDFE7E7E7F1F1F1
E7E7E7DFDFDFD4D4D4DFDFDFD0D0D0DADADAEFEFEFD2D2D2D8D8D8DADADA
D1D1D1CDCDCDF4F4F4EEEEEED7D7D7D8D8D8CBCBCBCECECEE1E1E1D3D3D3
DBDBDBCCCCCCCCCCCCC9C9C9D7D7D7F6F6F6F4F4F4F6F6F6F1F1F1
F5F5F5F5F5F5F9F9F9EAEAEAECECECEAEAEADEDEDEE5E5E5EFEFEFDEDEDE
E0E0E0EAEAEAE4E4E4DFDFDFF3F3F3EEEEEEE1E1E1DFDFDFE0E0E0D6D6D6
C7C7C7EFEFEFEDEDEDDDDDDDE2E2E2EEEEEEE4E4E4E1E1E1EAEAEAE2E2E2
E5E5E5E4E4E4DDDDDDE3E3E3E6E6E6E1E1E1E1E1E1DDDDDDD9D9D9EAEAEA
E4E4E44F4F4F0E0E0E2121211717170000001E1E1E818181020202262626
0404041111110707071111110E0E0E0000003F3F3F1818180A0A0A121212
3030300505051616160A0A0A252525181818111111090909474747181818
0000000000001111110E0E0E0E0E0E272727040404000000262626363636
0202021818182C2C2CD6D6D6D8D8D8EAEAEAE4E4E4DADADAE4E4E4E2E2E2
DEDEDEE0E0E0E8E8E8E2E2E2D4D4D4E2E2E2D4D4D4E2E2E2E0E0E0E4E4E4
DEDEDEDFDFDFDCDCDCDFDFDFECECECD2D2D2C0C0C0EDEDEDDEDEDEDADADA
F0F0F0DEDEDECCCCCCC3C3C3E7E7E7D9D9D9DADADAECECECC3C3C3CCCCCC
CCCCCCE3E3E3D5D5D5CECECEDADADAECECECEFEFEFF5F5F5EAEAEA
F8F8F8F5F5F5F6F6F6EDEDEDE6E6E6E7E7E7EAEAEAE3E3E3E7E7E7DFDFDF
DDDDDDE9E9E9E1E1E1DDDDDDE9E9E9EEEEEEDBDBDBE8E8E8E9E9E9E1E1E1
DCDCDCE8E8E8F4F4F4CFCFCFE6E6E6EAEAEAE2E2E2E3E3E3F2F2F2D6D6D6
E6E6E6E8E8E8E6E6E6E6E6E6E3E3E3EAEAEAE2E2E2D8D8D8E2E2E2E2E2E2
E1E1E16D6D6D212121202020111111000000101010B9B9B9252525212121
1818180B0B0B000000252525000000060606343434202020000000131313
2020200000000000001E1E1E1717171515152828281C1C1C101010161616
1717171515150E0E0E0F0F0F1212121515150000000E0E0E2626261A1A1A
0C0C0C232323C1C1C1DFDFDFBFBFBFEEEEEEEDEDEDE6E6E6E9E9E9E2E2E2
DADADAE6E6E6EFEFEFE3E3E3E1E1E1ECECECDDDDDDDFDFDFE2E2E2E6E6E6
DFDFDFDFDFDFD7D7D7E2E2E2DDDDDDE1E1E1DDDDDD979797E8E8E8D4D4D4
E8E8E8E6E6E6C0C0C0CDCDCDE5E5E5E2E2E2E4E4E4E9E9E9DFDFDFC9C9C9
C2C2C2EEEEEED1D1D1CECECEE1E1E1F7F7F7F5F5F5F5F5F5EEEEEE
F8F8F8F9F9F9EEEEEEEBEBEBEAEAEAE9E9E9E0E0E0EAEAEAE6E6E6E5E5E5
E7E7E7E6E6E6E7E7E7E8E8E8DCDCDCE7E7E7EFEFEFDFDFDFE6E6E6F1F1F1
F4F4F4D9D9D9D6D6D6EDEDEDD6D6D6DCDCDCE1E1E1E1E1E1DCDCDCF3F3F3
E8E8E8DDDDDDE1E1E1E4E4E4DEDEDEE2E2E2EFEFEFE5E5E5D7D7D7E4E4E4
DEDEDE9999992828280000001111111111116161611C1C1C313131000000
0000001111110D0D0D0000001717171616160000000E0E0E202020060606
0000001C1C1C3838380101010606062020200B0B0B1111112E2E2E010101
0909092323231313130606060B0B0B2C2C2C2020201A1A1A111111131313
1E1E1E272727272727E6E6E6DFDFDFDCDCDCE6E6E6F4F4F4E5E5E5F3F3F3
EEEEEEEDEDEDE0E0E0DDDDDDE8E8E8E7E7E7EDEDEDECECECD3D3D3DCDCDC
DBDBDBE1E1E1E1E1E1DCDCDCDFDFDFDEDEDEDDDDDDC3C3C3C6C6C6D6D6D6
D5D5D5CBCBCBE9E9E9F3F3F3C6C6C6D8D8D8CBCBCBBCBCBCEDEDEDE4E4E4
DFDFDFB2B2B2D0D0D0BABABAB4B4B4F6F6F6F3F3F3F5F5F5EFEFEF
F8F8F8F5F5F5F7F7F7EAEAEAF4F4F4EAEAEAE0E0E0F3F3F3EEEEEEE6E6E6
E2E2E2E6E6E6E6E6E6E4E4E4E8E8E8E4E4E4EBEBEBE6E6E6E4E4E4E2E2E2
E6E6E6E3E3E3E5E5E5E4E4E4DEDEDEEFEFEFE8E8E8D2D2D2D2D2D2F3F3F3
E7E7E7DDDDDDE2E2E2F3F3F3E6E6E6DFDFDFF2F2F2DADADADBDBDBE1E1E1
E7E7E7D0D0D01A1A1A0404040D0D0D0606066565652C2C2C1717170A0A0A
1313130808080808081515151717173737371C1C1C0B0B0B111111161616
0202028787871111110F0F0F111111252525000000171717131313000000
0303032323231515150000001313132222220F0F0F0000000F0F0F343434
1212121C1C1C303030D9D9D9EAEAEAF3F3F3ECECECECECECDBDBDBEAEAEA
E9E9E9E5E5E5E4E4E4E8E8E8EEEEEEE9E9E9EEEEEEEEEEEED8D8D8E4E4E4
E2E2E2E5E5E5DFDFDFF2F2F2F4F4F4DADADADADADADADADADEDEDEDEDEDE
DDDDDDDADADADEDEDEDCDCDCD8D8D8D5D5D5D6D6D6D6D6D6E3E3E3DFDFDF
D3D3D3C6C6C6D5D5D5C4C4C4A8A8A8F3F3F3F3F3F3F7F7F7EFEFEF
F5F5F5F5F5F5F4F4F4EFEFEFF0F0F0EAEAEAE9E9E9F1F1F1F6F6F6DADADA
E7E7E7F5F5F5E4E4E4D8D8D8EDEDEDF4F4F4E0E0E0E6E6E6EBEBEBE4E4E4
E0E0E0E6E6E6E7E7E7E2E2E2E9E9E9EBEBEBE6E6E6DEDEDEDDDDDDE8E8E8
DFDFDFD7D7D7DCDCDCF0F0F0E2E2E2DADADAEEEEEEE6E6E6E3E3E3EBEBEB
F2F2F2D6D6D68E8E8E3030301F1F1F0202021111111313130E0E0E1D1D1D
3030300B0B0B1717171A1A1A0000001616161D1D1D1111111212124A4A4A
7575752121211717170000000F0F0F0000001111110B0B0B2D2D2D000000
1818182020200F0F0F0101011111112F2F2F0000000000001F1F1F171717
0000002D2D2DEEEEEEA1A1A1E8E8E8E9E9E9EAEAEAE7E7E7E9E9E9DEDEDE
E4E4E4E8E8E8E1E1E1E2E2E2E7E7E7E9E9E9E6E6E6F4F4F4D7D7D7E3E3E3
E1E1E1E3E3E3CDCDCDEBEBEBF5F5F5C4C4C4E0E0E0E9E9E9DDDDDDE0E0E0
EDEDEDF4F4F4CECECEDCDCDCDADADAE0E0E0DFDFDFD7D7D7CFCFCFCACACA
DBDBDBD5D5D5D0D0D0CACACABEBEBEF3F3F3F7F7F7F8F8F8F1F1F1
F4F4F4F7F7F7F4F4F4EDEDEDE8E8E8E8E8E8EBEBEBDADADADCDCDCEEEEEE
E0E0E0D5D5D5EEEEEEF0F0F0DADADADFDFDFE8E8E8E1E1E1E6E6E6DFDFDF
EEEEEED7D7D7DFDFDFE5E5E5D4D4D4DFDFDFE6E6E6E1E1E1E5E5E5E6E6E6
E1E1E1DFDFDFE2E2E2DFDFDFEAEAEAE5E5E5DFDFDFE3E3E3DDDDDDE3E3E3
D2D2D2EBEBEBEEEEEE6565656868680000000808080F0F0F0A0A0A000000
0000000D0D0D1515150A0A0A1515153D3D3D1313130D0D0D4242426B6B6B
3D3D3D0F0F0F1111110000000D0D0D1A1A1A080808010101000000040404
1A1A1A0000000000002323230000000000002D2D2D202020000000111111
3131314242422B2B2BE5E5E5E6E6E6DCDCDCE2E2E2E3E3E3DFDFDFE4E4E4
E7E7E7DDDDDDDCDCDCDDDDDDD9D9D9EEEEEED7D7D7DDDDDDDDDDDDDDDDDD
DCDCDCD8D8D8DCDCDCC8C8C8D4D4D4E3E3E3DFDFDFCFCFCFDEDEDECECECE
CDCDCDD2D2D2EDEDEDDEDEDECCCCCCD1D1D1DADADAD0D0D0D0D0D0C8C8C8
D1D1D1D9D9D9CECECED2D2D2D6D6D6F0F0F0F5F5F5F3F3F3F1F1F1
F6F6F6F5F5F5F7F7F7EDEDEDECECECE6E6E6E6E6E6E4E4E4DBDBDBE3E3E3
E3E3E3DEDEDEEAEAEAE8E8E8DCDCDCDFDFDFE1E1E1D5D5D5E3E3E3E4E4E4
F1F1F1DEDEDEDEDEDEE1E1E1D9D9D9E8E8E8EEEEEEDDDDDDE0E0E0E9E9E9
DCDCDCDFDFDFDBDBDBE2E2E2E8E8E8DDDDDDDDDDDDDADADAD9D9D9DDDDDD
D8D8D8DFDFDFE6E6E62D2D2D393939000000010101090909343434000000
1212120E0E0E0101010000002C2C2C989898000000131313757575131313
0606061F1F1F1616160A0A0A0808081212120000000808082222221A1A1A
080808000000000000060606000000000000202020131313020202252525
292929202020E0E0E0EDEDEDE7E7E7E0E0E0E6E6E6E1E1E1DBDBDBE4E4E4
ECECECE4E4E4DADADAE1E1E1DEDEDEDCDCDCD5D5D5E4E4E4D8D8D8E2E2E2
E5E5E5D0D0D0DDDDDDD7D7D7D2D2D2E9E9E9EBEBEBD4D4D4D9D9D9C4C4C4
BEBEBECFCFCFE6E6E6D7D7D7BEBEBED3D3D3C5C5C5B5B5B5DADADADBDBDB
D0D0D0CCCCCCCDCDCDBCBCBCC4C4C4F0F0F0F5F5F5EFEFEFEFEFEF
F5F5F5F6F6F6F4F4F4EBEBEBEAEAEAE5E5E5E4E4E4DFDFDFE5E5E5E1E1E1
E4E4E4E1E1E1D7D7D7D7D7D7F6F6F6E1E1E1E5E5E5E5E5E5E4E4E4DFDFDF
D3D3D3F4F4F4E7E7E7EAEAEAE8E8E8DDDDDDDFDFDFE3E3E3F2F2F2E1E1E1
E5E5E5E8E8E8DCDCDCDADADADFDFDFDCDCDCDFDFDFD4D4D4E2E2E2E2E2E2
DCDCDCD5D5D5D6D6D6DADADA282828868686868686000000000000252525
0F0F0F0000004444443D3D3D0000000000002C2C2C151515636363515151
1F1F1F0606060101011A1A1A0000001111111D1D1D171717060606080808
0000000606060D0D0D060606212121171717000000151515787878303030
2E2E2EE6E6E6E5E5E5D7D7D7E6E6E6DFDFDFE3E3E3E3E3E3EEEEEED3D3D3
D8D8D8DFDFDFDFDFDFDFDFDFDDDDDDE6E6E6CECECEDEDEDEDDDDDDDEDEDE
DCDCDCDEDEDED9D9D9E7E7E7DEDEDED4D4D4DFDFDFDCDCDCD3D3D3DCDCDC
E7E7E7EAEAEACBCBCBE3E3E3D3D3D3D3D3D3ECECECE7E7E7CCCCCCC6C6C6
CBCBCBD4D4D4BDBDBDDCDCDCD7D7D7E4E4E4EEEEEEF3F3F3F1F1F1
F8F8F8F7F7F7F6F6F6E8E8E8E8E8E8EDEDEDE8E8E8E5E5E5E8E8E8E2E2E2
E0E0E0E5E5E5E1E1E1E3E3E3EBEBEBE5E5E5E8E8E8E6E6E6E6E6E6E0E0E0
E6E6E6EEEEEEF0F0F0E4E4E4F0F0F0DBDBDBD5D5D5E8E8E8F2F2F2E3E3E3
EEEEEEF4F4F4D7D7D7E2E2E2EEEEEEF1F1F1E4E4E4EAEAEADDDDDDDFDFDF
DCDCDCE1E1E1EBEBEBD6D6D68787879393934848480E0E0E1A1A1A131313
0000000A0A0A3737371C1C1C0000000101012222220000000404042A2A2A
1515150000000000000D0D0D0000001717170E0E0E0B0B0B000000010101
0505050000000D0D0D1212120000001818181C1C1C242424C5C5C5E6E6E6
E7E7E7E5E5E5EBEBEBD5D5D5E2E2E2DDDDDDDADADADEDEDEE5E5E5D4D4D4
D5D5D5E3E3E3E8E8E8D8D8D8E5E5E5F2F2F2D1D1D1DEDEDEE6E6E6E7E7E7
D3D3D3E2E2E2ECECECDFDFDFE1E1E1DCDCDCD9D9D9DADADADADADADDDDDD
DADADADCDCDCDCDCDCDBDBDBDADADAD3D3D3EEEEEEDCDCDCB8B8B8C4C4C4
D7D7D7D3D3D3BBBBBBEDEDEDDDDDDDEAEAEAEEEEEEF3F3F3F6F6F6
F8F8F8F8F8F8F5F5F5EDEDEDEBEBEBEAEAEAE3E3E3E8E8E8E6E6E6E4E4E4
E6E6E6E3E3E3E3E3E3E3E3E3E5E5E5E5E5E5E6E6E6E4E4E4E8E8E8E9E9E9
E8E8E8E0E0E0DCDCDCE3E3E3E0E0E0F2F2F2F0F0F0DADADAD3D3D3F2F2F2
E3E3E3E0E0E0ECECECEFEFEFDBDBDBD2D2D2E7E7E7E1E1E1DFDFDFE7E7E7
E3E3E3E2E2E2E1E1E1DFDFDFCECECE5757571919191515151F1F1F121212
1F1F1F6E6E6E1111110000002020203030301818182121210A0A0A000000
0000001D1D1D2121210101010D0D0D0B0B0B000000252525181818000000
0808080D0D0D0000000707070F0F0F2929290707070E0E0EE6E6E6E3E3E3
DEDEDEDEDEDEE3E3E3DCDCDCDADADAE1E1E1E8E8E8E6E6E6DBDBDBF5F5F5
E8E8E8E2E2E2E1E1E1ECECECDDDDDDD2D2D2F4F4F4ECECECD0D0D0DFDFDF
DFDFDFE1E1E1D8D8D8E3E3E3E1E1E1DDDDDDE1E1E1DCDCDCDADADAD1D1D1
CFCFCFDCDCDCDDDDDDDCDCDCCBCBCBE1E1E1B9B9B9CDCDCDEEEEEEDCDCDC
C1C1C1D0D0D0DEDEDEAEAEAEBCBCBCF3F3F3F5F5F5F6F6F6F6F6F6
F6F6F6F8F8F8F8F8F8F7F7F7F8F8F8DCDCDCE3E3E3F0F0F0ECECECE8E8E8
E2E2E2F2F2F2E6E6E6E3E3E3EBEBEBE6E6E6E5E5E5E4E4E4E6E6E6E7E7E7
E6E6E6E5E5E5E2E2E2E0E0E0E2E2E2EAEAEAECECECE6E6E6D9D9D9E6E6E6
E6E6E6DBDBDBEAEAEAE8E8E8D3D3D3D3D3D3E8E8E8E0E0E0E8E8E8EEEEEE
F3F3F3D6D6D6E0E0E0E2E2E2D9D9D98E8E8E686868515151414141686868
0A0A0A1212120B0B0B0000002A2A2A2A2A2A3D3D3D111111060606000000
0000001919191919191212122020200000000000002020202C2C2C000000
0808080808080000000000001B1B1B3333331A1A1A232323D9D9D9E6E6E6
E2E2E2DFDFDFE3E3E3DFDFDFE1E1E1E6E6E6E3E3E3E2E2E2DEDEDEE3E3E3
E7E7E7E2E2E2E2E2E2E6E6E6E2E2E2E0E0E0F1F1F1ECECECD3D3D3DCDCDC
F2F2F2DCDCDCD8D8D8EAEAEAE3E3E3D8D8D8DCDCDCDCDCDCCECECED5D5D5
E8E8E8DDDDDDD9D9D9D5D5D5D5D5D5D7D7D7D5D5D5D3D3D3E0E0E0E2E2E2
CCCCCCCECECED9D9D9BFBFBFBABABAF5F5F5F6F6F6F5F5F5F3F3F3
F8F8F8F9F9F9F6F6F6E8E8E8DFDFDFEEEEEEECECECD9D9D9E3E3E3E6E6E6
D5D5D5D4D4D4F3F3F3EAEAEAD6D6D6E1E1E1E6E6E6E1E1E1ECECECE5E5E5
E7E7E7E7E7E7E4E4E4E9E9E9ECECECE6E6E6E9E9E9F0F0F0F6F6F6E8E8E8
EBEBEBE9E9E9E0E0E0E3E3E3F5F5F5E9E9E9E6E6E6F2F2F2E3E3E3E2E2E2
DEDEDEF2F2F2F2F2F2E8E8E8E2E2E2D5D5D5ACACACDBDBDBD1D1D13E3E3E
1919191111111313131D1D1D1515150B0B0B0F0F0F2F2F2F0000002A2A2A
2020200000000000000000000000001919193232320000000000001D1D1D
0404040000004040402121210101010606063131318A8A8AD2D2D2E7E7E7
F0F0F0D7D7D7E3E3E3E2E2E2E1E1E1E2E2E2E1E1E1E3E3E3E4E4E4DBDBDB
DFDFDFE9E9E9E3E3E3DFDFDFEBEBEBF1F1F1D3D3D3E0E0E0EFEFEFE4E4E4
D5D5D5E3E3E3F6F6F6D4D4D4DDDDDDE3E3E3E1E1E1DCDCDCDFDFDFCDCDCD
CDCDCDDADADAD6D6D6D9D9D9D0D0D0DADADAD6D6D6CECECEB3B3B3C2C2C2
CBCBCBC8C8C8BFBFBFDFDFDFD8D8D8F3F3F3F5F5F5F5F5F5E4E4E4
F8F8F8F6F6F6F6F6F6EAEAEAE3E3E3EEEEEEEBEBEBE2E2E2DBDBDBE5E5E5
DCDCDCE1E1E1F3F3F3E5E5E5DADADAE6E6E6DFDFDFCECECEEAEAEAE6E6E6
E8E8E8DADADAE1E1E1D6D6D6E3E3E3E7E7E7DADADAE0E0E0E1E1E1E7E7E7
DFDFDFE6E6E6E5E5E5E4E4E4DEDEDEE9E9E9E6E6E6EDEDEDE1E1E1DCDCDC
D3D3D3EFEFEFECECECDFDFDFE8E8E8DCDCDCC8C8C8E6E6E6E1E1E1262626
5C5C5C3F3F3F0000000A0A0A181818111111111111111111111111070707
0F0F0F2525250D0D0D0D0D0D1313132525252323230B0B0B0000001A1A1A
0E0E0E1313132626263434340505050000005B5B5B747474EBEBEBE8E8E8
EFEFEFD5D5D5D3D3D3E3E3E3DCDCDCE2E2E2F3F3F3DFDFDFDADADAE6E6E6
DEDEDEDBDBDBE2E2E2DFDFDFE1E1E1E2E2E2DADADADCDCDCDFDFDFDDDDDD
D5D5D5DCDCDCEFEFEFD2D2D2DCDCDCE8E8E8DEDEDEDDDDDDE4E4E4BDBDBD
D4D4D4DADADAD3D3D3D0D0D0D7D7D7E1E1E1CECECECECECED2D2D2CECECE
CECECECBCBCBC4C4C4C6C6C6D1D1D1F3F3F3F1F1F1F3F3F3F3F3F3
F5F5F5F8F8F8F4F4F4ECECECEAEAEAD8D8D8E6E6E6E8E8E8E6E6E6E4E4E4
DEDEDEDFDFDFE6E6E6E6E6E6DEDEDEDFDFDFDFDFDFD5D5D5ECECECF1F1F1
DFDFDFD6D6D6E7E7E7E2E2E2DDDDDDEBEBEBE8E8E8DFDFDFD9D9D9E6E6E6
E4E4E4E7E7E7EEEEEEE8E8E8E8E8E8E2E2E2E1E1E1E1E1E1E4E4E4D6D6D6
DDDDDDDFDFDFDEDEDED7D7D7F2F2F2DADADAC9C9C9E7E7E7E7E7E7494949
3737371F1F1F0000000A0A0A2F2F2F1A1A1A171717171717000000050505
0606061F1F1F0606060D0D0D2828280606060D0D0D1D1D1D0D0D0D161616
2B2B2B1C1C1C1818181E1E1E0000004A4A4A696969C3C3C3E2E2E2F0F0F0
EBEBEBDDDDDDD6D6D6DFDFDFDDDDDDE5E5E5EFEFEFDBDBDBDBDBDBEEEEEE
E7E7E7E3E3E3E6E6E6E3E3E3DBDBDBDDDDDDE1E1E1DCDCDCDEDEDEDCDCDC
DFDFDFDFDFDFE0E0E0DADADAD9D9D9DFDFDFDADADAD8D8D8E3E3E3C0C0C0
CCCCCCD3D3D3DCDCDCD1D1D1DADADAE3E3E3C2C2C2BEBEBED8D8D8CECECE
BEBEBED8D8D8DBDBDBA3A3A3CFCFCFF3F3F3EFEFEFF6F6F6F1F1F1
F5F5F5F8F8F8F5F5F5EDEDEDE8E8E8E6E6E6DFDFDFE5E5E5E7E7E7E7E7E7
E9E9E9E7E7E7DFDFDFE1E1E1E9E9E9E6E6E6EFEFEFE4E4E4DDDDDDD5D5D5
D6D6D6EDEDEDDFDFDFF1F1F1F7F7F7D7D7D7D9D9D9E4E4E4E9E9E9E6E6E6
ECECECECECECE4E4E4E4E4E4E6E6E6DADADADFDFDFE0E0E0DFDFDFDEDEDE
E8E8E8E1E1E1DDDDDDDCDCDCD7D7D7E3E3E3EBEBEBD9D9D9D3D3D3A0A0A0
1B1B1B0303031111113131310000001111110000000B0B0B1B1B1B282828
1A1A1A0707070404040707070000002A2A2A3636360A0A0A1E1E1E1A1A1A
0A0A0A272727141414C5C5C5B4B4B4D9D9D9E4E4E4DFDFDFDEDEDED9D9D9
C7C7C7E6E6E6E5E5E5E2E2E2ECECECDFDFDFD5D5D5E3E3E3EEEEEEDCDCDC
DFDFDFE6E6E6E2E2E2D9D9D9E6E6E6EAEAEAE1E1E1DFDFDFE3E3E3D9D9D9
DEDEDEDADADAD7D7D7DDDDDDD5D5D5D4D4D4E0E0E0DADADAC9C9C9E0E0E0
E6E6E6CECECECCCCCCD9D9D9CACACAB3B3B3E2E2E2D3D3D3B5B5B5C9C9C9
CBCBCBBFBFBFB6B6B6D8D8D8CFCFCFF0F0F0EEEEEEF3F3F3EEEEEE
F5F5F5F6F6F6F6F6F6EAEAEAE3E3E3F2F2F2E9E9E9E7E7E7D8D8D8E6E6E6
E4E4E4E3E3E3E5E5E5E1E1E1E5E5E5E4E4E4DBDBDBE6E6E6E3E3E3DFDFDF
E3E3E3E9E9E9E1E1E1EBEBEBF1F1F1DFDFDFD0D0D0F7F7F7F0F0F0ECECEC
EFEFEFF1F1F1D8D8D8D7D7D7F7F7F7E6E6E6E7E7E7EDEDEDDFDFDFDEDEDE
D9D9D9E5E5E5E6E6E6E2E2E2E7E7E7DCDCDCDEDEDEDFDFDFE4E4E4D3D3D3
B4B4B41515156B6B6B7474741111112626260808080000001818181F1F1F
2222220000000404040000000000003E3E3E4F4F4F0000000000001F1F1F
020202070707838383C5C5C5E1E1E1E2E2E2DDDDDDD6D6D6DFDFDFE1E1E1
DDDDDDE5E5E5E9E9E9E1E1E1E4E4E4DFDFDFD2D2D2EAEAEAEFEFEFCECECE
E4E4E4ECECECE2E2E2C9C9C9F0F0F0F6F6F6CCCCCCDFDFDFECECECDFDFDF
D6D6D6E0E0E0EBEBEBD8D8D8EAEAEADADADADCDCDCD8D8D8D5D5D5DCDCDC
DADADAD9D9D9D5D5D5E6E6E6CBCBCBC4C4C4E2E2E2D1D1D1C3C3C3C8C8C8
E2E2E2B4B4B4A3A3A3D2D2D2C7C7C7F4F4F4EDEDEDF3F3F3EFEFEF
F8F8F8F9F9F9F5F5F5FAFAFAF4F4F4E3E3E3E6E6E6EDEDEDE3E3E3E7E7E7
E6E6E6E1E1E1E7E7E7DDDDDDE7E7E7E1E1E1DFDFDFE0E0E0E5E5E5E3E3E3
E6E6E6E6E6E6E6E6E6D6D6D6DBDBDBE9E9E9E7E7E7DBDBDBE5E5E5E6E6E6
DCDCDCD4D4D4E9E9E9E8E8E8DCDCDCE6E6E6E5E5E5DADADAF0F0F0EFEFEF
E6E6E6DCDCDCEBEBEBE0E0E0E0E0E0E8E8E8E3E3E3E5E5E5E1E1E1E7E7E7
DFDFDFDCDCDCD1D1D19797971515150D0D0D080808000000000000000000
0000003333332D2D2D3535351E1E1E0000003A3A3AA6A6A60808080B0B0B
2A2A2A505050B7B7B7D3D3D3E4E4E4E6E6E6E6E6E6DFDFDFE2E2E2DDDDDD
E5E5E5E1E1E1E1E1E1E1E1E1DDDDDDE1E1E1EFEFEFD7D7D7DFDFDFF0F0F0
DCDCDCDEDEDEE8E8E8ECECECCBCBCBD8D8D8F0F0F0DCDCDCE1E1E1EEEEEE
DFDFDFD2D2D2DADADAE4E4E4DFDFDFDEDEDEDCDCDCD4D4D4D8D8D8CECECE
D7D7D7D5D5D5D0D0D0D5D5D5D4D4D4E4E4E4C5C5C5CACACAD8D8D8C7C7C7
9A9A9ADBDBDBDBDBDBB5B5B5D3D3D3F4F4F4F5F5F5F4F4F4F4F4F4
F6F6F6F5F5F5F1F1F1FBFBFBF1F1F1E6E6E6EAEAEAEBEBEBE9E9E9F3F3F3
E8E8E8EBEBEBE2E2E2E5E5E5E8E8E8E1E1E1ECECECE6E6E6E3E3E3E7E7E7
E6E6E6E5E5E5E5E5E5E3E3E3E4E4E4E5E5E5E5E5E5D8D8D8E6E6E6E6E6E6
DEDEDEE7E7E7E8E8E8E9E9E9DDDDDDE4E4E4E0E0E0D8D8D8F2F2F2F3F3F3
F0F0F0D8D8D8E7E7E7DFDFDFE0E0E0E9E9E9E8E8E8E6E6E6E5E5E5DEDEDE
DFDFDFD4D4D4E2E2E2CECECE6E6E6E1717171B1B1B0D0D0D151515000000
6C6C6CC1C1C1D1D1D1C8C8C8949494010101626262DFDFDFA9A9A91F1F1F
2C2C2CB6B6B6BCBCBCDFDFDFE8E8E8E4E4E4EBEBEBE7E7E7E2E2E2D4D4D4
E2E2E2EDEDEDE8E8E8DCDCDCE4E4E4DFDFDFE6E6E6E2E2E2E1E1E1E4E4E4
E3E3E3DDDDDDE7E7E7EAEAEAE0E0E0D5D5D5F1F1F1DDDDDDDBDBDBEDEDED
F6F6F6D0D0D0DDDDDDE9E9E9C9C9C9DDDDDDEAEAEAD3D3D3C6C6C6D6D6D6
DADADAD0D0D0E2E2E2E0E0E0CECECED3D3D3CDCDCDCECECECACACAC7C7C7
B1B1B1CFCFCFDBDBDBB5B5B5D7D7D7F3F3F3F3F3F3F5F5F5F5F5F5
F8F8F8FAFAFAF5F5F5E8E8E8E7E7E7EDEDEDEBEBEBE8E8E8EAEAEAD5D5D5
D5D5D5E4E4E4E6E6E6E8E8E8E6E6E6ECECECDBDBDBDBDBDBE7E7E7E7E7E7
E6E6E6E5E5E5E4E4E4E6E6E6DFDFDFE1E1E1E1E1E1E3E3E3E6E6E6EBEBEB
EFEFEFE8E8E8D9D9D9DDDDDDF2F2F2E9E9E9E6E6E6F3F3F3D5D5D5DBDBDB
E1E1E1E6E6E6E2E2E2E8E8E8F6F6F6E0E0E0DEDEDEE9E9E9E3E3E3E8E8E8
ECECECE7E7E7D3D3D3DDDDDDEAEAEACECECE717171979797A5A5A5DDDDDD
DADADAD8D8D8E1E1E1D0D0D0CBCBCBE0E0E0B8B8B8D3D3D3CECECEC1C1C1
ADADADC9C9C9EEEEEEEDEDEDD1D1D1E1E1E1DCDCDCD6D6D6EFEFEFF4F4F4
F1F1F1D3D3D3E1E1E1D4D4D4DADADAE1E1E1E1E1E1E2E2E2D7D7D7DDDDDD
DFDFDFE3E3E3DADADACDCDCDE1E1E1F5F5F5E6E6E6EAEAEAE2E2E2D5D5D5
CDCDCDECECECF1F1F1DADADAEDEDEDD4D4D4D7D7D7E3E3E3E4E4E4D8D8D8
D0D0D0DFDFDFC3C3C3C2C2C2D3D3D3DCDCDCD0D0D0C8C8C8C3C3C3C6C6C6
C9C9C9BABABAA0A0A0BABABAC2C2C2F1F1F1F4F4F4F5F5F5F5F5F5
F8F8F8F6F6F6F8F8F8EDEDEDECECECEFEFEFEAEAEAE5E5E5EFEFEFE2E2E2
D8D8D8E5E5E5ECECECE5E5E5E6E6E6F2F2F2E2E2E2DCDCDCF1F1F1E6E6E6
E5E5E5E7E7E7F2F2F2CFCFCFCFCFCFDCDCDCE8E8E8E2E2E2DFDFDFE4E4E4
E3E3E3DFDFDFDCDCDCDFDFDFE7E7E7E1E1E1EEEEEEE3E3E3CDCDCDD6D6D6
E3E3E3E8E8E8DADADAE8E8E8F7F7F7DFDFDFE4E4E4F0F0F0E7E7E7E5E5E5
EEEEEEF0F0F0DFDFDFDADADAE2E2E2E2E2E2DEDEDEECECECCCCCCCD3D3D3
DFDFDFDADADADFDFDFDADADADCDCDCE3E3E3DADADAD0D0D0DCDCDCDADADA
DEDEDEDBDBDBE4E4E4ECECECDDDDDDDFDFDFD7D7D7D1D1D1EDEDEDF5F5F5
ECECECDCDCDCDDDDDDD2D2D2D4D4D4EFEFEFEEEEEECACACAD7D7D7E1E1E1
DCDCDCD3D3D3E3E3E3DFDFDFD8D8D8DFDFDFD6D6D6E1E1E1DDDDDDD9D9D9
C7C7C7E4E4E4E2E2E2D6D6D6E9E9E9DCDCDCCACACAE5E5E5ECECECC5C5C5
D7D7D7E7E7E7D2D2D2B9B9B9DDDDDDE2E2E2D2D2D2CECECEC1C1C1B3B3B3
B3B3B3CECECEC8C8C8B5B5B5D0D0D0F6F6F6EFEFEFF5F5F5F1F1F1
F7F7F7EFEFEFF9F9F9F0F0F0EDEDEDEBEBEBE9E9E9E6E6E6E9E9E9F2F2F2
ECECECE4E4E4E6E6E6E4E4E4EEEEEEDFDFDFF3F3F3F1F1F1D4D4D4E2E2E2
E5E5E5E6E6E6D7D7D7EEEEEEEBEBEBE1E1E1E1E1E1DFDFDFE7E7E7E7E7E7
EBEBEBEBEBEBDADADAE2E2E2E3E3E3DADADADFDFDFE1E1E1E3E3E3F0F0F0
E1E1E1DCDCDCE9E9E9D7D7D7DBDBDBECECECE2E2E2DCDCDCE3E3E3D7D7D7
CFCFCFDCDCDCE0E0E0E5E5E5E1E1E1DCDCDCD2D2D2CDCDCDE3E3E3DFDFDF
DDDDDDDADADAE0E0E0D8D8D8E2E2E2D8D8D8DDDDDDD8D8D8DDDDDDDFDFDF
DFDFDFE1E1E1DFDFDFD8D8D8E9E9E9E3E3E3DFDFDFF1F1F1DADADACECECE
DFDFDFE7E7E7DFDFDFE4E4E4EBEBEBD2D2D2C2C2C2F1F1F1E7E7E7DEDEDE
EAEAEAE5E5E5D3D3D3CACACAE5E5E5EAEAEADFDFDFE3E3E3DFDFDFD6D6D6
DADADAD9D9D9DDDDDDE2E2E2BBBBBBDBDBDBD2D2D2C9C9C9ADADADDFDFDF
D3D3D3B6B6B6DCDCDCE6E6E6A4A4A4AFAFAFD6D6D6B2B2B2CCCCCCD1D1D1
D1D1D19E9E9EABABABB6B6B6B9B9B9F4F4F4EFEFEFF5F5F5F4F4F4
F4F4F4F5F5F5F6F6F6EAEAEAEBEBEBEAEAEAE4E4E4E6E6E6E7E7E7E6E6E6
E4E4E4E4E4E4E3E3E3E6E6E6E8E8E8E4E4E4E9E9E9EFEFEFD6D6D6D3D3D3
EBEBEBE6E6E6D9D9D9F5F5F5EBEBEBDCDCDCE4E4E4E7E7E7E6E6E6EFEFEF
DEDEDEE0E0E0D9D9D9E6E6E6E6E6E6E5E5E5DDDDDDE5E5E5C9C9C9E3E3E3
DFDFDFE1E1E1E6E6E6D7D7D7DFDFDFE7E7E7E3E3E3D3D3D3E6E6E6DEDEDE
CFCFCFDFDFDFE3E3E3DCDCDCDADADAE9E9E9CECECED5D5D5EEEEEEE4E4E4
DCDCDCDADADAE6E6E6CDCDCDCACACAE4E4E4EFEFEFD7D7D7DCDCDCDCDCDC
CDCDCDD8D8D8E5E5E5DCDCDCD5D5D5D4D4D4DCDCDCDFDFDFDDDDDDDFDFDF
DDDDDDE2E2E2E4E4E4DCDCDCE5E5E5D9D9D9CACACAEBEBEBE4E4E4DDDDDD
E1E1E1F1F1F1C7C7C7D2D2D2F3F3F3E1E1E1DFDFDFE1E1E1D3D3D3CCCCCC
D2D2D2DADADADADADAD3D3D3D5D5D5D9D9D9D8D8D8B3B3B3B7B7B7D2D2D2
D3D3D3B2B2B2D4D4D4DCDCDCA6A6A6AEAEAEDCDCDCA6A6A6C8C8C8DADADA
DCDCDC919191A2A2A2BDBDBDA5A5A5F0F0F0F0F0F0F2F2F2F1F1F1
F6F6F6F7F7F7F8F8F8E2E2E2EDEDEDEEEEEEE9E9E9E8E8E8F3F3F3DADADA
DADADAE4E4E4ECECECE6E6E6ECECECEBEBEBE4E4E4E6E6E6E4E4E4E1E1E1
E3E3E3E4E4E4DBDBDBE7E7E7E1E1E1DADADAE8E8E8E3E3E3D8D8D8F8F8F8
E2E2E2E2E2E2E2E2E2E7E7E7E5E5E5E0E0E0F9F9F9ECECECD2D2D2DCDCDC
E1E1E1EBEBEBE2E2E2E3E3E3EDEDEDE7E7E7DFDFDFDFDFDFE2E2E2DCDCDC
D8D8D8DFDFDFE1E1E1D8D8D8DEDEDEE7E7E7CFCFCFDCDCDCDCDCDCDADADA
D9D9D9DEDEDEE5E5E5D8D8D8DFDFDFE8E8E8E7E7E7D1D1D1DCDCDCD6D6D6
D2D2D2D3D3D3E9E9E9DFDFDFDCDCDCE7E7E7CBCBCBCDCDCDDCDCDCE3E3E3
DDDDDDD5D5D5D8D8D8DCDCDCDADADACBCBCBD8D8D8DADADADDDDDDDADADA
DCDCDCE3E3E3C8C8C8D2D2D2E9E9E9E8E8E8E3E3E3E8E8E8D4D4D4C9C9C9
BDBDBDE7E7E7E0E0E0D0D0D0E3E3E3CECECED1D1D1DBDBDBDFDFDFCFCFCF
D0D0D0BFBFBFC6C6C6C8C8C8AFAFAFBFBFBFBCBCBCB9B9B9C3C3C3C7C7C7
C4C4C49F9F9F9F9F9FABABABA7A7A7F1F1F1EBEBEBF1F1F1F6F6F6
F5F5F5F7F7F7F6F6F6F2F2F2EAEAEAE8E8E8EEEEEEE8E8E8DCDCDCF6F6F6
E3E3E3DFDFDFE6E6E6E6E6E6E6E6E6E5E5E5E6E6E6E6E6E6E6E6E6DCDCDC
DFDFDFDFDFDFE1E1E1E1E1E1DFDFDFE2E2E2E6E6E6DFDFDFE6E6E6DBDBDB
E0E0E0E6E6E6DADADADFDFDFE2E2E2EEEEEED6D6D6D0D0D0E7E7E7EDEDED
E1E1E1E1E1E1E4E4E4D9D9D9DEDEDEE8E8E8E7E7E7E3E3E3E4E4E4DCDCDC
E4E4E4E5E5E5E2E2E2E6E6E6E5E5E5E1E1E1E4E4E4E4E4E4D0D0D0DFDFDF
E1E1E1E1E1E1D5D5D5EDEDEDE4E4E4D5D5D5E7E7E7E7E7E7E6E6E6F4F4F4
EEEEEEF0F0F0DCDCDCDDDDDDE7E7E7E1E1E1ECECECE2E2E2D8D8D8DFDFDF
E7E7E7E1E1E1DFDFDFDFDFDFE1E1E1DDDDDDDFDFDFDADADADCDCDCDDDDDD
D4D4D4D3D3D3EBEBEBE0E0E0BDBDBDD3D3D3DEDEDED0D0D0ECECECEDEDED
EDEDEDD5D5D5B7B7B7CFCFCFC7C7C7DADADAE1E1E1C9C9C9C7C7C7D2D2D2
C5C5C5B6B6B6D2D2D2C6C6C6C3C3C3C6C6C6C9C9C9CBCBCBC3C3C3A1A1A1
B1B1B1D4D4D4B4B4B4A5A5A5D3D3D3E2E2E2F4F4F4EFEFEFF5F5F5
F8F8F8F8F8F8F9F9F9EFEFEFEDEDEDE9E9E9ECECECE9E9E9E4E4E4F2F2F2
F0F0F0E5E5E5E6E6E6F1F1F1E9E9E9DFDFDFF2F2F2E6E6E6E8E8E8E2E2E2
ECECECD7D7D7DDDDDDE5E5E5E2E2E2D6D6D6E3E3E3E2E2E2D6D6D6ECECEC
E7E7E7DDDDDDDADADADBDBDBE3E3E3E8E8E8E1E1E1DDDDDDE4E4E4E3E3E3
DCDCDCE4E4E4EEEEEED3D3D3DFDFDFEFEFEFE5E5E5DBDBDBE8E8E8D5D5D5
D7D7D7E0E0E0DDDDDDE1E1E1E2E2E2E6E6E6E4E4E4E3E3E3E8E8E8DFDFDF
DFDFDFE5E5E5E4E4E4E8E8E8E1E1E1E3E3E3E2E2E2E3E3E3E6E6E6E6E6E6
EFEFEFECECECDFDFDFE2E2E2E2E2E2DEDEDEEEEEEEEFEFEFDEDEDED5D5D5
E7E7E7ECECECE4E4E4E3E3E3EDEDEDCECECEDBDBDBE1E1E1E2E2E2E1E1E1
DFDFDFE1E1E1E1E1E1DDDDDDD8D8D8DADADADDDDDDDEDEDEE3E3E3E7E7E7
E6E6E6C6C6C6C9C9C9C8C8C8CDCDCDE0E0E0EDEDEDC6C6C6BEBEBEE5E5E5
C4C4C4B6B6B6DBDBDBE0E0E0AEAEAEB9B9B9C3C3C3C1C1C1CFCFCFBCBCBC
BDBDBDB4B4B4BBBBBBABABABCCCCCCF0F0F0F5F5F5EFEFEFF5F5F5
F1F1F1F6F6F6F5F5F5E9E9E9EEEEEEEBEBEBE4E4E4EBEBEBF5F5F5DADADA
DCDCDCF0F0F0E6E6E6DFDFDFEBEBEBF4F4F4E3E3E3E3E3E3F1F1F1D9D9D9
D0D0D0E5E5E5DCDCDCE2E2E2E0E0E0E3E3E3E4E4E4E4E4E4DFDFDFE8E8E8
E6E6E6E1E1E1DDDDDDECECECEAEAEAE0E0E0EFEFEFE3E3E3DCDCDCE1E1E1
E8E8E8E6E6E6CECECEECECECE1E1E1D6D6D6E6E6E6E8E8E8E6E6E6F6F6F6
E8E8E8E6E6E6DCDCDCE4E4E4E4E4E4E3E3E3ECECECE7E7E7DFDFDFE5E5E5
E2E2E2E5E5E5E7E7E7DDDDDDE1E1E1DDDDDDE6E6E6E4E4E4E1E1E1D6D6D6
D9D9D9E6E6E6EEEEEEE3E3E3DFDFDFF0F0F0CECECEDEDEDEF4F4F4EDEDED
E1E1E1DFDFDFECECECC9C9C9DDDDDDE5E5E5E4E4E4D9D9D9DCDCDCE3E3E3
DFDFDFD7D7D7E6E6E6DADADADADADAE5E5E5E1E1E1EFEFEFC9C9C9D6D6D6
D2D2D2EBEBEBE1E1E1E9E9E9EAEAEACBCBCBCACACAE2E2E2E3E3E3D0D0D0
D7D7D7E0E0E0A7A7A7B1B1B1D3D3D3BBBBBBC1C1C1D5D5D5B3B3B3A2A2A2
A7A7A7A6A6A6AAAAAA9B9B9BC2C2C2F3F3F3F3F3F3F3F3F3F3F3F3
F8F8F8F6F6F6F3F3F3EDEDEDEAEAEAEBEBEBEEEEEEE4E4E4EBEBEBE2E2E2
E4E4E4E5E5E5E6E6E6E4E4E4F3F3F3F2F2F2E4E4E4E2E2E2EBEBEBE2E2E2
D6D6D6F2F2F2F7F7F7DEDEDEE8E8E8E7E7E7E5E5E5E3E3E3EBEBEBDBDBDB
DBDBDBEBEBEBE8E8E8E4E4E4EAEAEAE5E5E5E3E3E3E6E6E6DCDCDCE4E4E4
E8E8E8EAEAEAE8E8E8E8E8E8E6E6E6D5D5D5E9E9E9EDEDEDE3E3E3F2F2F2
F1F1F1E5E5E5D7D7D7EFEFEFE6E6E6D6D6D6EFEFEFEEEEEED4D4D4E3E3E3
E7E7E7D8D8D8DEDEDEECECECDFDFDFE1E1E1E4E4E4E2E2E2E5E5E5E8E8E8
DFDFDFDFDFDFE1E1E1E3E3E3E1E1E1E3E3E3E4E4E4D7D7D7E9E9E9E5E5E5
DDDDDDDBDBDBECECECCFCFCFD0D0D0E9E9E9EDEDEDD4D4D4DADADAD4D4D4
CCCCCCD6D6D6ECECECE9E9E9CECECEDFDFDFCECECECDCDCDE1E1E1DFDFDF
DDDDDDD9D9D9DADADAD7D7D7DCDCDCD5D5D5C3C3C3D0D0D0E6E6E6CDCDCD
DFDFDFE4E4E4A9A9A9A8A8A8DEDEDED1D1D1BCBCBCD7D7D7B7B7B7939393
999999D7D7D7B8B8B8AAAAAAE5E5E5F4F4F4EDEDEDEFEFEFF4F4F4
F5F5F5F3F3F3F7F7F7F1F1F1EDEDEDEAEAEAEAEAEAE7E7E7E4E4E4E7E7E7
DFDFDFE8E8E8ECECECEBEBEBE5E5E5D5D5D5F2F2F2EBEBEBEAEAEAEBEBEB
E7E7E7E6E6E6E6E6E6EAEAEAE9E9E9E6E6E6F3F3F3E6E6E6E7E7E7F7F7F7
E7E7E7E2E2E2E6E6E6ECECECE7E7E7E5E5E5E8E8E8EAEAEAE7E7E7E9E9E9
E7E7E7E4E4E4E6E6E6DEDEDEEBEBEBE8E8E8E4E4E4E7E7E7EEEEEEE2E2E2
E2E2E2E6E6E6E6E6E6E1E1E1ECECECF6F6F6D8D8D8E6E6E6E8E8E8E3E3E3
D8D8D8F0F0F0E9E9E9DFDFDFE8E8E8E7E7E7ECECECE4E4E4E7E7E7DCDCDC
E1E1E1E3E3E3E6E6E6E3E3E3E3E3E3DDDDDDE7E7E7E7E7E7E3E3E3E3E3E3
E8E8E8E3E3E3CFCFCFF3F3F3E3E3E3C8C8C8E3E3E3F1F1F1E1E1E1F3F3F3
EEEEEEEBEBEBD3D3D3DCDCDCE1E1E1E1E1E1DCDCDCE7E7E7DCDCDCD7D7D7
DCDCDCA2A2A2CECECED3D3D3D5D5D5D5D5D5D7D7D7BDBDBDC3C3C3CECECE
AEAEAEB2B2B2DBDBDBDCDCDC9A9A9AC0C0C0AAAAAA969696C5C5C5CACACA
C3C3C38B8B8BAAAAAA999999B5B5B5F4F4F4F3F3F3F8F8F8F3F3F3
F7F7F7F8F8F8FAFAFAF0F0F0F1F1F1F0F0F0E7E7E7EDEDEDFFFFFFD8D8D8
F0F0F0EDEDEDEEEEEEE4E4E4EBEBEBF9F9F9EDEDEDEBEBEBFBFBFBEEEEEE
EDEDEDF7F7F7FBFBFBECECECF6F6F6EDEDEDF0F0F0EAEAEAEAEAEAFEFEFE
EFEFEFE9E9E9E5E5E5EFEFEFF1F1F1DBDBDBFFFFFFF3F3F3DDDDDDF0F0F0
FDFDFDE8E8E8E2E2E2F4F4F4EDEDEDEEEEEEEFEFEFEDEDEDE8E8E8EDEDED
EDEDEDEFEFEFE8E8E8F1F1F1EBEBEBE7E7E7D4D4D4E4E4E4E7E7E7D9D9D9
DADADAEDEDEDF8F8F8D2D2D2EAEAEAECECECEAEAEAE5E5E5ECECECD7D7D7
DBDBDBE3E3E3E6E6E6E5E5E5E5E5E5E8E8E8E0E0E0E4E4E4E6E6E6E5E5E5
E3E3E3E6E6E6DCDCDCE8E8E8EBEBEBD5D5D5D6D6D6EEEEEEE6E6E6E6E6E6
F0F0F0F7F7F7CCCCCCD0D0D0F0F0F0DDDDDDEFEFEFF3F3F3D2D2D2C4C4C4
D0D0D0D7D7D7D9D9D9E2E2E2E0E0E0C7C7C7DBDBDBD3D3D3D0D0D0CCCCCC
CBCBCBC3C3C3D9D9D9C3C3C3B4B4B4B6B6B6B7B7B79B9B9BD7D7D7B2B2B2
CDCDCD8A8A8AABABABACACACADADADF4F4F4F4F4F4F4F4F4F4F4F4
F5F5F5F5F5F5F6F6F6F9F9F9F8F8F8F7F7F7F5F5F5F8F8F8F6F6F6F4F4F4
F7F7F7F5F5F5F6F6F6F5F5F5F9F9F9F6F6F6F7F7F7F5F5F5FDFDFDF6F6F6
F3F3F3F5F5F5F5F5F5F5F5F5F7F7F7F8F8F8F7F7F7F8F8F8FCFCFCF8F8F8
F8F8F8F6F6F6F5F5F5F8F8F8FAFAFAF9F9F9F9F9F9F7F7F7F5F5F5F8F8F8
F8F8F8F5F5F5F9F9F9F5F5F5F8F8F8F5F5F5F5F5F5F8F8F8F9F9F9F8F8F8
F5F5F5F7F7F7F4F4F4F8F8F8F5F5F5F5F5F5F5F5F5F6F6F6F3F3F3F3F3F3
F5F5F5F4F4F4F6F6F6F3F3F3F5F5F5F3F3F3F6F6F6F6F6F6F6F6F6F4F4F4
F6F6F6F5F5F5F8F8F8F3F3F3F3F3F3F5F5F5F4F4F4F5F5F5FBFBFBFBFBFB
F6F6F6F7F7F7F6F6F6F4F4F4F1F1F1F5F5F5F6F6F6FCFCFCF7F7F7F7F7F7
F9F9F9F5F5F5F4F4F4F7F7F7F4F4F4FCFCFCF6F6F6F6F6F6FCFCFCF3F3F3
F5F5F5F6F6F6F8F8F8F6F6F6F9F9F9F6F6F6F4F4F4F7F7F7F6F6F6F1F1F1
F5F5F5F3F3F3F1F1F1F3F3F3F0F0F0F3F3F3F5F5F5F1F1F1F3F3F3EDEDED
EDEDEDF5F5F5F6F6F6F1F1F1F1F1F1F4F4F4F4F4F4F8F8F8EFEFEF
F7F7F7F6F6F6F8F8F8F9F9F9F6F6F6F8F8F8F5F5F5F6F6F6F6F6F6F7F7F7
EEEEEEF6F6F6F8F8F8F4F4F4FAFAFAF4F4F4F7F7F7F7F7F7F9F9F9F8F8F8
F3F3F3F8F8F8F7F7F7F3F3F3F6F6F6F9F9F9F9F9F9F1F1F1F8F8F8FAFAFA
F7F7F7F5F5F5F1F1F1F7F7F7F8F8F8F8F8F8F8F8F8FAFAFAF6F6F6F8F8F8
F4F4F4F8F8F8F9F9F9F5F5F5F8F8F8F8F8F8F5F5F5FAFAFAF8F8F8F6F6F6
F8F8F8F5F5F5F5F5F5F9F9F9F7F7F7F6F6F6F5F5F5F5F5F5F4F4F4F5F5F5
F5F5F5F5F5F5F4F4F4F3F3F3F1F1F1F4F4F4F6F6F6F9F9F9F6F6F6F7F7F7
F7F7F7F5F5F5F5F5F5F5F5F5F7F7F7F7F7F7F6F6F6F6F6F6F9F9F9F6F6F6
F8F8F8F7F7F7F8F8F8F9F9F9F5F5F5F7F7F7F6F6F6FBFBFBFBFBFBF6F6F6
F8F8F8F8F8F8FAFAFAF5F5F5F1F1F1FEFEFEF5F5F5F7F7F7F9F9F9F7F7F7
F8F8F8F6F6F6F9F9F9F8F8F8F9F9F9F9F9F9F8F8F8F4F4F4F5F5F5F6F6F6
F6F6F6F5F5F5F7F7F7F5F5F5F3F3F3F5F5F5F1F1F1F3F3F3EDEDEDF1F1F1
F3F3F3F4F4F4F4F4F4F1F1F1F5F5F5F3F3F3F6F6F6F5F5F5F3F3F3
pop
grestore
%% End of Graphics
MathPictureEnd %% End of picture
\
\>"], "Graphics",
  ImageSize->{173, 171.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002]0000Za000`40O003h00O[Goo000017ooNmik
gWoo37_N00=oog_NNmh00W_N0Woo4G_N00Ag_G_NNmig_@]kgP03MkekgW_N00=kgP9oo`9kgP9oo`06
Nmig_GNmMkekgWNm17_N0gNm1G_N0Woo0W_N0Woo1G_N00Eg_G_NNmig_G_N009g_@AkgP04OomkgW_N
Nmh2Mkd3Nmh4Ool017NmNmikgWoo0gNm00=oog_NNmh00W_N00=oog_NNmh00W_N0WNm00EkgWNmMkeg
_G_N00=g_@03OomkgW_N00EkgP03OomkgW_N009kgP03MkekgW_N00Ag_@03Nmig_G_N009kgP5oo`00
0goo00EkgWooNmikgWoo00EkgP9cW0EkgPAoo`=kgP03MkekgW_N00=kgP9oo`AkgP03Mkeoog_N00Ek
gP05OomkgW_NNmig_@08Nmh00gooNmikgP04Nmh00gooNmikgP03Nmh7Mkd00g_NOomoo`02Nmh2Ool2
Nmh2Ool01G_NMkekgW_NLi`00g_N0WNm1W_N0Woo1g_N0goo00=kgWNmNmh01G_N00Ag_G_NOomoo`Yk
gP=g_@=kgP9oo`IkgP06OomkgW>LLiakgWNm0W_N00=oog_NNmh00g_N0Woo0G_N0Goo0003Ool01G_N
OomkgW_NOol01G_N0W>L1G_N17oo0g_N00=g_G_NNmh00g_N0Woo17_N00=g_GooNmh01G_N00Eoog_N
NmikgWNm00QkgP03OomkgW_N00AkgP03OomkgW_N00=kgPMg_@03Nmioogoo009kgP9oo`9kgP9oo`05
Nmig_G_NNmicW003Nmh2Mkd6Nmh2Ool7Nmh3Ool00g_NMkekgP05Nmh017NmNmioogoo2W_N0gNm0g_N
0Woo1W_N00Ioog_NLiacW7_NMkd2Nmh00gooNmikgP03Nmh2Ool1Nmh1Ool000=oo`05Nmioog_NNmio
o`0;Nmh00gooNmikgP0BNmh00gNmNmikgP05Nmh01GooNmikgW_NMkd00W_N00=g_GooNmh01G_N00=o
ogNmOol00Woo1G_N0WNm00EcW7NmNmikgWNm00=oo`EkgP03OomkgW_N00YkgP=g_@=kgP03OomkgW_N
009kgP04LiakgW_NMkd3Nmh00gooMkekgP02Nmh3Mkd2Nmh2Ool00g_NOomkgP03Nmh2Li`5Nmh00goo
Mkeg_@02Nmh2Mkd4Nmh00gooNmikgP02Nmh01GNmNmikgW_NMkd00W_N00Eg_G_NOomoog_N005oo`00
17_N0goo00=kgWooNmh02W_N00=oog_NNmh02G_N0goo17_N0Woo0g_N0goo00AkgWooOomoo`EkgPEo
o`=kgP=oo`05Nmioog_NNmioo`03Mkd4Nmh00g>LOomoo`02Ool00g_NOomoo`02Nmh4Ool3Nmh00goo
NmikgP04Nmh017NmNmikgW_N17oo17_N1Goo00EkgWooOomkgW>L009kgP06OomkgWooOomkgWoo0W_N
0Woo0W_N00Ioog_NOomoog_NMkd2Ool2Nmh3Ool017_NMkeg_GNm0g_N00=g_G_NNmh00W_N17oo0g_N
0Woo000017ooNmikgW_N0goo27_N00Eg_GooNmikgWoo00AkgPEoo`9kgP06Mkeoog_NNmioog_N0goo
1G_N0goo00AkgWooOomoo`EkgPQoo`9kgPEoo`03Nmioogoo009oo`=kgPMoo`03Nmioogoo00Eoo`06
NmioogooOomkgWoo0W_N00AoogNmNmikgPAoo`9kgPQoo`9kgP04Mkeoog_NNmh4Ool01W_NOomkgW_N
Oomg_@9oo`EkgP03OomkgW_N00Eoo`05NmioogooNmicW003Ool00g_NOomoo`02Nmh3Ool4Nmh1Ool0
0004OomkgW_NNmh3Ool8Nmh01GNmOomkgW_NOol017_N1Goo0W_N00Ig_GooNmikgWooNmh3Ool5Nmh3
Ool017_NOomoogoo1G_N27oo0W_N1Goo00=kgWooOol00Woo0g_N1goo00=kgWooOol01Goo00IkgWoo
Oomoog_NOol2Nmh017ooMkekgW_N17oo0W_N27oo0W_N00Ag_GooNmikgPAoo`06Nmioog_NNmioogNm
0Woo1G_N00=oog_NNmh01Goo00EkgWooOomkgW>L00=oo`03Nmioogoo009kgP=oo`AkgP5oo`0000=o
og_NNmh017oo2G_N00Eoog_NNmikgWNm00=kgPMoo`03Nmioogoo00Uoo`03Nmioogoo00Eoo`9kgP=o
o`=kgP9oo`AkgPAoo`=kgP03OomkgW_N009oo`=kgPAoo`03Nmioogoo009kgP9oo`AkgP03OomkgW_N
009kgP=oo`05NmioogooOomg_@05Ool2Nmh01WooNmioogooNmig_@9kgPAoo`03Nmioog_N00=kgPIo
o`05NmioogooOomkgP04Ool017_NOomoog_N1Goo0WNm00AkgWooOomoo`9kgPQoo`000g_N00Ioog_N
NmikgWooNmh3Ool4Nmh00gooNmikgP05Nmh00gooNmikgP02Nmh2Ool01G_NOomoogooNmh01Goo17_N
0Woo00AkgWooOomoo`AkgP03OomkgW_N009kgPAoo`AkgP05MkekgW_NNmioo`04Nmh2Ool4Nmh2Ool4
Nmh3Ool3Nmh4Ool2Nmh2Ool017_NOomoogoo0W_N0Woo17_N0Woo17_N0WNm0W_N0goo00EkgWooOomk
gWoo00IkgP06MkekgWooOomkgWoo0g_N00=oog_NNmh00W_N0goo1G_N0Woo0W_N0goo00=kgWooOol0
0Woo00001GooNmikgWooNmh00Woo37_N00Aoog_NOomoo`akgP05OomkgW_NNmig_@08Nmh3Ool8Nmh0
0gNmNmikgP05Nmh017NmNmig_GNm27_N00=g_GooNmh00g_N0W>L0W_N0WNm17_N0Woo0g_N00Aoog_N
NmikgP=oo`03Nmig_GNm00=g_@IkgP04OomkgW_NNmh2Mkd2Nmh4Ool2Nmh2Mkd00gooNmikgP02Nmh0
17NmNmikgWNm1g_N00IoogNmNmikgWooMkd4Nmh2Ool017NmNmikgW_N17oo0G_N0Goo00001GooNmik
gWooNmh00Woo37_N00Aoog_NOomoo`akgP05OomkgW_NNmig_@08Nmh3Ool8Nmh00gNmNmikgP05Nmh0
17NmNmig_GNm27_N00=g_GooNmh00g_N0W>L0W_N0WNm17_N0Woo0g_N00Aoog_NNmikgP=oo`03Nmig
_GNm00=g_@IkgP04OomkgW_NNmh2Mkd2Nmh4Ool2Nmh2Mkd00gooNmikgP02Nmh017NmNmikgWNm1g_N
00IoogNmNmikgWooMkd4Nmh2Ool017NmNmikgW_N17oo0G_N0Goo0005Ool2Nmh00gooNmikgP06Nmh3
Mkd<Nmh00gNmNmikgP02Nmh01GNmNmikgW_NOol00W_N00Ig_GooNmikgWooNmh6Ool01WNmOomoogoo
Nmig_@9oo`AkgP9g_@9oo`IkgP9oo`9kgP=oo`03Nmioogoo009oo`IkgP03OomkgW_N009kgP05Oomk
gW_NNmioo`02Nmh01WNmNmikgW_NMkekgP9g_@06Nmig_GNmMkekgWNm0W_N00Eoog_NNmikgWoo00=k
gP9g_@9cW09kgP9g_@03LiakgW_N009kgP03MkekgW_N009kgP9g_@IkgP9g_@03Nmig_GNm00=g_@=k
gP04MkeoogooNmh1Ool00003Nmioogoo00AkgPEg_@EcW09_N`06MkecW7>LLia_NgNm0fmk00DicPaS
36<000Q2008<H`04000HaPaS36<400001P@Q248<H`aS5:D000848@0636<8@P@Q124<Ha240PQ200H<
H`Q2000001BU00036<H01@aS12448@007>L00PaS00<U:ABU00000P0000D@Q0Q224800124008Li`06
00048@@Q124DY@aS0QcW00H@Q0aS2488@P@Q48@236<011S648AkgW_N17Nm00=_NdYBLi`00W>L0`Q2
00H@Q0Q2<H`aS7_NOol2248010@Q0000000011BU00<000Q200000`000P@Q00H8@PaS2488@P@Q5:D2
12401@Q2MkecW7>LIcT00fmk0V]J0WNm00A_NfLiLiacW0EkgP5oo`001Goo0W_N17Nm00=[FW>LLi`0
0W>L00Eg_G>LLiag_Fmk009cW09g_@=cW004DY@<H`aS124336<01P0048@<H`aS1240008<H`88@P<@
Q0<00088@P800005248HaPaS36<8@P0348@00`Q20008@P02248312401Q2436<8@PQ25:DLi`<000<@
Q004000HaPaS36<200025:D00`@Q48@HaP026<H300001QBU248<H`aSCW<48@=g_@05Liag_GNmG_M_
N`02JeX00fmk=JdDY@025:D01A24000007>LMkd00`0000D48@00000<Ha24008DY@D0000324848@@Q
0080008@Q0@8@P04>Li_Ne[FF]H2G_L3Kg/01F]JNmikgWNmKg/00W>L0W_N0Woo0GNm0Goo0005Ool2
Nmh4Mkd00f]JLiacW002Li`01GNmLiacW7NmKg/00W>L0WNm0g>L00ABU0aS36<48@<<H`06000@Q0aS
36<48@000PaS0PQ20a240`000PQ20P0000D8@QS636<<H`Q200<@Q003248000Q20088@P<48@0648@<
H`Q2248DYAcW0`000a2400@001S636<<H`80008DY@03124@Q1S6008HaP<000065:D8@PaS36=>L`@Q
0gNm00EcW7NmMkeNmfmk009[FP03Kg/e[ABU008DY@0548@00000Liag_@0300001@@Q000000aS48@0
0QBU1@0000<8@P@Q12400P000Q2410Q200@icVmkF]IJeP9Nm`=_N`05JeYkgW_NMke_N`02Li`2Nmh2
Ool1Mkd1Ool000Aoo`03Nmig_GNm00Ag_@05LiakgW>LLia_N`04Mkd017>LMkeg_GNm0g>L00Ag_F<H
12448@D8@P0536<8@PQ224848@0248@4248011BU000<H`aS0PQ20P0000<@Q1BU00000P0000DDY@00
0000012400@000@8@P8<H`050008@QBU5:D<H`0348@01PQ248@@Q1241248@P8DY@05248HaQS66<IB
U00312401PaS001cW7>LHaP000Ig_@06Liag_BDY9BU[FSF]0P@Q00H<HcW>48@@Q000Mkd2?Nl20002
24801P@Q2488@PQ200048@88@P040008@Q2448@2000224801P00248HaQS6JeY:DP8]J`04F]IBU6mk
Kg/4Li`2Kg/2JeX00g_NOomkgP02Nmh1Ool000Aoo`04Liag_GNmNmh3Mkd00gooLiacW002Li`01GNm
LiacW7>LNmh00Vmk17Nm00I_Ng_N2488@P00248236<4248010aS000000000PQ20P0000H<HaS636<<
H`0012425:D01PaS124@Q12424800088@P035:D001BU008DY@0536<48@@Q36<8@P02000011BU36<0
00000PaS0`Q200<48@Q224800PaS0`@Q00D000aS36=S66Li00@8@P9:DP04001g_E[FF]H2Li`2Kg/0
1V]JF]INmekgJeYF]@9W>@065:D000Q2248001S60U[F00<48@aS12400P@Q00@000Q224848@<00006
48@0000000048@000`Q200@@Q000001BU0=:DP03<Ha6<F]J009[FP03Kg][FV]J00A_N`03OomkgW_N
009kgP5oo`0017_N0gNm00=cW7NmMkd00WNm0g>L00I_NgNmLiacW7NmNmh2JeX00gNmLiacW002Li`0
1GNm5:DDY@Q236<00PQ20P000PaS00H000@Q48@@Q0Q236<248@01QS62488@PQ21248@P8@Q088@P8L
i`0448@000000002124248@01PaS24848@@Q36<48@8000035:DHaP@Q00848@0536<48@@Q0008@P02
36<2248236<01@Q236<aS36<Li`00acW00H000aS?Nlmk`00Nmh3Mkd3Li`01V]JHaQcW7>LMke_N`9S
60069BT0036<<H`e[@aS0V<H00H8@P@Q12448A24248312400`Q200000005000312401PQ248@00000
AS4icP8]J`03?NmNmf]J00=[FP9kgP04Kg]cW7NmMkd2Ool2Nmh2Ool000AkgP=g_@03Liag_GNm009g
_@=cW006Kg]g_G>LLiag_G_N0V]J00=g_G>LLi`00W>L00Eg_ABU5:D8@PaS0088@P80008<H`060004
8A2448@8@PaS0Q2400HHaPQ22488@P@Q248248@224827>L01124000000000P@Q0Q2400H<H`Q21244
8@aS124200000aBU6<H48@0212401@aS12448@0024800PaS0PQ20PaS00D8@PaS<H`aS7>L00<Li`06
000<Hcg_?Nl007_N0gNm0g>L00I[FV<HLiacW7NmKg/2HaP01RDY000aS36<=Jd<H`9S600624848@@Q
124@Q0Q20`@Q00<8@P0000001@000`@Q00H8@Q24000004Ha>Lh2;F/00cg_G_M[FP03JeX2Nmh016mk
Liag_GNm0Woo0W_N0Woo000017_NOomoog_N2GNm0W>L00=_NgNmLi`00W>L00=[FW_NNmh017>L00Ig
_F]J12448@Q2124200001QBU24848@@Q6<HDY@88@P0348@DY@aS008<H`0524848@@Q1248@P021240
0`aS5:D0000200001@Q2000000@Q48@010000QBU00@8@PaS36<<H`80008HaP065:D000Q2248DY@@Q
0`Q20`aS0P@Q0Re[00HaS6]JLiacW124124224801C6<:DYcW7>LMkd00fLi0WNm0R4800HYBW_NF]IJ
eTic:DX2G_L01SF]001[FV]J1240008DY@8000<48@<000031240000000L0008Li`066<H001S66<Hm
kcW>17>L0fmk0f]J00=oog_NNmh00W_N0Goo000017_NOomoog>L0gNm0W>L0W_N00Eg_G>LLiacW7Nm
00=cW003Kg]cW7>L00IcW003HaPDYABU00H48@80000448@48@00000236<3000011BU36<<H`000`@Q
00D000Q22488@P@Q00<00006248@Q0aS36<000@Q0`0000<48A2448@00P000`aS00@000Q2248<H`<0
000536<48@00000<H`0300001TicE[E[FV]J5:De[@8<H`06F]I:DW>LLiag_E[F0Vmk00IBU7>LAS56
<ABU<H`26<H01VLi9BUcW7>LCW<0009[FP040008@PaS36<:000312400`Q20000000200028@P00aS6
9BT]J`02;F/0148@Kg]_Ng>L0fmk0V]J0VLi1G_N0Goo0003Nmh00gooMkeg_@07Mkd3Li`016LiLiac
W7Nm17>L00=g_FmkKg/00Vmk0VLi00D000@Q2488@P0000<@Q0040008@PQ2248200026<H012480000
00000PQ20P0000D@Q1BU000000@Q00<000848@8<H`061248@P00000<H`Q20P0000HDYAS6000000aS
48@300001@aS2488@P0036<00PQ200H001BU12448@005:D236<01P0036<HaQS6Mke[FP9cW006HaQg
_G>LLiaS66Li0Q2400I241BU5:DDYF]JE[D2IcT017>L249:DTYB10000PQ20P@Q00<000@Q00000`00
0PaS100000H48@009BTU:@Q2>Lh2<H`01TicDYAS66<HF]IW>@9kgP06JeYg_GNmMkeoogNm0g_N0Goo
0003Nmh00gooMkeg_@07Mkd3Li`016LiLiacW7Nm17>L00=g_FmkKg/00Vmk0VLi00D000@Q2488@P00
00<@Q0040008@PQ2248200026<H01248000000000PQ20P0000D@Q1BU000000@Q00<000848@8<H`06
1248@P00000<H`Q20P0000HDYAS6000000aS48@300001@aS2488@P0036<00PQ200H001BU12448@00
5:D236<01P0036<HaQS6Mke[FP9cW006HaQg_G>LLiaS66Li0Q2400I241BU5:DDYF]JE[D2IcT017>L
249:DTYB10000PQ20P@Q00<000@Q00000`000PaS100000H48@009BTU:@Q2>Lh2<H`01TicDYAS66<H
F]IW>@9kgP06JeYg_GNmMkeoogNm0g_N0Goo0003Nmh00gooMkeg_@03Mkd2Kg/01G>LNmicW7>LKg/0
0g>L0V]J0fmk0g>L00I_Nf]JF]IJePQ2000212401@0036<@Q12400000`Q200H000Q248@@Q0aS2482
00001P@Q00000000248<H`800006248<H`000008@P@Q0`000`Q200H000Q22488@P0048@300001A24
12448@0024800P@Q00H8@P@Q2488@P005:D312401@002488@Q2412400QcW00Ig_G>LLiacW48@Kg/2
G_L01VmkJeXQ2248;F/aS08e[@06HaQ_NfmkKg/e[@aS0U:D100000@48A242488@PD000051248@PQ2
0008@P0212420002=Jd00acW;F/icP02>Lh01Be[IcUW>FmkLi`00Vmk00AcW6mkMkeg_@9kgP9g_@5k
gP5oo`001G_N0gNm00AcW7NmMkekgP=cW006MkecW6mkKg]kgWNm17>L0Vmk00E[FUkgE[EF]AS600<0
00848@80000636<48@@Q124DY@aS0`0000@8@P000008@P<DY@8000848@0624848A2448@48@000PaS
10@Q00H8@PaS12448A246<H248@01P00124@Q12436<48@80000512400000000@Q00300001Sg_2484
8@@Q48@DY@8Q209g_@9cW006@Q1cW7NmMke[FVmk0`@Q00@Q236<<HaBU0=_N`05F]H48DYBBU800004
12432482000236<01P0012400000248000848@066<H<H`00000@Q36<0RDY00HicTicIcUW>F]JKg/6
JeX2Nmh2Ool1Nmh1Ool00005NmioogooNmig_@02Nmh2Li`3Mkd3Li`017NmLiacW7>L0W_N0W>L00Ig
_G>LJeY[FV<HLi`2JeX01Be[2480000012400`Q21@@Q00D@Q0Q22488@PaS00800004248DYABU5:D2
000236<2000236<010@Q000@Q1240P000P@Q00@@Q0000000008<H`800006124<H`0000048@Q20PaS
00H48@Q248@@Q0Q2000224801P0024848@@Q5:ENm`8aS006Kg]kgRe[;F]Nmf]J0WNm00I[FU[FIcUW
>AcW5:D2=Jd01S6<AS5_NfmkG_LU:@8e[@061240000000048@000P@Q00D8@P0012448@aS00<00004
36<0012448@25:D200001QS6=JdicSW>E[E[FP9W>@9_N`9cW0A_N`03OomkgW_N009kgP5oo`0000Ek
gWooOomkgWNm009kgP9cW0=g_@=cW004MkecW7>LLi`2Nmh2Li`01WNmLia[FV]JHaQcW09[FP05;F/8
@P0000048@03248512401A242488@PQ236<00P0000@8@QBU5:DDY@80008<H`80008<H`0412400124
48@2000212401124000000000PaS0P0000H48@aS000000@Q248236<01P@Q248@Q12424800088@P06
0008@P@Q124DYEkg0S6<00I_Ng_N;F/]JekgJeX2Mkd01V]JF]IW>FLi7>LDY@8e[@06<Ha6<FmkKg]N
mbDY0SF]00H48@00000000@Q000212401@Q200048@@Q36<00`0000@<H`0048@@Q08DY@8000066<He
[CW>>LiF]F]J0VLi0Vmk0W>L16mk00=oog_NNmh00W_N0Goo0004Nmh017NmLiacW7Nm0g>L00Ag_G>L
LiacW09g_@9_N`9g_@9cW006MkecW6<HHaQW>F]J0Tic00DaS1BU000000@Q00<<H`0600048@aS36<8
@P@Q0QcW00<<H`0012400P@Q00D8@P000008@P0000<8@P0348@DYABU00800088@P8000848@062480
0000000<H`@Q0P000PaS0`0000<<H`0000000PQ20P0000@48@Q212448@8@Q088@P066<I_NfmkKg]c
W7_N0RDY00IcW7NmMkeg_FmkJeX2Li`01Q24JeY6<DHa000HaP9_N`055:Dmkbe[;F/48@0300001124
248000001P@Q0`0000D48@aS36<<Hc6<008@Q0046<HicSg_?Nl2Kg/2HaP01F]JLiag_GNmKg/00gNm
1G_N0Goo0004Nmh00gNmNmikgP04Mkd2Li`4Mkd2Kg/01G>LKg]cW7>LKg/00gNm00E_NcW>G_MNmf]J
00@@Q0051240000024848@0200001PaS5:D48@@Q000@Q0<48@<@Q00400048@0000022482000248@2
2482124300001AS648@@Q000124010000QS600HDY@@Q2488@P@Q000224801PaS24848@@Q36<mk`88
@P039BU_Ng>L009cW0046<Ig_GNmMkd3Li`01WNmKg]:DTYBKg]cW09_N`065:Dmkf]JJeXLigNm0PaS
00<000aS12400P@Q00<000Q224801@@Q00D000@Q124000@Q0088@P06000DYCW>>LhYBT8@0V]J00=:
DV<HLi`00g>L0V]J00AcW6LiHaQS609kgP9oo`5kgP5oo`0017oo00Eg_G_NNmig_G>L00Ag_@9cW09g
_@9cW003MkecW7>L00=cW09_N`06JeYF]EkgG_MW>C6<0PQ200H<H`00000000Q2124200000`aS48@0
000500001PQ248@<H`aS24848@88@P0436<48@000002248236<01P@Q36<48@@Q000HaP8@Q003000H
aP0000<0008HaP067>L48ABU5:D8@P000QBU00H@Q00012448A24=Jd200000c6<LiacW002Li`010aS
IcUW>G>L0fmk0W>L0R4800E[FVmkKg]_Nf]J00<mk`035:EcW0000080000548@8@PQ200048@020000
1P@Q000000001248@P8000@48@06;F/icS6<<H`]JdYB0Ukg00=W>EJeLi`00W>L0fmk00Ag_F]JJeY[
FP9g_@=kgP5oo`0017oo00Eg_G_NNmig_G>L00Ag_@9cW09g_@9cW003MkecW7>L00=cW09_N`06JeYF
]EkgG_MW>C6<0PQ200H<H`00000000Q2124200000`aS48@0000500001PQ248@<H`aS24848@88@P04
36<48@000002248236<01P@Q36<48@@Q000HaP8@Q003000HaP0000<0008HaP067>L48ABU5:D8@P00
0QBU00H@Q00012448A24=Jd200000c6<LiacW002Li`010aSIcUW>G>L0fmk0W>L0R4800E[FVmkKg]_
Nf]J00<mk`035:EcW0000080000548@8@PQ200048@0200001P@Q000000001248@P8000@48@06;F/i
cS6<<H`]JdYB0Ukg00=W>EJeLi`00W>L0fmk00Ag_F]JJeY[FP9g_@=kgP5oo`0000Eoog_NNmikgWNm
009cW003Nmig_G>L00=cW09_N`04LiakgW>LLi`4Mkd01VmkLia[FV]JIcUcW09[FP04IcU[FPaS36<4
248010@Q248@Q1240P000QS600D@Q0aS48@@Q0Q200<0000536<DY@Q2248DY@030002248248@22482
12401PaS2480000048@000848@03248@Q000008000051240000036<HaP0300001AS62488@RU:48@0
0RDY00IJeV<HLiacW5kg6<H6Li`01Vmk6<He[CF]JeYcW09_N`9F]@8U:@06HaQ_N`00000<H`Q20P00
00<@Q0Q236<00PaS00@@Q000000000<<H`05248<HbDY9BU24003<H`01SW>DYAW>FLiLia_N`9W>@9_
N`9cW006Kg]g_GNmMkekgWNm0Woo0G_N0Goo0004Nmh3Mkd2Nmh2Li`2Mkd2Li`00fmkMkeg_@02Mkd4
Li`3Mkd00f]JKg][FP02JeX00fmk2488@P0512400a2436<<H`0200026<H236<27>L400001ABU48@4
8@@Q5:D00`0000D8@Q24000000Q200<<H`060008@PaS36<48@Q20PaS00@Li`@Q000000848@800003
124<H`000080000548@HaQS6;F/48@02?Nl01W>LKg]g_GNm48AcW0=g_@=_N`06HaPHaW>LLia[FW>L
0Vmk00I245JeF]IJeW>LKg/600001Q2400048@@Q248@Q0<000<8@P06124HaQS66<HaS2DY0TYB00=6
<F<HKg/01fmk0W>L00A_Ng>LLiacW09kgP=g_@5oo`0017_N0goo00Ag_FmkNmikgPEg_@=cW0Eg_@05
Lia[FV]JKg][FP02HaP2Kg/2AS400`aS12448@0212401@Q2000001cW24800P@Q00H000@Q000000aS
6<H248@500001@aS48@@Q00012400QBU0P000PQ200H@Q00012448@Q2000224821242248010aS000@
Q1240P000QS600H@Q000G_MNmd8@E[D26<H01WNmNmh48@@QMkekgP9cW006Kg]g_F<HHaQW>GNm0Vmk
00IW>F]JLiacW4YB@Q02F]H2Li`200001P@Q248<H`aS24848@8@Q006124001BU5:D<HaBU0PaS00He
[DHaBU9:DTHa<H`2E[D2JeX2IcT4Kg/01W>LKg]_NfmkLia_N`9[FPAkgP5g_@5oo`0017_N0goo00Ag
_FmkNmikgPEg_@=cW0Eg_@05Lia[FV]JKg][FP02HaP2Kg/2AS400`aS12448@0212401@Q2000001cW
24800P@Q00H000@Q000000aS6<H248@500001@aS48@@Q00012400QBU0P000PQ200H@Q00012448@Q2
000224821242248010aS000@Q1240P000QS600H@Q000G_MNmd8@E[D26<H01WNmNmh48@@QMkekgP9c
W006Kg]g_F<HHaQW>GNm0Vmk00IW>F]JLiacW4YB@Q02F]H2Li`200001P@Q248<H`aS24848@8@Q006
124001BU5:D<HaBU0PaS00He[DHaBU9:DTHa<H`2E[D2JeX2IcT4Kg/01W>LKg]_NfmkLia_N`9[FPAk
gP5g_@5oo`0000Aoog_NNmioo`=g_@9cW09kgPEg_@04Kg]cW7>LOol4Mkd00g>LKg]_N`04Kg/01W>L
MkeS66<H=Jd<H`800005248@Q0Q22480000324800`@Q0008@P0224800`aS2488@P0500000`Q26<HH
aP020002248200028@P01RU:00000000124000<<H`D8@P8@Q0@<H`065:D48EkgG_L@Q6]J0QcW00Ag
_FLiIcUW>@9g_@=cW005MkekgW_NKg][FP02Li`01V]JMkecW7>L>LiNm`9_N`9cW0848@8000<48@05
248DYABU00048@027>L01PQ212448@@Q@Q0Q20924006>LiF]F<HHaQg_Fmk0V]J00AkgW>LKg]_N`9c
W09_N`04JeYcW7>LLi`5Nmh1Ool00004OomkgW_NOol3Mkd00g>LMkecW005Li`016mkMkeg_GNm17>L
00I[FW_NNmikgW>LJeX2Kg/01VLiJeYg_GNmG_L0008<H`04124000@Q1242248236<01@Q236<@Q124
36<00`@Q00DHaPaS5:DDYA2400<0000636<Q20000008@QcW0`0000DQ21cW7>L8@QS6008000062480
012448@<HbU:0Q2400<<H`Q236<00PaS00E[FRe[;F]Nmf]J009BU003CW<48G>L009cW005MkekgW_N
Nmi_N`02IcT01VmkJeXaS36<AS4DY@9Nm`06IcU[FV]JJeY_Nf<H0PaS00@000@Q2488@P848@88@P03
124HaP00008000055:DLiacW=Je240028@P01T8@HaQ[FV]JIcU[FP9kgP04IcU[FWNmMkd2Kg/2Li`0
17NmHaQ_Nfmk0W_N17oo000017ooNmikgW_N27Nm17>L00=g_G>LLi`017>L00=_Ng_NMkd00WNm00E[
FVmkKg]W>F]J009g_@05Nmh8@P0000048@0300001P@Q:DX8@PQ25:D48@80000548@<HaBU5:D48@03
2482000236<424801QBU12400000124DY@8HaP03248Li`0000<0008<H`8aS0924080008HaP06<Ha[
FQS66<Ig_G>L0VLi00<mkdicLi`00W>L17Nm0fmk00IcW6mk?Nlmkc6<5:D2AS44Li`00gNm>Lh00002
000010aS12448@000`aS00H000aS2488@PaS8@P26<H01BU:BU8mkcg_F]H016mk00=[FWNmMkd00V]J
0g>L00E[FWNmMkekgVLi009_N`EkgP5oo`0000Aoog_NNmikgPQg_@AcW003MkecW7>L00AcW003Kg]k
gWNm009g_@05JeY_NfmkIcU[FP02Mkd01G_N2480000012400`0000H48BU:2488@QBU124200001A24
36<DYABU12400`Q20P000PaS10Q200HDY@@Q000000@Q5:D26<H00`Q27>L00003000236<2<H`2@Q02
00026<H01S6<JeXHaQS6MkecW09W>@03?Nm>Lg>L009cW0Ag_@=_N`06Lia_Ncg_?NlaS1BU0THa17>L
00=g_CW>00000P0000@<H`@Q124000<<H`06000<H`Q2248<Hb480QS600DYBTYB?Nlmke[F00A_N`03
JeYg_GNm009[FP=cW005JeYg_GNmNmiW>@02Kg/5Nmh1Ool00005NmioogooMkeoo`02Nmh01G>LKg]g
_GNmLi`017Nm00=_Ng>LLi`00W>L0Vmk00EcW7NmMkeg_G>L00A_N`05JeYg_GNmKg/YBP0236<01P@Q
0000000048@<H`H000@@Q0060008@PQ2248<H`Q20Q2400H000Q200000124000224801P@Q36<8@PQ2
000DY@@0008<H`066<IF]CF]=JdaS0aS0QcW00A[FSg_@Q12409cW09_N`03;F]g_G>L00=cW09_N`03
JeYcW7>L009cW005JeXicSW>36=:DP02HaP01WNmLia_NfmkLi`<H`<000055:D<H`aS000<H`027>L2
000236<01P@Q<H`aS36<>Li6<@9Nm`03F]IW>F]J00I[FP03Liag_GNm009_N`=g_@03JeY_Nfmk009o
o`=kgP5oo`0017oo00Eg_FmkKg]kgWNm00=cW005JeY_NfmkLiag_@04Li`2Kg/4Li`4Kg/2Li`2IcT2
Kg/3Li`00aBU48@@Q0020002124010aS48@@Q124100000HLi`@Q36<<H`@Q0003248010aS2488@P@Q
0`Q200H48@0036<<H`@Q000236<011cW36<48@@Q0P000QS600IF]FLi000005[F5:D2Kg/00fLiMke[
FP02JeX016mkLiacW6mk17>L00E_Ng>LLia[FVmk008U:@04249F]FmkKg/5Li`01@0048@@Q0aS1240
0PaS00@@Q0000000008HaP8@Q00536=6<ABU5:ES6003G_L00f]JKg][FP02JeX015[FKg]_Nfmk1G>L
0Vmk00I[FW_NLiacW7ooNmh4Ool000=kgP04OomcW7>LLi`2Mkd2JeX01FmkLia_NfmkJeX00g>L00=_
NgNmJeX00V]J00=kgW>LLi`00W>L26mk0W>L00A_NcW>12448@80008@Q004124<H`aS36<200021240
1ABU248DYABU48@00`0000H48A2436<<Ha2436<312401A2436<<H`Q212400PQ200H48@Q2000000aS
F]H2G_L01EJe48AF]EJe=Jd00fLi00<006LiLi`00W>L00E_Ng>LLia[FW>L009kgP03Kg][FVmk009_
N`05JeYW>FLi?NmJeP02Li`2Kg/2Li`01V]J00048@@Q48@000848@0624800000000DYAcW0P@Q00I:
DU:D:DXYBU[FKg/2E[D01V]JKg][FV]JKg][FP=_N`McW004Kg]cW7>LLi`2Nmh2Ool1Nmh1Ool000=k
gP04OomcW7>LLi`2Mkd2JeX01FmkLia_NfmkJeX00g>L00=_NgNmJeX00V]J00=kgW>LLi`00W>L26mk
0W>L00A_NcW>12448@80008@Q004124<H`aS36<2000212401ABU248DYABU48@00`0000H48A2436<<
Ha2436<312401A2436<<H`Q212400PQ200H48@Q2000000aSF]H2G_L01EJe48AF]EJe=Jd00fLi00<0
06LiLi`00W>L00E_Ng>LLia[FW>L009kgP03Kg][FVmk009_N`05JeYW>FLi?NmJeP02Li`2Kg/2Li`0
1V]J00048@@Q48@000848@0624800000000DYAcW0P@Q00I:DU:D:DXYBU[FKg/2E[D01V]JKg][FV]J
Kg][FP=_N`McW004Kg]cW7>LLi`2Nmh2Ool1Nmh1Ool00004NmioogooNmh3Mkd00g>LMkeg_@02Mkd0
1G_NMkeg_GNmKg/00W>L00IkgW>LNmikgWNmJeX3Kg/5Li`2Kg/00g>LKg]_N`02Kg/012486<HHaPQ2
0`0000H<H`00000000Q236<212400`001240000200000`@Q2488@P060002124010aS00048@@Q0PQ2
0PaS00@8@P@Q48@@Q088@P8@Q006000YBVLiIcT@Q7>L0R4800EF]G>LLiacW7_N00EcW09[FP06HaQc
W7_NNmicW7Nm0W>L00IW>FmkLiacW6]JKg/2Li`016Li2488@PQ20P000`Q200D<HacW7>L8@P00008]
J`06AS5F]E[FF]I243F]0Vmk00=cW6<HLi`00W>L00A_Nf<HHaQg_@=cW005MkecW6mkKg]cW003Kg/5
Nmh1Ool00004OomkgW_NNmh4Mkd3Li`01GNmLiacW7>LMkd00g>L00Ig_G>LNmikgWNmKg/4Li`2Kg/0
0gNmNmi_N`02Kg/3Li`01VmkLi`LiacW1240008<H`06248000000008@PaS0PQ200<48A2400000P00
0aBU1P000QBU00@48@002488@P80008DY@0348@8@P@Q00D48@0636<icPaS36<e[FLi0R4800I_Ng>L
Kg]_Ng>LMkd2Li`01GNmLiaW>FLiG_L00gNm00IcW7NmKg]_Nf]JNmh2Mkd01V]JMkecW7>L@Q0000<8
@P056<H8@PQ2000e[@0248@01P@Q248icSW>E[ENm`9F]@03@Q16<Fmk009_N`05IcU_NfmkMkeW>@02
HaP01W_NKg]cW7>LMkekgP=[FP03Lia_Nfmk00EkgP5oo`0000Aoog_NNmioo`Eg_@9cW003MkecW7>L
00=cW0Ag_@9cW004Kg]kgWNmMkd2Li`2Mkd01VLiLiag_GNmLia_N`9cW006IcU[FV]JJeX<H`000P@Q
00<000@Q00000`000PaS00D8@PaS48@@Q0Q200<00006124<H`Q2248<Hb480P0000H48AS636<<Ha24
6<H300001@@Q48@@Q0Q248@00QBU00H48A2436<<HgNm8@P2Kg/017>LMkecW7>L0WNm0g>L00Eg_G_N
Nmig_F]J009cW006Kg]:DWooOomg_G>L0V]J00AcW6]JAS56<@8@Q0848@88@P848@06248aS1S66<H<
Hd8@0U[F00IBU4YBBU9:DVLiLi`2IcT01VmkMke_NfmkJeY_N`9g_@06Liag_G>LLia_Nf]J0WNm00Ek
gV]JKg]_Ngoo00AkgP5oo`0000EkgWooOomoog_N00Ag_@9cW003MkecW7>L00YcW005MkecW7>LLia_
N`02Mkd01VmkLiakgW_NLia_N`9kgP06Kg][FV]JJeYkgQ240P@Q00D8@P00000000aS00<8@P06124D
YA2448@<H`Q20`@Q00D000Q2248<HaBU00800003248@Q0Q20088@P056<H000001240000324801AS6
9BTU:Cg_12400g>L00DaS6mkKg]_Ng>L009g_@QcW006Mke_NfmkKg][FU:D0g>L00E[FVmkKg]cW248
008000061248@P0000048@Q20P0000H@Q1BU5:DDYBDY>Lh2E[D2CW<2HaP01V]JKg]W>FLiKg]cW09[
FP05IcUcW7_NNmicW003Mkd01VmkIcUkgW_NMke[FP9g_@05OomkgWooOomkgP01Ool00005Nmioogoo
OomkgP04Mkd2Li`00gNmLiacW00:Li`01GNmLiacW7>LKg/00WNm00I_Ng>LNmikgW>LKg/2Nmh01Vmk
JeY[FV]JNmh@Q0848@0524800000000<H`0324801P@Q5:D@Q12436<8@P<48@050008@PQ236<DY@02
00000`Q248@8@P0224801AS6000000@Q00000`Q200DHaRDY9BTmk`@Q00=cW005<Ha_NfmkKg]cW002
Mkd8Li`01WNmKg]_NfmkJeYBU0=cW005JeY_NfmkLi`Q200200001P@Q248000001248@P80000648@D
YABU5:DU:CW>0UJe0Tic0V<H00I[FVmkIcUW>FmkLi`2JeX01FLiLiakgW_NLi`00gNm00I_NfLiNmik
gWNmJeX2Mkd01GooNmioogooNmh00Goo0003Ool00g_NLiag_@02Mkd017>LKg]_NgNm0fmk1G>L00E_
Ng>LLiacW6mk00AcW09[FP06Liag_F]JJeY_Ng>L0Vmk00AkgWNmKg]_N`9W>@8@Q00500048@aS36<0
000312401PaS2488@PQ248@<H`88@P061248@P0000048@aS0P@Q00@U:E[F36<<H`80008icP065:D4
8@Q2248Li`000Sg_00IJeQcWJeY[FR48AS42G_L01FmkMkeg_GNmLi`016mk17>L00E[FU[FF]HmkeJe
009_N`06JeYg_FmkKg/8@Q240PQ200H000@Q48@@Q1S624825:D01P@Q00000000JeYBU09W>@05BU9J
eV<HHaQ[FP03Kg/01WNmIcU_NfmkMke_N`9W>@06MkeW>FmkKg]cW7_N0f]J00=g_F]JJeX01G_N0Goo
00001G_NOomoog_NLi`00gNm0g>L00AkgV]JJeY[FP9g_@9_N`9g_@=_N`05MkecW7>LLia_N`02Li`0
1VmkMke[FV]JKg]cW09_N`9g_@9_N`06HaQW>AS66<H000@Q0PaS00H000@Q48@@Q0@Q000236<010Q2
00048@@Q0PQ20`aS00@HaP@Q124000<@Q0061248@QBU5:D<H`Q20PaS00HHaP0012448EkgMkd2DY@0
1RDY?Nm[FV]JKg]kgP9g_@EcW005MkecW7>LLiaJeP03JeX01FLiJeY[FV]JLi`00PaS0PQ20PaS0P00
0Q2400HHaPQ25:DDY@@Q0002<H`01WNmHaQ6<DHaKg]Nm`9[FP06MkecW6mkKg]cW6mk0V]J00IcW6mk
Kg]_Ng>LKg/2Li`01VmkLia_NfmkJeY_N`9W>@05MkekgW_NNmig_@01Ool00005NmioogooNmig_@02
Li`01WNmLiacW7>LNmicW09[FP06MkecW6mkKg]cW7_N0V]J00I_Ng_NLiacW6mkLi`2Mkd01FmkLiag
_GNmJeX01G>L0Vmk00E[FVLiJeY[FP@Q00<<H`0600048@@Q1248@P000QS600H@Q0002488@PaS2484
5:D212401@0036<48@@Q5:D00`Q200H48@Q248@@Q0@Q000224801W>LMkdicSW>48@<H`8Li`06E[E[
FW>LLia_Nf]J0W>L00I_Ng_NNmikgVmk<H`2Kg/00f]JKg]_N`02Kg/00aBU2488@P020002248010aS
124000000PaS0QBU00H00124BU9:DU[FG_L2HaP01VmkIcUW>FLiNmicW09_N`9g_@=[FPAcW0=_N`03
JeY_Nfmk00=_N`9[FP05MkekgW_NNmig_@01Ool00005NmioogooNmig_@02Li`01WNmLiacW7>LNmic
W09[FP06MkecW6mkKg]cW7_N0V]J00I_Ng_NLiacW6mkLi`2Mkd01FmkLiag_GNmJeX01G>L0Vmk00E[
FVLiJeY[FP@Q00<<H`0600048@@Q1248@P000QS600H@Q0002488@PaS24845:D212401@0036<48@@Q
5:D00`Q200H48@Q248@@Q0@Q000224801W>LMkdicSW>48@<H`8Li`06E[E[FW>LLia_Nf]J0W>L00I_
Ng_NNmikgVmk<H`2Kg/00f]JKg]_N`02Kg/00aBU2488@P020002248010aS124000000PaS0QBU00H0
0124BU9:DU[FG_L2HaP01VmkIcUW>FLiNmicW09_N`9g_@=[FPAcW0=_N`03JeY_Nfmk00=_N`9[FP05
MkekgW_NNmig_@01Ool000=oo`9kgPIg_@03Liag_G>L009cW0=g_@06IcUcW7ooOomg_Fmk0W>L00Ag
_G>LKg]_N`9cW09_N`06Lia_NfmkKg][FVmk0W>L00I[FVmkKg]_Nf]J36<200000aS636<000020000
1B480000000036<00P@Q1P000QS600@000@Q36<<H`80008Li`06124<H`Q2248DY@@Q0Q240W>L0`aS
00D@Q1BU5:D48AS6008Li`8aS09Nm`05LiaF]Be[;F/DY@03Li`01WNmLiaW>FLiJeX8@P<00005124H
aQS65:D48@0324801@aS12448ABU@Q000Tic00I243g_DYABU5[FMkd2Li`2HaP2Mkd01W>LHaQg_GNm
NmiW>@9[FP03Kg][FWNm009g_@04Lia_NfmkJeX3Kg/4Nmh2Ool00004OomkgW_NNmh4Mkd00g>LMkeg
_@02Mkd4Li`2Mkd017>LKg]kgW_N17Nm00IcW7NmKg]_Ng_NMkd2Kg/2Li`2JeX2Mkd2Li`00f]JLia_
N`02Kg/01E[F36<<H`0024800PaS00H48ABU000000@Q36<212400`0048@0000300028@P01P@Q36<D
YABU1240008DY@0648@48@@Q124U:@000QcW00Ig_Be[5:DDYA24;F/29BT01PQ27>L<H`aS5:D<H`<H
aP051248@PQ2249g_@04Li`2IcT01F]J2488@PQ236<00a2400H8@P006<HHaPaS48@2:DX01Sg_F]IS
66<HF]INm`9W>@9[FP9g_@03Kg]W>G>L009cW005JeYkgW_NLiaW>@02Kg/00g>LKg]g_@02Mkd01G_N
HaQS66LiLi`00Vmk1G_N0Goo00000g_NOomoo`02Nmh6Mkd00g_NLiacW002Li`01GNmKg]_Ng>LMkd0
0g>L00AkgW>LLiacW0=kgP06JeY_Ng>LLia_NgNm0W_N00=_Nf]JLi`00W>L00E_Ng>LLiag_F]J008Q
20@48@0624848@@Q1248@P000R4800DaS0@Q7>LLi`aS00<0000636<8@P@Q124DYA240P0000H48@Q2
12448@006<H2Mkd01V<H48AJeU[FHaQ6<@8HaP0424848@@Q124236<312401A245:DDYDYBLi`00Vmk
00EcW6mkLiacW7_N00@00005124000006<H@Q00200001Q24:DXmkcg_F]IW>@=Nm`03JeY_Nfmk009_
N`9[FP03Kg]cW7>L009cW005Mke_NfmkJeYkgP02Mkd00fmkMke_N`03Kg/2Nmh00gNmLiakgP06Nmh1
Ool00003Nmioogoo009kgPIg_@03NmicW7>L009cW005Mke_NfmkLiag_@03Li`017_NLiacW7>L0g_N
00I[FVmkLiacW6mkMkd2Nmh00fmkJeYcW002Li`01FmkLiacW7NmJeX00R4810@Q00H8@P@Q12448@Q2
00028@P01C6<124LiacW36<00`0000H<H`Q212448ABU48@200001P@Q24848@@Q000HaP9g_@06HaP@
Q5[FF]IS64Ha0QS600@8@P@Q12448@8<H`<48@0548@DYABUBU9cW002Kg/01G>LKg]cW7>LNmh01000
00D48@00000HaQ240080000648@YBSg_?NmJeVLi0ekg00=[FVmkKg/00Vmk0V]J00=_Ng>LLi`00W>L
00Eg_FmkKg][FW_N009g_@03Kg]g_Fmk00=_N`9kgP03MkecW7_N00IkgP5oo`000goo00=kgWooMkd0
0gNm0W>L00=g_G>LLi`00W>L00=g_G>LLi`01G>L0gNm0W>L0W_N00A_Ng>LMkeg_@9cW09kgP06Lia_
NgNmMkecW6mk0gNm00EW>DicCW<@Q0@Q00800006124DY@Q224848@Q20PaS0PQ20`aS00<8@P@Q1240
10Q200HLiaBU12448@005:D312401E:DMkeg_Be[7>L01WNm00@Li`007>LLi`88@P8U:@06<H`8@PQ2
249[FW>L0WNm17>L00DaS0@Q2488@P@Q00<0000648@mk`@Q124icR480T8@00EJeVmkHaQS66Li00A_
N`04MkekgW_NLi`3JeX2Li`2JeX00fmkLiacW002Li`4Kg/016LiNmikgWNm0g>L00=oog_NOol00goo
00001G_NOomoogooMkd00W_N00Ig_G>LMkeg_G_NLi`2Mkd2Li`2Kg/00gNmLiacW006Li`00fmkLiac
W004Li`01WNmKg]_NfmkNmig_@=cW005Mke_NfmkIcUg_@02IcT01R48248<H`aS0008@P8<H`061240
00000008@P@Q0Q2410Q200D<H`Q22488@P0000@48@05000HaQS68@QcW002Kg/236<2Li`00gNmKg][
FP02JeX01ABU36<<H`Q236<00aBU00DQ212448ANmgNm00=cW004Kg][FV]J248348@01PQ25:DLiacW
:DXicP9F]@06;F]:DVLiIcTU:EJe0V<H00Ig_FmkLiacW7_NJeX2Kg/00g>LKg]cW002Li`3Kg/2Li`3
Kg/01F]JMkeg_FmkMkd00W>L00A_Ng>LIcUW>@Ioo`0000Aoog_NNmioo`Ag_@05Liag_GNmNmi_N`02
Li`017NmLia[FV]J0W_N0g>L00Eg_FmkKg][FWNm00IcW003MkecW7>L00EcW006Kg]g_F]JJeY_NgNm
0Vmk00A[FRe[12448@80008@Q003124000Q20088@P05000HaQS648@0000324801@@Q000000Q21240
0PaS00H8@QBU36<<HcW>Kg/2BU801Q248@QF]EJeBU8<H`848@06=JeJeQBU5:D48A240P0000HYBQS6
9BTU:EJeLi`2Mkd016]JLia_Nfmk0PQ20PaS00H48A24:DXYBTHaCW<2DY@01THaCW=6<DHa<Ha2409[
FP06Mke_NgNmMkekgVmk0V]J00Ag_G>LLiacW09g_@=[FP=_N`04JeYcW7>LLi`4Kg/016LiKg][FV]J
0W_N0Woo0GNm0Goo000017ooNmikgWoo17Nm00EcW7NmMkekgVmk009cW004MkecW6]JJeX2Nmh3Li`0
1GNmKg]_Nf]JMkd01W>L00=g_G>LLi`01G>L00I_NgNmJeY[FVmkMkd2Kg/016]J;F/48@@Q0P000Q24
00<48@0024800PQ200D001S66<H@Q00000<8@P051240000024848@0236<01PQ25:D<H`aS>Li_N`9:
DP0648@Q25JeE[E:DPaS0P@Q00He[E[F5:DDY@@Q48@200001RU:6<HU:BDYE[EcW09g_@04JeYcW6mk
Kg/2248236<01P@Q48@YBRU:AS5>L`9BU006AS5>LdHaAS4aS48@0V]J00Ig_FmkMkeg_G_NKg/2JeX0
17NmLiacW7>L0WNm0f]J0fmk00A[FW>LLiacW0A_N`04IcU_Nf]JJeX2Nmh2Ool1Mkd1Ool000=oo`03
Nmig_GNm00=g_@=cW004MkecW7>LKg/3Nmh01W>LJeYg_GNmKg]cW09g_@04NmicW6mkKg/4Li`00gNm
Kg]cW005Li`00fmkLiag_@02Mkd01FLiKg]_NfmkBU800PQ200@48@aS2488@P8<H`88@P0348@<H`00
00800005248HaQS600048@028@P01P0036<<H`aS48@DY@8@Q005Mke[FQBU5:DYBP03Li`2Kg/2Li`0
13F]48@e[CF]0P000R4800E>L`0036<<Hg_N00EcW08Li`06248<H`Q2248<Ha240ekg00E>Ld8@@Q0m
kdYB009F]@06DYAcW6mkKg]cW6mk0f]J00EkgWNmMkeNmg>L009_N`9W>@=g_@05HaQ[FV]JJeYW>@0:
Kg/00g_NOomkgP02Nmh1Ool00004NmioogooNmh7Mkd01VmkMkecW7>LKg]g_@9kgP06Lia_NgNmMkec
W7Nm0W>L00AkgV]JJeY[FP9_N`9g_@05NmiS66]JJeYg_@03Li`016mkLiacW7>L1Vmk0T8@00<48@aS
24800PQ200D000@Q124<HaS600<000<8@P06000DYA2448@8@P000PQ20P000fmk00<DY@@Q12400V]J
0dHa00E_Ng>LLia[FRDY008@Q006248DYAS66<He[@@Q0Q2400=g_G>LLi`00W>L00Eg_@@Q12448@Q2
008<H`066<IJeUkgG_M6<Cg_0UJe00ES66mkKg]_NfLi00E_N`9[FP06Kg]cW7>LLia[FVmk0f]J00EW
>G_NNmig_FLi00=[FP03IcUg_GNm00E_N`03IcUS66<H009kgP9oo`5kgP5oo`0000EkgWooOomkgWNm
009kgP05MkecW7NmMkekgP08Li`016mkLiacW7>L0gNm17>L00Eg_G>LMkeg_Goo00=_N`06NmicW7>L
Liag_G_N0f]J0gNm00I_Ng>LLiacW0@Q248200001P@Q000<H`aS124<H`@8@P848@06248DYA2448@0
00@Q0R4800H8@P00Oomoog_N1242G_L4Kg/01V<H:DXHaQS6>Lhmk`8YBP065:DQ20Q2248Li`aS0QS6
17>L00I_Ng>L000000Q236<212401QcWMkeW>FLi<HaF]@9[FP06Kg]g_G>LLiaW>F]J0W>L00=g_G>L
Mkd00WNm0g>L00A_Ng>LLiacW09_N`=g_@05Kg]cW7>LJeYS6002Nmh01WNmLia[FV]JKg]S609W>@9k
gP9oo`5kgP5oo`0000EkgWooOomkgWNm009kgP05MkecW7NmMkekgP08Li`016mkLiacW7>L0gNm17>L
00Eg_G>LMkeg_Goo00=_N`06NmicW7>LLiag_G_N0f]J0gNm00I_Ng>LLiacW0@Q248200001P@Q000<
H`aS124<H`@8@P848@06248DYA2448@000@Q0R4800H8@P00Oomoog_N1242G_L4Kg/01V<H:DXHaQS6
>Lhmk`8YBP065:DQ20Q2248Li`aS0QS617>L00I_Ng>L000000Q236<212401QcWMkeW>FLi<HaF]@9[
FP06Kg]g_G>LLiaW>F]J0W>L00=g_G>LMkd00WNm0g>L00A_Ng>LLiacW09_N`=g_@05Kg]cW7>LJeYS
6002Nmh01WNmLia[FV]JKg]S609W>@9kgP9oo`5kgP5oo`0000Aoog_NNmikgPEg_@9cW003Kg]cW7>L
00=cW09_N`EcW003MkecW7>L00EcW005NmicW7>LKg]g_@02Nmh2Mkd2Nmh01VmkJeYg_GNmNmi_N`9c
W0A_N`05:DX8@P@Q1248@P03000524801@002488@QS624800P@Q00HLi`@Q2488@QBU=Jd2Kg/00aBU
Kg]g_@02Mkd3Li`01V]JMke[FV]J>Lh<H`88@P0636<DY@aS36<8@PaS0Re[17>L00A_Nf<H36<<H`88
@P8Li`04AS5W>F<HHaP2Kg/2E[D01W_NF]IW>FLiMkekgP9cW004Kg]cW6mkKg/6Li`2Kg/017NmLiac
W7>L1Fmk00Eg_F<HHaQ[FVmk009kgP04JeYg_GNmMkd5Nmh1Ool00004OomkgW_NNmh3Li`00g_NMkec
W003Li`2IcT00f]JMke_N`02Kg/5Li`2Mkd8Li`017NmLiag_GNm0W>L0WNm00=[FVmkNmh00W_N00Ac
W7NmMkecW0=[FP04MkdQ20Q2248236<200001PaS48@48@@Q248DY@80000536<DY@Q2248<H`042480
1G>LAS56<EkgKg/017>L0Ukg00E244ic<H`aS48@00=>L`80008HaP061248@RDY9BUg_G>L0Vmk00Ac
W5Je2488@P8<H`848@05Lia[FV]JJeYcW003IcT00fmkIcUcW003Li`2Kg/01W>LNmi[FV]JLiag_@9c
W003IcUg_F]J009[FP05Liag_GNmLia_N`02Li`4Kg/016]JKg]cW7>L0Vmk0W>L00=oog_NNmh00W_N
0Goo0003Ool01G_NMkekgW_NMkd00g_N00Ag_G>LMkeg_@9cW09S6003Liag_G>L00EcW003Kg]cW7>L
00IcW004Kg]cW7>LMkd3Li`2Mkd3Kg/4Li`00fmkMkeg_@02Kg/2DY@00`Q21248@P0224801@@Q8@PQ
20Q212400PQ200H<H`Q212448ABU248212401AS6Mke_NfmkLi`00fLi00I_Ne[F5:DDY@Q2000236<0
1Q24000000007>L<H`800004248@Q0aS36<2Li`2Nmh01V]J48@@Q12436<@Q096<@04MkecW7>LLi`2
JeX2Kg/2Li`2Mkd00f]JMkeg_@02Mkd016mkNmikgW_N0fmk00=g_G>LMkd00gNm0V]J00EcW6mkKg]_
NgNm00E_N`9[FP9_N`9[FP05OomkgWooOomkgP01Ool000=oo`05Nmig_G_NNmig_@03Nmh017NmLiag
_GNm0W>L0V<H00=cW7NmLi`01G>L00=_Ng>LLi`01W>L00A_Ng>LLiag_@=cW09g_@=_N`AcW003Kg]g
_GNm009_N`9BU00324848@Q20088@P05124Q224824848@0224801PaS24848@@Q5:D8@P848@056<Ig
_FmkKg]cW003IcT01VmkF]HDYABU2480008<H`0648@00000000Li`aS0P0000@8@Q2436<<H`9cW09k
gP06JeX@Q12448@<Ha240THa00Ag_G>LLiacW09[FP9_N`9cW09g_@03JeYg_GNm009g_@04Kg]kgW_N
Nmh3Kg/00gNmLiag_@03Mkd2JeX01G>LKg]_NfmkMkd01Fmk0V]J0Vmk0V]J00Eoog_NOomoog_N005o
o`000goo00=kgWNmMkd00WNm0g>L00=kgW>LLi`00W>L00=_NfLiIcT00W_N0gNm00EcW6]JJeYcW7Nm
00=cW005MkecW7>LKg]g_@04Li`;Kg/017NmLiacW6]J0fmk00<8@P@Q12400P@Q00<000Q224800P00
0Q2400H8@P00000000@Q248212401VLiKg]W>FLiCW<e[@<@Q00336<8@PQ200848@8@Q08<H`848@04
248@Q0@Q1242248212401VLiLiacW7>LHaP8@P8DY@88@P9g_@06Lia_NfmkKg][FVLi0Vmk00=g_Fmk
Li`00W>L00E_Ng>LLiacW6mk00=cW0=_N`03Nmi_NgNm00=g_@9[FPA_N`06MkekgV]JJeYW>Fmk0V]J
16mk00=kgWooNmh00W_N0Goo0004Ool4Mkd3Li`01F]JMke_NfmkJeX00gNm00E_Ng>LLiacW6Li00Ak
gP03IcUcW7>L009_N`9g_@04Nmi_NfmkKg/5Li`00fmkLiacW005Li`01F]JKg]_Ng>LKg/00W>L00H]
J`Q2000001BU36<200000`Q26<H0000200037>L01Q24?Nl@Q124@Q1[FP9g_@06LiaS636<<Ha[FVLi
0SW>00@HaPQ212448@8<H`8Q200600048@Q2248000@Q0PQ200DLifmkJeY[FTHa00<8@P0336<Q27>L
009cW003MkecW7>L00EcW003Kg]g_GNm00UcW005Kg]cW7>LLiag_@03JeX017>LMkeg_G>L0fmk00AW
>F]JNmikgPEcW0=_N`9kgP9g_@9oo`000goo17_N00Ag_G>LMkeg_@9_N`9cW004Kg]cW7>LLi`2Kg/2
Li`016mkMkekgW_N17>L00I_Ng>LNmikgWNmJeX2Kg/01W>LKg]W>FLiMkecW09[FP9cW09_N`04Lia_
Ng>LLi`2Kg/2JeX01Tic2488@PQ248@48@8000065:D<H`@Q124003W>0Q240QBU0U[F0Vmk0g_N00E_
NgNmMke_Nf<H009cW006JeYW>G>LLiaW>Be[0PQ200<48@aS24800`Q20PaS00HHaU[FLiacW1242482
36<011S6Lia[FV]J0WNm0Vmk17>L00A_Ng>LLiacW09_N`=cW005IcUcW7>LLia_N`02Mkd2Li`2JeX0
0fmkLia_N`03Kg/2Li`2JeX2Nmh01G>LKg]_NfmkMkd00fLi1G_N0Goo0003Ool4Nmh017NmLiag_GNm
0Vmk0W>L00A_Ng>LLiacW09_N`9cW004Kg]g_G_NNmh4Li`01VmkLiakgW_NMke[FP9_N`06Lia_NfLi
IcUg_G>L0V]J0W>L0Vmk00AcW6mkLiacW09_N`9[FP06CW<8@PQ2248@Q0@Q0P0000HDY@aS12448@00
>Lh248@25:D2F]H2Kg/3Nmh01FmkMkeg_FmkHaP00W>L00I[FVLiLiacW6Li;F/224800`@Q36<8@P03
248236<01QS6F]IcW7>L48@8@P8<H`046<IcW6]JJeX2Mkd2Kg/4Li`016mkLiacW7>L0Vmk0g>L00EW
>G>LLiacW6mk009g_@9cW09[FP03Kg]cW6mk00=_N`9cW09[FP9kgP05Lia_NfmkKg]g_@03IcT5Nmh1
Ool00004NmioogooOol4Mkd01G_NLiacW6]JLi`00Vmk1W>L0WNm00IcW6mkKg]_Ng>LNmh2Li`00gNm
Nmi_N`02Kg/017_NMkeg_GNm0g_N00=_Ng>LMkd00WNm0g>L0Vmk1g>L00@<HaBU5:D000<8@P0536<4
8B488@PLi`03124236<2Mkd2Li`2Kg/01W>LIcUS66<HLiag_@9[FP03:DX8@P00008000058@QS66<H
E[DLi`026<H2248236<01P@Q;F]cW7>L248@Q0848@05249kgWNmMkecW003Mkd2Li`3Nmh00fmkMkeg
_@02Li`2Kg/00g_NMkecW009Li`5Mkd01G>LKg]_Ng_NLi`00V]J16mk00AW>GNmLiacW09oo`9kgP9o
o`000goo00AkgWNmKg]_N`9kgP9_N`06MkecW6]JJeYcW7Nm0W>L00A_NgNmKg]_N`UcW004NmicW7>L
Li`5Mkd2Nmh00f]JLiag_@02Mkd01G>LMkeg_FmkLi`00Vmk00Eg_G>LLiacW7_N00<48@035:D<H`@Q
00848@035:D@Q124008<H`848@03?NmcW7>L00=cW09W>@06Kg][FVmkKg]Nmg>L0`0000D<H`Q22480
00Q2008HaP06000e[A2448@aS1BU0PQ200H@Q1S6JeY[FPQ2124236<01248Mkeg_GNm0W>L0WNm17>L
00AkgVmkMkeg_@9cW09_N`9kgP9[FP03Liag_G>L00=cW09[FP03Kg]cW7>L00IcW0=_N`05JeY_Nfmk
Kg][FP03Li`2Ool3Nmh1Ool00005NmioogooOomcW004Mkd4Li`2Kg/01F]JNmig_GNmJeX00fmk00=[
FW_NMkd00WNm0g>L00=_Ng>LLi`00W>L00=_Ng>LLi`02G>L0gNm0Vmk0V]J00Eg_G>LLiacW7Nm00@4
8@0536<00000248Q200200000`Q25:EcW005Li`00fmkJeY_N`02Kg/01F<H=Jde[CF]<H`00P@Q0PaS
0`Q200<DY@aS36<00P000VLi00I240Q25:DDYAcW6<H2000010aS124<H`aS0WNm0W>L00=g_G>LMkd0
0WNm1G>L0gNm0g>L00Ag_G_NJeY[FP9cW09_N`05Liag_F]JJeY_N`03Mkd2Kg/2Nmh4Kg/01V]JKg]_
NfmkLia_N`9cW005OomkgWooOomkgP01Ool00005NmioogooOomcW004Mkd4Li`2Kg/01F]JNmig_GNm
JeX00fmk00=[FW_NMkd00WNm0g>L00=_Ng>LLi`00W>L00=_Ng>LLi`02G>L0gNm0Vmk0V]J00Eg_G>L
LiacW7Nm00@48@0536<00000248Q200200000`Q25:EcW005Li`00fmkJeY_N`02Kg/01F<H=Jde[CF]
<H`00P@Q0PaS0`Q200<DY@aS36<00P000VLi00I240Q25:DDYAcW6<H2000010aS124<H`aS0WNm0W>L
00=g_G>LMkd00WNm1G>L0gNm0g>L00Ag_G_NJeY[FP9cW09_N`05Liag_F]JJeY_N`03Mkd2Kg/2Nmh4
Kg/01V]JKg]_NfmkLia_N`9cW005OomkgWooOomkgP01Ool000EkgP9g_@03Kg]cW7Nm00Eg_@06Nmi_
Ng>LLiakgW>L0WNm00AcW6]JKg]_N`AcW09g_@9cW003MkecW7>L00=cW09_N`03Liag_G>L00=cW09_
N`Ag_@9cW09W>@05JeX8@P@Q1240000412401@aS6<HHaWNmKg/00V]J1G>L00E[FV<HHaP]Jc6<00@H
aP8Q2005<H`HaQcW7>LHaP0300001QS68@PLiacWJeX8@P<000057>LHaQS648@Q2004Li`2Nmh9Li`0
0gNmLiacW002Kg/2Li`2Kg/2Mkd01W>LKg]g_GNmLiaW>@9g_@06NmicW7>LLiakgVmk0g>L0fmk00I[
FW>LJeY[FVmkJeX2Kg/00gNmNmikgP02Nmh1Ool000AkgP03Mke_Nfmk00Ag_@EcW003JeYcW7>L00Ag
_@06NmiW>FmkKg]cW7Nm0Vmk0W_N0V]J17>L17_N00=_Ng>LLi`01G>L00=_NgNmLi`00g>L0V]J00E_
N`@Q2488@P0000<48@80009kgP03Mke_Ng>L009cW0=_N`04IcUBU12448@26<H27>L01TicIcUJeU[F
HaQNm`8mk`03:DXQ21cW008Li`0524848@@Q248e[@0212401PQ248@HaQS6Kg]g_@=cW005Nmig_GNm
JeYg_@02Nmh01W>LKg]g_GNmNmi_N`IcW003Kg]cW7>L009cW005Kg]cW7>LLia[FP02Nmh00gNmKg]g
_@02Mkd3JeX01WooLiaW>FLiJeYg_@9[FP06IcUg_FmkKg]kgWoo0g_N0Goo000017_NOomoog_N1GNm
17>L0Vmk00=cW7NmLi`00g>L0fmk00EkgWNmMke_Ng>L009g_@03JeY_NgNm009g_@=_N`03LiaW>G>L
009cW004MkecW7>LLi`4Kg/7Li`01W_N36<0000036<HaP8<H`06AS5kgVLiIcUF]GNm0Vmk0W>L0Q24
00HHaRe[>LhicTicE[D3JeX00fLiMkeg_@02Kg/3JeX016<HE[EF]C6<0`@Q00H00248>LhicR482483
Mkd01G>LMkeg_G_NMkd00Vmk00Ig_G>LJeY[FWNmNmh2Kg/00f]JLiacW003Li`2Kg/2Li`2Kg/01W>L
Kg]_NfmkLiag_@9W>@03Kg]cW6mk009_N`=cW004JeYcW7NmMkd2JeX2Mkd01G>LJeY_NfmkNmh01Goo
000017_NOomoog_N1GNm17>L0Vmk00=cW7NmLi`00g>L0fmk00EkgWNmMke_Ng>L009g_@03JeY_NgNm
009g_@=_N`03LiaW>G>L009cW004MkecW7>LLi`4Kg/7Li`01W_N36<0000036<HaP8<H`06AS5kgVLi
IcUF]GNm0Vmk0W>L0Q2400HHaRe[>LhicTicE[D3JeX00fLiMkeg_@02Kg/3JeX016<HE[EF]C6<0`@Q
00H00248>LhicR482483Mkd01G>LMkeg_G_NMkd00Vmk00Ig_G>LJeY[FWNmNmh2Kg/00f]JLiacW003
Li`2Kg/2Li`2Kg/01W>LKg]_NfmkLiag_@9W>@03Kg]cW6mk009_N`=cW004JeYcW7NmMkd2JeX2Mkd0
1G>LJeY_NfmkNmh01Goo0007Nmh00g>LMkecW009Li`00gNmLia[FP02JeX00gNmLiacW004Kg/00f]J
Kg]g_@02Mkd016]JLiacW6mk0f]J00AcW7NmKg]_N`9cW09[FP03Liag_Fmk009_N`05Lia[FV]JKg/4
8@0224801QS69BT@Q124Liag_@8e[@04?Nm[FV]JJeX4<H`00aS6>Li[FP02JeX01FLiMkeg_F]JIcT0
0WNm00=cW6mkMkd00WNm0f<H00He[@@Q48@@Q0Q236<27>L01RU:Mkeg_GNmLia_N`9cW004MkecW6mk
Kg/2Li`2JeX01WNmNmi[FV]JKg]g_@9_N`05Lia_Ng_NNmi[FP04Kg/00g>LKg]_N`04Kg/00g>LKg][
FP02JeX01FmkLiacW6]JKg/00WNm00=_Nf]JLi`00W>L00A_Ng>LLiakgPEoo`0000AkgWooOomkgP=c
W003Nmig_G>L00EcW004Kg]cW7>LLi`4Mkd6Li`2Kg/01WNmLiaW>FLiLiakgP9cW09kgP9g_@04JeYg
_GNmMkd2Li`2Mkd2Kg/7Li`00`002488@P0236<2G_L01Tic7>M_NfmkLi`Q208YBP06AS5>LfLiIcUN
mdYB0Ukg00I_Nf<HJeY[FVmkMkd2IcT01V<HLiacW7>LKg]g_@9_N`048@PLi`@Q124436<00fLiMkeg
_@02Mkd4Li`3Mkd01VmkLiakgW_NJeYcW0=kgP03Kg]cW7>L00UcW003Kg]cW7>L009cW0=_N`04JeYc
W7>LLi`3JeX5Li`01GNmJeY[FV<HLi`00V]J0W_N0Woo0G_N0Goo000017_NOomoogoo0g>L00EoogNm
LiacW7_N00A_N`Ag_@05Nmi_NfmkLiag_@08Li`2JeX4Li`00g_NMkecW005Li`01WNmNmioogooKg][
FP9kgP9cW09g_@06Nmh48@000008@QBU0V<H00HaS7>LLiacW1cW>Lh2CW<01UJe?NmW>FLiF]I:DP9S
6006JeYS65JeE[Eg_G>L0SW>00DU:D8@G_MNmf<H00=cW0060008@P@Q124000aS0QBU00=[FVmkLi`0
1G>L00=g_G>LKg/01Fmk0W>L0g_N17>L0f]J00Ioog_NLiacW7_NJeX2Kg/01G_NKg][FV]JLi`00gNm
27>L00A[FW>LLiacW0A_N`04OomkgW_NNmh2Ool00004NmioogooOol3Li`01GooMkecW7>LNmh016mk
17Nm00EkgVmkKg]cW7Nm00QcW09[FPAcW003Nmig_G>L00EcW006MkekgWooOom_Nf]J0W_N0W>L0WNm
00IkgP@Q000000Q25:D2HaP01S6<LiacW7>L7>LicP9>L`06E[DmkfLiIcUJeTYB0V<H00I[FV<HE[EF
]GNmLi`2>Lh01BDY@Q1NmekgHaP00g>L00H000Q212448@0036<25:D00f]JKg]cW005Li`00gNmLia_
N`05Kg/2Li`3Nmh4Li`3JeX01WooNmicW7>LNmi[FP9_N`05Nmi_Nf]JJeYcW003Mkd8Li`016]JLiac
W7>L16mk00Aoog_NNmikgP9oo`0000=kgWooOol00Woo1WNm00EcW7_NMkeg_G>L00Ag_@05Liag_GNm
MkecW002Kg/4Li`016mkLiacW7>L0Vmk0WNm00IcW6mkLiacW6mkMkd2Li`017NmLia_Nfmk0W_N0g>L
00EkgV]JJeY[FQBU0088@P060008@UJeE[ES66Li0PaS00<Q24HaHaP00V<H00=F]EkgG_L00U[F0Ukg
00=_NfLiKg/01Fmk00H]J`Q236<<HaS6124224801RU:7>L<H`aS5:D48@8U:@04NmicW7>LLi`2Mkd;
Li`01GNmKg]_NfmkLi`00Vmk00AcW7ooOomoo`9[FP9cW004JeY_NgNmMkd2JeX3Li`01FmkMkeg_GNm
Kg/00W>L0Vmk0W>L0Vmk0WNm00AcW6mkLiacW09oo`=kgP5oo`000goo0W_N1WNm00=cW7_NMkd00WNm
00E_NgNmMkeg_G>L00=kgP05JeYcW7>LNmicW002Kg/00gNmLiacW003Li`2IcT2Li`2Kg/2Li`2Mkd0
0g>LMkeg_@05Mkd01W>LNmi_NfmkJeXYBP<000052496<DHaKg/Li`0248@01T8@G_MNmekgHaQNm`9[
FP06HaQJeSg_?Nm>Lekg0THa0W>L0V]J00DQ20aS36<<HacW00<0000548@LibU::DXDY@03248017_N
MkekgW_N0WNm0V]J00=W>GNmMkd00WNm00=cW7NmMkd017>L00=g_G>LLi`00g>L0fmk00A[FVmkKg][
FP=g_@06JeY_Ng>LLia_NfLi0g_N00A_Nf]JJeYcW0=_N`9cW0A_N`9cW09kgP9oo`5kgP5oo`0017oo
2GNm0Vmk17>L00=g_G>LNmh00W_N00E_Ng>LLiakgWNm009_N`04Nmig_FmkKg/4Li`2Nmh2Li`4Kg/4
Li`00fmkLiacW003Li`3Kg/00dHa2488@P0424801CF]124mkcg_HaP00ekg00IBU6LiMkeg_F]JF]H2
=Jd01UJe?Nl@Q124LiakgP9W>@9[FP9cW006F]H<H`00000DY@aS0RDY00DLi`@Q48@@Q7oo00=g_@9k
gP9_N`06Liag_G>LLia_Ng_N0WNm00I[FVmkMkeg_G_NKg/2Nmh2Kg/3JeX4Kg/3Li`2JeX2Mkd2Kg/2
Nmh01W>LJeY_NfmkMke_N`=cW004Nmi[FV]JIcT3Kg/017_NOomkgW_N0Woo0004Ool9Mkd2Kg/4Li`0
0gNmLiakgP02Nmh01FmkLiacW7_NMkd00Vmk00AkgWNmKg]_N`AcW09kgP9cW0A_N`AcW003Kg]cW7>L
00=cW0=_N`03AS48@PQ200@8@P05=Jd48Cg_?NmS6003G_L01U:DIcUg_GNmJeYJeP8e[@06E[Dmka24
48AcW7_N0VLi0V]J0W>L00IJePaS000001BU36<29BT01AcW124@Q124Ool00gNm0W_N0Vmk00IcW7Nm
LiacW6mkNmh2Mkd01V]JKg]g_GNmNmi_N`9kgP9_N`=[FPA_N`=cW09[FP9g_@9_N`9kgP06Lia[FVmk
Kg]g_Fmk0g>L00AkgV]JJeYW>@=_N`04Nmioog_NNmh2Ool00005OomkgW_NOomkgP02Mkd2Li`2Mkd4
Li`2Mkd2Kg/01WNmNmi[FV]JLiag_@9cW006JeYg_G_NNmi[FW>L0WNm00I_Ng>LNmikgW>LKg/4Li`2
Mkd2Li`4Kg/4Li`2Mkd2Li`2CW<01P00124@Q1246<HLi`8YBP06IcUcW5JeE[Eg_G_N0UJe00INmfLi
DYABU2U:Kg/2;F/01PQ248@@Q1248@PYBP8DY@06AS48@P0000048A240RDY00H8@QS68@PQ27NmLi`2
Mkd00f]JKg]g_@02Mkd01F]JKg]_Ng>LJeX00W>L0WNm0V]J00=_NfLiLi`00g>L0V]J16mk00IcW6mk
JeY[FVmkMkd2Li`01GNmLia[FV]JIcT00gNm0Vmk0W>L0VLi0WNm00IcW6mkMkeg_G_NOol3Nmh1Ool0
0005OomkgW_NMkekgP06Mkd00g>LMkecW003Li`2Mkd6Li`2Kg/01G>LMkeg_GNmKg/00g>L0Vmk0WNm
00=_Ng>LLi`00W>L00E[FW>LLiag_G>L009S6006MkecW7>LLia_NgNm0fmk00EcW6LiIcT<H`Q2008<
H`06>Lhe[B488@QJeVLi0UJe00=g_G>LIcT00fLi0Ukg00HLidicCW=>L`aS8@P2Kg/01Tic6<I>Ldic
BU800088@P848@8aS006;F/<H`Q2249Nmg>L0WNm00I_Ng>LLiacW7NmKg/3Li`01FmkLiacW7>LMkd0
0V]J00IcW6mkKg]_Ng>LNmh2Mkd01FmkLia_NfmkJeX00gNm00I_Nf]JKg]_Ng>LKg/4JeX2Mkd01Vmk
Lia_NfmkIcU_N`9g_@04Lia[FW>LLi`5Nmh1Ool00005OomkgW_NOomg_@02Li`2Mkd3Li`3Kg/00gNm
LiacW002Li`00gNmKg]_N`04Li`017_NLia_Nfmk0WNm0Vmk00Ig_FmkKg]_NgooMkd2Kg/01V]JNmic
W7>LKg]kgP9g_@03Lia_Nfmk009_N`03Lia_Nfmk009cW08HaP0336<8@V<H009S6005JeXe[CF]AS5[
FP02IcT00fmkJeY_N`05Kg/01V]J5:E2448@Kg]>L`9[FP05Lia_NdHaAS5S600312400`0012448@02
12401AS648@@Q4icMkd00g>L00Eg_F]JJeY_NgNm00=cW005MkekgW_NLia_N`02Nmh01WNmLiakgW_N
IcU[FP9cW0A_N`06Lia[FVLiIcUcW6mk0W>L00Ig_F]JLiacW6mkJeX2Kg/017>LIcU_Nfmk0W>L0VLi
0Vmk0V<H0W_N0WNm0Woo00001GooNmikgWooMkd00W>L0WNm0g>L0fmk00=g_G>LLi`00W>L00=g_Fmk
Kg/017>L00AkgW>LKg]_N`9g_@9_N`06Mke_NfmkKg]oogNm0Vmk00I[FW_NLiacW6mkNmh2Mkd00g>L
Kg]_N`02Kg/00g>LKg]_N`02Li`26<H00`aS249S6002HaP01F]J=Jde[DHaJeX00VLi00=_Nf]JKg/0
1Fmk00I[FQBU@Q1246mkCW<2JeX01G>LKg]6<DHaHaP00`@Q00<000@Q12400P@Q00DHaQ2448A>LgNm
00=cW005Mke[FV]JKg]g_@03Li`01GNmNmikgW>LKg/00W_N00Ig_G>LNmikgVLiJeX2Li`4Kg/01W>L
JeYW>FLiLia_N`9cW006Mke[FW>LLia_Nf]J0Vmk00AcW6LiKg]_N`9cW09W>@9_N`9S609kgP9g_@9o
o`0000Eoog_NNmioogNm009kgP03MkecW7Nm009g_@04Kg]cW7>LMkd3Li`2Mkd2Kg/01W>LMkecW7>L
JeYcW09g_@AcW006Kg]cW7>LLiag_G>L0WNm00EcW7NmMkeg_F]J00=g_@03Kg]cW7>L009cW005Kg]k
gW_NMkde[@0336<01EJeG_MNmgNmLi`00SF]00=JeV]JKg/00fmk0g>L16mk00DYBSW>>LicW6]J00=c
W005HaQW>FLiAS4HaP0224800`002480000200001AS69BTU:C6<Li`00WNm00=cW7NmMkd01WNm00=_
NgNmMkd00W>L0W_N0WNm0W_N00E_Ng>LLiacW7_N00=cW005Nmi_Nf<HHaQg_@03Li`2Mkd2Kg/01V]J
LiacW7>LKg]cW0A_N`9cW004Kg]g_FmkKg/2Ool3Nmh1Ool00004NmioogooOol5Mkd2Li`00fmkNmic
W003Li`2Nmh01W>LKg]g_GNmLiag_@9cW003MkecW7>L00]cW09g_@06Lia_NgNmMkekgV]J0W>L00Ig
_FmkKg]_NgNmNmh2IcT01T8@48@48@@QAS5[FP9S6005Lia[FS6<<HaJeP03Kg/6Li`2Kg/2Li`29BT0
1U[FKg]:DTYBCW=g_@9cW00636<000aS36<48@000b4800@000Q2248@Q0=g_@05Liag_G>LLiag_@08
Li`017NmKg]_NgNm0g>L0W_N0W>L00=_NgNmKg/00Vmk0gNm00=W>FmkKg/00Vmk00E[FWNmMkecW6Li
009_N`IcW0=_N`=cW005NmioogooOomkgP01Ool00004NmioogooOol5Mkd3Li`017NmLiacW7>L0gNm
0Vmk0W_N0W>L0WNm00IkgW>LJeY[FWNmLi`2Mkd01W_NLiacW7>LNmig_@9cW09g_@IcW004MkecW6mk
Kg/2Mkd2IcT25:D212401VmkMkde[CF]JeXmk`8]J`06F]IcW7_NNmi_Ng>L0W_N00Ig_FmkMkeg_G>L
IcT2?Nl01Re[LiaNmekg000aS09cW0038@P000Q20088@P05124LiacW7>L0000212401R48NmicW7>L
MkekgP9cW0Eg_@03Nmig_GNm00IcW0=_N`=cW003JeYg_Fmk009_N`05Nmig_GNmIcUcW003Kg/01F]J
NmikgW_NHaP00fmk00E[FWNmMkeg_G>L009[FP04Lia_NfmkKg/2Ool2Nmh2Ool00004NmioogooOol5
Mkd3Li`017NmLiacW7>L0gNm0Vmk0W_N0W>L0WNm00IkgW>LJeY[FWNmLi`2Mkd01W_NLiacW7>LNmig
_@9cW09g_@IcW004MkecW6mkKg/2Mkd2IcT25:D212401VmkMkde[CF]JeXmk`8]J`06F]IcW7_NNmi_
Ng>L0W_N00Ig_FmkMkeg_G>LIcT2?Nl01Re[LiaNmekg000aS09cW0038@P000Q20088@P05124LiacW
7>L0000212401R48NmicW7>LMkekgP9cW0Eg_@03Nmig_GNm00IcW0=_N`=cW003JeYg_Fmk009_N`05
Nmig_GNmIcUcW003Kg/01F]JNmikgW_NHaP00fmk00E[FWNmMkeg_G>L009[FP04Lia_NfmkKg/2Ool2
Nmh2Ool000Aoo`04Nmig_GNmLi`4Mkd017>LMkeg_GNm0g>L00IoogNmKg]_NgNmLi`3JeX017NmNmik
gVmk17>L17Nm1g>L00=g_G>LLi`00g>L0WNm00I[FVmk7>LLi`aS1242AS401Vmk>LicW7>LMkd@Q08L
i`06IcUcW7>LLiakgWNm0Vmk1G>L00E_NfLiIcTQ27_N00=_N`05BU9NmekgJeX@Q003248011cW0000
00000aBU00H48GNmNmikgVmkLi`3Mkd016mkMkeg_G>L0f]J0WNm0W>L00Ig_G>LLiacW6mkLi`2Kg/0
1W_NLiacW7>LMke_N`9[FP04Nmig_G>LLi`2Nmh2JeX01VLiMkeg_GNmNmig_@9W>@03JeY_Nfmk00=_
N`9cW003Nmioog_N009kgP5oo`0000AkgWooOomkgPMg_@QcW09g_@=_N`05Lia[FV]JJeYg_@02Li`0
1VmkMkecW7>LKg]g_@9kgP06Lia_NgNmMkecW6]J0g_N0g>L0Vmk0g>L00E_N`aS36<<H`Q2009cW006
IcTU:FmkKg][FPQ20QcW0W>L0V]J00IcW7NmKg]_Ng>LMkd3Kg/00gNmLiacW002F]H3Kg/01GNmLiac
W6mkF]H00`Q200@U:A2448@8@P<@Q00436=g_G_NNmh2Li`3Mkd01G>LMkeg_FmkJeX00Vmk00EkgWNm
Kg]_NgNm00=[FPAcW003Kg]cW6mk009_N`AcW0=_N`AcW004Kg]g_GNmMkd2Li`4IcT2Mkd01W>LMkec
W7>LMkekgP9oo`5kgP5oo`0000=kgWooOol00W_N17Nm1W>L00=[FWNmMkd00WNm00=_Ng>LLi`01G>L
00=g_G>LLi`017>L00I_Ng_NNmikgW>LMkd2Nmh00g>LKg]kgP02Nmh4Li`01FmkLiacW7_NMkd00PQ2
00H48AcWJeY[FWNm<H`2>Lh01R4836<YBRU:HaQcW09_N`06MkecW6]JJeYcW7Nm0fmk00Eg_G>LLia[
FW>L009_N`06LiakgWNmMke_Nekg0PQ200HDYBDY:DXYBQ24000236<00aBUNmig_@02Mkd5Li`2Kg/0
1W>LKg]_NfmkMkecW09_N`06Mke[FVmkKg]kgW>L0WNm00I_Ng_NKg]_Nf]JNmh2Mkd00fLiKg]_N`02
Kg/016]JLiacW7>L0fmk00IcW6mkJeY[FVmkJeX2Li`01FmkMkekgW_NOol00g_N0Woo00000g_NOomo
o`02Nmh4Mkd6Li`00f]JMkeg_@02Mkd00fmkLiacW005Li`00gNmLiacW004Li`01VmkNmikgW_NLiag
_@9kgP03Lia_Ng_N009kgPAcW005Kg]cW7>LNmig_@0224801P@Q7>M[FV]JMkdaS08icP068@P<HbU:
:DYS67>L0Vmk00Ig_G>LJeY[FW>LMkd3Kg/01GNmLiacW6]JLi`00Vmk00IcW7_NMkeg_FmkG_L22480
1QBU9BTYBRU:48@0008<H`035:EkgWNm009g_@EcW09_N`06Lia_NfmkKg]g_G>L0Vmk00Ig_F]JKg]_
Ng_NLi`2Mkd01VmkNmi_NfmkJeYkgP9g_@03IcU_Nfmk009_N`04JeYcW7>LLi`3Kg/01W>LKg][FV]J
Kg][FP9cW005Kg]g_G_NNmioo`03Nmh2Ool000AkgPAg_@04Kg]kgW_NNmh4Li`01GNmLiacW7>LMkd0
0fmk17>L00E_Ng>LLiacW6mk00=g_@05Kg][FV]JMke_N`02JeX01W>LMkeW>FLiKg]g_@9cW006Kg]g
_GNmMkeW>D8@0Q2400H8@Q24CW=>LeJe6<H336<01ABU6<HHaV]JLi`00fmk0g>L16mk00IkgV]JLiac
W7NmKg/2Li`00gNmJeYcW002Li`01@aS12448CW>=Jd00`@Q00@Li`Q224848@Ag_@=cW004JeYcW7>L
Li`2Mkd7Li`3Nmh01FLiJeYg_GNmLi`00fmk00=g_F]JLi`00W>L0fmk00Ig_FmkKg]_Ng>LKg/2JeX6
Kg/2JeX016mkJeYW>FLi0W_N0Woo0G_N0Goo0005Nmh4Mkd3Nmh01G>LMkeg_G_NLi`00Vmk00IkgWNm
LiacW7_NMkd2Kg/01W>LMkeg_GNmLiakgP9g_@IcW09_N`9cW09_N`06Liag_FmkKg]cW7_N0WNm00A_
NdYB36<<H`88@P8mk`0600048ABU5:D8@Q240R4800=[FWNmLi`01g>L0Vmk0V]J0W>L00=g_FmkLi`0
0W>L00E[FW>LLiaS60Q200800006BU96<@000008@PaS0P@Q00@8@W_NMkeg_@9cW09g_@06Liag_G>L
Lia[FVmk27Nm0W_N00I_Ng>LLiacW7NmKg/2Nmh017NmKg]cW7>L17Nm00IkgW>LKg]_Nf]JLi`2Kg/2
Mkd4Kg/3Li`01FmkIcUW>G_NOol00g_N0Goo000017_NOomoogoo0gNm0W_N0WNm17>L00I_Ng_NNmik
gW>LKg/2Mkd01VmkMkekgW_NMkecW09[FPAcW003Mke_Ng>L00EcW004Kg]cW7_NNmh2Li`2Mkd01W>L
Kg][FV]JMkde[@80000624848@000008@QBU0P0000D<Hb487>LLiekg00EcW09_N`06IcU_Ne[FF]Ha
S48@17Nm0fmk00EkgWNmMkd<H`@Q008DY@848@9:DP037>L000aS008<H`045:DLiacWJeX8Mkd01G>L
Mkeg_GNmLi`00gNm00AcW6mkKg]g_@AcW004Nmi[FV]JJeX3Mkd016]JLia[FV]J0Vmk0WNm00=cW6mk
Li`00W>L00E_Ng>LLia_Ng>L00=_N`03JeYcW7>L00Aoo`5kgP5oo`0000AkgWooOomoo`=g_@9kgP9g
_@AcW006Kg]kgW_NNmicW6mk0WNm00I_NgNmNmikgWNmLi`2JeX4Li`00gNmKg]cW005Li`016mkLiak
gW_N0W>L0WNm00IcW6mkJeY[FWNm=Jd200001PQ212400000248DY@80000536<Q21cW7>MNm`05Li`2
Kg/01VLiKg]JeU[F<Ha240Ag_@=_N`05Nmig_GNm36<48@025:D21242BU800acW000<H`0236<011BU
7>LLif]J27Nm00EcW7NmMkeg_G>L00=g_@04Lia_NfmkMkd4Li`017_NJeY[FV]J0gNm00A[FW>LJeY[
FP9_N`9g_@03Lia_Ng>L009cW005Kg]cW7>LKg]cW003Kg/00f]JLiacW004Ool1Nmh1Ool00005Nmio
ogooOomkgP06Mkd00g>LMkecW002Li`3Mkd5Li`01GooNmikgW_NKg/017>L0W_N00Eg_FmkKg]_NgNm
00=cW003MkecW7>L00McW09_N`05@Q08@PQ2248@Q00300001QBU6<H00000248U:@8DY@06F]Ig_GNm
MkeW>EJe0Ukg00I>Le:DLiacW5:D9BT3Li`3Kg/01WNmLia_Nfmk7>L8@P8Li`0636<8@QcW7>LQ20Q2
0aS60`0000=>LfmkMkd00gNm0W>L00AoogNmLiacW0Ag_@04Liag_GNmMkd6Li`2Kg/2Li`2Kg/016]J
Lia_Nfmk0W>L0WNm00AcW6]JLiacW09[FP=kgP05Kg]cW7>LMke[FP02IcT4Ool1Nmh1Ool000AkgPag
_@=cW005NmicW7NmMkekgP03Kg/00g>LNmig_@02Mkd017_NLiacW6]J17Nm00EcW7NmMke_Ng>L009g
_@03Lia_Ng>L00=cW09_N`848@<00003124<H`aS00848@88@P06124002DY9BUg_Fmk0VLi00HYBRDY
9BTU:FLi48@212401DHaF]Ig_GNmLi`00fmk0W>L0Ukg00H@Q5:DJeY[FS6<36<300001ABU36<<H`00
6<H00R4800<YBTYBMkd00WNm00AcW7_NNmi_N`=cW005Mke_NgNmMkekgP07Li`016mkLiag_GNm0W>L
0WNm00=cW6mkNmh00W_N00=g_F]JJeX00WNm0V]J0W_N0f]J0g>L00A[FWNmLiacW09oo`=kgP5oo`00
0goo00=kgWNmMkd00WNm00EkgVmkKg]cW7Nm009_N`03Liag_G>L00IcW004MkecW7>LLi`4Mkd01G_N
Kg]_Nf]JNmh00WNm00IcW7NmNmikgW>LJeX2Nmh01WNmKg]g_GNmKg]W>@9_N`06248000@Q1248@P@Q
0PaS00@8@QBU48@@Q08<H`9F]@9_N`9Nm`057>L@Q6]JJeX]J`0324801000?Nlmkcg_1Fmk00EcW6]J
JeX48Fmk009BU004G_LU:B488@P2248312435:D00bU:9BUcW003Li`2Mkd00fmkLiacW002Li`01Fmk
LiacW7ooJeX00W>L00AkgW>LJeY[FP9g_@=_N`AcW0U_N`9cW09g_@9[FP06Kg]cW7>LLiaW>G_N0gNm
00AkgWooOomkgP5oo`000goo00=kgWNmMkd00WNm00EkgVmkKg]cW7Nm009_N`03Liag_G>L00IcW004
MkecW7>LLi`4Mkd01G_NKg]_Nf]JNmh00WNm00IcW7NmNmikgW>LJeX2Nmh01WNmKg]g_GNmKg]W>@9_
N`06248000@Q1248@P@Q0PaS00@8@QBU48@@Q08<H`9F]@9_N`9Nm`057>L@Q6]JJeX]J`0324801000
?Nlmkcg_1Fmk00EcW6]JJeX48Fmk009BU004G_LU:B488@P2248312435:D00bU:9BUcW003Li`2Mkd0
0fmkLiacW002Li`01FmkLiacW7ooJeX00W>L00AkgW>LJeY[FP9g_@=_N`AcW0U_N`9cW09g_@9[FP06
Kg]cW7>LLiaW>G_N0gNm00AkgWooOomkgP5oo`0017_N00=oog_NNmh00W>L17Nm1g>L00Eg_FmkKg]c
W7Nm009kgP04MkecW7>LLi`2JeX3Nmh00fmkLiacW002Li`2JeX2Mkd2Kg/01W>LKg]_NfmkIcUcW09W
>@0524848@0000048@0436<01AcW12448@Q248@00UJe00IJeVmkMkeg_DHa5:D3Kg/00dic?Nlmk`02
48@2=Jd01QBUJeYkgW_NMkecW0<@Q0050008@PQ248@DY@0236<00a2436<<H`0236<01A242488@R48
9BT01W>L00IkgWNmKg]_Ng>LMkd3JeX01G_NMkeg_FmkMkd00W>L00E[FVmkLiacW6mk00=cW004Kg]c
W6]JJeX2Kg/2Mkd016]JKg]cW7>L0V]J0W_N00Eg_F]JMkeg_G>L00=W>@04OomkgW_NNmh2Ool00005
NmioogooNmioo`02Nmh017NmKg]kgW_N1GNm00=_Ng>LLi`017Nm00AcW6mkKg]_N`9cW09g_@03Kg]c
W7>L00McW09_N`04MkecW6]JJeX2Li`2JeX4Li`01P001248@PQ2000@Q08DY@060008@PQ224848@Q2
0U:D0VLi0Vmk00ENmcF]2488@U[F00=_N`039BT8@Q24008@Q005Kg]cW7>LNmiNm`0236<01QBU1240
00005:DLi`8<H`061248@PaS36<001S60Q2400HHaRU:Mkeg_G>LKg/2JeX01W>LKg]_NfmkLiag_@9c
W006Kg]g_G>LLiaW>GNm0W_N0V]J0WNm00IcW6mkMkeg_G>LJeX3Mkd01FmkLiacW6mkJeX00Vmk00Ic
W6mkKg]_Ng>LJeX2Kg/01W>LHaQ[FV]JNmig_@Aoo`0000EkgWooOomoogNm009kgPEg_@05Liag_GNm
MkecW002Kg/01GooKg]g_GNmNmh00fmk00AcW7NmLiacW09g_@=cW0=g_@QcW003MkecW6mk00=_N`9g
_@03124<H`0000800003124DYABU00800088@P0536<48G>LLiag_@04Kg/01Ekg@Q124000>Lh00R48
00H48ABUAS56<Be[Mkd2Li`01WNm?Nl48@@Q36=Nm`8Li`8HaP<8@P05124<H`aS000Q200248@00bU:
JeYcW002Li`01GNmNmikgVmkLi`016mk0W>L00Eg_FmkMkeg_Fmk00=cW006Kg][FWNmMkecW6]J0WNm
00=cW6]JMkd00WNm00E_Ng>LLiag_G>L009W>@03Liag_Fmk009_N`04Lia_NfmkIcT3Kg/2Nmh4Ool0
0005NmioogooOomg_@02Nmh5Mkd01G>LMkeg_GNmLi`00Vmk00EoofmkMkeg_G_N00=_N`04Liag_G>L
Li`2Mkd3Li`3Mkd8Li`00gNmLia_N`03Kg/2Mkd00`@Q36<0000200000`@Q5:DDY@02000224801@aS
125cW7>LMkd016mk00ENmd8@@Q0003W>008Q2006124DYDHaAS4]JgNm0W>L00Ig_Cg_12448@aSG_L2
7>L26<H324801@@Q36<<H`008@P00Q2400<YBV]JLi`00W>L00Eg_G_NNmi_Ng>L00A_N`9cW005Mke_
NgNmMke_N`03Li`01VmkJeYg_GNmLia[FP9g_@03Lia[FWNm009g_@05Kg]cW7>LMkecW002IcT00g>L
Mke_N`02Kg/017>LKg]_NfLi0fmk0W_N17oo000017ooNmikgWoo1GNm0W>L00Ig_G>LLiacW7NmNmh2
Mkd01V]JLiacW7>LKg]kgP9cW006MkecW7NmMke_Ng>L0gNm0g>L17Nm27>L00I[FVmkJeY[FR481242
5:D01Q240008@PQ248@DY@<@Q0057>L]Jbe[JeYkgP02Li`01F<HDY@icSW>8@P00`Q200H<H`Q28@PQ
24HaMkd2Li`01Vmk@Q048@@Q000<H`96<@80008<H`06000DYAS66<HDY@000PQ200<U:CW>Mkd00WNm
00AcW6mkKg]g_@=cW003MkecW7>L009cW005Kg]cW7>LJeYcW002Kg/00g>LNmi_N`02Kg/01GNmLiac
W7>LNmh00VLi00IcW7NmLiacW6]JMkd2Nmh01VmkJeY_NfmkMke_N`9cW0A_N`9kgP9oo`5kgP5oo`00
00=oog_NNmh00W_N0WNm00=cW7NmMkd00WNm00=cW7NmMkd00WNm0g>L00Eg_FmkKg]_Ng_N00=g_@05
Liag_GNmJeY_N`02Nmh00gNmKg]cW002Li`3JeX016mkLia[FV]J0W>L0Vmk00IcW6mkIcUW>AS636<2
248011S624848@@Q0QS60PaS00HLicF]E[EF]F]JNmh2Mkd01VmkJeX8@PQ200048@88@P066<H8@QBU
5:D@Q6]J0gNm00DaS0000008@Q2400@<H`8DY@06000<HaS66<H@Q0000P@Q00H@Q2e[Mkeg_G_NLi`2
Kg/01WNmKg]_NfmkMkeoo`=_N`03Nmig_GNm00I_N`AcW09g_@9cW09_N`9cW0A_N`9g_@06JeYNmg_N
Nmi_Nf<H0W>L00Ag_FLiKg]_N`Aoo`5kgP5oo`0017oo1gNm00=cW6mkLi`01G>L1GNm0g>L0WNm0Vmk
00IcW7_NLiacW6mkNmh2Li`4Mkd01VmkLiakgW_NLiakgP9cW006Kg]cW2U::DXDY@@Q0PaS00H48A24
2488@PaS24828@P01RDY>Lig_GNmNmi[FP9_N`06Lia[FW>LLia:DQS60PaS00H48@00000001248@P2
IcT01Vmk=Jd48@@Q36<@Q088@P0536<48@aS36<@Q00312401PaS5:D@Q124IcUcW09_N`06LiakgWNm
Mke_Ng>L0W_N0W>L0g_N00A_NgNmMkeg_@=_N`06Lia_NfmkKg]cW6mk0W>L0Vmk0WNm00IcW6mkMkeg
_G_NKg/2IcT01W_NKg][FV]JLiag_@9_N`04HaQg_FmkKg/5Nmh1Ool000Aoo`Mg_@03Lia_Ng>L00Ec
W0Eg_@=cW09g_@9_N`06LiakgW>LLia_Ng_N0W>L17Nm00I_Ng>LNmikgW>LNmh2Li`01VmkLi`YBRU:
5:D48@8<H`06124@Q0Q2248<H`Q20R4800HU:CW>Mkeg_G_NJeX2Kg/01W>LJeYcW7>LBU8HaP8<H`06
12400000000@Q2480VLi00I_NcF]12448@aS48@224801@aS124<H`aS48@00`@Q00H<HaBU48@@Q6Li
Li`2Kg/01W>LNmig_GNmKg]cW09kgP9cW0=kgP04Kg]g_GNmMkd3Kg/01W>LKg]_NfmkLia_N`9cW09_
N`9g_@06Lia_NgNmMkekgVmk0VLi00IkgVmkJeY[FW>LMkd2Kg/016<HMke_Nfmk1G_N0Goo0004Ool5
Mkd2Kg/00gNmKg]_N`02Kg/7Li`00gNmLiacW002Li`01FmkLiacW7_NMkd00f]J00A_Ng>LLiag_@=k
gP05JeYcW7NmMkecW003Nmh01VLiKg/aS36<8@P8@P8<H`04248Q212448@236<2;F/016<HKg]_Nfmk
17>L00A_Ng>LMkeg_@9cW09[FP06DY@]JbDY9BUJeT8@0RDY00=F]AS612400P@Q00D@Q0Q224848@00
008<H`05124<HaS66<HDY@0324801QBUNmi_NfmkMkecW09g_@9cW09kgP06Lia[FWNmMkekgW>L0gNm
00=cW6mkKg/00W_N0Vmk00IcW6mkJeY[FVmkLi`2Kg/017>LKg]cW7>L0Vmk0g>L16mk00EcW6]JJeY[
FW>L009_N`9kgP=g_@5oo`000goo00IkgWooOomoogNmLi`6Mkd5Li`017NmLiacW7Nm1G>L16mk0gNm
00A_Ng>LLia[FP=_N`05Nmig_F]JJeYcW003JeX2Mkd28@P01P@Q48@00000:DXaS08HaP0548@<He:D
DYAJeP03G_L01V]JLiacW7>LKg]g_@A_N`9cW006Kg]cW7NmMkeNmdYB16<H0U[F00=BU0@Q12400P@Q
00@8@P@Q124HaP<00006248HaPaS36<@Q2e[0WNm0W>L0Vmk0W>L0Vmk00=cW7NmKg/00Vmk00EcW6mk
Kg]cW7_N009g_@06JeY_Ng>LLia_Ng>L0WNm00=_Nf]JKg/01Fmk00IcW6]JIcUW>F]JKg/2Li`00eJe
JeYcW002Li`00f]JKg]_N`04Nmh1Mkd1Ool000Aoo`=kgP06MkecW7_NNmicW7_N0gNm17>L00A[FWNm
Mkeg_@=cW09_N`=cW003MkecW7>L00EcW003Kg]cW7>L009cW09_N`06Lia_Ng>LLiag_G_N0Re[0PQ2
0P0000@YBPQ248@@Q0848@9240067>L<HbU::DXLifmk1W>L00=_Ng>LKg/00fmk0V]J00I_Nf<HKg]_
Nf]JIcT2Kg/01U:D124@Q1247>L8@P8<H`06124000aS36<000aS0Q240QS60V]J1W>L0Vmk00Ag_Fmk
Kg]_N`AcW004MkekgVmkKg/2JeX4Li`2Nmh01V<HJeYkgW_NKg]W>@9_N`05Lia[FVLiIcUcW003Kg/0
16]JIcU_Nfmk0V]J0Vmk0W_N0WNm0G_N0Goo0004Ool3Nmh01WNmLiakgW_NLiakgP=g_@AcW004JeYg
_GNmMkd3Li`2Kg/3Li`00gNmLiacW005Li`00fmkLiacW002Li`2Kg/01W>LKg]cW7>LMkekgP8]J`88
@P800004:DX8@Q2448@21242@Q001QcW36<YBRU:7>M_N`IcW003Kg]cW6mk00=_N`9[FP06Kg]S66mk
Kg][FVLi0Vmk00IBU0@Q48@@Q1cW248236<01P@Q000<H`aS000<H`8@Q08HaP9[FPIcW09_N`04Mke_
NfmkKg/4Li`017NmNmi_Nfmk0V]J17>L0W_N00IS66]JNmikgVmkIcT2Kg/01G>LJeYW>FLiLi`00fmk
00A[FVLiKg]_N`9[FP9_N`9kgP9g_@5kgP5oo`0000Eoog_NNmioogNm009cW09g_@9cW003Mke_Nfmk
009_N`05NmicW7>LLiag_@02IcT016]JLia_Nfmk0W>L0WNm00=_Ng>LLi`00g>L0WNm00=_Ng>LLi`0
0W>L00Eg_G>LLiacW6mk009g_@9[FP8aS005248001S66<HLi`0300001QS6248aS36<;F/Q209S6004
?NmNmfmkKg/4Li`4Kg/017>LKg]_Nfmk0W>L0Vmk0V]J0V<H00I244Ha;F/]J`00124300001@aS5:DD
YAS600000PaS00D8@QS6LiacW7Nm00McW003MkecW7>L00IcW003Kg][FV]J009kgP9cW004Nmi_Nfmk
Kg/2Mkd3Kg/01GNmKg]_Nf<HLi`00V]J00=W>FmkKg/00Vmk00EW>FmkKg]_Nf]J009cW005Nmig_G_N
Nmig_@01Ool00003Nmig_GNm009kgP=g_@EcW09[FPEcW005MkeW>FLiKg]kgP03Li`01GNmNmikgV]J
Li`00WNm0W>L0WNm00=[FW>LLi`00W>L00Eg_G>LLiacW6mk00=cW004Kg]W>FLi48@324801Q242484
8@@Q5:DU:@8icP0636=:DQ2448@DYB480Sg_00=cW7_NKg/00Vmk1G>L0WNm0V]J0Vmk0V]J0V<H00Ha
S2DY000000@Q000212401PQ25:D@Q1246<H000848@0524848GooOomg_@05Li`2Kg/017_NMke_Nfmk
27>L00I_Ng>LLiacW7NmLi`2JeX01W>LNmi_NfmkLiag_@9W>@06JeYkgW_NNmi[FVmk0V]J00=W>F<H
Mkd00WNm00=S67>LLi`00W_N0Woo0G_N0Goo00000gooNmikgP02Ool3Mkd00g>LMkeg_@02Li`2Kg/0
0g>LKg]_N`02Kg/01GNmKg]_Ng>LMkd00g>L0gNm00=[FW>LLi`00g>L0W_N0Vmk0W>L00Ig_G>LLiac
W7NmJeX2Kg/01WNmLia[FV]J6<HDY@848@0648@8@P000008@P@Q0SF]00H8@T8@12448A24F]H2Li`2
Mkd3Kg/016<HKg]_NfLi0g>L00I246<HLiacW6]JKg/2F]H01VLi6<H8@PQ2124000<48@058@P<H`aS
48@8@P0236<00`@Q249g_@03Mkd2JeX017>LKg]_Nfmk0W_N0Vmk00I[FW>LKg]_Ng_NMkd2Li`2Kg/2
Li`01FmkLiag_GNmLi`016mk00Eg_F]JJeY_NgNm009kgP06Liag_FmkKg]NmfLi0W_N00Ag_FLiMkeg
_@EkgP5oo`0000=oog_NNmh00Woo0gNm00=cW7NmMkd00W>L0Vmk00=cW6mkKg/00Vmk00Eg_FmkKg]c
W7Nm00=cW0=g_@03JeYcW7>L00=cW09kgP9_N`9cW006MkecW7>LLiag_F]J0Vmk00Ig_G>LJeY[FQS6
5:D212401Q242480000024848@8e[@06249240@Q124@Q5[F0W>L0WNm0fmk00AS66mkKg]W>@=cW006
@Q1S67>LLia[FVmk0U[F00IW>AS62488@P@Q000312401B4836<<Ha2424800PaS00<48@Q2Mkd00gNm
0V]J00AcW6mkKg]_N`9kgP9_N`06JeYcW6mkKg]kgWNm0W>L0Vmk0W>L00E_Ng>LMkeg_G>L00A_N`05
Mke[FV]JKg]g_@02Nmh01W>LMke_NfmkG_MW>@9kgP04MkeW>GNmMkd5Nmh1Ool000Aoo`Qg_@A_N`=c
W006MkecW7>LLiag_G>L17Nm0W>L00Eg_G_NKg]_NgNm00=cW0AkgPEcW0=g_@06JeYcW7>LLi`aS000
0Q2400<<H`@Q24800PQ20`@Q00H8@PaS6<HHaQBULi`2Mkd01FmkJeYS66<HJeX00fLi00IcW4Ha36<<
Hg>LCW<2G_L01UJe?NlQ2248<H`8@P<0000524848@@Q0008@P0336<01AcW2488@QcWBU8017>L0gNm
00=cW7_NNmh00Vmk0WNm00EkgW>LMkeg_F]J00=_N`05MkecW7>LLiag_@07Kg/01G>LKg]_NfmkMkd0
0f]J00IcW6mkKg]_NgNmLi`3HaP016mkHaQS67Nm0g_N0GNm0Goo0003Nmh017ooMkekgW_N17Nm00Ak
gVLiJeY[FPA_N`9g_@AcW09g_@EcW003MkecW7>L00AcW006MkekgWNmMke_NgNm0g>L0g_N0Vmk0W>L
00H]J`@Q2488@P@Q000212401Q2436<8@PQ2124<H`848@06:DY_NfmkKg]S61240Re[00HDY@aS8@PQ
24ic248236<00e:D>LiF]@02E[D0100012448@aS0`Q200D000Q212448@0000<DY@060008@QS66<Hm
kf]J0gNm1G>L0WNm17>L00Ig_G>LNmikgVmkJeX2Kg/4Mkd01W_NJeY[FV]JMkecW09_N`9cW0=[FPM_
N`06JeY_NekgG_MJeV]J0V<H1G_N0Goo00001GooNmikgW_NOol00WNm00EcW7NmMkeg_Fmk00=g_@Ec
W003IcUcW7>L00EcW003MkecW7>L00IcW09g_@03Kg]cW7>L009cW004Kg]cW7>LLi`3Kg/017>LKg][
FV]J0QcW0P0000H48@aS2488@PaS7>L29BT01P002480000036=S609JeP0648@000Q2248001BU0PaS
00H@Q1BU6<HHaP@Q2482:DX01PaS9BTYBRU:48@00088@P067>L8@RDY9BT<H`000`@Q00DHaRU::DYJ
eW>L009_N`EcW005Kg]cW7>LMkecW004Kg/2IcT2Nmh2Mkd00f]JLia[FP02JeX3Mkd00f<HKg]_N`02
Kg/01F]JKg]_NfmkIcT016mk0V]J00=W>F]JKg/00Vmk00=W>G>LLi`01G_N0Goo00001GooNmikgW_N
Ool00WNm00EcW7NmMkeg_Fmk00=g_@EcW003IcUcW7>L00EcW003MkecW7>L00IcW09g_@03Kg]cW7>L
009cW004Kg]cW7>LLi`3Kg/017>LKg][FV]J0QcW0P0000H48@aS2488@PaS7>L29BT01P0024800000
36=S609JeP0648@000Q2248001BU0PaS00H@Q1BU6<HHaP@Q2482:DX01PaS9BTYBRU:48@00088@P06
7>L8@RDY9BT<H`000`@Q00DHaRU::DYJeW>L009_N`EcW005Kg]cW7>LMkecW004Kg/2IcT2Nmh2Mkd0
0f]JLia[FP02JeX3Mkd00f<HKg]_N`02Kg/01F]JKg]_NfmkIcT016mk0V]J00=W>F]JKg/00Vmk00=W
>G>LLi`01G_N0Goo000017ooNmikgW_N0gNm0W>L0WNm00AcW7_NMkeg_@EcW003JeYg_GNm009cW0=g
_@03Kg]cW7>L00EcW004Mke[FV]JMkd3Li`00fmkLiacW002Li`01FmkJeY[FW>LKg/00V]J00INmcg_
000000@Q48@2124224827>L01P00248DYABU0012408e[@88@P8@Q0@8@PP<H`065:DaS0@Q124<H`@Q
0PQ200D48@005:DDYA2400<00004248@Q0Q22482Kg/2JeX00fmkMkeg_@02Mkd4Li`01FmkLiacW6mk
Li`00Vmk00IcW7_NLiacW6mkJeX2Kg/01F]JKg]g_GNmJeX00fmk00I[FVLiNmikgWNmJeX2Kg/2IcT2
Li`00f]JKg]W>@03IcT2JeX5Nmh1Ool000=kgP03Oomg_GNm009g_@05Kg]cW7>LMke_N`02Li`01WNm
Lia_NfmkNmig_@9cW005Kg]cW6]JJeYS6003Mkd016mkLiag_GNm0W>L0WNm17>L00=_Ng>LLi`00g>L
0fmk00Eg_G>LLi`U:@@Q008@Q006248000aS36=240000Q2400H000Q2000000Q2124200001QcW36<4
8@@Q248HaP80000624848A2448@<H`Q20P@Q00<Q20aS00000P0000D8@P@Q12448A2400<0000548@H
aQS6000<H`025:D01V]JKg]g_GNmLia_N`=cW005Kg]cW7>LMkecW002JeX00g>LJeYcW003Li`6Kg/0
1GNmJeYS66<HMkd00fmk00IkgVmkIcUW>F<HLi`3Kg/00gNmHaQS6002IcT2Li`016]JIcU_Nfmk0WNm
0W_N0GNm0Goo00001GooNmikgW_NMkd00g>L00Ag_G>LLiacW0=_N`04MkecW6mkKg/2Mkd2Kg/2Mkd2
Li`01VmkMkekgW_NIcUcW09g_@9cW09kgP04JeYcW7NmMkd4Li`017NmLia_Nfmk17>L00He[A2448@@
Q0Q2000224801Ukg48@@Q12436<48@80000648@00000000HaQ240P0000<8@Q2400000P0000D<H`Q2
2488@QBU008<H`D8@P<48@88@P800006124@Q0aS36<48A240V<H00=_NekgMkd00WNm00EcW7NmMkec
W6mk009cW005MkecW7>LLiag_@03Kg/2Li`3Kg/01F]JLiacW6mkLi`00Vmk00I:DWNmJeY[FWNmLi`2
HaP00fLiLiacW002Li`01GNmKg]_NfLiHaP00WNm00A[FVLiLiacW0AkgP5g_@5oo`000goo1GNm00=c
W7NmMkd01W>L0WNm00I_Ng>LMkeg_FmkLi`3Nmh01FmkJeY[FWNmJeX00Vmk0W>L0Vmk00AkgWNmKg]_
N`9cW09_N`06Liag_G>LLia[FW>L0Vmk00A>LaBU00000088@P8aS00336<HaP000080000424848@@Q
000324801000124@Q1240P000PaS00HLi`0000000124124224801QBU00048@@Q48@8@P800005124D
YA2448@<H`0324801@aS48@@Q124Li`00fmk00EcW7_NLiacW7_N00=g_@05Lia_NgNmMkecW003Mkd0
16]JKg]_Nfmk0W>L1Vmk0V<H0f]J00EW>GNmMkekgV<H009_N`06IcUNmgNmMkecW6mk0U[F00A[FUkg
F]IJePAkgP5g_@5oo`000goo1GNm00=cW7NmMkd01W>L0WNm00I_Ng>LMkeg_FmkLi`3Nmh01FmkJeY[
FWNmJeX00Vmk0W>L0Vmk00AkgWNmKg]_N`9cW09_N`06Liag_G>LLia[FW>L0Vmk00A>LaBU00000088
@P8aS00336<HaP000080000424848@@Q000324801000124@Q1240P000PaS00HLi`00000001241242
24801QBU00048@@Q48@8@P800005124DYA2448@<H`0324801@aS48@@Q124Li`00fmk00EcW7_NLiac
W7_N00=g_@05Lia_NgNmMkecW003Mkd016]JKg]_Nfmk0W>L1Vmk0V<H0f]J00EW>GNmMkekgV<H009_
N`06IcUNmgNmMkecW6mk0U[F00A[FUkgF]IJePAkgP5g_@5oo`0000Eoog_NNmikgWNm009kgP05Mkec
W7_NNmig_@07Li`017NmLiag_GNm2G>L00A_NgNmMkeg_@=[FP06NmicW6mkKg]cW7_N0W>L00=_Ng_N
Kg/00Vmk0g>L00I[FPaS000000@Q0002<H`01ABU24848@@Q24800`@Q0PQ20QS600<<H`@Q24800PQ2
00D0048@@Q08@P@Q0088@P0348@000Q20088@P<0000648@8@P000008@Q240P@Q00H000@Q6<HHaPQ2
36<26<H016mkMkekgW_N0WNm0Vmk0WNm0g>L1gNm00=_Ng>LLi`00W>L00A_Ng_NNmikgPe_N`A[FP9c
W006Kg][FV<HHaQ[FV<H0UJe17_N0GNm0Goo0004Nmh00gNmNmikgP02Mkd3Nmh01FmkLiacW7_NLi`0
0Vmk00=g_G_NLi`00W>L00=g_G>LLi`01G>L0gNm00IcW6mkKg]_NgNmKg/2JeX01VmkNmicW7>LKg]g
_@=cW005MkekgW_NJeY6<@026<H00`aS0008@P0224801@@Q36<<HaS612400PQ200D<H`002488@PaS
00<8@P069BTicQ2448@8@P000P@Q00H000Q212448ABU000236<01Q2412400000248DY@<0000536<8
@PQ2000DY@02Mkd00e:DMkeg_@02Mkd01G>LMkeg_FmkLi`00WNm17>L00Eg_G>LNmikgV]J00AcW005
IcUg_GNmNmiS6002Li`01WNmKg]cW7>LMkekgP9W>@9_N`9cW003Kg][FVLi009W>@05Kg][FV]JJeYW
>@02G_L2Nmh2Ool1Nmh1Ool000AkgPEg_@=_N`05MkecW7>LJeYg_@02Nmh2Kg/2Mkd2Li`2Kg/01WNm
JeY_NfmkLia[FP9_N`IcW09_N`06Lia_NgNmMkecW6mk0W>L00A_Ng>LJeY[FP9g_@8aS003=Jd000@Q
00<48@<000051248@PQ21248@P027>L01PQ2124Q2248=JdLi`848@06248000@Q124<H`@Q10000PaS
0P000Q240P000QBU00H@Q0002488@QS68@P25:D2Li`2Kg/2Li`2Kg/2Li`6Kg/00gNmJeY_N`07Kg/2
IcT01V]JLia_NfmkIcU_N`=W>@05JeYg_GNmKg]W>@02JeX01VmkJeY[FV]JIcU[FP9_N`04IcU[FV]J
JeX5Nmh1Ool000AkgPEg_@=_N`05MkecW7>LJeYg_@02Nmh2Kg/2Mkd2Li`2Kg/01WNmJeY_NfmkLia[
FP9_N`IcW09_N`06Lia_NgNmMkecW6mk0W>L00A_Ng>LJeY[FP9g_@8aS003=Jd000@Q00<48@<00005
1248@PQ21248@P027>L01PQ2124Q2248=JdLi`848@06248000@Q124<H`@Q10000PaS0P000Q240P00
0QBU00H@Q0002488@QS68@P25:D2Li`2Kg/2Li`2Kg/2Li`6Kg/00gNmJeY_N`07Kg/2IcT01V]JLia_
NfmkIcU_N`=W>@05JeYg_GNmKg]W>@02JeX01VmkJeY[FV]JIcU[FP9_N`04IcU[FV]JJeX5Nmh1Ool0
00AkgP=g_@AcW005Kg]cW7>LLia_N`03Mkd2Kg/2Li`01F]JLiacW7>LNmh00fmk00=cW6mkMkd00WNm
00A_Ng>LLiag_@A_N`03Liag_GNm00U_N`04Li`DYABU7>L300001P@Q6<H0000024848@<000055:E>
Ldic0008@P02>Lh01@Q2000<H`aS24800`@Q00H8@P0012448A2436<21246000248@01PQ2000@Q124
5:D@Q09cW003MkecW7>L00=cW09_N`06Liag_G>LLia_Ng>L0fmk00A[FW>LLia_N`=cW003JeY_Nf]J
009[FP=g_@06JeY_Nf<HHaQNmfLi0W>L00I[FUkgJeY[FV<HF]H3Kg/01F]JIcUW>FLiG_L00V<H0W_N
0gNm0Goo0004Nmh3Mkd2Li`2Kg/5Li`3JeX00g_NLiacW003Li`2Kg/016]JNmicW7>L0WNm0fmk00=c
W7_NNmh00W>L0WNm1Vmk0V]J0W>L0Vmk0V]J0Vmk00@DYD8@@Q124080008@Q005124002488@PLi`03
00001QBU248aS36<:DX<H`<0000536<00000248<H`0224800`001240000200001@@Q000001242480
0P0000D8@Sg_6<HHaQBU00=cW004JeYcW6mkKg/2Li`2Mkd00f]JKg]_N`05Kg/00g>LIcU_N`07Kg/2
Li`00fmkJeY_N`02Kg/01F]JKg]_Ng>LMkd00VLi00IcW6]JJeY[FWNmLi`2IcT01V<HIcU[FV]JG_M_
N`9[FP03Liag_G_N009kgP5oo`0000Aoog_NNmikgPEg_@9cW003MkecW7>L00EcW004MkecW7NmMkd5
Li`01GNmNmikgW>LNmh00Vmk00I[FWNmNmikgW>LMkd2Nmh01V]JLiag_GNmNmicW09g_@A_N`06Liag
_F]JJeY244YB0RDY00H48@aS2488@P0012426<H01@aS0000000048@00`0000<DY@Q200000P0000@4
8@000008@P<48@D000041248@PQ2000336<00a24HaQcW003Li`2Mkd00f]JLia_N`03Kg/2Li`2JeX2
Li`01WNmKg]cW7>LNmi[FP9_N`9cW09[FP05Liag_FmkKg]cW00=Kg/2JeX01GNmKg]NmekgHaP00f]J
00ANmgNmKg]_N`9g_@=kgP5oo`0000Aoog_NNmikgPEg_@9cW003MkecW7>L00EcW004MkecW7NmMkd5
Li`01GNmNmikgW>LNmh00Vmk00I[FWNmNmikgW>LMkd2Nmh01V]JLiag_GNmNmicW09g_@A_N`06Liag
_F]JJeY244YB0RDY00H48@aS2488@P0012426<H01@aS0000000048@00`0000<DY@Q200000P0000@4
8@000008@P<48@D000041248@PQ2000336<00a24HaQcW003Li`2Mkd00f]JLia_N`03Kg/2Li`2JeX2
Li`01WNmKg]cW7>LNmi[FP9_N`9cW09[FP05Liag_FmkKg]cW00=Kg/2JeX01GNmKg]NmekgHaP00f]J
00ANmgNmKg]_N`9g_@=kgP5oo`000goo00=kgWNmMkd00WNm00=cW7NmMkd03G>L17Nm00=cW6mkKg/0
0W>L0g_N00A_Nf]JJeYkgP=cW09g_@9_N`05JeYcW7>LLia_N`05Li`2Kg/01VLi:DX<H`aS248<H`88
@P0636<e[@Q2248001240QS600@<Ha2412448@80008<H`0348@000@Q00848@05000@Q12436<00003
124300001@@Q5:D0000012400g>L0Vmk0W>L0Vmk0W>L00Ig_G>LKg]_Ng_NMkd3Li`01GNmKg]_Nf]J
Nmh00WNm00I[FVmkKg]_Ng>LKg/3Li`00fmkLiacW002Kg/2JeX00fLiKg]_N`02Kg/01FLiLiacW5kg
IcT00WNm00I_Nf<HJeY[FVmkE[D2G_L5Nmh1Ool00005NmioogooOomkgP02Ool016mkLiakgW_N0WNm
0W>L00EkgW>LLiacW7Nm00ecW0=g_@03Lia_Nfmk009cW09_N`9g_@=[FP03MkecW7>L009g_@9kgP06
JeYcW7>LLia_NdHa0SF]00HYBR48=Jde[@@Q248212401P005:DDYABU7>L8@P@000<<H`03248@Q124
0080008@Q0035:D000@Q00848@<0000636<HaPaS36<@Q6mk0g>L00A_Ng>LLia_N`EcW09_N`UcW005
Nmig_GNmJeY_N`02Nmh2Kg/2Mkd00g>LKg]_N`02Kg/016LiJeY[FWNm0fmk1V]J0g>L0fLi00A_Nekg
G_MNm`EkgP5oo`000goo00AkgWNmKg]_N`9g_@9_N`9cW0=[FP04Nmig_GNmJeX4Li`00gNmLiacW004
Li`2Mkd2Li`017NmNmikgW_N17Nm0W>L0W_N00Ag_G>LNmikgP9cW09_N`9kgP9g_@06Lia[FUJeE[E_
Nf]J0QcW00H<H`Q22488@PaS248312401ABU000001BU48@01P0000<<HaS600000P0000D<H`000000
0248008@Q080008HaP06AS5[FW>LLiakgV]J2W>L0Vmk0WNm00IcW6mkMkeg_G_NJeX2Li`01WNmLia[
FV]JLiakgP9[FP04Kg]cW7>LLi`2Kg/3IcT01FmkJeY[FVmkJeX00Vmk00E[FVLiF]IJeV<H00=W>@04
G_M_NfmkKg/4Nmh1Li`1Ool000=oo`04Nmig_FmkKg/2Mkd2Kg/2Li`3JeX017_NMkeg_F]J17>L00=g
_G>LLi`017>L0WNm0W>L00Ag_G_NNmikgPAg_@9cW09kgP04MkecW7_NNmh2Li`2Kg/2Nmh2Mkd01W>L
JeYF]EJeKg][FP8Li`0636<8@PQ2248<H`Q20`@Q00DDY@00000DYA2400H0000336<HaP0000800005
36<00000000Q200248@200026<H01THaJeYcW7>LNmi[FPYcW09_N`9g_@06Lia_NgNmMkekgV]J0W>L
00Ig_G>LJeY[FW>LNmh2JeX016mkLiacW7>L0Vmk0fLi00E_Nf]JJeY_Nf]J009_N`05JeYW>E[FF]IS
6003IcT015kgKg]_Nfmk17_N0G>L0Goo00001GooNmikgW_NMkd00W>L0WNm0W>L00I_Ng>LKg]_Ng>L
Nmh2Li`01VmkLia_NfmkIcUg_@9cW005Mke_Ng>LLia[FP03Li`00fmkLiacW002Li`00fmkLiacW002
Li`2Kg/01WNmLiag_GNmLia_N`9[FP9g_@9_N`04Mke_NfLiIcT2Li`248@01Re[7>L00000124<H`H8
@P0400048A2448@21242248248@212401P0036<48@@Q248@Q08HaP80008]J`03>Lig_GNm009g_@=[
FP05Lia_Ng>LLiakgP03Kg/01W>LKg]_NfmkLia_N`=cW0E_N`9[FP06Kg]g_F]JJeY_NgNm0fmk00Ec
W5kgG_M[FVmk00A[FP9cW09W>@9[FPAW>@9S609[FPEkgP5oo`0000AkgWooOomkgP=g_@04Kg]cW7Nm
Mkd2Li`3Kg/3Li`4Kg/01V]JMkekgW_NKg][FP=cW004Kg]g_GNmMkd3Kg/4Li`4Mkd5Li`00f]JKg]_
N`02Kg/2JeX017_NKg]W>FLi0W>L0RDY00HHaPaS000000@Q5:D236<22484000236<01P00124DYABU
00048@8<H`041248@QBU5:D436<01P009BTe[CF]HaQcW09kgP04Mke_Nf]JJeX2Kg/2Li`01GNmKg]_
NfmkMkd01G>L0fmk00=cW6mkKg/01Fmk00=cW6mkKg/01Fmk00EcW6<HHaQW>F]J009_N`06JeY_Ng>L
LiaS65kg0Vmk00=W>EkgKg/00Vmk00EBU6LiIcUkgWNm00=kgP5oo`0000AkgWooOomkgP=g_@03Lia_
Ng>L00=cW09g_@06Lia_Ng>LLiag_G>L0WNm00=cW6mkJeX00V]J00=g_FmkKg/00W_N0V]J00E_Ng>L
Mkeg_G>L00=g_@AcW09_N`9cW09_N`9g_@06Lia_NfmkKg][FW>L0WNm00I_Nf]JDYABU0aS00022480
1QS60008@PQ200048@8<H`035:D<H`0000D000045:DHaP@Q124236<212401Q24249S66<HF]I_N`9c
W0A_N`03HaQcW7>L009cW005Mke_NfmkJeYcW002Mkd2Kg/3Li`01FmkLiacW7NmLi`00Vmk00=cW6mk
Kg/00Vmk00=[FVmkKg/00V]J0W>L00=_NfLiLi`00W>L0fLi00I_NfLiF]IJeW>LJeX2F]H2IcT2G_L0
1U[FKg]W>FLiNmig_@9kgP5g_@5oo`0000AkgWooOomkgP=g_@03Lia_Ng>L00=cW09g_@06Lia_Ng>L
Liag_G>L0WNm00=cW6mkJeX00V]J00=g_FmkKg/00W_N0V]J00E_Ng>LMkeg_G>L00=g_@AcW09_N`9c
W09_N`9g_@06Lia_NfmkKg][FW>L0WNm00I_Nf]JDYABU0aS000224801QS60008@PQ200048@8<H`03
5:D<H`0000D000045:DHaP@Q124236<212401Q24249S66<HF]I_N`9cW0A_N`03HaQcW7>L009cW005
Mke_NfmkJeYcW002Mkd2Kg/3Li`01FmkLiacW7NmLi`00Vmk00=cW6mkKg/00Vmk00=[FVmkKg/00V]J
0W>L00=_NfLiLi`00W>L0fLi00I_NfLiF]IJeW>LJeX2F]H2IcT2G_L01U[FKg]W>FLiNmig_@9kgP5g
_@5oo`0017_N00Eg_G>LLiakgWNm009cW003Kg]cW7>L00McW09_N`9cW09_N`06Liag_G>LLiag_G_N
0Vmk00A[FW_NNmikgP9g_@9kgP04Kg][FW_NNmh2Li`2Mkd4Kg/5Li`4Kg/01G>LJeY[FU[F24800SF]
00HicPQ248@@Q0@Q000336<00a240000000400000acW9BT0000200001@aS00000000@Q000V<H0W>L
0Vmk00I[FVmkLiacW6mkLi`2Mkd2Li`2Kg/01V]JMkeg_GNmIcUcW09g_@03LiaW>G_N009kgP05IcU_
NfmkMke_N`02JeX01G>LMke_NfmkMkd016mk00=[FVmkKg/00Vmk0V]J00IcW6LiHaQS67>LJeX2HaP0
1VLiLiaJeU[FDYA[FP9S6005Nmig_G_NNmig_@01Ool000=oo`04Nmioog_NNmh2Li`2Mkd6Li`2Kg/2
Li`2Kg/8Li`01V]JKg]g_GNmLia_N`=cW003Kg][FV]J009g_@9_N`9cW09_N`06Nmig_G>LLia_NgNm
0g>L00=g_G>LLi`017>L0Vmk0V]J00=:DPQ212400P@Q1@000QS600HDYAS636<<H`007>L2DY@21242
5:D012U:F]I[FV]J17>L00A_Ng>LKg]_N`EcW005Kg]cW7>LMke[FP02Kg/017_NKg]_Nfmk0WNm0VLi
00I_Ng_NKg]_Ng>LMkd2Kg/016]JKg]cW7>L16mk00A[FVmkIcUW>@I[FP9cW006HaQW>FmkKg]S64ic
0fmk00=JeV]JJeX01G_N0Goo0004Nmh017ooNmikgW>L17Nm00AkgWNmMkeg_@=cW004MkecW7NmMkd=
Li`01FmkLiacW7>LKg/00W>L0WNm0Vmk0W>L0Vmk17_N00E_Ng>LKg]_Ng>L00=g_@9cW0=_N`05JeYc
W7>LIcTe[@0224801PaS1248@PQ2000e[@9S6006JeYW>DYBBU80036<0Vmk00IF]@aS5:DDYE[FG_L2
Kg/017NmLiag_GNm0W>L0V]J00IcW7NmMkeg_FmkLi`2Kg/6Li`2Kg/01W>LMkecW7>LJeYkgP=_N`05
MkekgW_NJeY_N`02Mkd01VLiKg]g_GNmJeYS609[FP03Kg][FW>L009cW003IcU[FV]J00AW>@06HaQJ
eVLiIcU_Ne[F0V]J1G_N0Goo0004Nmh017ooNmikgW>L17Nm00AkgWNmMkeg_@=cW004MkecW7NmMkd=
Li`01FmkLiacW7>LKg/00W>L0WNm0Vmk0W>L0Vmk17_N00E_Ng>LKg]_Ng>L00=g_@9cW0=_N`05JeYc
W7>LIcTe[@0224801PaS1248@PQ2000e[@9S6006JeYW>DYBBU80036<0Vmk00IF]@aS5:DDYE[FG_L2
Kg/017NmLiag_GNm0W>L0V]J00IcW7NmMkeg_FmkLi`2Kg/6Li`2Kg/01W>LMkecW7>LJeYkgP=_N`05
MkekgW_NJeY_N`02Mkd01VLiKg]g_GNmJeYS609[FP03Kg][FW>L009cW003IcU[FV]J00AW>@06HaQJ
eVLiIcU_Ne[F0V]J1G_N0Goo0003Ool017_NMkecW7>L1GNm0f]J0W>L0WNm00=cW7NmKg/00Vmk27>L
00=_Ng>LLi`017>L17Nm0Vmk0W_N00Ig_G>LNmikgV]JKg/4Li`2Mkd01W_NLia_NfmkMkecW0=g_@05
Lia[FV]JKg]g_@02IcT013W>BU9BU5:D16mk00IcW6]JIcUW>G>LG_L2JeX01FLiHaQF]EJeIcT00gNm
00I[FW>LKg]_Nf]JMkd3Nmh01F]JLiacW6]JKg/017>L0V]J0Vmk0W>L00I_NfLiLiacW7_NLi`2Mkd0
1W>LJeYW>FLiMkekgP9_N`04Mke[FV]JJeX2Li`2Kg/00f]JKg]S6002HaP01F]JKg]_Nf]JIcT00f<H
00EW>EkgG_MBU5kg009S60EkgP5oo`0000Aoog_NNmioo`Eg_@9cW006MkecW6mkKg]cW7Nm0g>L00Ek
gW>LLia_Ng_N00AcW09kgP9W>@9_N`04MkecW6mkKg/2Li`4Kg/3Li`01GNmLiacW6LiJeX00W>L00Ig
_FmkMkeg_G_NKg/2Li`01W_NLiacW7>LMkekgP=_N`=cW005Kg]g_FLiIcU[FP07Kg/017>LKg][FV]J
1Fmk00=cW7NmMkd00Vmk0f]J00Ag_G_NNmig_@=_N`9[FP=g_@05IcU[FV]JLia_N`02JeX00g>LKg]_
N`02Kg/00f]JLiacW002Kg/2HaP2Li`2JeX01WNmKg]W>FLiLiag_@9S6006JeYcW6]JJeYNmfmk0W>L
00A[FVLiHaQS609JeP=W>@05F]I[FV]JNmig_@03Nmh1Ool00005Nmig_GNmOomkgP04Mkd2Li`017Nm
Nmig_GNm17>L00=g_FmkNmh00W_N00=[FW>LLi`00W>L0V]J0WNm0g>L00A_Ng>LLiacW0=g_@04Kg]c
W7>LLi`2Kg/3Li`01G_NLiacW6mkMkd00V]J00I_NgNmLiacW6mkLi`2JeX00fLiKg]cW003Li`2Kg/0
16]JIcUcW7>L16mk00AcW6mkLiacW0Q_N`06Lia_NfmkKg]g_G>L0Vmk00IkgVmkIcUW>FmkLi`2Kg/0
1W>LMke[FV]JHaQkgP9cW006Kg]g_G>LLia[FVLi0W>L00Ig_FmkLiacW6mkJeX4Kg/2Li`01UkgKg][
FV]JIcUF]@9_N`06JeYJeVmkKg]cW5:D0UJe00A[FU[FIcUW>@9[FP9>L`06E[EJeUkgG_MkgWNm0g_N
0Goo00001G_NMkeg_GooNmh017Nm0W>L00Ag_G_NMkeg_@AcW003Mke_Ng_N009kgP03JeYcW7>L009c
W09[FP9g_@=cW004Kg]cW7>LLi`3Mkd016mkLiacW7>L0Vmk0g>L00EkgW>LLia_NgNm009[FP06Kg]g
_G>LLia_Ng>L0V]J00=W>FmkLi`00g>L0Vmk00A[FVLiLiacW0A_N`04Lia_Ng>LLi`8Kg/01W>LKg]_
NfmkMkecW09_N`06Nmi_NfLiIcU_Ng>L0Vmk00IcW7NmJeY[FV<HNmh2Li`01VmkMkecW7>LJeYW>@9c
W006Mke_Ng>LLia_Nf]J16mk0W>L00INmfmkJeY[FVLiE[D2Kg/01V]JF]I_NfmkLiaBU09F]@04JeYJ
eVLiIcT2JeX2CW<01UJeF]INmekgNmig_@=kgP5oo`0017_N17Nm2g>L00=g_G>LMkd00WNm0f]J00Ig
_G>LKg]_Ng_NMkd2Kg/4Li`01GNmKg]cW7>LKg/017>L00E_Ng>LLiaW>G>L009_N`9cW09[FP06Kg]c
W7>LLia[FW>L0Vmk00AW>FmkLiacW09_N`9g_@05IcU[FWNmMkecW003Kg/01W>LIcUW>FLiLiag_@9[
FP9_N`9W>@04Kg]cW6mkKg/2JeX7Kg/3Li`01VmkLia_NfmkIcUg_@9cW006Kg]cW7_NNmiS66]J0W_N
00IcW6mkLiacW6]JIcT2JeX2Kg/3JeX3Kg/2F]H3JeX01E[FJeY[FVmkDY@00UJe00A_Ne:DIcUW>@9_
N`9:DP04DYANme:DDY@5Nmh1Ool000=kgP03OomcW7Nm00Eg_@06Nmi_NfmkKg]cW7Nm0W>L0WNm27>L
0Vmk0W>L0Vmk00Eg_G>LKg]_Ngoo00QcW005Oomg_GNmJeY_N`02Li`01WNmLiacW7>LMkecW0=_N`03
Lia_Nfmk009_N`9cW09_N`9cW003IcU_Nfmk00E_N`06Lia_NfmkKg]g_G>L0V]J00=_Nf]JJeX00V]J
00Eg_FmkKg]_Ng>L00=W>@05Kg]cW7>LKg][FP04Kg/2IcT6Kg/2Li`00fLiJeYg_@02Mkd01G>LMkeg
_F]JIcT00Ukg0W>L0V]J00AcW6LiJeY[FP9_N`9W>@06JeYNmf<HHaQW>EJe15kg16<H0dic00EF]E:D
DYAkgWNm00=kgP5oo`001G_N1WNm00E_Ng_NLiacW6mk00UcW0A_N`=cW005Kg]cW7>LLia_N`02Li`0
16mkLiacW7>L0Vmk0W>L00Ig_F]JJeY[FW>LMkd4Li`3Kg/00gNmLiacW002Li`2Kg/:Li`2JeX01Vmk
LiacW7>LJeYg_@9cW003JeYcW7>L009cW004Nmig_GNmNmh3Kg/2Li`2Mkd017>LKg]_Nfmk0W>L0fmk
00=cW6mkKg/01Fmk0f]J00Ig_G>LG_MNmf]JKg/2JeX4Mkd01V]JF]IW>FLiHaQ_N`9cW006IcUS66]J
JeYS65[F0V]J16<H0VLi0V<H00IBU5[FJeY[FU[FDY@2JeX01G>LNmig_GNmNmh00Goo0005Nmh6Mkd0
1FmkNmicW7>LKg/02G>L16mk0g>L00E_Ng>LLiacW6mk009cW004Kg]cW7>LLi`2Kg/2Li`01WNmJeY[
FV]JLiag_@AcW0=_N`03MkecW7>L009cW09_N`YcW09[FP06Kg]cW7>LLia[FWNm0W>L00=[FW>LLi`0
0W>L00AkgWNmMkekgP=_N`9cW09g_@04Lia_NfmkKg/2Li`3Kg/00g>LKg]_N`05Kg/3JeX01WNmLiaN
mekgJeY_N`9[FPAg_@06JeYJeVLiIcUS66mk0W>L00IW>F<HJeY[FV<HF]H2JeX4HaP2IcT2HaP01U:D
F]I[FV]JF]IBU09[FP05LiakgWNmMkekgP01Ool000Aoo`Mg_@04LiakgW_NNmh2Li`2Nmh01WNmKg]k
gW_NLiag_@9cW004Mke[FVmkKg/2Li`2JeX2Li`2JeX00gNmLia_N`03Kg/2Li`017NmLia_Nfmk0W>L
0Vmk00IcW7NmJeY[FVmkMkd2Li`00fmkMke[FP02JeX00g>LKg]_N`06Li`2Mkd2Kg/3Li`00gNmLiac
W006Li`3Mkd01FmkLiacW7>LKg/00gNm00E_Nf]JJeYcW7Nm00=cW004MkeW>FLiKg/4Li`016mkLiac
W7>L1fmk17>L00=S66LiIcT00VLi00EcW7NmMkeS65kg009cW006HaQJeVmkKg]cW5Je0Ukg0V<H0VLi
0Ukg0U[F00ANmeJeIcUW>@9kgP9g_@5kgP5oo`0017_N17Nm00AcW7NmMkekgP=_N`06NmicW6mkKg]g
_G_N0g>L00EkgVmkKg][FW>L009_N`IcW09_N`05MkecW7>LLia_N`03Mkd01W>LMkecW7>LKg]cW09g
_@06LiaW>GNmMkecW6]J0W>L00Ig_G>LNmikgWNmLi`2Kg/4Li`017NmLia_Nfmk1G>L00A_Ng>LLia_
N`AcW005JeY_NfmkLiag_@02Li`01VmkNmiW>FLiKg]kgP9g_@06Lia_NgNmMkeW>Fmk0g>L0fmk00Ec
W6mkJeY[FW>L00=_N`9cW09g_@06IcU[FV]JJeYg_G>L0gNm0fLi0W>L0f]J00EcW5:DDYAJeV]J009N
m`04HaQ[FU[FF]H4DY@015JeCW=S66<H1G_N0Goo000017ooNmikgW_N1GNm0W>L00=g_G>LLi`01G>L
0W_N0g>L00Ag_G>LLia[FP=kgP03Kg]g_G>L00=cW09g_@9_N`=g_@03Liag_GNm00AcW003Kg]cW7Nm
00Eg_@03Lia[FWNm009g_@05LiakgW_NNmicW002JeX017NmLia[FV]J0WNm0V]J0W>L0fmk00=g_Fmk
Kg/01G>L00Ag_FmkKg]_N`McW004JeYg_G>LLi`2Kg/2Mkd00fLiJeYg_@02Mkd01F]JKg]_Nf]JIcT0
0V]J0WNm0VLi00E_NfLiIcUW>G>L00E_N`9[FP06Kg][FV<HHaQ[FW>L0VLi00=_Ng>LE[D00UJe00E_
Nf]JJeYNmf]J009JeP06BU9>Lf]JJeYNmeJe0W>L00EkgWNmMkeg_G_N005oo`0000Aoog_NNmikgPEg
_@9cW003MkecW7>L00EcW09kgP=cW004MkecW7>LJeX3Nmh00fmkMkecW003Li`2Mkd2Kg/3Mkd00g>L
Mkeg_@04Li`00fmkLiag_@05Mkd00g>LJeYg_@02Mkd01G>LNmikgW_NLi`00V]J00Ag_G>LJeY[FP9g
_@9[FP9cW0=_N`03Mke_Nfmk00EcW004Mke_NfmkKg/7Li`016]JMkecW7>L0Vmk0WNm00=W>F]JMkd0
0WNm00E[FVmkKg][FVLi009[FP9g_@9W>@05Kg]W>FLiIcUcW005Kg/2JeX01VmkJeYS66<HJeYcW09W
>@03Kg]cW5Je009F]@05Kg][FV]JG_M[FP02F]H01TYBCW=[FV]JG_MF]@9cW005Nmig_GNmMkekgP01
Ool000EkgPAg_@AcW09_N`Ag_@04Lia[FW_NNmh4Mkd4Li`2Mkd2Li`01G_NLiacW7>LNmh017>L00Ag
_G>LLiacW0=g_@03Liag_G>L00=cW09_N`9g_@=cW003MkecW7>L00EcW005MkekgW_NKg]cW002Mkd0
1W>LKg]kgW_NMke_N`9g_@03Liag_G>L009cW003Kg]cW7>L00EcW003Kg]cW7>L00AcW006MkecW6Li
IcUkgW>L0VLi00EcW7_NLiacW7_N00=g_@03JeY_Ng>L009cW005Kg]cW7>LKg][FP02Kg/00e:DIcU[
FP05JeX01UkgHaQW>FLiE[EJeP=_N`05CW=S66<HE[E:DP02HaP01VLiHaQ6<DHaE[E>L`9JeP9kgP9o
o`5kgP5oo`0000AkgWooOomoo`AkgP05Liag_GNmOom_N`02Nmh2Mkd2Li`00gNmOomg_@02Mkd01Goo
Mkeg_GNmNmh00Woo00Eg_G_NMkeg_G_N00=g_@06Oomg_GNmMkecW7Nm0W_N00I_NgooNmikgVmkNmh2
Ool017NmLiakgW_N37Nm00EkgWNmLiacW6]J00=cW09_N`9g_@03Oom[FWNm00=g_@9cW004Mke[FVmk
Kg/5Li`00gNmLiacW006Li`2Kg/2Mkd3JeX017NmLiacW7>L0g_N00IW>F]JNmikgVmkMkd2Nmh00f]J
HaQ[FP02JeX01FmkLiacW7>LHaP00Vmk0V]J0fLi00AS66mkKg]S60AJeP05CW=[FV]JF]IW>@02AS44
E[D5Nmh1Ool000AkgP=oo`9kgP9oo`QkgP03OomkgW_N009kgP03OomkgW_N00IkgP9oo`03Nmioogoo
00=oo`=kgPEoo`=kgP=oo`05Nmioog_NNmioo`03Nmh4Ool4Nmh00gooNmikgP0FNmh00gooNmikgP05
Nmh3Ool9Nmh01GooNmikgW_NOol01W_N00Eoog_NNmikgWoo00AkgP04OomkgW_NOolCNmh2Mkd8Nmh2
Ool1Mkd1Ool000AkgP=oo`9kgP9oo`QkgP03OomkgW_N009kgP03OomkgW_N00IkgP9oo`03Nmioogoo
00=oo`=kgPEoo`=kgP=oo`05Nmioog_NNmioo`03Nmh4Ool4Nmh00gooNmikgP0FNmh00gooNmikgP05
Nmh3Ool9Nmh01GooNmikgW_NOol01W_N00Eoog_NNmikgWoo00AkgP04OomkgW_NOolCNmh2Mkd8Nmh2
Ool1Mkd1Ool000=kgP9oo`9kgP03OomkgW_N00=kgP9g_@05Nmioog_NNmioo`04Nmh3Ool00g_NOomk
gP03Nmh3Ool017_NOomoogoo1G_N1Woo00AkgWooNmikgP9oo`9kgP9oo`9kgP9oo`9kgP05OomkgW_N
Nmioo`0ANmh2Ool=Nmh01GooNmikgWooNmh00goo17_N0goo00=kgWooOol00Woo0g_N00Ioog_NNmik
gWooNmh2Ool00g_NOomoo`05Ool>Nmh2Mkd=Nmh1Ool00001\
\>"],
  ImageRangeCache->{{{136.5, 308.5}, {228.5, 57.875}} -> {-0.793933, 
  0.336563, 0.00581543, 0.00581543}}]
}, Closed]],

Cell[CellGroupData[{

Cell["SIGNAL DECOMPOSITION", "Section"],

Cell["\<\
The complex Fourier series is a representation of a periodic signal in terms \
of linear combinations of harmonically related complex exponentials:\
\>", "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm
      \`x(t)\  = \ 
        \[Sum]\+\(k = \(-\[Infinity]\)\)\%\[Infinity] c\_k\ \ 
            \[ExponentialE]\^\(\ \ j\ \(\(2  \[Pi]\)\/T\) k\ t\)\)]],
  "\t\t(* synthesis formula *)"
}], "NumberedEquation"],

Cell[TextData[{
  "where T is the period of the signal ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\)]],
  ". The quantity ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(\(2  \[Pi]\)\/T = \ \(2  \[Pi]\ f\_T\  = \[Omega]\_T\)\ \)\)]],
  " is called the fundamental frequency (in radians/sec). All other complex \
exponentialss have frequencies that are integer multiples of the fundamental. \
The generally complex coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`c\_k\)]],
  " are known as the Fourier series coefficients of the signal ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\)]],
  ". Equation (1) is called the synthesis equation, since given a set of FS \
coefficients (possibly infinite) it provides a formula for \"synthesizing\" \
the continuous time signal ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\)]],
  ". Immediately, two important questions arise:\n(1) What kind of signals \
posses a FS expansion?\n(2) How to obtain the FS coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`c\_k\)]],
  "?\nYou will be asked to consider the first of the questions in a homework \
problem. Here we turn to the second of these questions. The \"inverse\" \
relationship between a continuous-time signal and its FS coefficients is not \
very difficult to derive and the specifics can be found in most introductory \
texts on the subject [Oppenheim, pp. 190-191]. Here we simply state the \
analysis formula:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm
      \`c\_k = \ 
        \(1\/T\) 
          \(\[Integral]\_\(-\(T\/2\)\)\%\(T\/2\)\ 
            \(x(t)\)\ \ 
              \(\[ExponentialE]\^\(\(-\ j\) 2 \( \[Pi]\ \)\/T\ k\ t\)\) 
              \[DifferentialD]t\)\)]],
  "\t\t\t(* analysis formula *)"
}], "NumberedEquation"],

Cell["\<\
Equations (1) and (2) define the so-called complex Fourier series \
formulation. Other related formulations found in the literature are the \
trigonometric series formulation and the cosine series formulation [Kreyszig, \
1972].\
\>", "Text"],

Cell[CellGroupData[{

Cell["Problem 1.", "Exercise"],

Cell[TextData[{
  "Using Euler's identity, ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[ExponentialE]\^\(\ \[ImaginaryI]\ \[Theta]\)\  = \ \ 
        cos(\[Theta])\  + \ \[ImaginaryI]\ \(sin(\[Theta])\)\)]],
  ", rewrite (1) in terms of sine and cosine functions."
}], "ExerciseText"]
}, Open  ]],

Cell[TextData[{
  "We now turn our attention to the problem of evaluating (1) given a \
specific periodic signal. Assume signal ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\)]],
  " is a pulse train, with a period ",
  Cell[BoxData[
      \(TraditionalForm\`T = 1\)]],
  ", and pulse width  \[Tau]= ",
  Cell[BoxData[
      \(TraditionalForm\`T\/4\)]],
  ", centered on ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  "."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0 0.412023 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.4875 .0824 -18 -4.5 ]
[.4875 .0824 0 4.5 ]
[.4875 .16481 -18 -4.5 ]
[.4875 .16481 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .32962 -18 -4.5 ]
[.4875 .32962 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .57683 -18 -4.5 ]
[.4875 .57683 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12.875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 0 m
.02381 .00625 L
s
[(-2)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-1)] .2619 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .0824 m
.50625 .0824 L
s
[(0.2)] .4875 .0824 1 0 Mshowa
.5 .16481 m
.50625 .16481 L
s
[(0.4)] .4875 .16481 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.6)] .4875 .24721 1 0 Mshowa
.5 .32962 m
.50625 .32962 L
s
[(0.8)] .4875 .32962 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1.2)] .4875 .49443 1 0 Mshowa
.5 .57683 m
.50625 .57683 L
s
[(1.4)] .4875 .57683 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .10301 m
.50375 .10301 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .51503 m
.50375 .51503 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.875000 moveto
 460.000000 16.875000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.875000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Periodic) show
113.625000 13.000000 moveto
(pulse) show
146.250000 13.000000 moveto
(train) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.006 w
.02381 .41202 m
.04262 .41202 L
.06244 .41202 L
.07216 .41202 L
.0775 .41202 L
.08013 .41202 L
.08128 .41202 L
.08255 .41202 L
.08327 .41202 L
.08394 0 L
.08465 0 L
.08542 0 L
.08852 0 L
.09396 0 L
.10458 0 L
.1458 0 L
.1664 0 L
.17642 0 L
.18551 0 L
.19009 0 L
.19503 0 L
.1973 0 L
.1997 0 L
.20069 0 L
.20175 0 L
.20291 .41202 L
.204 .41202 L
.22371 .41202 L
.26507 .41202 L
.28576 .41202 L
.29487 .41202 L
.30491 .41202 L
.30953 .41202 L
.3145 .41202 L
.31678 .41202 L
.31919 .41202 L
.32019 .41202 L
.32125 .41202 L
.32241 0 L
.3235 0 L
.34324 0 L
.38474 0 L
.40554 0 L
.41467 0 L
.42472 0 L
.42938 0 L
.43437 0 L
.4368 0 L
.43799 0 L
.43909 0 L
Mistroke
.44009 0 L
.44116 .41202 L
.44234 .41202 L
.44341 .41202 L
.46319 .41202 L
.50331 .41202 L
.52172 .41202 L
.53217 .41202 L
.54191 .41202 L
.55156 .41202 L
.55434 .41202 L
.55696 .41202 L
.55811 .41202 L
.55932 .41202 L
.55996 0 L
.56066 0 L
.56189 0 L
.58296 0 L
.62322 0 L
.64173 0 L
.65222 0 L
.66196 0 L
.67167 0 L
.67447 0 L
.67584 0 L
.67711 0 L
.67826 0 L
.67948 .41202 L
.6807 .41202 L
.68204 .41202 L
.70315 .41202 L
.74354 .41202 L
.76216 .41202 L
.78242 .41202 L
.78776 .41202 L
.79069 .41202 L
.79344 .41202 L
.79577 .41202 L
.79708 .41202 L
.79828 0 L
.79953 0 L
.80089 0 L
.80364 0 L
.82375 0 L
.86428 0 L
.88299 0 L
.90329 0 L
.90867 0 L
.91162 0 L
.91306 0 L
Mistroke
.91438 0 L
.91558 0 L
.91673 .41202 L
.91793 .41202 L
.91925 .41202 L
.92461 .41202 L
.94476 .41202 L
.97619 .41202 L
Mfstroke
.5 Mabswid
[ .05 .05 ] 0 setdash
.02381 0 m
.06244 0 L
.10458 0 L
.14415 0 L
.18221 0 L
.22272 0 L
.26171 0 L
.30316 0 L
.34309 0 L
.3815 0 L
.42237 0 L
.46172 0 L
.49955 0 L
.53984 0 L
.57861 0 L
.61984 0 L
.65954 0 L
.69774 0 L
.73838 0 L
.77751 0 L
.81909 0 L
.85916 0 L
.89771 0 L
.93871 0 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "NumberedFigure",
  ImageSize->{216, 133.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003H0000QA000`40O003h00Of7oo000KOol3000U
Ool5001:Ool5000UOol3000IOol001]oo`03001oogoo02Moo`03001oogoo04aoo`03001oogoo02Eo
o`03001oogoo01Uoo`005Woo0`000goo00<007ooOol087oo0`000goo00<007ooOol0C7oo00<007oo
Ool09Woo00<007ooOol067oo000LOol00`00Oomoo`0VOol00`00Oomoo`1<Ool00`00Oomoo`0VOol0
0`00Oomoo`0HOol001]oo`03001oo`0002Moo`03001oogoo04aoo`03001oogoo02Eoo`03001oo`00
01Uoo`0077oo00<007ooOol09Goo0P00CGoo0P00:7oo00<007ooOol067oo003HOol00=Qoo`00f7oo
003HOol001Ioojd001Eoo`006Woo00<007ooOol01Goo00<007oo00001Goo00<007ooOol01Woo00<0
07ooOol00goo00<007oo00001goo00<007ooOol01Goo00<007oo00001Goo00<007ooOol01Woo00<0
07ooOol00goo00<007oo00001goo00<007ooOol01Goo00<007oo00001Goo00<007ooOol01Woo00<0
07ooOol00goo00<007oo00001goo00<007ooOol01Goo00<007oo00001Goo00<007ooOol01Goo00<0
07ooOol00goo00@007ooOol000Moo`03001oogoo01Moo`0097oo00<007ooOol04Woo00<007ooOol0
4Goo00<007ooOol04Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol04Woo00<007ooOol0
4Goo00<007ooOol04Goo00<007ooOol08Woo000TOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00
Oomoo`0BOol00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00
Oomoo`0AOol00`00Oomoo`0ROol002Aoo`03001oogoo019oo`03001oogoo015oo`03001oogoo019o
o`03001oogoo00Moo`8000Qoo`03001oogoo019oo`03001oogoo015oo`03001oogoo015oo`03001o
ogoo029oo`0097oo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol01goo
00<007ooOol01goo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol08Woo
000TOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`07Ool00`00Oomo
o`07Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0ROol002Aoo`03
001oogoo019oo`03001oogoo015oo`03001oogoo019oo`03001oogoo00Moo`8000Qoo`03001oogoo
019oo`03001oogoo015oo`03001oogoo015oo`03001oogoo029oo`0097oo00<007ooOol04Woo00<0
07ooOol04Goo00<007ooOol04Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol04Woo00<0
07ooOol04Goo00<007ooOol04Goo00<007ooOol08Woo000TOol00`00Oomoo`0BOol00`00Oomoo`0A
Ool00`00Oomoo`0BOol00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0BOol00`00Oomoo`0A
Ool00`00Oomoo`0AOol00`00Oomoo`0ROol002Aoo`03001oogoo019oo`03001oogoo015oo`03001o
ogoo019oo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo019oo`03001oogoo015oo`03001o
ogoo015oo`03001oogoo029oo`0097oo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Woo
00<007ooOol01goo0P0027oo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Goo00<007oo
Ool08Woo000TOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0=Ool00`00Oomoo`02Ool0
1000Oomoogoo0`000goo00<007ooOol01goo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol0
4Goo00<007ooOol08Woo000TOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0<Ool00`00
Ool00003Ool01@00Oomoogoo00001Goo00<007ooOol01goo00<007ooOol04Woo00<007ooOol04Goo
00<007ooOol04Goo00<007ooOol08Woo000TOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomo
o`0<Ool00`00Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool20008Ool00`00Oomoo`0BOol0
0`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0ROol002Aoo`03001oogoo019oo`03001oogoo
015oo`03001oogoo00aoo`03001oo`0000=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo
00Moo`03001oogoo019oo`03001oogoo015oo`03001oogoo015oo`03001oogoo029oo`0097oo00<0
07ooOol04Woo00<007ooOol04Goo00<007ooOol037oo00<007oo00000goo00L007ooOomoo`00Ool0
0003Ool00`00Oomoo`07Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomo
o`0ROol002Aoo`03001oogoo019oo`03001oogoo015oo`03001oogoo00eoo`03001oogoo009oo`03
001oogoo009oo`03001oogoo009oo`03001oogoo00Moo`03001oogoo019oo`03001oogoo015oo`03
001oogoo015oo`03001oogoo029oo`0097oo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol0
4Woo00<007ooOol01goo0P0027oo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Goo00<0
07ooOol08Woo000TOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0R
Ool002Aoo`03001oogoo019oo`03001oogoo015oo`03001oogoo019oo`03001oogoo00Moo`03001o
ogoo00Moo`03001oogoo019oo`03001oogoo015oo`03001oogoo015oo`03001oogoo029oo`0097oo
00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol01goo0P0027oo00<007oo
Ool04Woo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol08Woo000TOol00`00Oomoo`0BOol0
0`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0BOol0
0`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0ROol002Aoo`03001oogoo019oo`03001oogoo
015oo`03001oogoo019oo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo019oo`03001oogoo
015oo`03001oogoo015oo`03001oogoo029oo`0097oo00<007ooOol04Woo00<007ooOol04Goo00<0
07ooOol04Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol04Woo00<007ooOol04Goo00<0
07ooOol04Goo00<007ooOol08Woo000TOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0B
Ool00`00Oomoo`07Ool20008Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0AOol00`00
Oomoo`0ROol002Aoo`03001oogoo019oo`03001oogoo015oo`03001oogoo019oo`03001oogoo00Mo
o`03001oogoo00Moo`03001oogoo019oo`03001oogoo015oo`03001oogoo015oo`03001oogoo029o
o`0097oo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol03Goo00<007ooOol00Woo00<007oo
Ool00Woo0`000Woo00<007ooOol01goo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Goo
00<007ooOol08Woo000TOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0<Ool00`00Ool0
0003Ool00`00Oomoo`03Ool01@00Oomoogoo00002Goo00<007ooOol04Woo00<007ooOol04Goo00<0
07ooOol04Goo00<007ooOol08Woo000TOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0<
Ool00`00Ool00003Ool01000Oomoogoo10000Woo0P0027oo00<007ooOol04Woo00<007ooOol04Goo
00<007ooOol04Goo00<007ooOol08Woo000TOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomo
o`0<Ool00`00Ool00003Ool01`00Oomoogoo001oo`0000=oo`03001oogoo00Moo`03001oogoo019o
o`03001oogoo015oo`03001oogoo015oo`03001oogoo029oo`0097oo00<007ooOol04Woo00<007oo
Ool04Goo00<007ooOol037oo00<007oo00000goo00<007ooOol00Woo0P000goo00<007ooOol01goo
00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol08Woo000TOol00`00Oomo
o`0BOol00`00Oomoo`0AOol00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01000Oomo
ogoo0P0027oo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol08Woo000T
Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0ROol002Aoo`03001o
ogoo019oo`03001oogoo015oo`03001oogoo019oo`03001oogoo00Moo`03001oogoo00Moo`03001o
ogoo019oo`03001oogoo015oo`03001oogoo015oo`03001oogoo029oo`0097oo00<007ooOol04Woo
00<007ooOol04Goo00<007ooOol04Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol04Woo
00<007ooOol04Goo00<007ooOol04Goo00<007ooOol08Woo000TOol00`00Oomoo`0BOol00`00Oomo
o`0AOol00`00Oomoo`0BOol00`00Oomoo`07Ool20008Ool00`00Oomoo`0BOol00`00Oomoo`0AOol0
0`00Oomoo`0BOol00`00Oomoo`0QOol002Aoo`03001oogoo019oo`03001oogoo015oo`03001oogoo
019oo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo019oo`03001oogoo015oo`03001oogoo
019oo`03001oogoo025oo`0097oo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Woo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Woo00<0
07ooOol08Goo000TOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`07
Ool20008Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0QOol002Ao
o`03001oogoo019oo`03001oogoo015oo`03001oogoo019oo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo019oo`03001oogoo015oo`03001oogoo019oo`03001oogoo025oo`0097oo00<007oo
Ool04Woo00<007ooOol04Goo00<007ooOol03Goo00<007ooOol00Woo00@007ooOomoo`8000Aoo`03
001oogoo00Moo`03001oogoo019oo`03001oogoo015oo`03001oogoo019oo`03001oogoo025oo`00
97oo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol037oo00<007oo00000goo00L007ooOomo
o`00Ool00003Ool00`00Oomoo`07Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol0
0`00Oomoo`0QOol002Aoo`03001oogoo019oo`03001oogoo015oo`03001oogoo00aoo`03001oo`00
00=oo`07001oogooOol007oo00000goo0P0027oo00<007ooOol04Woo00<007ooOol04Goo00<007oo
Ool04Woo00<007ooOol08Goo000TOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0<Ool0
0`00Ool00003Ool01000Oomoogoo0P0017oo00<007ooOol01goo00<007ooOol04Woo00<007ooOol0
4Goo00<007ooOol04Woo00<007ooOol08Goo000TOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00
Oomoo`0<Ool00`00Ool00003Ool01@00Oomoogoo00001Goo00<007ooOol01goo00<007ooOol04Woo
00<007ooOol04Goo00<007ooOol04Woo00<007ooOol08Goo000TOol00`00Oomoo`0BOol00`00Oomo
o`0AOol00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`02Ool20003Ool20008Ool00`00Oomo
o`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0QOol002Aoo`03001oogoo019oo`03
001oogoo015oo`03001oogoo019oo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo019oo`03
001oogoo015oo`03001oogoo019oo`03001oogoo025oo`0097oo00<007ooOol04Woo00<007ooOol0
4Goo00<007ooOol04Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol04Woo00<007ooOol0
4Goo00<007ooOol04Woo00<007ooOol08Goo000TOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00
Oomoo`0BOol00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00
Oomoo`0BOol00`00Oomoo`0QOol002Aoo`03001oogoo019oo`03001oogoo015oo`03001oogoo019o
o`03001oogoo00Moo`8000Qoo`03001oogoo019oo`03001oogoo015oo`03001oogoo019oo`03001o
ogoo025oo`0097oo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol01goo
00<007ooOol01goo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol08Goo
000TOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`07Ool00`00Oomo
o`07Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0QOol002Aoo`03
001oogoo019oo`03001oogoo015oo`03001oogoo019oo`03001oogoo00Moo`8000Qoo`03001oogoo
019oo`03001oogoo015oo`03001oogoo019oo`03001oogoo025oo`0097oo00<007ooOol04Woo00<0
07ooOol04Goo00<007ooOol04Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol04Woo00<0
07ooOol04Goo00<007ooOol04Woo00<007ooOol08Goo000TOol00`00Oomoo`0BOol00`00Oomoo`0A
Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`07
Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0QOol002Aoo`03001o
ogoo019oo`03001oogoo015oo`03001oogoo00aoo`03001oo`0000=oo`07001oogooOol007oo0000
0goo00<007ooOol01goo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol0
8Goo000TOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0<Ool00`00Ool00003Ool01`00
Oomoogoo001oo`0000=oo`8000Qoo`03001oogoo019oo`03001oogoo015oo`03001oogoo019oo`03
001oogoo025oo`0097oo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol037oo00<007oo0000
0goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01goo00<007ooOol04Woo00<007ooOol0
4Goo00<007ooOol04Woo00<007ooOol08Goo000TOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00
Oomoo`0<Ool00`00Ool00003Ool01`00Oomoogoo001oo`0000=oo`03001oogoo00Moo`03001oogoo
019oo`03001oogoo015oo`03001oogoo019oo`03001oogoo025oo`0097oo00<007ooOol04Woo00<0
07ooOol04Goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo0P00
27oo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol08Goo000TOol00`00
Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0QOol002Aoo`03001oogoo019o
o`03001oogoo015oo`03001oogoo019oo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo019o
o`03001oogoo015oo`03001oogoo019oo`03001oogoo025oo`0097oo00<007ooOol04Woo00<007oo
Ool04Goo00<007ooOol04Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol04Woo00<007oo
Ool04Goo00<007ooOol04Woo00<007ooOol08Goo000TOol00`00Oomoo`0BOol00`00Oomoo`0AOol0
0`00Oomoo`0BOol00`00Oomoo`07Ool20008Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomo
o`0BOol00`00Oomoo`0QOol002Aoo`03001oogoo019oo`03001oogoo015oo`03001oogoo019oo`03
001oogoo00Moo`03001oogoo00Moo`03001oogoo019oo`03001oogoo015oo`03001oogoo019oo`03
001oogoo025oo`0097oo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol0
8Goo000TOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0QOol002Ao
o`03001oogoo019oo`03001oogoo015oo`03001oogoo019oo`03001oogoo00Moo`8000Qoo`03001o
ogoo019oo`03001oogoo015oo`03001oogoo019oo`03001oogoo025oo`0097oo00<007ooOol04Woo
00<007ooOol04Goo00<007ooOol04Woo00<007ooOol01@000Woo00<007ooOol01goo00<007ooOol0
4Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol08Goo000TOol00`00Oomoo`0BOol00`00
Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00
Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0QOol001Yoo`/001AooaD001Ao
oaD001AooaD001Aoo`/001Uoo`00Igoo00<007ooOol00Woo00<007ooOol0JGoo001WOol00`00Oomo
o`02Ool00`00Oomoo`1YOol006Ioo`8000Aoo`03001oogoo06Uoo`00K7oo0P00JWoo001/Ool00`00
Oomoo`1YOol006aoo`03001oogoo06Uoo`00K7oo0P00JWoo001/Ool00`00Oomoo`1YOol006aoo`03
001oogoo06Uoo`00K7oo00<007ooOol0JGoo001/Ool2001ZOol005]oo`D0009oo`04001oogooOol3
0003Ool00`00Oomoo`1YOol005eoo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo06Uoo`00
GGoo00<007ooOol01goo00<007ooOol00Woo0P00JWoo001MOol00`00Oomoo`07Ool00`00Oomoo`02
Ool00`00Oomoo`1YOol005eoo`03001oogoo00Ioo`03001oo`0000=oo`03001oogoo06Uoo`00G7oo
0P002Goo00<007ooOol00Woo00<007ooOol0JGoo001/Ool2001ZOol006aoo`03001oogoo06Uoo`00
K7oo00<007ooOol0JGoo001/Ool2001ZOol006aoo`03001oogoo06Uoo`00K7oo00<007ooOol0JGoo
001/Ool00`00Oomoo`1YOol006aoo`8006Yoo`00Fgoo1@000Woo00<007ooOol00Woo0`000Woo00<0
07ooOol0JGoo001MOol00`00Oomoo`08Ool01@00Oomoogoo0000Jgoo001MOol00`00Oomoo`06Ool4
0002Ool2001ZOol005eoo`03001oogoo00Ioo`03001oo`0000=oo`03001oogoo06Uoo`00GGoo00<0
07ooOol01goo0P000goo00<007ooOol0JGoo001LOol2000:Ool01@00Oomoogoo0000Jgoo001/Ool2
001ZOol006aoo`03001oogoo06Uoo`00K7oo00<007ooOol0JGoo001/Ool00`00Oomoo`1YOol00=Qo
o`00f7oo003HOol00=Qoo`00IWoo0`00Kgoo001WOol00`00Oomoo`1^Ool003=oo`<000Aoo`80009o
o`<0009oo`<000=oo`8000=oo`<00004Ool000000002Ool3000=Ool30003Ool3000017oo00000000
0Woo0P0017oo0P002goo0P000Woo0`000Woo100000Eoo`00000007oo0080009oo`03001oogoo03Io
o`00=7oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`00009oo`03
001oo`00009oo`04001oogoo0003Ool00`00Oomoo`0=Ool01P00Oomoo`00Ool0009oo`04001oogoo
0005Ool01000Oomoo`0037oo00@007ooOol0009oo`04001oogooOol30003Ool01@00Oomoogoo0000
0Woo00<007ooOol0=Woo000dOol30002Ool30003Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo
00<007oo00000Woo00@007ooOol000=oo`03001oogoo00eoo`06001oogoo001oo`000Woo00@007oo
Ool000Aoo`04001oogooOol3000:Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01@00Oomoogoo0000
0goo00@007ooOol003Qoo`00=7oo00D007ooOol007oo00<0009oo`@00003Ool0000000Aoo`8000=o
o`<00003Ool0000000=oo`<000aoo`@00004Ool00000Ool20002Ool00`00Oomoo`02Ool20002Ool3
0009Ool40002Ool40002Ool20002Ool20002Ool4000iOol003Aoo`04001oogoo000HOol00`00Oomo
o`0OOol00`00Oomoo`0COol00`00Oomoo`1=Ool003=oo`@000eoo`03001oogoo00Qoo`80009oo`03
001oogoo01]oo`8002Eoo`03001oogoo03eoo`00f7oo003HOol00=Qoo`00\
\>"],
  ImageRangeCache->{{{101.5, 316.5}, {239.313, 106.875}} -> {-5.12861, 
  1.35124, 0.0244274, 0.0141158}}],

Cell["\<\
The FS coefficients are evaluated using (2). We first solve the general \
result (we also simplify using Euler's relation).\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]\_\(-\ \[Tau]\)\%\[Tau]\ 
        \(\[ExponentialE]\^\(\ \(-\[ImaginaryI]\)\ \(2\ \[Pi]\)\/T\ k\ t\)\) 
          \[DifferentialD]t\  // ExpToTrig\)], "Input"],

Cell[BoxData[
    \(\(T\ Sin[\(2\ k\ \[Pi]\ \[Tau]\)\/T]\)\/\(k\ \[Pi]\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "For the specific case of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau] = T\/4\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`T = 1\)]],
  ", we get:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(c\_k_\  := \ 
      \(c\_k\  = 
        \(T\ Sin[\(2\ k\ \[Pi]\ \[Tau]\)\/T]\)\/\(k\ \[Pi]\)\  /. 
          \ {\[Tau] -> 0.125, \ T -> 1}\); \nc\_k\)], "Input"],

Cell[BoxData[
    \(Sin[0.785398163397448278`\ k]\/\(k\ \[Pi]\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "For the special case of ",
  Cell[BoxData[
      \(TraditionalForm\`k = 0\)]],
  ", we get"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(c\_0 = Limit[c\_k, k -> 0]\)], "Input"],

Cell[BoxData[
    \(0.25`\)], "Output"]
}, Open  ]],

Cell["\<\
Here are a few of the values of the FS coefficients of the periodic pulse \
train\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListSignalPlot[Table[c\_k, {k, \(-21\), 21}], PlotRange -> All, 
      PlotLabel \[Rule] "\<FS coefficients of pulse train\>"]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0226757 0.117755 1.94226 [
[.04649 .10525 -9 -9 ]
[.04649 .10525 9 0 ]
[.27324 .10525 -9 -9 ]
[.27324 .10525 9 0 ]
[.72676 .10525 -6 -9 ]
[.72676 .10525 6 0 ]
[.95351 .10525 -6 -9 ]
[.95351 .10525 6 0 ]
[.4875 .02064 -30 -4.5 ]
[.4875 .02064 0 4.5 ]
[.4875 .21487 -24 -4.5 ]
[.4875 .21487 0 4.5 ]
[.4875 .31198 -18 -4.5 ]
[.4875 .31198 0 4.5 ]
[.4875 .40909 -24 -4.5 ]
[.4875 .40909 0 4.5 ]
[.4875 .50621 -18 -4.5 ]
[.4875 .50621 0 4.5 ]
[.4875 .60332 -24 -4.5 ]
[.4875 .60332 0 4.5 ]
[.5 .63053 -92 0 ]
[.5 .63053 92 12.875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.04649 .11775 m
.04649 .124 L
s
[(-20)] .04649 .10525 0 1 Mshowa
.27324 .11775 m
.27324 .124 L
s
[(-10)] .27324 .10525 0 1 Mshowa
.72676 .11775 m
.72676 .124 L
s
[(10)] .72676 .10525 0 1 Mshowa
.95351 .11775 m
.95351 .124 L
s
[(20)] .95351 .10525 0 1 Mshowa
.125 Mabswid
.09184 .11775 m
.09184 .1215 L
s
.13719 .11775 m
.13719 .1215 L
s
.18254 .11775 m
.18254 .1215 L
s
.22789 .11775 m
.22789 .1215 L
s
.31859 .11775 m
.31859 .1215 L
s
.36395 .11775 m
.36395 .1215 L
s
.4093 .11775 m
.4093 .1215 L
s
.45465 .11775 m
.45465 .1215 L
s
.54535 .11775 m
.54535 .1215 L
s
.5907 .11775 m
.5907 .1215 L
s
.63605 .11775 m
.63605 .1215 L
s
.68141 .11775 m
.68141 .1215 L
s
.77211 .11775 m
.77211 .1215 L
s
.81746 .11775 m
.81746 .1215 L
s
.86281 .11775 m
.86281 .1215 L
s
.90816 .11775 m
.90816 .1215 L
s
.00113 .11775 m
.00113 .1215 L
s
.99887 .11775 m
.99887 .1215 L
s
.25 Mabswid
0 .11775 m
1 .11775 L
s
.5 .02064 m
.50625 .02064 L
s
[(-0.05)] .4875 .02064 1 0 Mshowa
.5 .21487 m
.50625 .21487 L
s
[(0.05)] .4875 .21487 1 0 Mshowa
.5 .31198 m
.50625 .31198 L
s
[(0.1)] .4875 .31198 1 0 Mshowa
.5 .40909 m
.50625 .40909 L
s
[(0.15)] .4875 .40909 1 0 Mshowa
.5 .50621 m
.50625 .50621 L
s
[(0.2)] .4875 .50621 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(0.25)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .04006 m
.50375 .04006 L
s
.5 .05949 m
.50375 .05949 L
s
.5 .07891 m
.50375 .07891 L
s
.5 .09833 m
.50375 .09833 L
s
.5 .13718 m
.50375 .13718 L
s
.5 .1566 m
.50375 .1566 L
s
.5 .17602 m
.50375 .17602 L
s
.5 .19545 m
.50375 .19545 L
s
.5 .23429 m
.50375 .23429 L
s
.5 .25371 m
.50375 .25371 L
s
.5 .27314 m
.50375 .27314 L
s
.5 .29256 m
.50375 .29256 L
s
.5 .3314 m
.50375 .3314 L
s
.5 .35083 m
.50375 .35083 L
s
.5 .37025 m
.50375 .37025 L
s
.5 .38967 m
.50375 .38967 L
s
.5 .42852 m
.50375 .42852 L
s
.5 .44794 m
.50375 .44794 L
s
.5 .46736 m
.50375 .46736 L
s
.5 .48678 m
.50375 .48678 L
s
.5 .52563 m
.50375 .52563 L
s
.5 .54505 m
.50375 .54505 L
s
.5 .56447 m
.50375 .56447 L
s
.5 .5839 m
.50375 .5839 L
s
.5 .00122 m
.50375 .00122 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -153 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.875000 moveto
 460.000000 16.875000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.875000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(FS) show
81.000000 13.000000 moveto
(coefficients) show
159.000000 13.000000 moveto
(of) show
177.000000 13.000000 moveto
(pulse) show
213.000000 13.000000 moveto
(train) show
243.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.02381 .11775 m
.02381 .09694 L
s
.04649 .11775 m
.04649 .11775 L
s
.06916 .11775 m
.06916 .14076 L
s
.09184 .11775 m
.09184 .1521 L
s
.11451 .11775 m
.11451 .14347 L
s
.13719 .11775 m
.13719 .11775 L
s
.15986 .11775 m
.15986 .08861 L
s
.18254 .11775 m
.18254 .0736 L
s
.20522 .11775 m
.20522 .08413 L
s
.22789 .11775 m
.22789 .11775 L
s
.25057 .11775 m
.25057 .1575 L
s
.27324 .11775 m
.27324 .17958 L
s
.29592 .11775 m
.29592 .16633 L
s
.31859 .11775 m
.31859 .11775 L
s
.34127 .11775 m
.34127 .0553 L
s
.36395 .11775 m
.36395 .01472 L
s
.38662 .11775 m
.38662 .03032 L
s
.4093 .11775 m
.4093 .11775 L
s
.43197 .11775 m
.43197 .26348 L
s
.45465 .11775 m
.45465 .42687 L
s
.47732 .11775 m
.47732 .55492 L
s
.5 .11775 m
.5 .60332 L
s
.52268 .11775 m
.52268 .55492 L
s
.54535 .11775 m
.54535 .42687 L
s
.56803 .11775 m
.56803 .26348 L
s
.5907 .11775 m
.5907 .11775 L
s
.61338 .11775 m
.61338 .03032 L
s
.63605 .11775 m
.63605 .01472 L
s
.65873 .11775 m
.65873 .0553 L
s
.68141 .11775 m
.68141 .11775 L
s
.70408 .11775 m
.70408 .16633 L
s
.72676 .11775 m
.72676 .17958 L
s
.74943 .11775 m
.74943 .1575 L
s
.77211 .11775 m
.77211 .11775 L
s
.79478 .11775 m
.79478 .08413 L
s
.81746 .11775 m
.81746 .0736 L
s
.84014 .11775 m
.84014 .08861 L
s
.86281 .11775 m
.86281 .11775 L
s
.88549 .11775 m
.88549 .14347 L
s
.90816 .11775 m
.90816 .1521 L
s
.93084 .11775 m
.93084 .14076 L
s
.95351 .11775 m
.95351 .11775 L
s
.97619 .11775 m
.97619 .09694 L
s
.02 w
.02381 .09694 Mdot
.04649 .11775 Mdot
.06916 .14076 Mdot
.09184 .1521 Mdot
.11451 .14347 Mdot
.13719 .11775 Mdot
.15986 .08861 Mdot
.18254 .0736 Mdot
.20522 .08413 Mdot
.22789 .11775 Mdot
.25057 .1575 Mdot
.27324 .17958 Mdot
.29592 .16633 Mdot
.31859 .11775 Mdot
.34127 .0553 Mdot
.36395 .01472 Mdot
.38662 .03032 Mdot
.4093 .11775 Mdot
.43197 .26348 Mdot
.45465 .42687 Mdot
.47732 .55492 Mdot
.5 .60332 Mdot
.52268 .55492 Mdot
.54535 .42687 Mdot
.56803 .26348 Mdot
.5907 .11775 Mdot
.61338 .03032 Mdot
.63605 .01472 Mdot
.65873 .0553 Mdot
.68141 .11775 Mdot
.70408 .16633 Mdot
.72676 .17958 Mdot
.74943 .1575 Mdot
.77211 .11775 Mdot
.79478 .08413 Mdot
.81746 .0736 Mdot
.84014 .08861 Mdot
.86281 .11775 Mdot
.88549 .14347 Mdot
.90816 .1521 Mdot
.93084 .14076 Mdot
.95351 .11775 Mdot
.97619 .09694 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00OSgoo0P00Sgoo001[
Ool3000QOol00`00Oomoo`0OOol3001/Ool006Yoo`D0021oo`03001oogoo01ioo`D006]oo`00JWoo
1@002goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007oo
Ool07Woo1@00Jgoo001ZOol5000:Ool00`00Ool00007Ool00`00Ool00002Ool00`00Ool00004Ool0
0`00Oomoo`0NOol5001[Ool006]oo`<000Ioo`<0009oo`03001oo`0000Moo`03001oo`0000Aoo`03
001oogoo009oo`<001moo`<006aoo`00K7oo00@007ooOomoo`<000Ioo`03001oo`0000Moo`03001o
o`00009oo`8000Eoo`03001oogoo01Uoo`<000Aoo`03001oogoo06]oo`00K7oo00<007ooOol01@00
1Goo00<007oo00001goo00<007oo00000Woo00<007ooOol017oo00<007ooOol067oo1@000goo00<0
07ooOol0Jgoo001/Ool00`00Oomoo`050006Ool00`00Oomoo`07Ool01000Oomoogoo0`0017oo00<0
07ooOol067oo1@000goo00<007ooOol0Jgoo001/Ool00`00Oomoo`05000KOol00`00Oomoo`0HOol5
0003Ool00`00Oomoo`1[Ool006aoo`04001oogooOol3000LOol2000JOol30004Ool00`00Oomoo`1[
Ool006aoo`03001oogoo00=oo`03001oogoo01Yoo`03001oogoo01]oo`03001oogoo009oo`03001o
ogoo06]oo`00IGoo0`0017oo00<007ooOol00goo00<007ooOol06Woo00<007ooOol06goo00<007oo
Ool00Woo00<007ooOol00Woo0`00IWoo001TOol50003Ool00`00Oomoo`03Ool00`00Oomoo`0JOol0
0`00Oomoo`0KOol00`00Oomoo`02Ool01000Oomoogoo1@00IGoo001TOol50003Ool00`00Oomoo`03
Ool00`00Oomoo`0JOol00`00Oomoo`0KOol00`00Oomoo`02Ool01000Oomoogoo1@00IGoo001TOol5
0003Ool00`00Oomoo`03Ool00`00Oomoo`0JOol2000LOol00`00Oomoo`02Ool01000Oomoogoo1@00
IGoo001UOol30004Ool00`00Oomoo`03Ool00`00Oomoo`0JOol00`00Oomoo`0KOol00`00Oomoo`02
Ool00`00Oomoo`02Ool3001VOol003]oo`<002Qoo`03001oogoo00=oo`03001oogoo00=oo`03001o
ogoo01Yoo`03001oogoo01]oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo02Ioo`<003ao
o`00>Woo1@009goo00<007ooOol00goo00<007ooOol00goo00<007ooOol06Woo00<007ooOol06goo
00<007ooOol00Woo00<007ooOol00goo00<007ooOol09Goo1@00>goo000HOol30003Ool00`00Oomo
o`0IOol5000COol50002Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomo
o`0JOol00`00Oomoo`0KOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool50002Ool0
0`00Oomoo`0AOol5000LOol30003Ool00`00Oomoo`0FOol001Qoo`03001oogoo009oo`03001oo`00
01Yoo`D0009oo`<0011oo`07001oogooOol007oo00002goo00<007ooOol00goo00<007ooOol00goo
00<007ooOol06Woo0P0077oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol037oo00L007oo
Oomoo`00Ool0000=Ool30002Ool5000LOol00`00Oomoo`02Ool00`00Ool0000GOol001=oo`<000=o
o`07001oogooOol007oo00005Goo0`000goo0`000Woo1@002Goo0`000goo00L007ooOomoo`00Ool0
000;Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0JOol00`00Oomoo`0KOol00`00Oomo
o`02Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool01`00Oomoogoo001oo`0000aoo`D0009oo`<0009o
o`<001Uoo`07001oogooOol007oo00005goo000IOol01`00Oomoogoo001oo`0001Aoo`D000=oo`04
001oogooOol5000?Ool01`00Oomoogoo001oo`0000]oo`03001oogoo00=oo`03001oogoo00=oo`03
001oogoo01Yoo`03001oogoo01]oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00aoo`07
001oogooOol007oo000037oo1@000goo00<007ooOol01@0067oo00L007ooOomoo`00Ool0000GOol0
019oo`<000=oo`03001oo`00009oo`03001oo`0001Aoo`D000=oo`04001oogooOol5000?Ool01`00
Oomoogoo001oo`0000]oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo01Yoo`03001oogoo
01]oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00aoo`07001oogooOol007oo000037oo
1@000goo00<007ooOol01@005goo00<007oo00000Woo00@007oo001oo`<001=oo`004Goo1@000goo
00<007ooOol00Woo00<007ooOol04goo1@000goo00<007ooOol00Woo0`003goo0P0017oo00<007oo
Ool02Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol06Woo00<007ooOol06goo00<007oo
Ool00Woo00<007ooOol00goo00<007ooOol02goo0P0017oo00<007ooOol037oo0`0017oo00<007oo
Ool01@0067oo00<007ooOol00Woo00<007oo000010004Woo000AOol5000OOol30004Ool00`00Oomo
o`03Ool00`00Oomoo`0QOol00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0JOol2000LOol0
0`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0QOol00`00Oomoo`03Ool01000Oomoogoo0`00
87oo1@004Woo000AOol5000POol00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0QOol00`00
Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0JOol00`00Oomoo`0KOol00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`0QOol00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0NOol5000B
Ool0019oo`<0025oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo025oo`03001oogoo00=o
o`03001oogoo00=oo`03001oogoo01Yoo`03001oogoo01]oo`03001oogoo009oo`03001oogoo00=o
o`03001oogoo025oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo01moo`<001=oo`004goo
00<007ooOol00Woo0`005Goo0`000goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00Woo
0`005Goo0`0017oo00<007ooOol00goo00<007ooOol00goo00@007ooOomoo`<001Ioo`03001oogoo
01Aoo`<000Aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`<001Eoo`<000Aoo`03
001oogoo00=oo`03001oogoo00=oo`04001oogooOol3000EOol30004Ool00`00Oomoo`0BOol001=o
o`04001oogooOol5000COol50002Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01000Oomoogoo1@00
4goo1@000goo00<007ooOol00goo00<007ooOol00goo00<007ooOol01@005Goo00<007ooOol04goo
1@000goo00<007ooOol00Woo00<007ooOol00goo00@007ooOomoo`D001=oo`D000=oo`03001oogoo
00=oo`03001oogoo00=oo`03001oogoo00D001=oo`D000=oo`03001oogoo019oo`003Gooo`001P00
3Woo000=Ool00`00Oomoo`07Ool50003Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01000Oomoogoo
1@0027oo00<007ooOol01goo1@000goo00<007ooOol00goo00<007ooOol00goo00@007ooOomoo`D0
00Uoo`03001oogoo00Ioo`D000=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03
001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`04001oogooOol50008Ool00`00Oomoo`07
Ool50003Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01000Oomoogoo1@002Goo00<007ooOol01Woo
1@000goo00<007ooOol00goo00<007ooOol00goo00@007ooOomoo`D000Uoo`03001oogoo00aoo`00
67oo0`0017oo00<007ooOol00goo00<007ooOol00goo00<007ooOol00Woo0`0057oo0`0017oo00<0
07ooOol00goo00<007ooOol00goo00<007ooOol00Woo0`0057oo0`0017oo00<007ooOol00goo00<0
07ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<0
07ooOol00Woo0`0057oo0`0017oo00<007ooOol00goo00<007ooOol00goo00<007ooOol00Woo0`00
57oo0`0017oo00<007ooOol00goo00<007ooOol00goo00<007ooOol00Woo0`006Goo000OOol00`00
Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0POol00`00Oomoo`03Ool00`00Oomoo`03Ool00`00
Oomoo`0POol00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00
Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0POol00`00Oomoo`03Ool00`00Oomoo`03Ool00`00
Oomoo`0POol00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0NOol001ioo`<000Aoo`03001o
ogoo00=oo`03001oogoo021oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo021oo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001o
ogoo00=oo`03001oogoo021oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo021oo`03001o
ogoo00=oo`03001oogoo009oo`<001moo`007Goo1@000goo00<007ooOol00Woo0`008Goo00<007oo
Ool00goo00<007ooOol00goo00<007ooOol087oo00<007ooOol00goo00<007ooOol00goo00<007oo
Ool00goo0P0017oo00<007ooOol00goo00<007ooOol00goo00<007ooOol087oo00<007ooOol00goo
00<007ooOol00goo00<007ooOol07goo0`0017oo00@007ooOomoo`D001ioo`007Goo1@000goo00@0
07ooOomoo`D0021oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo021oo`03001oogoo00=o
o`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=o
o`03001oogoo021oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo01ioo`D000=oo`04001o
ogooOol5000NOol001eoo`D0009oo`<0009oo`D0021oo`03001oogoo00=oo`03001oogoo00=oo`03
001oogoo021oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03
001oogoo00=oo`03001oogoo00=oo`03001oogoo021oo`03001oogoo00=oo`03001oogoo00=oo`03
001oogoo01ioo`D0009oo`<0009oo`D001ioo`007Woo0`000Woo1@0000=oo`0000000`0087oo00<0
07ooOol00goo00<007ooOol00goo00<007ooOol087oo00<007ooOol00goo00<007ooOol00goo00<0
07ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol087oo00<0
07ooOol00goo00<007ooOol00goo00<007ooOol07Woo1@0000=oo`0000000`000Woo0`007goo000S
Ool50002Ool3000POol30004Ool00`00Oomoo`03Ool00`00Oomoo`0POol00`00Oomoo`03Ool00`00
Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00
Oomoo`0POol00`00Oomoo`03Ool00`00Oomoo`02Ool3000POol30002Ool5000TOol002=oo`D002Ao
o`D000=oo`03001oogoo00=oo`03001oogoo021oo`03001oogoo00=oo`03001oogoo00=oo`03001o
ogoo00=oo`8000Aoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo021oo`03001oogoo00=o
o`04001oogooOol5000TOol5000TOol002Aoo`<002Eoo`D000=oo`03001oogoo009oo`<0025oo`03
001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03
001oogoo00=oo`03001oogoo01moo`<000Aoo`04001oogooOol5000UOol3000UOol004aoo`D000=o
o`04001oogooOol5000POol00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomo
o`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0NOol50003Ool01000Oomoogoo1@00
CGoo001=Ool30004Ool01000Oomoogoo1@0087oo00<007ooOol00goo00<007ooOol00goo00<007oo
Ool00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol07Woo1@000goo
00<007ooOol00Woo0`00CWoo001COol30002Ool5000POol00`00Oomoo`03Ool00`00Oomoo`03Ool0
0`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0NOol5
0002Ool3001DOol0059oo`D0009oo`<0025oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo
00=oo`8000Aoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo01moo`<0009oo`D005=oo`00
DWoo1@009Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<0
07ooOol00goo00<007ooOol00goo00<007ooOol097oo1@00Dgoo001BOol5000VOol00`00Oomoo`03
Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03
Ool00`00Oomoo`0TOol5001COol005=oo`<002Moo`03001oogoo00=oo`03001oogoo00=oo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo02Eoo`<005Ao
o`00OGoo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007oo
Ool00goo00<007ooOol00goo00<007ooOol0O7oo001mOol00`00Oomoo`03Ool00`00Oomoo`03Ool0
0`00Oomoo`03Ool20004Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`1lOol007eoo`03
001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03
001oogoo00=oo`03001oogoo07aoo`00OGoo00<007ooOol00goo00<007ooOol00goo00<007ooOol0
0goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol0O7oo001jOol01P00
Oomoo`00Ool000=oo`8000Aoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001o
ogoo00=oo`03001oogoo07aoo`00NGoo00D007oo001oo`0000Eoo`03001oo`00009oo`<000Aoo`03
001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo07aoo`00NGoo00D007oo001o
o`0000Eoo`03001oo`0000=oo`8000Aoo`<000=oo`03001oogoo00=oo`03001oogoo00=oo`03001o
ogoo07aoo`00NGoo00D007oo001oo`0000Eoo`03001oo`00009oo`8000Eoo`03001oogoo00=oo`03
001oogoo00=oo`03001oogoo00=oo`03001oogoo07aoo`00NGoo00D007oo001oo`0000Eoo`03001o
o`00009oo`8000Eoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo07ao
o`00NWoo00@007ooOol000Eoo`8000=oo`<000Aoo`03001oogoo00=oo`03001oogoo00=oo`03001o
ogoo00=oo`03001oogoo07aoo`00OGoo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo
00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol0O7oo001mOol00`00Oomo
o`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomo
o`03Ool00`00Oomoo`1lOol007eoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`80
00Aoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo07aoo`00OGoo00<007ooOol00goo00<0
07ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<0
07ooOol0O7oo001mOol00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03
Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`1lOol007eoo`03001oogoo00=oo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001o
ogoo07aoo`00OGoo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo
00<007ooOol00goo00<007ooOol00goo00<007ooOol0O7oo001lOol30004Ool00`00Oomoo`03Ool0
0`00Oomoo`03Ool20004Ool00`00Oomoo`03Ool00`00Oomoo`02Ool3001mOol007]oo`D000=oo`03
001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`04001oogooOol5001l
Ool007]oo`D000=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=o
o`04001oogooOol5001lOol007]oo`D000=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo
00=oo`03001oogoo00=oo`04001oogooOol5001lOol007aoo`<000Aoo`03001oogoo00=oo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo009oo`<007eoo`00Pgoo00<007oo
Ool00goo00<007ooOol00goo0P0017oo00<007ooOol00goo00<007ooOol0PWoo0023Ool00`00Oomo
o`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`22Ool008=oo`03
001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo089oo`00
Pgoo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol0
PWoo0023Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00
Oomoo`22Ool008=oo`03001oogoo00=oo`03001oogoo00=oo`8000Aoo`03001oogoo00=oo`03001o
ogoo089oo`00Pgoo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo
00<007ooOol0PWoo0023Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomo
o`03Ool00`00Oomoo`22Ool007moo`04001oogooOol20002Ool50003Ool00`00Oomoo`03Ool00`00
Oomoo`03Ool00`00Oomoo`22Ool007ioo`03001oo`00009oo`03001oogoo00=oo`03001oogoo00=o
o`03001oogoo00=oo`03001oogoo00=oo`03001oogoo089oo`00OWoo00<007oo00000Woo00<007oo
Ool00goo00<007ooOol00goo0`000goo00<007ooOol00goo00<007ooOol0PWoo001nOol00`00Ool0
0002Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomo
o`22Ool007ioo`03001oo`00009oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03
001oogoo00=oo`03001oogoo089oo`00Ogoo00D007ooOomoo`0000Aoo`8000Eoo`03001oogoo00=o
o`03001oogoo00=oo`03001oogoo089oo`00Pgoo00<007ooOol00goo00<007ooOol00goo00<007oo
Ool00goo00<007ooOol00goo00<007ooOol0PWoo0023Ool00`00Oomoo`03Ool00`00Oomoo`03Ool2
0004Ool00`00Oomoo`03Ool00`00Oomoo`22Ool008=oo`03001oogoo00=oo`03001oogoo00=oo`03
001oogoo00=oo`03001oogoo00=oo`03001oogoo089oo`00Pgoo00<007ooOol00goo00<007ooOol0
0goo00<007ooOol00goo00<007ooOol00goo00<007ooOol0PWoo0023Ool00`00Oomoo`03Ool00`00
Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`22Ool008=oo`03001oogoo00=o
o`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo089oo`00Pgoo00<007oo
Ool00goo00<007ooOol00goo0P0017oo00<007ooOol00goo00<007ooOol0PWoo0023Ool00`00Oomo
o`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`22Ool008=oo`03
001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo089oo`00
Pgoo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol0
PWoo0023Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00
Oomoo`22Ool008=oo`03001oogoo00=oo`03001oogoo00=oo`8000Aoo`03001oogoo00=oo`03001o
ogoo089oo`00Pgoo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo
00<007ooOol0PWoo0023Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomo
o`03Ool00`00Oomoo`22Ool008=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03
001oogoo00=oo`03001oogoo089oo`00Pgoo00<007ooOol00goo00<007ooOol00goo00<007ooOol0
0goo00<007ooOol00goo00<007ooOol0PWoo0023Ool00`00Oomoo`03Ool00`00Oomoo`03Ool20004
Ool00`00Oomoo`03Ool00`00Oomoo`22Ool008=oo`03001oogoo00=oo`03001oogoo00=oo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo089oo`00Pgoo00<007ooOol00goo00<007ooOol00goo
00<007ooOol00goo00<007ooOol00goo00<007ooOol0PWoo001jOol00`00Oomoo`02Ool00`00Oomo
o`050002Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`22Ool007Uo
o`03001oo`0000Moo`8000=oo`<000Aoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo089o
o`00NGoo00<007oo00001goo0P0017oo0P0017oo0`000goo00<007ooOol00goo00<007ooOol0PWoo
001iOol00`00Ool00007Ool20003Ool20005Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomo
o`22Ool007Uoo`03001oo`0000Moo`8000=oo`8000Eoo`03001oogoo00=oo`03001oogoo00=oo`03
001oogoo089oo`00NWoo00<007ooOol01Goo0`000goo0`0017oo00<007ooOol00goo00<007ooOol0
0Woo0`00Pgoo0021Ool50003Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01000Oomoogoo1@00PWoo
0021Ool50003Ool00`00Oomoo`03Ool20004Ool01000Oomoogoo1@00PWoo0021Ool50003Ool00`00
Oomoo`03Ool00`00Oomoo`03Ool01000Oomoogoo1@00PWoo0022Ool30004Ool00`00Oomoo`03Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool30023Ool008Uoo`03001oogoo00=oo`03001oogoo00=oo`03
001oogoo08Qoo`00RGoo00<007ooOol00goo00<007ooOol00goo00<007ooOol0R7oo0029Ool00`00
Oomoo`03Ool20004Ool00`00Oomoo`28Ool008Uoo`03001oogoo00=oo`03001oogoo00=oo`03001o
ogoo08Qoo`00RGoo00<007ooOol00goo00<007ooOol00goo00<007ooOol0R7oo0029Ool00`00Oomo
o`03Ool00`00Oomoo`03Ool00`00Oomoo`28Ool008Uoo`03001oogoo00=oo`03001oogoo00=oo`03
001oogoo08Qoo`00RGoo00<007ooOol00goo0P0017oo00<007ooOol0R7oo0029Ool00`00Oomoo`03
Ool00`00Oomoo`03Ool00`00Oomoo`28Ool008Uoo`03001oogoo00=oo`03001oogoo00=oo`03001o
ogoo08Qoo`00RGoo00<007ooOol00goo00<007ooOol00goo00<007ooOol0R7oo0029Ool00`00Oomo
o`03Ool00`00Oomoo`03Ool00`00Oomoo`28Ool008Uoo`03001oogoo00=oo`8000Aoo`03001oogoo
08Qoo`00RGoo00<007ooOol00goo00<007ooOol00goo00<007ooOol0R7oo0029Ool00`00Oomoo`03
Ool00`00Oomoo`03Ool00`00Oomoo`28Ool007moo`03001oogoo009oo`04001oogooOol30004Ool0
0`00Oomoo`03Ool00`00Oomoo`28Ool007ioo`03001oo`0000Moo`8000Eoo`03001oogoo00=oo`03
001oogoo08Qoo`00OWoo00<007oo000027oo00<007ooOol00goo0`000goo00<007ooOol0R7oo001n
Ool00`00Ool00008Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`28Ool007ioo`03001o
o`0000Moo`<000Aoo`03001oogoo00=oo`03001oogoo08Qoo`00Ogoo00<007ooOol01goo00<007oo
Ool00goo00<007ooOol00goo00<007ooOol0R7oo0029Ool00`00Oomoo`03Ool00`00Oomoo`03Ool0
0`00Oomoo`28Ool008Uoo`03001oogoo00=oo`8000Aoo`03001oogoo08Qoo`00RGoo00<007ooOol0
0goo00<007ooOol00goo00<007ooOol0R7oo0029Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00
Oomoo`28Ool008Uoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo08Qoo`00RGoo00<007oo
Ool00goo00<007ooOol00goo00<007ooOol0R7oo0029Ool00`00Oomoo`03Ool20004Ool00`00Oomo
o`28Ool008Qoo`<000Aoo`03001oogoo009oo`<008Uoo`00Qgoo1@000goo00@007ooOomoo`D008Qo
o`00Qgoo1@000goo00@007ooOomoo`D008Qoo`00Qgoo1@000goo00@007ooOomoo`D008Qoo`00R7oo
0`0017oo0P000goo0`00RGoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<0
07ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`8008moo`00Sgoo00<007ooOol0SWoo002?Ool0
0`00Oomoo`2>Ool008moo`03001oogoo08ioo`00NWoo00<007ooOol00Woo00@007ooOomoo`<000=o
o`03001oogoo009oo`<008moo`00NGoo00<007oo00001goo00<007ooOol00Woo00<007oo00000Woo
1@00SWoo001iOol00`00Ool00008Ool00`00Oomoo`03Ool00`00Oomoo`05002>Ool007Uoo`03001o
o`0000Qoo`04001oogooOol20003Ool5002>Ool007Uoo`03001oo`0000Moo`03001oo`00009oo`03
001oogoo00=oo`<008moo`00NWoo00<007ooOol01goo00@007ooOomoo`<000Aoo`03001oogoo08io
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00:Moo`<007Ioo`00Z7oo00<0
07ooOol0MGoo000eOol30003Ool3000:Ool30003Ool20003Ool20002Ool30002Ool30002Ool30002
Ool30002Ool30003Ool200000goo00000002Ool00`00Oomoo`020002Ool2000FOol20002Ool3000:
Ool30003Ool3000017oo000000000Woo0P0017oo0P003Woo0P000Woo0`000Woo100000Eoo`000000
07oo0080009oo`03001oogoo03Yoo`00=Woo00<007ooOol00Woo00<007oo00002Woo00<007ooOol0
0Woo00H007ooOol007oo0005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00001Goo
00D007ooOomoo`0000Aoo`06001oogoo001oo`000Woo00D007ooOomoo`0001Aoo`04001oogoo0002
Ool00`00Oomoo`09Ool01P00Oomoo`00Ool0009oo`04001oogoo0005Ool01000Oomoo`003goo00@0
07ooOol0009oo`04001oogooOol30003Ool01@00Oomoogoo00000Woo00<007ooOol0>Woo000fOol0
0`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`02Ool01@00Oomoo`00Ool00`000goo00<007oo
Ool00Woo00<007ooOol00Woo00D007ooOomoo`0000Eoo`04001oogooOol30002Ool01P00Oomoo`00
Ool000Eoo`03001oogoo01=oo`04001oogoo0002Ool00`00Oomoo`09Ool01P00Oomoo`00Ool0009o
o`04001oogoo0004Ool01000Oomoogoo0`003Goo00<007ooOol00goo00<007ooOol00goo00D007oo
Oomoo`0000=oo`04001oogoo000lOol003Ioo`8000Aoo`03001oogoo00Uoo`<000=oo`80009oo`<0
009oo`<0009oo`<0009oo`8000=oo`<0009oo`8000=oo`<00003Ool0000000800003Ool000000080
00=oo`8001Eoo`80009oo`<000Uoo`@00004Ool00000Ool20002Ool00`00Oomoo`02Ool20002Ool3
000<Ool40002Ool40002Ool20002Ool20002Ool4000mOol003Ioo`08001oogoo001oo`00Ool001Yo
o`03001oogoo009oo`03001oogoo01Yoo`03001oogoo01moo`03001oogoo01Aoo`03001oogoo01Io
o`03001oogoo055oo`00=Goo1@0000Aoo`00000001]oo`03001oogoo009oo`05001oogooOol00009
Ool00`00Oomoo`0^Ool00`00Oomoo`0BOol2000XOol00`00Oomoo`11Ool00?moob5oo`00ogoo8Goo
003oOolQOol00001\
\>"],
  ImageRangeCache->{{{93.5, 380.5}, {291.375, 114.438}} -> {-40.1688, 
  0.165815, 0.169488, 0.00197876}}]
}, Open  ]],

Cell[TextData[{
  "This graphical representation of the Fourier series coefficients is called \
a line spectrum. Typically the magnitude is plotted as a function of the \
integer index ",
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`k\)]]],
  ". The frequency corresponding to ",
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`k = 1\)]]],
  " is called the fundamental harmonic, which in the present case is ",
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\(2  \[Pi]\)\/T = \(2  \[Pi]\)\/2\)]]],
  " ",
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`radians\/sec\)]]],
  " or ",
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`1\/2\)]]],
  " Hz. Note the symmetry in the values of the coefficients and the fact that \
they are REAL. Both characteristics are a direct consequence of the \
properties of the original time-domain signal."
}], "Text"],

Cell[CellGroupData[{

Cell["Problem 1.", "Exercise"],

Cell[TextData[{
  "Recalculate the Fourier series coefficients of the signal ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\)]],
  ", keeping the period fixed and decreasing the pulse width to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau] = T\/8\)]],
  ". Discuss the effect on the FS line spectrum."
}], "ExerciseText"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["SIGNAL RECONSTRUCTION", "Section"],

Cell[TextData[{
  "Any periodic function that satisfies the so-called ",
  StyleBox["Dirichlet conditions",
    FontSlant->"Italic"],
  " has a Fourier series representation in terms of linear combinations of \
harmonically related sinusoids. The superposition coefficients are the FS \
coefficients of the signal ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\)]],
  ". As the synthesis formula (2) shows, a periodic signal is an infinite sum \
of harmonically related sinusoids. For practical reasons, it is of interest \
to investigate the behaviour of FINITE sums."
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm
    \`\(x\_M\)(t)\  = \ 
      \[Sum]\+\(k = \(-M\)\)\%M\ 
        c\_k\ \ \[ExponentialE]\^\(\ j\ \[Omega]\_T\ k\ t\)\)]]], 
  "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`x\_M\)]],
  " is the approximating signal, synthesized from ",
  Cell[BoxData[
      \(TraditionalForm\`2  M + 1\)]],
  " FS coefficients. Given the FS coefficients calculated in the earlier \
example, we obtain approximations of the original signal using ",
  Cell[BoxData[
      \(TraditionalForm\`M = 1, 5, 11, 21\)]],
  " coefficients."
}], "Text"],

Cell[BoxData[
    \(x\_M_[t_] := 
      \(x\_M[t] = 
        \[Sum]\+\(k = \(-M\)\)\%M c\_k\ 
            \[ExponentialE]\^\(\ \[ImaginaryI]\ 2  \[Pi]\ k\ t\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[{{
            Plot[c\_0, {t, \(-1\), 1}, PlotLabel \[Rule] "\<1 coefficient\>", 
              DisplayFunction \[Rule] Identity], 
            Plot[x\_5[t], {t, \(-1\), 1}, 
              PlotLabel \[Rule] "\<5 coefficients\>", 
              DisplayFunction \[Rule] Identity]}, {
            Plot[x\_11[t], {t, \(-1\), 1}, 
              PlotLabel \[Rule] "\<11 coefficients\>", 
              DisplayFunction \[Rule] Identity], 
            Plot[x\_21[t], {t, \(-1\), 1}, 
              PlotLabel \[Rule] "\<21 coefficients\>", 
              DisplayFunction \[Rule] Identity]}}]]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.0538505 0.496789 [
[.02381 .04135 -6 -9 ]
[.02381 .04135 6 0 ]
[.2619 .04135 -12 -9 ]
[.2619 .04135 12 0 ]
[.7381 .04135 -9 -9 ]
[.7381 .04135 9 0 ]
[.97619 .04135 -3 -9 ]
[.97619 .04135 3 0 ]
[.4875 .15321 -18 -4.5 ]
[.4875 .15321 0 4.5 ]
[.4875 .25257 -18 -4.5 ]
[.4875 .25257 0 4.5 ]
[.4875 .35192 -18 -4.5 ]
[.4875 .35192 0 4.5 ]
[.4875 .45128 -18 -4.5 ]
[.4875 .45128 0 4.5 ]
[.4875 .55064 -6 -4.5 ]
[.4875 .55064 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12.875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 .05385 m
.02381 .0601 L
s
[(-1)] .02381 .04135 0 1 Mshowa
.2619 .05385 m
.2619 .0601 L
s
[(-0.5)] .2619 .04135 0 1 Mshowa
.7381 .05385 m
.7381 .0601 L
s
[(0.5)] .7381 .04135 0 1 Mshowa
.97619 .05385 m
.97619 .0601 L
s
[(1)] .97619 .04135 0 1 Mshowa
.125 Mabswid
.07143 .05385 m
.07143 .0576 L
s
.11905 .05385 m
.11905 .0576 L
s
.16667 .05385 m
.16667 .0576 L
s
.21429 .05385 m
.21429 .0576 L
s
.30952 .05385 m
.30952 .0576 L
s
.35714 .05385 m
.35714 .0576 L
s
.40476 .05385 m
.40476 .0576 L
s
.45238 .05385 m
.45238 .0576 L
s
.54762 .05385 m
.54762 .0576 L
s
.59524 .05385 m
.59524 .0576 L
s
.64286 .05385 m
.64286 .0576 L
s
.69048 .05385 m
.69048 .0576 L
s
.78571 .05385 m
.78571 .0576 L
s
.83333 .05385 m
.83333 .0576 L
s
.88095 .05385 m
.88095 .0576 L
s
.92857 .05385 m
.92857 .0576 L
s
.25 Mabswid
0 .05385 m
1 .05385 L
s
.5 .15321 m
.50625 .15321 L
s
[(0.2)] .4875 .15321 1 0 Mshowa
.5 .25257 m
.50625 .25257 L
s
[(0.4)] .4875 .25257 1 0 Mshowa
.5 .35192 m
.50625 .35192 L
s
[(0.6)] .4875 .35192 1 0 Mshowa
.5 .45128 m
.50625 .45128 L
s
[(0.8)] .4875 .45128 1 0 Mshowa
.5 .55064 m
.50625 .55064 L
s
[(1)] .4875 .55064 1 0 Mshowa
.125 Mabswid
.5 .07869 m
.50375 .07869 L
s
.5 .10353 m
.50375 .10353 L
s
.5 .12837 m
.50375 .12837 L
s
.5 .17805 m
.50375 .17805 L
s
.5 .20289 m
.50375 .20289 L
s
.5 .22773 m
.50375 .22773 L
s
.5 .27741 m
.50375 .27741 L
s
.5 .30225 m
.50375 .30225 L
s
.5 .32708 m
.50375 .32708 L
s
.5 .37676 m
.50375 .37676 L
s
.5 .4016 m
.50375 .4016 L
s
.5 .42644 m
.50375 .42644 L
s
.5 .47612 m
.50375 .47612 L
s
.5 .50096 m
.50375 .50096 L
s
.5 .5258 m
.50375 .5258 L
s
.5 .02901 m
.50375 .02901 L
s
.5 .00417 m
.50375 .00417 L
s
.5 .57548 m
.50375 .57548 L
s
.5 .60032 m
.50375 .60032 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.875000 moveto
 460.000000 16.875000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.875000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(11) show
81.000000 13.000000 moveto
(coefficients) show
153.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .58178 m
.03279 .5544 L
.03543 .54075 L
.03793 .529 L
.03902 .52472 L
.04018 .52097 L
.04145 .51794 L
.04262 .51629 L
.04384 .51583 L
.04498 .51662 L
.04623 .51885 L
.04693 .52072 L
.04758 .52281 L
.0503 .53523 L
.05288 .55116 L
.05546 .56879 L
.0579 .58448 L
.05896 .59038 L
.06008 .59567 L
.06131 .60005 L
.06244 .60254 L
.06369 .60329 L
.06486 .6019 L
.06613 .59786 L
.06685 .59437 L
.0675 .5904 L
.06883 .57997 L
.07027 .56499 L
.07289 .52823 L
.07793 .42798 L
.08259 .31434 L
.08809 .18202 L
.09078 .12687 L
.09325 .08512 L
.09584 .05171 L
.0972 .0386 L
.09864 .02806 L
.09935 .02403 L
.10011 .02058 L
.10082 .01808 L
.10147 .01644 L
.10224 .01522 L
.10307 .01472 L
.10386 .01496 L
.10458 .01576 L
.10583 .01829 L
.10702 .02181 L
.10925 .03054 L
.11427 .05342 L
.11638 .06167 L
Mistroke
.11753 .06541 L
.11861 .06833 L
.1199 .07099 L
.12107 .07261 L
.12216 .07343 L
.12334 .0736 L
.12464 .07297 L
.12584 .07168 L
.12716 .06962 L
.12858 .06678 L
.1341 .05305 L
.13676 .04715 L
.13806 .04484 L
.13927 .04316 L
.14037 .04204 L
.14153 .04129 L
.1427 .041 L
.14398 .04121 L
.15423 .05531 L
.15672 .05912 L
.15808 .06079 L
.15937 .06201 L
.16011 .06254 L
.1609 .06296 L
.16162 .06321 L
.16229 .06334 L
.1636 .06326 L
.16427 .06306 L
.165 .06274 L
.16628 .06189 L
.16751 .0608 L
.1698 .05819 L
.17494 .0514 L
.1771 .04899 L
.17828 .04794 L
.17939 .04716 L
.18059 .04657 L
.18191 .04624 L
.18303 .04623 L
.18424 .04648 L
.18541 .04698 L
.18667 .04776 L
.18893 .0497 L
.19408 .05528 L
.19541 .05666 L
.19687 .05798 L
.19815 .05894 L
.19885 .05937 L
.1995 .05971 L
.20073 .06017 L
Mistroke
.20137 .06031 L
.20207 .06039 L
.20331 .06032 L
.20444 .06005 L
.20558 .05958 L
.2068 .05888 L
.20899 .0572 L
.21395 .05246 L
.21639 .05035 L
.21758 .04951 L
.21868 .04887 L
.21969 .04843 L
.22075 .04812 L
.22181 .04797 L
.22298 .048 L
.22428 .04827 L
.22549 .04873 L
.22682 .04944 L
.22822 .0504 L
.23319 .05468 L
.23532 .05649 L
.23762 .05806 L
.23893 .05872 L
.24014 .05914 L
.24129 .05935 L
.2425 .05938 L
.24381 .05918 L
.24501 .0588 L
.24567 .05852 L
.24638 .05815 L
.24768 .05735 L
.2525 .05344 L
.25526 .05117 L
.25677 .05012 L
.25818 .04934 L
.25939 .04884 L
.26068 .04852 L
.26141 .04843 L
.26211 .04842 L
.26342 .04857 L
.26467 .04893 L
.26538 .04922 L
.26602 .04954 L
.26847 .05111 L
.27304 .05494 L
.27562 .057 L
.27688 .05783 L
.27803 .05846 L
.27924 .05896 L
.28053 .05929 L
Mistroke
.28121 .05938 L
.28195 .05939 L
.28264 .05934 L
.28328 .05923 L
.28434 .05893 L
.28548 .05845 L
.28655 .05785 L
.28753 .0572 L
.29221 .05325 L
.29454 .05122 L
.29576 .05027 L
.29707 .04939 L
.29833 .04872 L
.29946 .04829 L
.30061 .04803 L
.30169 .04796 L
.30285 .04808 L
.30409 .04842 L
.30527 .04894 L
.30634 .04958 L
.30896 .05163 L
.31144 .05399 L
.31384 .05631 L
.31638 .05844 L
.31771 .0593 L
.31841 .05967 L
.31917 .05998 L
.31987 .0602 L
.3205 .06033 L
.32176 .06039 L
.32283 .06023 L
.32398 .05986 L
.32507 .05932 L
.32605 .05867 L
.32847 .05659 L
.33075 .05417 L
.33311 .05154 L
.33565 .04897 L
.33687 .04795 L
.33804 .04717 L
.33908 .04666 L
.34023 .04631 L
.34139 .04621 L
.34263 .04638 L
.34379 .04682 L
.34485 .04744 L
.34611 .04843 L
.34747 .04978 L
.34994 .05276 L
.35495 .05933 L
Mistroke
.35616 .06066 L
.35747 .06184 L
.35821 .06238 L
.3589 .06278 L
.35958 .06308 L
.36023 .06326 L
.36139 .06335 L
.36262 .06308 L
.36368 .06255 L
.36484 .06167 L
.36608 .06039 L
.36742 .05867 L
.36984 .05487 L
.37412 .04746 L
.37524 .0457 L
.37647 .04402 L
.37754 .0428 L
.37868 .04182 L
.37933 .04143 L
.38004 .04114 L
.38128 .04102 L
.38251 .0414 L
.38365 .04222 L
.38481 .04351 L
.38588 .04506 L
.38827 .04968 L
.39371 .06322 L
.3961 .06859 L
.39747 .07097 L
.39875 .07259 L
.39996 .07345 L
.40126 .07357 L
.40194 .07327 L
.40266 .07269 L
.40394 .07094 L
.40461 .06966 L
.40533 .068 L
.40663 .06434 L
.40958 .05322 L
.41218 .04143 L
.41493 .02894 L
.41606 .02441 L
.41727 .02025 L
.41797 .0183 L
.41861 .01685 L
.41986 .01504 L
.42116 .01487 L
.42236 .0165 L
.42306 .0183 L
.42369 .02052 L
Mistroke
.42441 .0238 L
.4251 .02761 L
.42635 .03644 L
.42749 .04679 L
.43008 .07813 L
.43265 .11993 L
.43547 .17661 L
.44117 .31311 L
.4462 .43524 L
.44897 .4935 L
.45159 .53876 L
.45402 .57045 L
.4554 .58361 L
.45668 .59272 L
.45774 .59814 L
.45892 .60184 L
.46016 .6033 L
.46131 .60261 L
.47025 .55573 L
.47261 .54047 L
.47385 .53343 L
.47516 .52705 L
.47631 .52255 L
.47757 .51887 L
.47872 .51676 L
.47979 .51587 L
.4805 .51587 L
.48118 .51628 L
.48244 .51809 L
.48315 .51967 L
.4838 .52147 L
.48528 .52659 L
.49027 .5505 L
.4927 .56263 L
.49498 .57223 L
.49625 .57633 L
.49692 .57806 L
.49762 .57955 L
.49886 .58127 L
.50001 .58178 L
.50126 .58115 L
.5024 .57951 L
.50371 .57643 L
.50496 .57244 L
.50717 .56325 L
.50957 .55134 L
.51222 .53779 L
.51366 .53099 L
.51502 .52544 L
.51627 .52126 L
Mistroke
.51741 .51839 L
.51869 .51641 L
.51939 .51591 L
.52005 .51584 L
.52074 .51618 L
.52138 .51689 L
.52258 .51924 L
.52388 .52321 L
.52528 .52906 L
.52781 .54302 L
.53014 .55838 L
.53291 .57714 L
.53549 .59212 L
.5368 .59773 L
.53753 .60012 L
.53819 .60176 L
.53892 .6029 L
.53971 .60332 L
.54046 .60286 L
.54115 .60166 L
.54233 .59783 L
.54357 .59122 L
.54462 .5834 L
.54578 .57252 L
.54836 .53948 L
.55077 .49853 L
.5598 .28876 L
.56492 .16812 L
.56744 .11837 L
.56976 .0805 L
.57243 .04759 L
.57384 .03499 L
.57456 .02981 L
.57533 .02514 L
.57658 .01952 L
.57774 .01628 L
.57845 .01519 L
.57913 .01474 L
.5804 .01529 L
.58164 .01738 L
.58235 .01914 L
.58299 .02108 L
.58543 .03049 L
.59 .05139 L
.59257 .06168 L
.59383 .06573 L
.59497 .06873 L
.59618 .07114 L
.59748 .07282 L
.59815 .07333 L
Mistroke
.59889 .0736 L
.59958 .07359 L
.60022 .07336 L
.60128 .07256 L
.60241 .07115 L
.60348 .06938 L
.60447 .06743 L
.60915 .05592 L
.61154 .05011 L
.61376 .04566 L
.61488 .04391 L
.61608 .04248 L
.61676 .04188 L
.61741 .04145 L
.61862 .04103 L
.61977 .04109 L
.62101 .04162 L
.62218 .04253 L
.62325 .04368 L
.62587 .04744 L
.62835 .05172 L
.63074 .05585 L
.63328 .05961 L
.63474 .06128 L
.63607 .06239 L
.63671 .06278 L
.6374 .06309 L
.63865 .06335 L
.63981 .06325 L
.64089 .06289 L
.64207 .06219 L
.64334 .06115 L
.64592 .05827 L
.64827 .05516 L
.65248 .04983 L
.65363 .04867 L
.65487 .04764 L
.65604 .04691 L
.65711 .04646 L
.65829 .04622 L
.65959 .04628 L
.66081 .04661 L
.66194 .04716 L
.66324 .04804 L
.66442 .04903 L
.66706 .05173 L
.66939 .05433 L
.67185 .0569 L
.67395 .05867 L
.67514 .05943 L
Mistroke
.67625 .05995 L
.67755 .06031 L
.67873 .06039 L
.67939 .06034 L
.6801 .0602 L
.68139 .05976 L
.68206 .05943 L
.68279 .059 L
.68428 .05794 L
.68695 .05556 L
.69177 .051 L
.69309 .04997 L
.6945 .04907 L
.69518 .04872 L
.69583 .04845 L
.69704 .0481 L
.69826 .04796 L
.69939 .04803 L
.70064 .04832 L
.70195 .04885 L
.70322 .04957 L
.70442 .0504 L
.70713 .05265 L
.7094 .0547 L
.71187 .05676 L
.71301 .05757 L
.71421 .05829 L
.71535 .05882 L
.71638 .05915 L
.71768 .05937 L
.71841 .05939 L
.71909 .05935 L
.72032 .0591 L
.72163 .05862 L
.72282 .05801 L
.72392 .05731 L
.72643 .05538 L
.73161 .05105 L
.73303 .05008 L
.73453 .04926 L
.73582 .04877 L
.73655 .04858 L
.73723 .04846 L
.73852 .04843 L
.73916 .04849 L
.73987 .04863 L
.74112 .04903 L
.74228 .04957 L
.74491 .0513 L
.74771 .05362 L
Mistroke
.75039 .0559 L
.7517 .05691 L
.75291 .05773 L
.75399 .05835 L
.75517 .05887 L
.75636 .05922 L
.75762 .05939 L
.75887 .05934 L
.76004 .05909 L
.7611 .05871 L
.76225 .05814 L
.76483 .05636 L
.76722 .05431 L
.7695 .05227 L
.7719 .05031 L
.77395 .049 L
.77511 .04847 L
.77619 .04814 L
.77736 .04797 L
.77842 .04799 L
.77965 .04822 L
.78081 .04863 L
.78206 .04928 L
.7832 .05005 L
.7858 .05223 L
.79046 .05671 L
.79274 .05856 L
.79374 .05921 L
.79483 .05977 L
.796 .06018 L
.79712 .06037 L
.7984 .06034 L
.79959 .06008 L
.80027 .05982 L
.80092 .0595 L
.80212 .05876 L
.80483 .05642 L
.80988 .05092 L
.81255 .04836 L
.81332 .04776 L
.81405 .04728 L
.81472 .04691 L
.81542 .0466 L
.81668 .04626 L
.81784 .04622 L
.81909 .04646 L
.81981 .04674 L
.82047 .04708 L
.82166 .04789 L
.82274 .04884 L
Mistroke
.82519 .05156 L
.83012 .05808 L
.83147 .05971 L
.83291 .0612 L
.83361 .06181 L
.83427 .0623 L
.83551 .06298 L
.8366 .0633 L
.83776 .06333 L
.83874 .0631 L
.83983 .06258 L
.841 .0617 L
.84225 .06042 L
.84451 .05734 L
.8491 .0495 L
.85162 .04543 L
.85285 .04378 L
.85399 .04255 L
.85462 .04201 L
.85531 .04154 L
.85601 .04121 L
.85675 .04102 L
.85804 .04113 L
.85925 .04174 L
.86048 .04288 L
.8616 .04434 L
.86412 .04895 L
.86942 .06202 L
.87221 .06843 L
.87362 .07092 L
.87442 .07201 L
.87517 .0728 L
.87586 .07331 L
.87652 .07357 L
.87776 .07347 L
.87845 .07305 L
.87909 .07243 L
.87979 .07149 L
.88054 .07018 L
.88188 .06707 L
.88315 .0633 L
.88551 .05436 L
.89016 .03313 L
.89263 .02301 L
.89334 .02063 L
.89401 .01868 L
.89528 .01598 L
.89653 .01476 L
.89769 .01515 L
.89897 .01749 L
Mistroke
.89961 .01951 L
.90032 .02242 L
.90149 .02887 L
.90275 .03822 L
.90503 .06177 L
.90765 .09932 L
.91041 .15018 L
.91534 .26277 L
.92032 .38654 L
.92502 .49078 L
.92707 .52754 L
.92924 .55898 L
.93037 .57209 L
.93162 .58381 L
.93275 .59202 L
.93381 .59762 L
.93504 .60168 L
.93621 .60325 L
.93726 .60291 L
.93841 .60082 L
.93965 .59676 L
.94097 .59074 L
.94335 .57672 L
.94587 .55962 L
.9486 .54167 L
.94985 .53443 L
.95117 .52784 L
.95241 .52285 L
.95354 .51941 L
.95469 .51707 L
.95592 .5159 L
.95706 .51604 L
.95814 .51722 L
.95939 .51981 L
.96055 .52324 L
.96317 .53394 L
.96733 .55496 L
.96969 .56626 L
.97084 .571 L
.9719 .5747 L
.97289 .57752 L
.97397 .57983 L
.97505 .58126 L
.97619 .58178 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.0629327 0.499383 [
[.02381 .05043 -6 -9 ]
[.02381 .05043 6 0 ]
[.2619 .05043 -12 -9 ]
[.2619 .05043 12 0 ]
[.7381 .05043 -9 -9 ]
[.7381 .05043 9 0 ]
[.97619 .05043 -3 -9 ]
[.97619 .05043 3 0 ]
[.4875 .16281 -18 -4.5 ]
[.4875 .16281 0 4.5 ]
[.4875 .26269 -18 -4.5 ]
[.4875 .26269 0 4.5 ]
[.4875 .36256 -18 -4.5 ]
[.4875 .36256 0 4.5 ]
[.4875 .46244 -18 -4.5 ]
[.4875 .46244 0 4.5 ]
[.4875 .56232 -6 -4.5 ]
[.4875 .56232 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12.875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 .06293 m
.02381 .06918 L
s
[(-1)] .02381 .05043 0 1 Mshowa
.2619 .06293 m
.2619 .06918 L
s
[(-0.5)] .2619 .05043 0 1 Mshowa
.7381 .06293 m
.7381 .06918 L
s
[(0.5)] .7381 .05043 0 1 Mshowa
.97619 .06293 m
.97619 .06918 L
s
[(1)] .97619 .05043 0 1 Mshowa
.125 Mabswid
.07143 .06293 m
.07143 .06668 L
s
.11905 .06293 m
.11905 .06668 L
s
.16667 .06293 m
.16667 .06668 L
s
.21429 .06293 m
.21429 .06668 L
s
.30952 .06293 m
.30952 .06668 L
s
.35714 .06293 m
.35714 .06668 L
s
.40476 .06293 m
.40476 .06668 L
s
.45238 .06293 m
.45238 .06668 L
s
.54762 .06293 m
.54762 .06668 L
s
.59524 .06293 m
.59524 .06668 L
s
.64286 .06293 m
.64286 .06668 L
s
.69048 .06293 m
.69048 .06668 L
s
.78571 .06293 m
.78571 .06668 L
s
.83333 .06293 m
.83333 .06668 L
s
.88095 .06293 m
.88095 .06668 L
s
.92857 .06293 m
.92857 .06668 L
s
.25 Mabswid
0 .06293 m
1 .06293 L
s
.5 .16281 m
.50625 .16281 L
s
[(0.2)] .4875 .16281 1 0 Mshowa
.5 .26269 m
.50625 .26269 L
s
[(0.4)] .4875 .26269 1 0 Mshowa
.5 .36256 m
.50625 .36256 L
s
[(0.6)] .4875 .36256 1 0 Mshowa
.5 .46244 m
.50625 .46244 L
s
[(0.8)] .4875 .46244 1 0 Mshowa
.5 .56232 m
.50625 .56232 L
s
[(1)] .4875 .56232 1 0 Mshowa
.125 Mabswid
.5 .0879 m
.50375 .0879 L
s
.5 .11287 m
.50375 .11287 L
s
.5 .13784 m
.50375 .13784 L
s
.5 .18778 m
.50375 .18778 L
s
.5 .21275 m
.50375 .21275 L
s
.5 .23772 m
.50375 .23772 L
s
.5 .28765 m
.50375 .28765 L
s
.5 .31262 m
.50375 .31262 L
s
.5 .33759 m
.50375 .33759 L
s
.5 .38753 m
.50375 .38753 L
s
.5 .4125 m
.50375 .4125 L
s
.5 .43747 m
.50375 .43747 L
s
.5 .48741 m
.50375 .48741 L
s
.5 .51238 m
.50375 .51238 L
s
.5 .53735 m
.50375 .53735 L
s
.5 .03796 m
.50375 .03796 L
s
.5 .01299 m
.50375 .01299 L
s
.5 .58728 m
.50375 .58728 L
s
.5 .61225 m
.50375 .61225 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.875000 moveto
 460.000000 16.875000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.875000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(21) show
81.000000 13.000000 moveto
(coefficients) show
153.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .57064 m
.02499 .57029 L
.02605 .56937 L
.02729 .56769 L
.02846 .56561 L
.03056 .56117 L
.03279 .55659 L
.03395 .55471 L
.03524 .55334 L
.03641 .55288 L
.0375 .55319 L
.03879 .55452 L
.03997 .55659 L
.04132 .55979 L
.04262 .56336 L
.045 .57002 L
.04568 .57166 L
.04633 .57298 L
.04753 .57472 L
.04867 .57529 L
.04973 .57476 L
.05088 .57295 L
.0521 .56973 L
.05488 .55866 L
.05624 .55257 L
.05751 .54752 L
.05866 .54401 L
.05987 .54196 L
.0611 .54209 L
.06179 .54326 L
.06244 .54511 L
.0637 .5507 L
.06486 .55792 L
.06746 .57878 L
.06881 .5897 L
.07008 .59792 L
.07139 .60282 L
.07209 .6033 L
.07283 .60188 L
.07409 .59423 L
.07479 .5867 L
.07545 .57756 L
.07665 .55509 L
.07791 .52331 L
.08011 .45047 L
.08253 .35135 L
.08535 .22839 L
.08802 .12525 L
.0895 .08069 L
.09028 .06161 L
Mistroke
.09111 .0449 L
.09187 .0328 L
.09257 .02461 L
.09327 .01893 L
.09392 .01582 L
.09522 .0154 L
.09588 .0177 L
.09659 .02181 L
.09786 .03219 L
.09905 .04406 L
.10044 .05874 L
.10192 .07287 L
.10319 .08225 L
.10391 .08613 L
.10458 .0887 L
.10584 .09067 L
.107 .08933 L
.10827 .08487 L
.10891 .08169 L
.1096 .07767 L
.11224 .06048 L
.11369 .05209 L
.1144 .04878 L
.11506 .04634 L
.11635 .04343 L
.11703 .04299 L
.11775 .04332 L
.11892 .04549 L
.1202 .04983 L
.12269 .06164 L
.12497 .07207 L
.12611 .07582 L
.12735 .07826 L
.12852 .07879 L
.1296 .07776 L
.13075 .07525 L
.13201 .07115 L
.13457 .0609 L
.13565 .0568 L
.1368 .05324 L
.13805 .05059 L
.1392 .04956 L
.14027 .04987 L
.14127 .0512 L
.14237 .05368 L
.14354 .0572 L
.14612 .06615 L
.14754 .07041 L
.14823 .07206 L
.14886 .07324 L
Mistroke
.14998 .07449 L
.1512 .07453 L
.15251 .07307 L
.15377 .07044 L
.15634 .06287 L
.15775 .05862 L
.15907 .05532 L
.15983 .05392 L
.16065 .05289 L
.16139 .05242 L
.16208 .0524 L
.16272 .05274 L
.16343 .05349 L
.16417 .05467 L
.16486 .05607 L
.16725 .06241 L
.16852 .06594 L
.16986 .0692 L
.17102 .07128 L
.17231 .0725 L
.17349 .07251 L
.17459 .07158 L
.17525 .07061 L
.17596 .06931 L
.17721 .06644 L
.18004 .05917 L
.18119 .05671 L
.18241 .05483 L
.18312 .05419 L
.18376 .05391 L
.18501 .05421 L
.1862 .05549 L
.18732 .05744 L
.18986 .06339 L
.19113 .06642 L
.19234 .06886 L
.193 .06992 L
.19373 .07078 L
.195 .07148 L
.19621 .07112 L
.19731 .06998 L
.19858 .06786 L
.19978 .0653 L
.20189 .06039 L
.20301 .05808 L
.20421 .05616 L
.20552 .05496 L
.20674 .05482 L
.20746 .0552 L
.20814 .05584 L
Mistroke
.20942 .05771 L
.21061 .06006 L
.21172 .0625 L
.21421 .06776 L
.2155 .06967 L
.2167 .07065 L
.21739 .07082 L
.21803 .0707 L
.21876 .07027 L
.21945 .06957 L
.22012 .06866 L
.22083 .06747 L
.22211 .06491 L
.22349 .0619 L
.22501 .05881 L
.22566 .05769 L
.22635 .05669 L
.22761 .05553 L
.22835 .05527 L
.22905 .05534 L
.23036 .05624 L
.23159 .05791 L
.23272 .05998 L
.23529 .06537 L
.23652 .06767 L
.23717 .06866 L
.23785 .06949 L
.23861 .07013 L
.23931 .07042 L
.23996 .07044 L
.24068 .07016 L
.24143 .06955 L
.24211 .06873 L
.24365 .06619 L
.24641 .0605 L
.24767 .0582 L
.24835 .05718 L
.249 .05642 L
.25014 .05561 L
.25139 .05559 L
.25208 .05598 L
.25275 .0566 L
.25399 .05833 L
.25678 .06384 L
.25796 .0662 L
.25921 .06831 L
.2604 .06969 L
.26147 .07029 L
.26273 .07015 L
.26345 .06966 L
Mistroke
.2641 .06897 L
.26531 .06718 L
.26658 .06476 L
.2678 .06222 L
.26913 .05955 L
.2703 .05758 L
.27155 .05613 L
.27267 .05553 L
.2739 .05572 L
.27502 .05665 L
.27608 .05809 L
.27866 .06313 L
.28007 .06602 L
.28138 .06829 L
.28251 .06967 L
.28371 .0704 L
.28439 .07044 L
.28504 .07022 L
.28625 .06917 L
.28732 .06762 L
.28845 .06551 L
.29049 .06122 L
.29154 .05911 L
.29267 .05722 L
.29392 .05581 L
.29508 .05527 L
.2963 .05559 L
.29699 .05616 L
.29763 .05692 L
.2988 .05881 L
.30005 .06132 L
.30222 .06599 L
.30336 .06813 L
.30459 .06983 L
.30582 .07072 L
.30696 .07071 L
.30827 .06972 L
.30946 .068 L
.31057 .06588 L
.31176 .06325 L
.31394 .05855 L
.31515 .0565 L
.31584 .05565 L
.31648 .0551 L
.31779 .05479 L
.31852 .05509 L
.31918 .05566 L
.32037 .05731 L
.32167 .05984 L
.32403 .06529 L
Mistroke
.32527 .06793 L
.32643 .06989 L
.32748 .07104 L
.32861 .07149 L
.32985 .07098 L
.33116 .06938 L
.33228 .0673 L
.3335 .06449 L
.3357 .05915 L
.33691 .05665 L
.33805 .05491 L
.33911 .05403 L
.34027 .05397 L
.34132 .05475 L
.3423 .05612 L
.34693 .06725 L
.3482 .06999 L
.34884 .07106 L
.34954 .07193 L
.35077 .07263 L
.35193 .07223 L
.3531 .0708 L
.35422 .06862 L
.3563 .06315 L
.35852 .05707 L
.35978 .05441 L
.36097 .05284 L
.36217 .05237 L
.36346 .05321 L
.36417 .05424 L
.36485 .05556 L
.36611 .05875 L
.36841 .06579 L
.36967 .06947 L
.37085 .07226 L
.37152 .07343 L
.37225 .07428 L
.37351 .07463 L
.3748 .07347 L
.37598 .07115 L
.37728 .06748 L
.3787 .06264 L
.38019 .05746 L
.38085 .05538 L
.38157 .05335 L
.38279 .05078 L
.38409 .04956 L
.38477 .04962 L
.3855 .05024 L
.3862 .05134 L
Mistroke
.38683 .05276 L
.38805 .05643 L
.38938 .06146 L
.39065 .06667 L
.3918 .07117 L
.39293 .07487 L
.39414 .07765 L
.39543 .07881 L
.39664 .07803 L
.39777 .07563 L
.39897 .07155 L
.40112 .0616 L
.4024 .05525 L
.40361 .04983 L
.40428 .04734 L
.40501 .04519 L
.40628 .04313 L
.40749 .04348 L
.40878 .04644 L
.40988 .05092 L
.4111 .05757 L
.41382 .07524 L
.41524 .08344 L
.41596 .08665 L
.41675 .08917 L
.41744 .09041 L
.41818 .0906 L
.41888 .08962 L
.41951 .08774 L
.42082 .08099 L
.42205 .07143 L
.42428 .04916 L
.42551 .03643 L
.42668 .02583 L
.42733 .02105 L
.42805 .01719 L
.4293 .01474 L
.43058 .01916 L
.43176 .0305 L
.43241 .03987 L
.43311 .05258 L
.43438 .0824 L
.43674 .15935 L
.44205 .38438 L
.44447 .47831 L
.44672 .54497 L
.44786 .56903 L
.44908 .58746 L
.44977 .59466 L
.45043 .59939 L
Mistroke
.45166 .60327 L
.45273 .60209 L
.45386 .59723 L
.45483 .59094 L
.45589 .5826 L
.45828 .5629 L
.45944 .55465 L
.4605 .5487 L
.46163 .54426 L
.46285 .54196 L
.46348 .54174 L
.46417 .5422 L
.46542 .54471 L
.46673 .54913 L
.46812 .555 L
.4706 .56578 L
.4717 .56969 L
.47288 .57285 L
.474 .57466 L
.47501 .57528 L
.4762 .57479 L
.4775 .57295 L
.47873 .57024 L
.47986 .56719 L
.4826 .5595 L
.48394 .55639 L
.48517 .55432 L
.48629 .5532 L
.48748 .55288 L
.48867 .55341 L
.48997 .55487 L
.49262 .5598 L
.49402 .56284 L
.4955 .56589 L
.49679 .56812 L
.49753 .56911 L
.49822 .56984 L
.49943 .57056 L
.50073 .57051 L
.50204 .56959 L
.50278 .56872 L
.50347 .56771 L
.50608 .56264 L
.50864 .55721 L
.50976 .55527 L
.51097 .55373 L
.51218 .55295 L
.51329 .55299 L
.51436 .55376 L
.51548 .55532 L
Mistroke
.51667 .55771 L
.51778 .56048 L
.52029 .56763 L
.52159 .57102 L
.52228 .57252 L
.52301 .57382 L
.52364 .57464 L
.52434 .57517 L
.52558 .57504 L
.52677 .57353 L
.52806 .57041 L
.52928 .56623 L
.5304 .56163 L
.53172 .55573 L
.53313 .54968 L
.53382 .54711 L
.53446 .54504 L
.53567 .5424 L
.53695 .54182 L
.53767 .54263 L
.53833 .54415 L
.539 .54646 L
.53974 .54986 L
.54123 .55922 L
.54372 .5794 L
.54504 .58996 L
.54576 .59496 L
.54644 .59883 L
.54709 .60153 L
.54779 .60313 L
.54901 .60193 L
.55025 .59448 L
.55139 .58128 L
.5525 .56204 L
.55354 .53834 L
.55591 .46508 L
.56067 .26566 L
.56339 .15451 L
.56472 .10873 L
.56595 .07382 L
.56707 .04904 L
.56826 .03023 L
.56945 .01897 L
.57076 .01472 L
.57145 .01548 L
.57216 .01817 L
.57345 .02683 L
.57483 .03983 L
.57634 .05569 L
.57765 .06873 L
Mistroke
.57837 .075 L
.57905 .0801 L
.58037 .08729 L
.58157 .09037 L
.58272 .09021 L
.58397 .08693 L
.58514 .08146 L
.58621 .07509 L
.58886 .05784 L
.59002 .05139 L
.59131 .04614 L
.59254 .04344 L
.59384 .04322 L
.59453 .04416 L
.59526 .04592 L
.59596 .04818 L
.5966 .0507 L
.5992 .0632 L
.60046 .06918 L
.60161 .07372 L
.60268 .07677 L
.60369 .07842 L
.60475 .07877 L
.60591 .07757 L
.60709 .07481 L
.60835 .0706 L
.6106 .06153 L
.61173 .05722 L
.61293 .05338 L
.61407 .05086 L
.61511 .04968 L
.61633 .04977 L
.61702 .0505 L
.61766 .05158 L
.61883 .05443 L
.62008 .05837 L
.62269 .06736 L
.624 .0711 L
.62475 .07271 L
.62544 .07381 L
.62669 .07468 L
.62782 .07421 L
.62913 .07229 L
.63037 .06936 L
.63296 .06152 L
.63437 .05743 L
.63507 .05575 L
.6357 .05446 L
.63639 .05339 L
.63714 .05264 L
Mistroke
.63791 .05236 L
.63872 .0526 L
.63941 .05322 L
.64005 .05412 L
.64075 .05543 L
.6415 .05713 L
.64411 .06431 L
.64549 .06793 L
.64624 .0696 L
.64694 .07087 L
.64821 .07234 L
.64889 .07262 L
.64961 .07254 L
.6509 .07143 L
.65207 .06946 L
.65467 .06313 L
.65594 .05985 L
.65711 .05722 L
.65818 .05537 L
.65931 .05419 L
.66044 .05389 L
.66168 .05461 L
.66287 .05625 L
.66415 .05881 L
.66646 .0644 L
.66783 .06752 L
.66913 .06982 L
.67029 .07109 L
.67155 .07147 L
.67265 .07093 L
.67386 .06946 L
.67513 .06714 L
.67631 .0645 L
.67842 .05966 L
.67953 .05749 L
.68071 .05578 L
.68144 .05512 L
.6821 .05481 L
.68338 .05502 L
.68469 .05628 L
.68593 .05829 L
.68825 .06328 L
.68952 .06605 L
.6907 .06828 L
.69198 .06999 L
.69266 .07053 L
.69339 .0708 L
.69468 .07046 L
.69586 .06928 L
.69658 .06823 L
Mistroke
.69724 .06706 L
.69873 .06397 L
.70006 .06109 L
.70145 .05835 L
.7026 .05662 L
.70387 .05549 L
.70501 .05528 L
.70608 .0558 L
.70734 .05724 L
.70849 .05917 L
.71107 .06453 L
.71215 .06668 L
.7133 .06857 L
.71456 .06996 L
.71572 .07046 L
.7168 .0702 L
.71781 .06935 L
.71891 .06783 L
.7201 .06567 L
.72274 .06022 L
.72414 .05776 L
.72492 .05671 L
.72562 .05603 L
.7263 .05562 L
.72702 .05549 L
.72834 .05604 L
.72966 .05752 L
.73087 .05954 L
.73334 .0646 L
.73455 .06693 L
.73565 .06865 L
.73681 .06987 L
.73806 .07035 L
.73871 .07024 L
.73942 .06984 L
.7407 .06843 L
.74524 .05971 L
.74648 .0576 L
.74778 .05609 L
.7489 .05552 L
.75012 .05573 L
.75082 .05624 L
.75146 .05694 L
.7522 .05799 L
.75289 .05917 L
.75548 .06444 L
.75665 .06675 L
.75789 .06874 L
.75854 .06951 L
.75925 .07011 L
Mistroke
.7605 .07045 L
.76117 .07025 L
.76191 .06973 L
.7626 .06897 L
.76324 .06805 L
.76574 .06321 L
.76703 .06049 L
.76841 .05791 L
.76921 .05675 L
.76993 .05595 L
.77063 .05547 L
.77136 .05526 L
.77258 .05565 L
.77371 .05678 L
.77496 .05874 L
.77629 .06141 L
.77878 .06672 L
.77946 .06797 L
.78019 .0691 L
.78088 .06994 L
.78152 .07047 L
.78284 .07079 L
.7841 .07009 L
.78541 .06841 L
.78614 .06711 L
.78683 .06573 L
.78936 .06012 L
.7906 .05768 L
.79174 .05598 L
.79239 .05531 L
.79309 .05488 L
.79379 .05476 L
.79455 .055 L
.79587 .05626 L
.7971 .05829 L
.80004 .06489 L
.80149 .06799 L
.80212 .06913 L
.80283 .07017 L
.80401 .07126 L
.80526 .07142 L
.80592 .07108 L
.80663 .07039 L
.80791 .06841 L
.80909 .06592 L
.81033 .06292 L
.81255 .05771 L
.81379 .0555 L
.81449 .05464 L
.81513 .05413 L
Mistroke
.81636 .05394 L
.81752 .05476 L
.81818 .05563 L
.81888 .05684 L
.82014 .05958 L
.82297 .06688 L
.82418 .06958 L
.8255 .07168 L
.82674 .07259 L
.8279 .07239 L
.82904 .07118 L
.83008 .06933 L
.83128 .06648 L
.83241 .06338 L
.83478 .05691 L
.83597 .05441 L
.83728 .05274 L
.83796 .05239 L
.8387 .05245 L
.83939 .05293 L
.84002 .0537 L
.84132 .0562 L
.84254 .05945 L
.84476 .06628 L
.84597 .06976 L
.84711 .07238 L
.84807 .0739 L
.84911 .07465 L
.85027 .07431 L
.85132 .07294 L
.85247 .07038 L
.85354 .06724 L
.85597 .05885 L
.85719 .05493 L
.85833 .05198 L
.85966 .04993 L
.86086 .04958 L
.86202 .05069 L
.86326 .05338 L
.86443 .05711 L
.8655 .0612 L
.86679 .06645 L
.86815 .07174 L
.86932 .07543 L
.87061 .07807 L
.87191 .07879 L
.87314 .07752 L
.87383 .07598 L
.87447 .07409 L
.8759 .06843 L
Mistroke
.87849 .05572 L
.87976 .05 L
.88091 .04595 L
.88198 .04364 L
.88299 .04299 L
.88405 .04405 L
.88521 .04725 L
.88639 .05252 L
.88765 .05979 L
.8899 .07459 L
.89103 .08132 L
.89223 .08696 L
.89337 .09007 L
.89441 .09057 L
.89563 .08801 L
.89632 .08503 L
.89696 .08132 L
.89813 .07241 L
.89938 .06059 L
.90199 .03361 L
.9033 .02254 L
.90405 .01807 L
.90474 .01549 L
.90599 .01556 L
.90712 .02179 L
.90844 .03727 L
.90968 .06055 L
.91102 .09513 L
.91245 .14155 L
.91501 .24368 L
.9178 .36571 L
.92081 .48348 L
.92207 .52277 L
.92339 .55588 L
.92452 .57706 L
.92576 .59278 L
.92692 .60092 L
.92816 .60332 L
.92934 .60067 L
.9304 .59513 L
.93306 .57441 L
.93554 .55521 L
.93679 .54819 L
.93749 .54532 L
.93813 .54343 L
.93883 .54217 L
.9396 .54173 L
.94032 .54215 L
.94098 .54321 L
.94214 .5463 L
Mistroke
.94322 .55033 L
.94524 .55921 L
.9464 .56418 L
.94761 .56876 L
.94864 .57184 L
.94978 .57414 L
.95075 .57513 L
.9518 .5752 L
.95278 .57437 L
.95368 .57298 L
.95471 .57074 L
.95584 .56779 L
.95788 .56194 L
.95894 .5591 L
.96008 .55649 L
.96133 .55436 L
.9625 .55319 L
.96381 .5529 L
.96506 .55358 L
.96618 .5549 L
.9674 .55694 L
.97619 .57064 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.0147151 1.17721 [
[.02381 .00222 -6 -9 ]
[.02381 .00222 6 0 ]
[.2619 .00222 -12 -9 ]
[.2619 .00222 12 0 ]
[.7381 .00222 -9 -9 ]
[.7381 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.4875 .13244 -18 -4.5 ]
[.4875 .13244 0 4.5 ]
[.4875 .25016 -18 -4.5 ]
[.4875 .25016 0 4.5 ]
[.4875 .36788 -18 -4.5 ]
[.4875 .36788 0 4.5 ]
[.4875 .4856 -18 -4.5 ]
[.4875 .4856 0 4.5 ]
[.4875 .60332 -18 -4.5 ]
[.4875 .60332 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 .01472 m
.02381 .02097 L
s
[(-1)] .02381 .00222 0 1 Mshowa
.2619 .01472 m
.2619 .02097 L
s
[(-0.5)] .2619 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(0.5)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .13244 m
.50625 .13244 L
s
[(0.1)] .4875 .13244 1 0 Mshowa
.5 .25016 m
.50625 .25016 L
s
[(0.2)] .4875 .25016 1 0 Mshowa
.5 .36788 m
.50625 .36788 L
s
[(0.3)] .4875 .36788 1 0 Mshowa
.5 .4856 m
.50625 .4856 L
s
[(0.4)] .4875 .4856 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(0.5)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .03826 m
.50375 .03826 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .08535 m
.50375 .08535 L
s
.5 .10889 m
.50375 .10889 L
s
.5 .15598 m
.50375 .15598 L
s
.5 .17952 m
.50375 .17952 L
s
.5 .20307 m
.50375 .20307 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .2737 m
.50375 .2737 L
s
.5 .29724 m
.50375 .29724 L
s
.5 .32079 m
.50375 .32079 L
s
.5 .34433 m
.50375 .34433 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .41497 m
.50375 .41497 L
s
.5 .43851 m
.50375 .43851 L
s
.5 .46205 m
.50375 .46205 L
s
.5 .50914 m
.50375 .50914 L
s
.5 .53269 m
.50375 .53269 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57977 m
.50375 .57977 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.875000 moveto
 460.000000 16.875000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.875000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
75.000000 13.000000 moveto
(coefficient) show
141.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.0714188 0.49319 [
[.02381 .05892 -6 -9 ]
[.02381 .05892 6 0 ]
[.2619 .05892 -12 -9 ]
[.2619 .05892 12 0 ]
[.7381 .05892 -9 -9 ]
[.7381 .05892 9 0 ]
[.97619 .05892 -3 -9 ]
[.97619 .05892 3 0 ]
[.4875 .17006 -18 -4.5 ]
[.4875 .17006 0 4.5 ]
[.4875 .26869 -18 -4.5 ]
[.4875 .26869 0 4.5 ]
[.4875 .36733 -18 -4.5 ]
[.4875 .36733 0 4.5 ]
[.4875 .46597 -18 -4.5 ]
[.4875 .46597 0 4.5 ]
[.4875 .56461 -6 -4.5 ]
[.4875 .56461 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12.875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 .07142 m
.02381 .07767 L
s
[(-1)] .02381 .05892 0 1 Mshowa
.2619 .07142 m
.2619 .07767 L
s
[(-0.5)] .2619 .05892 0 1 Mshowa
.7381 .07142 m
.7381 .07767 L
s
[(0.5)] .7381 .05892 0 1 Mshowa
.97619 .07142 m
.97619 .07767 L
s
[(1)] .97619 .05892 0 1 Mshowa
.125 Mabswid
.07143 .07142 m
.07143 .07517 L
s
.11905 .07142 m
.11905 .07517 L
s
.16667 .07142 m
.16667 .07517 L
s
.21429 .07142 m
.21429 .07517 L
s
.30952 .07142 m
.30952 .07517 L
s
.35714 .07142 m
.35714 .07517 L
s
.40476 .07142 m
.40476 .07517 L
s
.45238 .07142 m
.45238 .07517 L
s
.54762 .07142 m
.54762 .07517 L
s
.59524 .07142 m
.59524 .07517 L
s
.64286 .07142 m
.64286 .07517 L
s
.69048 .07142 m
.69048 .07517 L
s
.78571 .07142 m
.78571 .07517 L
s
.83333 .07142 m
.83333 .07517 L
s
.88095 .07142 m
.88095 .07517 L
s
.92857 .07142 m
.92857 .07517 L
s
.25 Mabswid
0 .07142 m
1 .07142 L
s
.5 .17006 m
.50625 .17006 L
s
[(0.2)] .4875 .17006 1 0 Mshowa
.5 .26869 m
.50625 .26869 L
s
[(0.4)] .4875 .26869 1 0 Mshowa
.5 .36733 m
.50625 .36733 L
s
[(0.6)] .4875 .36733 1 0 Mshowa
.5 .46597 m
.50625 .46597 L
s
[(0.8)] .4875 .46597 1 0 Mshowa
.5 .56461 m
.50625 .56461 L
s
[(1)] .4875 .56461 1 0 Mshowa
.125 Mabswid
.5 .09608 m
.50375 .09608 L
s
.5 .12074 m
.50375 .12074 L
s
.5 .1454 m
.50375 .1454 L
s
.5 .19472 m
.50375 .19472 L
s
.5 .21938 m
.50375 .21938 L
s
.5 .24404 m
.50375 .24404 L
s
.5 .29335 m
.50375 .29335 L
s
.5 .31801 m
.50375 .31801 L
s
.5 .34267 m
.50375 .34267 L
s
.5 .39199 m
.50375 .39199 L
s
.5 .41665 m
.50375 .41665 L
s
.5 .44131 m
.50375 .44131 L
s
.5 .49063 m
.50375 .49063 L
s
.5 .51529 m
.50375 .51529 L
s
.5 .53995 m
.50375 .53995 L
s
.5 .04676 m
.50375 .04676 L
s
.5 .0221 m
.50375 .0221 L
s
.5 .58927 m
.50375 .58927 L
s
.5 .61393 m
.50375 .61393 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.875000 moveto
 460.000000 16.875000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.875000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
75.000000 13.000000 moveto
(coefficients) show
147.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60327 L
.02605 .60314 L
.02729 .60289 L
.02846 .60254 L
.02954 .60213 L
.03053 .60167 L
.03279 .60032 L
.03506 .59847 L
.03756 .59581 L
.04017 .59223 L
.04262 .58801 L
.04761 .57641 L
.05217 .5616 L
.05744 .53872 L
.06244 .51062 L
.07289 .43178 L
.08259 .33845 L
.09391 .21986 L
.10458 .1191 L
.10937 .08261 L
.11444 .05202 L
.11709 .03961 L
.11999 .0289 L
.12127 .02517 L
.12263 .02182 L
.12392 .01928 L
.1251 .01744 L
.12626 .01611 L
.1275 .01518 L
.12873 .01475 L
.12944 .01472 L
.1301 .01482 L
.13129 .01534 L
.13238 .01616 L
.13358 .01743 L
.13484 .01916 L
.13703 .02306 L
.13907 .02758 L
.14371 .04026 L
.15423 .07404 L
.1594 .08885 L
.16167 .0943 L
.16417 .09938 L
.1664 .10301 L
.1685 .10557 L
.16965 .10663 L
.17071 .10736 L
.17193 .10794 L
.17309 .10823 L
Mistroke
.17425 .10825 L
.17549 .10799 L
.17665 .10749 L
.17771 .10683 L
.17896 .10579 L
.18031 .10437 L
.18275 .1011 L
.19221 .08209 L
.20234 .05875 L
.20533 .05295 L
.20816 .04835 L
.21069 .0451 L
.21201 .04377 L
.21345 .04261 L
.2141 .04219 L
.2148 .04181 L
.21606 .04132 L
.21677 .04115 L
.21751 .04106 L
.21814 .04105 L
.21884 .04112 L
.22008 .04142 L
.22078 .04169 L
.22141 .042 L
.22265 .04278 L
.22381 .04371 L
.2261 .04609 L
.22861 .04946 L
.23369 .05819 L
.2428 .0769 L
.24792 .08675 L
.25075 .09134 L
.25342 .09492 L
.25591 .09747 L
.25731 .09854 L
.25861 .09929 L
.2597 .09973 L
.26091 .10001 L
.26217 .10008 L
.26335 .09993 L
.26452 .09958 L
.26578 .09899 L
.26696 .09822 L
.26804 .09735 L
.27067 .09458 L
.27317 .09119 L
.28351 .07171 L
.29231 .05415 L
.29472 .05017 L
.29732 .04657 L
Mistroke
.29857 .04511 L
.29977 .04392 L
.30094 .04294 L
.302 .04222 L
.30317 .04163 L
.30441 .04122 L
.30556 .04106 L
.30665 .04109 L
.30791 .04137 L
.30908 .04184 L
.31036 .04261 L
.31171 .04369 L
.31425 .04644 L
.31661 .04981 L
.32199 .05984 L
.33083 .08029 L
.33549 .09083 L
.34044 .10014 L
.34302 .10381 L
.3444 .10535 L
.34587 .10666 L
.34653 .10713 L
.34723 .10753 L
.34847 .10804 L
.34963 .10826 L
.3509 .1082 L
.3522 .10782 L
.35338 .10719 L
.35404 .10672 L
.35475 .10612 L
.35603 .10478 L
.35852 .10132 L
.36081 .09714 L
.3651 .08704 L
.36982 .07327 L
.37937 .0425 L
.38187 .0351 L
.38459 .02794 L
.38699 .02265 L
.3883 .02024 L
.38954 .01834 L
.39076 .01683 L
.39207 .01564 L
.39326 .01497 L
.39436 .01472 L
.3954 .01482 L
.39654 .01531 L
.39772 .01628 L
.39883 .01761 L
.40013 .01971 L
Mistroke
.40155 .02266 L
.40411 .02985 L
.40662 .03915 L
.40892 .04975 L
.41417 .08077 L
.41973 .12327 L
.43948 .32037 L
.44812 .40643 L
.45755 .48492 L
.46271 .51877 L
.46749 .54415 L
.47207 .56319 L
.47695 .57842 L
.47966 .5849 L
.48259 .59052 L
.48535 .59467 L
.4879 .59764 L
.4902 .59971 L
.49272 .60138 L
.494 .60201 L
.49536 .60255 L
.49665 .60292 L
.49783 .60315 L
.499 .60328 L
.50011 .60332 L
.50132 .60326 L
.50263 .60307 L
.50392 .60277 L
.50458 .60257 L
.50529 .60231 L
.50657 .60175 L
.50773 .60112 L
.51003 .59953 L
.51248 .59725 L
.51475 .59453 L
.5169 .59137 L
.51942 .58682 L
.52208 .58089 L
.52686 .56695 L
.532 .54649 L
.53766 .5166 L
.54781 .44272 L
.5571 .35563 L
.56793 .24238 L
.57799 .1432 L
.58719 .07182 L
.58984 .05618 L
.59234 .04371 L
.59456 .03449 L
.597 .02644 L
Mistroke
.59953 .02036 L
.60091 .01799 L
.60219 .01637 L
.6034 .01536 L
.6045 .01484 L
.60577 .01473 L
.60697 .01506 L
.60827 .0159 L
.60892 .0165 L
.60965 .01729 L
.61213 .02099 L
.61502 .027 L
.61773 .03398 L
.62669 .06205 L
.6316 .07765 L
.63624 .09048 L
.63888 .09649 L
.64173 .10172 L
.64299 .10357 L
.64433 .10519 L
.64558 .10641 L
.64672 .10725 L
.64788 .10785 L
.64912 .1082 L
.65027 .10826 L
.65136 .10809 L
.65263 .1076 L
.6538 .1069 L
.65509 .10584 L
.65646 .10442 L
.65883 .10128 L
.66138 .09703 L
.666 .0876 L
.67653 .06304 L
.68189 .05229 L
.68459 .04801 L
.68613 .04597 L
.68754 .04441 L
.68875 .04329 L
.69007 .04233 L
.69079 .04191 L
.69146 .0416 L
.69277 .04119 L
.69389 .04105 L
.69513 .04113 L
.69643 .04147 L
.69764 .04202 L
.69889 .04282 L
.70022 .04391 L
.70261 .04648 L
Mistroke
.70803 .05474 L
.71789 .07464 L
.7229 .08456 L
.72761 .09232 L
.72967 .09499 L
.73184 .09724 L
.73298 .09817 L
.73423 .09899 L
.73536 .09954 L
.73642 .09988 L
.73768 .10008 L
.73832 .10008 L
.73902 .10002 L
.74026 .09974 L
.74143 .09927 L
.7421 .09891 L
.7428 .09847 L
.74405 .0975 L
.74688 .09456 L
.74933 .09123 L
.75161 .08757 L
.75678 .07776 L
.76568 .05939 L
.77037 .05101 L
.77294 .04729 L
.77534 .04452 L
.7767 .04328 L
.77795 .04238 L
.77861 .04199 L
.77933 .04164 L
.78009 .04136 L
.78081 .04118 L
.78208 .04105 L
.78279 .04109 L
.78343 .04119 L
.78469 .04158 L
.78586 .04217 L
.78708 .043 L
.78835 .04411 L
.79064 .0467 L
.7931 .05028 L
.7958 .05504 L
.80535 .07632 L
.81439 .09625 L
.81677 .10036 L
.8193 .10391 L
.82061 .10537 L
.82207 .10666 L
.82339 .10752 L
.82463 .10803 L
Mistroke
.82583 .10826 L
.82697 .10822 L
.82799 .10797 L
.82911 .10747 L
.83032 .10664 L
.83162 .10545 L
.83394 .10251 L
.83666 .09782 L
.83959 .09136 L
.84492 .07666 L
.85487 .04462 L
.85945 .03128 L
.86198 .02516 L
.86437 .02046 L
.86572 .01836 L
.86643 .01743 L
.86719 .01658 L
.86782 .01598 L
.86852 .01545 L
.86976 .01486 L
.87101 .01472 L
.87171 .01485 L
.87235 .01511 L
.87354 .01593 L
.87479 .01731 L
.87611 .01933 L
.87731 .0217 L
.88 .02888 L
.88249 .03787 L
.88485 .04843 L
.89013 .07921 L
.89585 .12272 L
.91532 .31675 L
.92565 .41874 L
.93134 .46688 L
.93675 .50548 L
.94183 .53499 L
.94737 .55986 L
.95241 .57645 L
.95708 .58744 L
.95958 .59183 L
.96192 .59517 L
.96405 .59761 L
.9663 .59964 L
.96748 .6005 L
.96876 .6013 L
.96995 .6019 L
.97102 .60236 L
.9723 .60278 L
.973 .60296 L
Mistroke
.97366 .60309 L
.97484 .60325 L
.97612 .60332 L
.97619 .60332 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol001Yoo`D000moo`03001oogoo009oo`03001oogoo009o
o`03001oogoo021oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00ioo`D002eoo`D0011o
o`03001oogoo009oo`03001oogoo009oo`03001oogoo021oo`03001oogoo009oo`03001oogoo009o
o`03001oogoo00ioo`D001Ioo`0077oo00<007ooOol03Woo00<007oo00001goo00<007oo000087oo
00<007oo00001goo00<007oo00004Goo00<007ooOol0;goo00<007ooOol03goo00<007oo00001goo
00<007oo000087oo00<007oo00001goo00<007oo00004Goo00<007ooOol05Woo000FOol30003Ool0
0`00Oomoo`09Ool30002Ool00`00Ool00009Ool00`00Oomoo`0NOol00`00Ool00009Ool00`00Oomo
o`0?Ool00`00Oomoo`0YOol30003Ool00`00Oomoo`0:Ool30002Ool00`00Ool00009Ool00`00Oomo
o`0NOol00`00Ool00009Ool00`00Oomoo`0?Ool00`00Oomoo`0FOol001aoo`03001oogoo00ioo`03
001oo`0000Moo`80025oo`03001oo`0000Moo`80019oo`03001oogoo02moo`03001oogoo00moo`03
001oo`0000Moo`80011oo`03001oogoo00ioo`03001oo`0000Moo`80019oo`03001oogoo01Ioo`00
77oo00<007ooOol03Woo00<007oo00001goo00<007ooOol03goo00<007ooOol03Woo00<007oo0000
1goo00<007ooOol04Goo00<007ooOol0;goo00<007ooOol00Woo00<007ooOol02Woo00<007oo0000
1goo00<007ooOol027oo00<007ooOol017oo00<007ooOol017oo00<007ooOol01goo00<007oo0000
1goo00<007ooOol02goo00<007ooOol00goo00<007ooOol05Woo000KOol20005Ool00`00Oomoo`09
Ool00`00Oomoo`06Ool30007Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00
Oomoo`06Ool30009Ool20005Ool2000`Ool20004Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool30007
Ool20006Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`06Ool3000:Ool20004Ool2000H
Ool0025oo`8001ioo`8000Ioo`03001oogoo00Eoo`03001oogoo01aoo`8003eoo`03001oogoo01io
o`8000Ioo`03001oogoo00Aoo`03001oogoo01ioo`8001ioo`008Goo0P007Woo0P001Woo00<007oo
Ool017oo00<007oo00007Goo0P00?Goo10006goo10001Woo00<007ooOol017oo00<007oo000077oo
10007Woo000QOol20002Ool20002Ool20002Ool20006Ool20002Ool20002Ool2000017oo001oo`00
1Woo00<007ooOol017oo00@007oo001oo`<00003Ool0000000=oo`03001oogoo00Aoo`80009oo`80
009oo`800004Ool007oo000mOol600001Goo001oo`00Ool0100000Eoo`00Ool007oo00H00003Ool0
07oo00H000Ioo`03001oogoo00Aoo`P00005Ool007oo001oo`0200001goo001oo`00Ool007oo00@0
0003Ool007oo00H001ioo`0067ooI000:WooI@005Goo000JOol00`00Oomoo`04Ool01000Ool00000
0Woo0P000Woo0P000Woo0`0000=oo`0000000Woo0P000Woo0P000Woo0P0000=oo`00Ool01Goo00<0
07ooOol017oo00@007oo0000009oo`80009oo`80009oo`800004Ool000000002Ool20002Ool20002
Ool200000goo001oo`05Ool00`00Oomoo`0]Ool00`00Oomoo`04Ool700000goo001oo`0600001Goo
001oo`00Ool01P0000=oo`0000001@001Woo00<007ooOol017oo1`0000Eoo`00Ool007oo00@00005
Ool007oo001oo`0600000goo001oo`050006Ool00`00Oomoo`0EOol0025oo`04001oo`00000JOol2
00000goo001oo`05Ool00`00Oomoo`04Ool01000Ool000006Woo0P0000=oo`00Ool0?7oo1@006Goo
00<007oo00000P001Woo00<007ooOol017oo0P0000=oo`0000006Goo00<007oo00000P007Woo000Q
Ool00`00Oomoo`0NOol00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`0NOol00`00Oomoo`0k
Ool2000NOol30006Ool00`00Oomoo`03Ool00`00Ool0000NOol3000NOol0025oo`03001oogoo01io
o`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo01ioo`03001oogoo03Yoo`03001oogoo021o
o`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo021oo`03001oogoo01aoo`008Goo00<007oo
Ool07Woo00<007ooOol017oo00<007ooOol017oo00<007ooOol07Woo00<007ooOol0>Woo00<007oo
Ool087oo00<007ooOol017oo00<007ooOol00goo00<007ooOol087oo00<007ooOol077oo000QOol0
0`00Oomoo`0NOol00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`0NOol00`00Oomoo`0jOol0
0`00Oomoo`0POol00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`0POol00`00Oomoo`0LOol0
025oo`03001oogoo01ioo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo01ioo`03001oogoo
03Yoo`03001oogoo025oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo021oo`03001oogoo
01aoo`008Goo00<007ooOol05goo00<007ooOol00Woo00@007oo001oo`<0009oo`03001oogoo00Ao
o`03001oogoo01moo`03001oogoo03Uoo`03001oogoo01Uoo`03001oogoo009oo`03001oogoo00@0
009oo`03001oogoo00=oo`03001oogoo021oo`03001oogoo01aoo`008Goo00<007ooOol05Woo00<0
07oo00001Goo00<007oo000017oo00<007ooOol00goo00<007ooOol087oo00<007ooOol0>Goo00<0
07ooOol067oo00<007oo00001Woo0P0017oo00<007ooOol00goo00<007ooOol087oo00<007ooOol0
77oo000POol00`00Oomoo`0GOol00`00Ool00006Ool00`00Ool00003Ool20004Ool00`00Oomoo`0P
Ool00`00Oomoo`0iOol00`00Oomoo`0HOol00`00Ool00006Ool00`00Ool00003Ool20004Ool00`00
Oomoo`0POol00`00Oomoo`0LOol0021oo`03001oogoo01Moo`03001oo`0000Ioo`03001oo`0000=o
o`03001oogoo00=oo`03001oogoo021oo`03001oogoo03Uoo`03001oogoo01Qoo`03001oo`0000Io
o`03001oo`0000=oo`03001oogoo00=oo`03001oogoo021oo`03001oogoo01aoo`0087oo00<007oo
Ool05goo00<007oo00001Woo0P0000Eoo`00Oomoo`0000Eoo`03001oogoo021oo`03001oogoo03Uo
o`03001oogoo01Qoo`03001oo`0000Ioo`800005Ool007ooOol00005Ool00`00Oomoo`0POol00`00
Oomoo`0LOol0021oo`03001oogoo01Qoo`03001oogoo00Eoo`03001oo`0000=oo`03001oogoo00=o
o`03001oogoo021oo`03001oogoo03Uoo`03001oogoo01Uoo`03001oogoo00Eoo`03001oo`0000=o
o`03001oogoo00=oo`03001oogoo021oo`03001oogoo01aoo`0087oo00<007ooOol087oo00<007oo
Ool00goo00<007ooOol00goo00<007ooOol087oo00<007ooOol0>Goo00<007ooOol08Goo00<007oo
Ool00goo00<007ooOol00goo00<007ooOol08Goo00<007ooOol06goo000POol00`00Oomoo`0POol0
0`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0POol00`00Oomoo`0iOol00`00Oomoo`0QOol0
0`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0QOol00`00Oomoo`0KOol0021oo`03001oogoo
021oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo021oo`03001oogoo03Uoo`03001oogoo
025oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo025oo`03001oogoo01]oo`0087oo00<0
07ooOol087oo00<007ooOol00goo00<007ooOol00goo00<007ooOol087oo00<007ooOol0>Goo00<0
07ooOol08Goo00<007ooOol00goo00<007ooOol00goo00<007ooOol08Goo00<007ooOol06goo000P
Ool00`00Oomoo`0HOol00`00Oomoo`02Ool01@00Oomoo`00Ool00`0000=oo`00Ool017oo00<007oo
Ool087oo00<007ooOol0>Goo00<007ooOol06Goo00<007ooOol00Woo00D007ooOol007oo00<00003
Ool007oo00Aoo`03001oogoo025oo`03001oogoo01]oo`0087oo00<007ooOol05goo00<007oo0000
1Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo021oo`03001oogoo03Uoo`03001oogoo
01Qoo`03001oo`0000Ioo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`0QOol00`00Oomo
o`0KOol0021oo`03001oogoo01Moo`03001oo`0000Ioo`D00003Ool0000000Aoo`03001oogoo021o
o`03001oogoo03Uoo`03001oogoo01Qoo`03001oo`0000Ioo`D00003Ool0000000Aoo`03001oogoo
025oo`03001oogoo01]oo`0087oo00<007ooOol05goo00<007oo00001Woo0P0000Eoo`00Oomoo`00
00Eoo`03001oogoo021oo`03001oogoo03Uoo`03001oogoo01Qoo`03001oo`0000Ioo`800005Ool0
07ooOol00005Ool00`00Oomoo`0QOol00`00Oomoo`0KOol0021oo`03001oogoo01Moo`03001oo`00
00Ioo`04001oo`000002Ool00`00Oomoo`03Ool00`00Oomoo`0POol00`00Oomoo`0iOol00`00Oomo
o`0HOol00`00Ool00006Ool01000Ool000000Woo00<007ooOol00goo00<007ooOol08Goo00<007oo
Ool06goo000POol00`00Oomoo`0HOol00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00goo
00<007ooOol087oo00<007ooOol0>Goo00<007ooOol06Goo00<007ooOol01Goo00@007ooOol0009o
o`03001oogoo00=oo`03001oogoo025oo`03001oogoo01]oo`0087oo00<007ooOol087oo00<007oo
Ool00goo00<007ooOol00goo00<007ooOol087oo00<007ooOol0>Goo00<007ooOol08Goo00<007oo
Ool00goo00<007ooOol00goo00<007ooOol08Goo00<007ooOol06goo000POol00`00Oomoo`0POol0
0`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0POol00`00Oomoo`0iOol00`00Oomoo`0QOol0
0`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0QOol00`00Oomoo`0KOol0021oo`03001oogoo
021oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo021oo`03001oogoo03Uoo`03001oogoo
025oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo025oo`03001oogoo01]oo`0087oo00<0
07ooOol087oo00<007ooOol00goo00<007ooOol00goo00<007ooOol087oo00<007ooOol0>Goo00<0
07ooOol08Goo00<007ooOol00goo00<007ooOol00goo00<007ooOol08Goo00<007ooOol06goo000P
Ool00`00Oomoo`0HOol00`00Oomoo`02Ool00`00Oomoo`030003Ool00`00Oomoo`03Ool00`00Oomo
o`0QOol00`00Oomoo`0hOol00`00Oomoo`0IOol00`00Oomoo`02Ool00`00Oomoo`030003Ool00`00
Oomoo`03Ool00`00Oomoo`0QOol00`00Oomoo`0KOol0021oo`03001oogoo01Moo`03001oo`0000Io
o`800005Ool007ooOol00005Ool00`00Oomoo`0QOol00`00Oomoo`0hOol00`00Oomoo`0HOol00`00
Ool00006Ool200001Goo001oogoo00001Goo00<007ooOol08Goo00<007ooOol06goo000POol00`00
Oomoo`0GOol00`00Ool00006Ool2000017oo001oogoo0P0017oo00<007ooOol08Goo00<007ooOol0
>7oo00<007ooOol067oo00<007oo00001Woo0P0000Aoo`00Oomoo`8000Aoo`03001oogoo025oo`03
001oogoo01]oo`0087oo00<007ooOol05goo00<007oo00001Woo0`000goo00<007ooOol00goo00<0
07ooOol08Goo00<007ooOol0>7oo00<007ooOol067oo00<007oo00001Woo0`000goo00<007ooOol0
0goo00<007ooOol08Goo00<007ooOol06goo000OOol00`00Oomoo`0HOol00`00Ool00006Ool20004
Ool00`00Oomoo`03Ool00`00Oomoo`0QOol00`00Oomoo`0hOol00`00Oomoo`0HOol00`00Ool00006
Ool20004Ool00`00Oomoo`03Ool00`00Oomoo`0QOol00`00Oomoo`0KOol001moo`03001oogoo01Uo
o`03001oogoo00Ioo`<0009oo`03001oogoo00=oo`03001oogoo025oo`03001oogoo03Qoo`03001o
ogoo01Uoo`03001oogoo00Eoo`04001oo`000002Ool00`00Oomoo`03Ool00`00Oomoo`0QOol00`00
Oomoo`0KOol001moo`03001oogoo029oo`03001oogoo009oo`03001oogoo009oo`03001oogoo029o
o`03001oogoo03Qoo`03001oogoo025oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo025o
o`03001oogoo01]oo`007goo00<007ooOol08Woo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool08Woo00<007ooOol0>7oo00<007ooOol08Goo00<007ooOol00goo00<007ooOol00goo00<007oo
Ool08Goo00<007ooOol06goo000OOol00`00Oomoo`0ROol00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`0ROol00`00Oomoo`0hOol00`00Oomoo`0QOol00`00Oomoo`03Ool00`00Oomoo`03Ool0
0`00Oomoo`0QOol00`00Oomoo`0KOol001moo`03001oogoo01Uoo`03001oogoo009oo`04001oogoo
Ool20003Ool00`00Oomoo`02Ool00`00Oomoo`0ROol00`00Oomoo`0hOol00`00Oomoo`0QOol00`00
Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0QOol00`00Oomoo`0KOol001moo`03001oogoo01Qo
o`03001oo`0000Moo`03001oo`00009oo`03001oogoo009oo`03001oogoo029oo`03001oogoo03Qo
o`03001oogoo01Uoo`03001oogoo009oo`06001oogoo001oo`000goo00<007ooOol00goo00<007oo
Ool08Goo00<007ooOol06goo000OOol00`00Oomoo`0HOol00`00Ool00007Ool00`00Ool00002Ool2
0003Ool00`00Oomoo`0ROol00`00Oomoo`0hOol00`00Oomoo`0HOol00`00Ool00006Ool200001Goo
001oogoo00001Goo00<007ooOol08Goo00<007ooOol06goo000OOol00`00Oomoo`0HOol00`00Ool0
0007Ool20003Ool00`00Oomoo`02Ool00`00Oomoo`0ROol00`00Oomoo`0hOol00`00Oomoo`0HOol0
0`00Ool00006Ool2000017oo001oogoo0P0017oo00<007ooOol08Goo00<007ooOol06goo000OOol0
0`00Oomoo`0HOol00`00Ool00007Ool00`00Ool00002Ool00`00Oomoo`02Ool00`00Oomoo`0ROol0
0`00Oomoo`0hOol00`00Oomoo`0HOol00`00Ool00006Ool00`00Ool00003Ool00`00Oomoo`03Ool0
0`00Oomoo`0QOol00`00Oomoo`0KOol001moo`03001oogoo01Uoo`03001oogoo00Ioo`8000=oo`03
001oogoo009oo`03001oogoo029oo`03001oogoo03Qoo`03001oogoo01Qoo`03001oo`0000Ioo`80
0005Ool007ooOol00005Ool00`00Oomoo`0QOol00`00Oomoo`0KOol001moo`03001oogoo029oo`03
001oogoo009oo`03001oogoo009oo`03001oogoo029oo`03001oogoo03Moo`03001oogoo01Yoo`03
001oogoo00Eoo`03001oo`0000=oo`03001oogoo00=oo`03001oogoo025oo`03001oogoo01]oo`00
7goo00<007ooOol08Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol08Woo00<007ooOol0
=goo00<007ooOol08Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol08Goo00<007ooOol0
6goo000OOol00`00Oomoo`0ROol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0ROol00`00
Oomoo`0gOol00`00Oomoo`0ROol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0ROol00`00
Oomoo`0KOol001aoo`04001oogoo000TOol02000Oomoo`00Ool007oo0002Ool00`00Oomoo`0ROol0
0`00Oomoo`02000eOol00`00Oomoo`0SOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0R
Ool00`00Oomoo`0KOol001]oo`80009oo`03001oogoo025oo`X00003Ool007oo02=oo`03001oogoo
008003Eoo`03001oogoo02=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo029oo`03001o
ogoo01]oo`006goo00D007oo001oo`0002Aoo`<00008Ool00000001oo`00Ool002Aoo`03001oogoo
008003=oo`<002Aoo`D00004Ool007ooOol3000TOol00`00Ool0000KOol001]oo`04001oo`00000U
Ool3000027oo00000000Ool007oo000UOol200000goo001oo`0`Ool00`00Ool00002000UOol70000
17oo0000000097oo00@007oo001oo`8001Qoo`006goo00@007oo000002Ioo`800008Ool00000001o
o`00Ool002Eoo`800003Ool007oo031oo`D002Eoo`/002Aoo`03001oo`0000<001Qoo`006Woo00<0
07ooOol00P009Woo0P000Woo0P0000Aoo`00Ool002Eoo`80009oo`03001oogoo02eoo`03001oo`00
00<002Eoo`H00003Ool00000008002Aoo`800005Ool00000Ool0000GOol001Yoo`03001oogoo0080
02Eoo`8000=oo`03001oogoo008002Ioo`80009oo`03001oogoo02moo`@002Eoo`<0009oo`04001o
o`00Ool2000UOol00`00Ool0000JOol001eoo`8002Ioo`05001oogooOol00003Ool00`00Oomoo`0T
Ool2000fOol2000UOol20003Ool01000Oomoogoo0P009Goo00<007ooOol06Woo000MOol2000VOol0
1@00Oomoogoo00000goo00<007ooOol097oo0P00=goo00<007ooOol08goo00<007ooOol00Woo00@0
07ooOomoo`8002Eoo`03001oogoo01Yoo`00BGoo00<007ooOol0S7oo00<007ooOol0AGoo0019Ool0
0`00Oomoo`2<Ool00`00Oomoo`15Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo000LOol:0009Ool30003Ool20003Ool20002Ool30002Ool30002Ool30002Ool30002Ool30003
Ool200000goo00000002Ool00`00Oomoo`020002Ool20014Ool300000goo000000030009Ool30003
Ool20003Ool20002Ool30002Ool30002Ool30002Ool30002Ool30003Ool200000goo00000002Ool0
0`00Oomoo`020002Ool2000YOol001ioo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo009o
o`06001oogoo001oo`001Goo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000Eoo`05
001oogooOol00004Ool01P00Oomoo`00Ool0009oo`05001oogooOol00013Ool00`00Oomoo`03Ool0
0`00Oomoo`09Ool00`00Oomoo`02Ool01P00Oomoo`00Ool000Eoo`03001oogoo009oo`03001oogoo
009oo`05001oogooOol00005Ool01@00Oomoogoo000017oo00H007ooOol007oo0002Ool01@00Oomo
ogoo0000:7oo000NOol00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`02Ool01@00Oomoo`00
Ool00`000goo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000Eoo`04001oogooOol3
0002Ool01P00Oomoo`00Ool000Eoo`03001oogoo04=oo`03001oogoo009oo`03001oogoo00Uoo`03
001oogoo009oo`05001oogoo001oo`030003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomo
ogoo00001Goo00@007ooOomoo`<0009oo`06001oogoo001oo`001Goo00<007ooOol09goo000NOol0
0`00Oomoo`02Ool00`00Oomoo`09Ool30003Ool20002Ool30002Ool30002Ool30002Ool20003Ool3
0002Ool20003Ool300000goo0000000200000goo000000020003Ool20014Ool00`00Oomoo`02Ool0
0`00Oomoo`09Ool30003Ool20002Ool30002Ool30002Ool30002Ool20003Ool30002Ool20003Ool3
00000goo0000000200000goo000000020003Ool2000XOol001ioo`03001oogoo009oo`03001oogoo
01Uoo`03001oogoo009oo`03001oogoo01Yoo`03001oogoo04Qoo`03001oo`0000=oo`03001oogoo
01Uoo`03001oogoo009oo`03001oogoo01Yoo`03001oogoo02eoo`007Goo0P000goo0P0077oo00<0
07ooOol00Woo00D007ooOomoo`0000Uoo`03001oogoo05Moo`04001oogooOol2000LOol00`00Oomo
o`02Ool01@00Oomoogoo00002Goo00<007ooOol0>goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`007Goo1@003Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol07Goo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol037oo1@00;goo1@004Goo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol08Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol03Woo1@005Goo000OOol0
0`00Oomoo`0=Ool00`00Ool00007Ool00`00Ool0000MOol00`00Ool00007Ool00`00Ool0000?Ool0
0`00Oomoo`0aOol00`00Oomoo`0@Ool00`00Ool00007Ool00`00Ool0000QOol00`00Ool00007Ool0
0`00Ool0000AOol00`00Oomoo`0EOol001Uoo`<000=oo`03001oogoo00Qoo`<0009oo`03001oo`00
00Uoo`03001oogoo01]oo`03001oo`0000Uoo`03001oogoo00eoo`03001oogoo02]oo`<000=oo`03
001oogoo00]oo`<0009oo`03001oo`0000Uoo`03001oogoo00eoo`03001oogoo00moo`03001oo`00
00Uoo`03001oogoo00moo`03001oogoo01Eoo`007goo00<007ooOol03Goo00<007oo00001goo0P00
7Woo00<007oo00001goo0P0047oo00<007ooOol0<Goo00<007ooOol047oo00<007oo00001goo0P00
47oo00<007ooOol03goo00<007oo00001goo0P004Woo00<007ooOol05Goo000OOol00`00Oomoo`0=
Ool00`00Ool00007Ool00`00Oomoo`0MOol00`00Ool00007Ool00`00Oomoo`0?Ool00`00Oomoo`0a
Ool00`00Oomoo`05Ool30008Ool00`00Ool00007Ool00`00Oomoo`03Ool30009Ool00`00Oomoo`07
Ool20006Ool00`00Ool00007Ool00`00Oomoo`06Ool20009Ool00`00Oomoo`0EOol001ioo`80011o
o`03001oogoo00Ioo`<001ioo`03001oogoo00Ioo`<000ioo`80039oo`8000Moo`03001oo`0000Uo
o`03001oogoo00Ioo`<000=oo`03001oo`0000Uoo`03001oogoo00Moo`03001oo`0000Ioo`03001o
ogoo00Ioo`<000Ioo`03001oo`0000Moo`8001Moo`00/Goo00<007oo00001goo0P001goo0P001Woo
00<007oo00002Goo00<007ooOol01goo00<007oo00001Woo0P001goo0P001Woo00@007ooOol0021o
o`00/Goo00<007oo00001Woo00<007oo00001Woo00<007oo00001Woo00@007ooOol000Qoo`03001o
ogoo00Ioo`04001oogoo0005Ool40005Ool40005Ool01000Oomoo`0087oo0019Ool00`00Oomoo`1U
Ool01000Oomoo`0017oo00D007ooOomoo`0000Eoo`04001oogoo0004Ool01@00Oomoogoo000027oo
00<007ooOol01Woo00D007ooOomoo`0000Aoo`04001oogoo0005Ool01000Oomoo`001Goo00@007oo
Ool0021oo`006gooGP00;7ooI`0057oo000MOol01@00Oomoogoo000017oo00D007ooOomoo`0000Ao
o`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=o
o`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=o
o`03001oogoo009oo`05001oogooOol0000aOol00`00Oomoo`02Ool01000Oomoogoo0P000goo0P00
00Eoo`00Oomoo`00009oo`04001oo`000002Ool02000Oomoo`00Ool007oo0002Ool20003Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool01000Oomoogoo0P000Woo0P000Woo00<007oo00000Woo00D007oo
001oo`00009oo`03001oo`00009oo`8000=oo`8000=oo`03001oogoo009oo`03001oogoo01Aoo`00
BGoo00<007ooOol0I7oo00<007ooOol00Woo00<007oo00001Woo00@007ooOol000Eoo`04001oogoo
0004Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`02Ool01000Oomoo`001Goo00@007oo
000000Aoo`05001oogooOol00004Ool00`00Oomoo`0MOol004Uoo`03001oogoo06=oo`03001oogoo
00=oo`<000Moo`8000Moo`<000Aoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo009oo`03
001oo`0000Ioo`<000Ioo`03001oo`0000Eoo`03001oogoo01eoo`00BGoo00<007ooOol0Hgoo00<0
07ooOol017oo0P0047oo0P001Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol00goo0`00
3goo0`001Goo00<007ooOol07Goo0019Ool00`00Oomoo`1SOol00`00Oomoo`0NOol00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`0MOol00`00Oomoo`0MOol004Uoo`03001oogoo06=oo`03001o
ogoo01ioo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo01eoo`03001oogoo01eoo`00BGoo
00<007ooOol0Hgoo00<007ooOol07Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol07Goo
00<007ooOol07Goo0019Ool00`00Oomoo`1SOol00`00Oomoo`0HOol00`00Oomoo`02Ool20002Ool3
0002Ool00`00Oomoo`05Ool00`00Oomoo`0MOol00`00Oomoo`0MOol003]oo`03001oogoo009oo`03
001oogoo00D00003Ool007oo06Aoo`03001oogoo01Moo`03001oo`0000Aoo`04001oogoo0004Ool0
0`00Oomoo`05Ool00`00Oomoo`0MOol00`00Oomoo`0MOol003Yoo`03001oo`0000Qoo`05001oogoo
Ool0001TOol00`00Oomoo`0HOol00`00Ool00004Ool01@00Oomoogoo00000goo0P001Woo00<007oo
Ool07Goo00<007ooOol07Goo000jOol00`00Ool00008Ool01000Oomoogoo0P00Hgoo00<007ooOol0
67oo00<007oo000017oo00D007ooOomoo`0000=oo`03001oogoo00Eoo`03001oogoo01ioo`03001o
ogoo01aoo`00>Woo00<007oo000027oo00D007ooOomoo`0006Aoo`03001oogoo01Qoo`03001oo`00
00Eoo`05001oo`00Ool00002Ool00`00Oomoo`05Ool00`00Oomoo`0NOol00`00Oomoo`0LOol003Yo
o`03001oo`0000Qoo`05001oogooOol0001TOol00`00Oomoo`0IOol00`00Oomoo`04Ool01000Oomo
o`000goo00<007ooOol017oo00<007ooOol07goo00<007ooOol077oo000kOol00`00Oomoo`06Ool2
0003Ool00`00Oomoo`1ROol00`00Oomoo`0POol00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomo
o`0OOol00`00Oomoo`0LOol004Uoo`03001oogoo069oo`03001oogoo021oo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo01moo`03001oogoo01aoo`00BGoo00<007ooOol0HWoo00<007ooOol0
87oo00<007ooOol017oo00<007ooOol017oo00<007ooOol07goo00<007ooOol077oo0019Ool00`00
Oomoo`1ROol00`00Oomoo`0POol00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`0OOol00`00
Oomoo`0LOol004Uoo`03001oogoo069oo`03001oogoo01Uoo`03001oogoo009oo`03001oo`00009o
o`<00003Ool007oo00Eoo`03001oogoo01moo`03001oogoo01aoo`00BGoo00<007ooOol0HWoo00<0
07ooOol067oo00<007oo00001Goo00D007ooOomoo`00009oo`03001oogoo00Aoo`03001oogoo01mo
o`03001oogoo01aoo`00>goo00<007ooOol00Woo00@007ooOomoo`<0009oo`03001oogoo069oo`03
001oogoo01Qoo`03001oo`0000Eoo`03001oo`0000<00003Ool0000000Eoo`03001oogoo01moo`03
001oogoo01aoo`00>Woo00<007oo00001goo00<007ooOol00Woo00<007ooOol0HWoo00<007ooOol0
67oo00<007oo00001Goo00D007oo001oo`00009oo`03001oogoo00Aoo`03001oogoo021oo`03001o
ogoo01]oo`00>Woo00<007oo000027oo00@007ooOomoo`80069oo`03001oogoo01Uoo`03001oo`00
00Ioo`04001oo`000002Ool00`00Oomoo`04Ool00`00Oomoo`0POol00`00Oomoo`0KOol003Yoo`03
001oo`0000Qoo`05001oogooOol0001SOol00`00Oomoo`0JOol00`00Oomoo`05Ool01000Oomoo`00
0Woo00<007ooOol017oo00<007ooOol087oo00<007ooOol06goo000jOol00`00Ool00007Ool00`00
Ool00002Ool00`00Oomoo`1QOol00`00Oomoo`0ROol00`00Oomoo`03Ool00`00Oomoo`03Ool00`00
Oomoo`0QOol00`00Oomoo`0KOol003]oo`03001oogoo00Moo`05001oogooOol0001SOol00`00Oomo
o`0ROol00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0QOol00`00Oomoo`0KOol004Uoo`03
001oogoo065oo`03001oogoo029oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo025oo`03
001oogoo01]oo`00BGoo00<007ooOol0HGoo00<007ooOol08Woo00<007ooOol00goo00<007ooOol0
0goo00<007ooOol08Goo00<007ooOol06goo000MOomI000gOol00`00Oomoo`0ROol00`00Oomoo`03
Ool00`00Oomoo`03Ool00`00Oomoo`0QOol00`00Oomoo`0KOol004Uoo`03001oogoo065oo`03001o
ogoo01Yoo`03001oogoo009oo`03001oogoo00<000=oo`03001oogoo00=oo`03001oogoo025oo`03
001oogoo01]oo`00BGoo00<007ooOol0HGoo00<007ooOol06Goo00<007oo00001Woo0P0000Eoo`00
Oomoo`0000Eoo`03001oogoo025oo`03001oogoo01]oo`00>goo00<007ooOol00Woo00@007ooOomo
o`8000=oo`03001oogoo065oo`03001oogoo01Uoo`03001oo`0000Moo`03001oo`00009oo`8000Ao
o`03001oogoo029oo`03001oogoo01Yoo`00>Woo00<007oo00002Goo00@007ooOol006=oo`03001o
ogoo01Uoo`03001oo`0000Moo`8000=oo`03001oogoo00=oo`03001oogoo029oo`03001oogoo01Yo
o`00>Woo00<007oo000027oo00@007ooOomoo`80065oo`03001oogoo01Yoo`03001oo`0000Moo`03
001oogoo009oo`03001oogoo00=oo`03001oogoo029oo`03001oogoo01Yoo`00>Woo00<007oo0000
2Goo00@007ooOol0069oo`03001oogoo01]oo`03001oogoo00Ioo`<0009oo`03001oogoo009oo`03
001oogoo02=oo`03001oogoo01Yoo`00>Woo00<007oo00001goo00<007oo00000Woo00<007ooOol0
H7oo00<007ooOol097oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol08goo00<007ooOol0
6Woo000kOol00`00Oomoo`07Ool01@00Oomoogoo0000HWoo00<007ooOol097oo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol08goo00<007ooOol06Woo0019Ool00`00Oomoo`1POol00`00Oomo
o`0TOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0SOol00`00Oomoo`0JOol004Uoo`03
001oogoo061oo`03001oogoo02Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo02=oo`03
001oogoo01Yoo`00BGoo00<007ooOol0H7oo00<007ooOol06goo00<007ooOol00Woo00@007ooOomo
o`8000=oo`03001oogoo009oo`03001oogoo02Aoo`03001oogoo01Uoo`00BGoo00<007ooOol0H7oo
00<007ooOol06Woo00<007oo00001goo0`000Woo00<007ooOol00Woo00<007ooOol097oo00<007oo
Ool06Goo0019Ool00`00Oomoo`1OOol00`00Oomoo`0KOol00`00Ool00007Ool30002Ool20003Ool0
0`00Oomoo`0TOol00`00Oomoo`0IOol003]oo`03001oogoo009oo`03001oogoo009oo`<00003Ool0
07oo061oo`03001oogoo01]oo`03001oo`0000Qoo`05001oogooOol00003Ool00`00Oomoo`0UOol0
0`00Oomoo`0IOol003Yoo`03001oo`0000Uoo`04001oogoo001QOol00`00Oomoo`0KOol00`00Ool0
0007Ool30002Ool01@00Oomoogoo00009goo00<007ooOol06Goo000jOol00`00Ool00007Ool40000
0goo0000001POol00`00Oomoo`0LOol00`00Oomoo`07Ool01@00Oomoogoo00000goo00<007ooOol0
9Goo00<007ooOol06Goo000jOol00`00Ool00007Ool00`00Ool00002Ool00`00Oomoo`1OOol00`00
Oomoo`0VOol01@00Oomoogoo00000goo00<007ooOol09Goo00<007ooOol06Goo000jOol00`00Ool0
0008Ool20002Ool00`00Oomoo`1OOol00`00Oomoo`0VOol01@00Oomoogoo00000goo00<007ooOol0
9Goo00<007ooOol06Goo000kOol00`00Oomoo`08Ool01000Oomoo`00HGoo00<007ooOol09Woo00D0
07ooOomoo`0000=oo`03001oogoo02Ioo`03001oogoo01Qoo`00BGoo00<007ooOol0Ggoo00<007oo
Ool09goo00@007ooOol0009oo`03001oogoo02Moo`03001oogoo01Qoo`00BGoo00<007ooOol0GWoo
00<007ooOol09Goo1@0000Eoo`00Oomoo`0002Uoo`03001oogoo01Qoo`00BGoo00<007ooOol0GWoo
00<007ooOol09goo0P000Woo00@007ooOol002Yoo`03001oogoo01Moo`00BGoo00<007ooOol0GWoo
00<007ooOol09goo0P000Woo0P0000=oo`00Ool0:Goo00<007ooOol05goo0019Ool00`00Oomoo`1N
Ool00`00Oomoo`0WOol01`00Ool007oo001oo`0002]oo`03001oogoo01Moo`00>goo00<007ooOol0
0Woo00<007ooOol00Woo00D007ooOomoo`0005moo`03001oogoo02Qoo`07001oo`00Ool007oo0000
;7oo00<007ooOol05Woo000jOol00`00Ool00007Ool00`00Ool00002Ool00`00Oomoo`1LOol2000Y
Ool200000goo00000002000]Ool2000GOol003Yoo`03001oo`0000Uoo`03001oogoo008005aoo`80
02ioo`8002moo`8001Ioo`00>Woo00<007oo00001goo0P000goo00<007ooOol0S7oo00<007ooOol0
AGoo000jOol00`00Ool00007Ool00`00Oomoo`3IOol003]oo`03001oogoo00Ioo`<00=Uoo`00ogoo
8Goo003oOolQOol00?moob5oo`008Woo1@0027oo0`000goo0P000goo0P000Woo0`000Woo0`000Woo
0`000Woo0`000Woo0`000goo0P0000=oo`0000000Woo00<007ooOol00P00C7oo00<007ooOol027oo
0`000goo0P000goo0P000Woo0`000Woo0`000Woo0`000Woo0`000Woo0`000goo0P0000=oo`000000
0Woo00<007ooOol00P000Woo0P00;7oo000TOol00`00Oomoo`08Ool00`00Oomoo`02Ool01P00Oomo
o`00Ool000Eoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00005Ool01@00Oomoogoo
000017oo00H007ooOol007oo0002Ool00`00Oomoo`18Ool00`00Ool00009Ool00`00Oomoo`02Ool0
1P00Oomoo`00Ool000Eoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00005Ool01@00
Oomoogoo000017oo00H007ooOol007oo0002Ool01@00Oomoogoo0000:goo000TOol00`00Oomoo`08
Ool00`00Oomoo`02Ool01@00Oomoo`00Ool00`000goo00<007ooOol00Woo00<007ooOol00Woo00D0
07ooOomoo`0000Eoo`04001oogooOol30002Ool01P00Oomoo`00Ool004moo`03001oogoo00Moo`03
001oogoo009oo`05001oogoo001oo`030003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomo
ogoo00001Goo00@007ooOomoo`<0009oo`06001oogoo001oo`001Goo00<007ooOol0:Woo000TOol0
0`00Oomoo`08Ool30003Ool20002Ool30002Ool30002Ool30002Ool20003Ool30002Ool20003Ool3
00000goo0000000200000goo00000002001;Ool2000:Ool30003Ool20002Ool30002Ool30002Ool3
0002Ool20003Ool30002Ool20003Ool300000goo0000000200000goo000000020003Ool2000[Ool0
02Aoo`03001oogoo01Qoo`03001oogoo009oo`03001oogoo01Yoo`03001oogoo04]oo`03001oogoo
01Uoo`03001oogoo009oo`03001oogoo01Yoo`03001oogoo031oo`008goo0P006goo00<007ooOol0
0Woo00D007ooOomoo`0000Uoo`03001oogoo05Uoo`<001Yoo`03001oogoo009oo`05001oogooOol0
0009Ool00`00Oomoo`0nOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{136.5, 423.5}, {410.063, 233.125}} -> {-1.05386, 
  1.67912, 0.00733523, 0.00733523}, {{143.625, 273.5}, {405.813, 
  325.563}} -> {-4.45239, 4.44197, 0.0211955, 0.0203167}, {{286.438, 
  416.313}, {405.813, 325.563}} -> {-7.36411, 4.3504, 0.0208689, 
  0.0198997}, {{143.625, 273.5}, {317.563, 237.313}} -> {-4.74809, 1.19285, 
  0.0226032, 0.00914318}, {{286.438, 416.313}, {317.563, 
  237.313}} -> {-7.25633, 2.58802, 0.0205635, 0.0198547}}]
}, Open  ]],

Cell[TextData[{
  "Clearly, as the number of coefficients increases, the approximation \
improves. The interesting question to ask is whether this result generalizes \
to any periodic function? Also, how good is the approximation in some general \
sense? A mathematically rigorous treatment of Fourier theory provides answers \
to these important questions. It is well known that the FS yields the best \
approximation in the mean squared error sense to periodic signals that \
satisfy the Dirichlet conditions. In addition, for continuous periodic \
signals, the approximating signal converges to the original (zero error at \
every value of t), while for signals with discontinuities, the approximating \
signal converges to the average value at the discontinuity and to the signal \
everywhere else. For finite sums, the behaviour of the approximating signal \
exhibits ripples and overshoots at a discontinuity. This is known as the ",
  StyleBox["Gibb's",
    FontSlant->"Italic"],
  " phenomenon.  In order to determine how good a particular approximation \
is, we need to specify a quantitative measure of the size of the \
approximation error. A commonly used criterion is the energy over one period \
or average power, of the error signal:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm
    \`E\_M\  = \ 
      \(1\/T\) \(\[Integral]\_\(-\(T\/2\)\)\%\(T\/2\)\( | 
            \(e\_M\)(t)\( | \^2\)\[DifferentialD]t\)\)\)]]], 
  "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(e\_M\)(t)\)]],
  " denotes the approximation error, defined in the following way"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm
    \`\(e\_M\)(t)\  = \ 
      \(x(t)\  - \ \(x\_M\)(t)\  = \ 
        x(t)\  - \ 
          \[Sum]\+\(k = \(-M\)\)\%M c\_k\ 
              \[ExponentialE]\^\(\ \ j\ \ \[Omega]\_T\ k\ t\)\)\)]]], 
  "NumberedEquation"],

Cell[CellGroupData[{

Cell["Problem 2", "Exercise"],

Cell[TextData[{
  "Plot the reconstruction error signal  ",
  Cell[BoxData[
      \(TraditionalForm\`\(e\_M\)(t)\  = \ x(t) - \(x\_M\)(t)\)]],
  ", for  ",
  Cell[BoxData[
      \(TraditionalForm\`M = 11, 21\)]],
  " on the interval ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] t \[LessEqual] 0.5\)]],
  "."
}], "ExerciseText"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["SIGNAL POWER", "Section"],

Cell[TextData[{
  "Periodic, continuous-time signals are also known as power signals. The \
following relation, known as ",
  StyleBox["Parseval's relation",
    FontSlant->"Italic"],
  " for periodic signals, establishes an equality between time and \
frequency-domain evaluation of average signal power. "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm
      \`P\_T = \(\(1\/T\) \[Integral]\_\(-\(T\/2\)\)\%\(T\/2\) \[VerticalBar] 
            x(t)\( \[VerticalBar] \^2\)\[DifferentialD]t\  = \ 
          \[Sum]\+\(k = \(-\[Infinity]\)\)\%\[Infinity]\( \[VerticalBar] 
              c\_k\ \( \[VerticalBar] \^2\)\)\)\)]],
  "\t"
}], "NumberedEquation"],

Cell[TextData[{
  "This relationship can be easily derived [Oppenheim, p. 205] and verified. \
As an example, consider using (6) to calculate average power in the periodic \
pulse train. The time domain calculation is trivial and by inspection the \
signal power is ",
  Cell[BoxData[
      \(TraditionalForm\`P\_T\)]],
  "=",
  Cell[BoxData[
      \(TraditionalForm\`1\/4\)]],
  ". However, the rhs of (6) requires an infinite summation. Consider \
therefore an approximation to the rhs by evaluating the sum over a finite \
number of coefficients. Intuitively, as the number of coefficients is \
increased, since ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_M\)(t)\  \[Rule] \ x(t)\)]],
  ", then the sum should converge to ",
  Cell[BoxData[
      \(TraditionalForm\`P\_T\)]],
  ". Here we verify that this indeed happens. "
}], "Text"],

Cell[BoxData[
    \(P\_T\  = \ 0.25; \n
    P\_M_\  := \ \(P\_M = \[Sum]\+\(k = \(-M\)\)\%M Abs[c\_k]\^2\)\)], "Input"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`P\_M\)]],
  " is the approximation signal average power. Here are a few values of the \
average power as a function of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[P\_M, \ {M, 11}]\)], "Input"],

Cell[BoxData[
    \({0.163821183642337775`, 0.214481775463506663`, 0.225739684757099734`, 
      0.225739684757099734`, 0.229792532102793245`, 0.235421486749589803`, 
      0.237489266007596677`, 0.237489266007596677`, 0.238740144817995947`, 
      0.240766568490842702`, 0.241603933644911617`}\)], "Output"]
}, Open  ]],

Cell["\<\
The ratio of signal power in the approximation and the original signal \
defines a common measure of the quality of the approximation. The closer this \
number is to unity the better is the FS representation of the original signal \
(in the sense of mean squared error). \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(%\/P\_T\)], "Input"],

Cell[BoxData[
    \({0.655284734569351101`, 0.857927101854026652`, 0.902958739028398937`, 
      0.902958739028398937`, 0.919170128411172981`, 0.941685946998359213`, 
      0.94995706403038671`, 0.94995706403038671`, 0.954960579271983789`, 
      0.963066273963370811`, 0.966415734579646468`}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The approximation error average power ",
  Cell[BoxData[
      \(TraditionalForm\`E\_M\)]],
  " defined in (4) is clearly the difference between total power and power in \
the approximating signal. We use Parseval's relation to calculate ",
  Cell[BoxData[
      \(TraditionalForm\`E\_M\)]],
  " for selected values of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(E\_M_ := P\_T - P\_M; \nTable[E\_M, \ {M, 21}]\)], "Input"],

Cell[BoxData[
    \({0.0861788163576622245`, 0.0355182245364933368`, 0.024260315242900261`, 
      0.024260315242900261`, 0.0202074678972067323`, 0.0145785132504102072`, 
      0.0125107339924033222`, 0.0125107339924033222`, 0.0112598551820040637`, 
      0.00923343150915731314`, 0.00839606635508838294`, 
      0.00839606635508838294`, 0.00779653272406863351`, 
      0.00676264309506516259`, 0.00631232672332146549`, 
      0.00631232672332146549`, 0.00596173439237909796`, 
      0.00533629498717949601`, 0.00505562688844726793`, 
      0.00505562688844726793`, 0.00482587363755762588`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[%, \ PlotRange -> {0, \ 0.1}, \ 
      PlotStyle -> PointSize[0.02]]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0453515 0 6.18034 [
[.25057 -0.0125 -3 -9 ]
[.25057 -0.0125 3 0 ]
[.47732 -0.0125 -6 -9 ]
[.47732 -0.0125 6 0 ]
[.70408 -0.0125 -6 -9 ]
[.70408 -0.0125 6 0 ]
[.93084 -0.0125 -6 -9 ]
[.93084 -0.0125 6 0 ]
[.01131 .12361 -24 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -24 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -24 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -24 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.25057 0 m
.25057 .00625 L
s
[(5)] .25057 -0.0125 0 1 Mshowa
.47732 0 m
.47732 .00625 L
s
[(10)] .47732 -0.0125 0 1 Mshowa
.70408 0 m
.70408 .00625 L
s
[(15)] .70408 -0.0125 0 1 Mshowa
.93084 0 m
.93084 .00625 L
s
[(20)] .93084 -0.0125 0 1 Mshowa
.125 Mabswid
.06916 0 m
.06916 .00375 L
s
.11451 0 m
.11451 .00375 L
s
.15986 0 m
.15986 .00375 L
s
.20522 0 m
.20522 .00375 L
s
.29592 0 m
.29592 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38662 0 m
.38662 .00375 L
s
.43197 0 m
.43197 .00375 L
s
.52268 0 m
.52268 .00375 L
s
.56803 0 m
.56803 .00375 L
s
.61338 0 m
.61338 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.74943 0 m
.74943 .00375 L
s
.79478 0 m
.79478 .00375 L
s
.84014 0 m
.84014 .00375 L
s
.88549 0 m
.88549 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(0.02)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(0.04)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(0.06)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(0.08)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0309 m
.02756 .0309 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .58713 m
.02756 .58713 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.02 w
.06916 .53261 Mdot
.11451 .21951 Mdot
.15986 .14994 Mdot
.20522 .14994 Mdot
.25057 .12489 Mdot
.29592 .0901 Mdot
.34127 .07732 Mdot
.38662 .07732 Mdot
.43197 .06959 Mdot
.47732 .05707 Mdot
.52268 .05189 Mdot
.56803 .05189 Mdot
.61338 .04819 Mdot
.65873 .0418 Mdot
.70408 .03901 Mdot
.74943 .03901 Mdot
.79478 .03685 Mdot
.84014 .03298 Mdot
.88549 .03125 Mdot
.93084 .03125 Mdot
.97619 .02983 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo001HOol0
0`00Oomoo`0dOol50002Ool00`00Oomoo`0`Ool50002Ool00`00Oomoo`0bOol30003Ool00`00Oomo
o`0BOol005Moo`03001oo`0003Moo`07001oogooOol007oo0000<goo00L007ooOomoo`00Ool0000c
Ool00`00Oomoo`02Ool00`00Ool0000COol005Uoo`03001oogoo03Eoo`07001oogooOol007oo0000
<goo00<007ooOol00goo00<007ooOol0<Woo00L007ooOomoo`00Ool0000COol005Moo`8003Qoo`07
001oogooOol007oo0000<goo00@007ooOomoo`8003Eoo`07001oogooOol007oo00004goo001GOol0
0`00Oomoo`0gOol01`00Oomoogoo001oo`0003=oo`05001oogooOol0000eOol00`00Ool00002Ool0
0`00Ool0000COol005Moo`<003Ioo`8000Aoo`03001oogoo035oo`8000=oo`<003Aoo`03001oogoo
009oo`03001oogoo019oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol001Qo
ool000D000Aoo`007Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0
2Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol0
2Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0
2Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0
27oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo000NOol00`00Oomoo`3oOol001io
o`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo
0=1oo`<000Qoo`<000Uoo`<000Uoo`<000Uoo`007Woo00<007ooOol0a7oo0`0027oo1@001Woo1@00
1goo1@001goo1@0027oo000NOol2002]Ool30009Ool30008Ool50007Ool50006Ool50007Ool50007
Ool50008Ool001ioo`03001oogoo0:5oo`<000Moo`D000Moo`D000Moo`D000Moo`D000Ioo`D000Mo
o`D000Moo`D000Qoo`007Woo00<007ooOol0UGoo0`0027oo1@001Woo1@001goo1@001goo1@0027oo
0`0027oo0`002Goo0`002Goo0`002Goo000NOol00`00Oomoo`1mOol30009Ool30008Ool50007Ool5
0006Ool50007Ool50008Ool3000hOol001ioo`03001oogoo07aoo`D000Moo`D000Moo`D000Moo`D0
00Moo`<000Uoo`<004Aoo`007Woo00<007ooOol0LWoo0`001goo1@001goo1@001goo1@0027oo0`00
Fgoo000NOol00`00Oomoo`1aOol50006Ool50007Ool50008Ool3001WOol001ioo`03001oogoo075o
o`D000Moo`<000Uoo`<007=oo`007Woo0P00Igoo0`0027oo1@00RGoo000NOol00`00Oomoo`1UOol5
0008Ool3002:Ool001ioo`03001oogoo04ioo`<000Uoo`<000Qoo`D009Eoo`007Woo00<007ooOol0
CGoo1@001goo1@001goo1@00UGoo000NOol00`00Oomoo`1=Ool50007Ool50008Ool3002FOol001io
o`03001oogoo04=oo`<000Moo`D000Moo`D00:5oo`007Woo00<007ooOol0@Woo1@001goo0`002Goo
0`00XWoo000NOol00`00Oomoo`12Ool5002hOol001ioo`8004=oo`D00;Qoo`007Woo00<007ooOol0
@goo0`00^Goo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo
000NOol00`00Oomoo`3oOol000Uoo`03001oogoo009oo`03001oogoo009oo`04001oogooOol30004
Ool00`00Oomoo`0gOol30035Ool000Qoo`03001oo`0000Moo`03001oo`00009oo`03001oogoo00Ao
o`03001oogoo03Ioo`D00<Aoo`0027oo00<007oo00001goo00<007oo00000goo00<007ooOol00goo
0`00=Woo1@00a7oo0008Ool00`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`03Ool00`00Oomo
o`0fOol50034Ool000Qoo`03001oo`0000Moo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo
03Moo`<00<Eoo`002Goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo01moo`<000Uoo`<00=5oo`007Woo00<007oo
Ool07Woo1@001goo1@00d7oo000NOol00`00Oomoo`0NOol50007Ool5003@Ool001ioo`8001moo`D0
00Moo`D00=1oo`007Woo00<007ooOol07goo0`002Goo0`00dGoo000NOol00`00Oomoo`3oOol001io
o`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo
0?moo`007Woo00<007ooOol0ogoo000NOol2003oOol1Ool001ioo`03001oogoo0?moo`007Woo00<0
07ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo
000NOol00`00Oomoo`3oOol001ioo`03001oogoo01Aoo`<00>Qoo`007Woo0P0057oo1@00igoo000N
Ool00`00Oomoo`0COol5003WOol001ioo`03001oogoo01=oo`D00>Moo`007Woo00<007ooOol057oo
0`00j7oo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`002Goo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol00Woo0`000goo00<007ooOol0ogoo0008Ool00`00Ool00007Ool00`00
Ool00004Ool00`00Oomoo`02Ool00`00Oomoo`3oOol000Qoo`03001oo`0000Moo`03001oo`00009o
o`@000=oo`<00?moo`0027oo00<007oo00001goo00<007oo00000Woo00<007oo000017oo00<007oo
Ool0ogoo0008Ool00`00Ool00007Ool00`00Ool00003Ool20004Ool00`00Oomoo`3oOol000Uoo`03
001oogoo00Moo`03001oogoo00=oo`03001oogoo009oo`03001oogoo0?moo`007Woo00<007ooOol0
ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol2
003oOol1Ool001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol0
01ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001o
ogoo0?moo`007Woo0P00ogoo0Goo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo
00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0
ogoo000NOol00`00Oomoo`3oOol001ioo`800?moo`5oo`007Woo00<007ooOol0ogoo000NOol00`00
Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol0
00Uoo`03001oogoo009oo`03001oogoo009oo`04001oogooOol20005Ool00`00Oomoo`3oOol000Qo
o`03001oo`0000Moo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo0?moo`0027oo00<007oo
00001goo00<007oo00000Woo00<007oo000017oo0`00ogoo0008Ool00`00Ool00007Ool00`00Ool0
0002Ool20005Ool00`00Oomoo`3oOol000Qoo`03001oo`0000Moo`03001oo`00009oo`03001oogoo
00Aoo`03001oogoo0?moo`002Goo00<007ooOol01goo00<007ooOol00Woo0P0017oo00<007ooOol0
ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol0
0`00Oomoo`3oOol001ioo`800?moo`5oo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol0
01ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001o
ogoo0?moo`007Woo00<007ooOol0ogoo000NOol2003oOol1Ool001ioo`03001oogoo0?moo`007Woo
00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0
ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo0P00ogoo0Goo000NOol00`00
Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol0
01ioo`03001oogoo0?moo`002Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol0ogoo0008Ool00`00Ool00007Ool00`00Ool00002Ool00`00Ool00004
Ool00`00Oomoo`3oOol000Qoo`03001oo`0000Moo`03001oo`00009oo`03001oo`0000Aoo`<00?mo
o`0027oo00<007oo00001goo00<007oo00000goo00<007ooOol00goo00<007ooOol0ogoo0008Ool0
0`00Ool00007Ool00`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`3oOol000Uoo`03001oogoo
00Moo`03001oogoo009oo`03001oogoo00=oo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000N
Ool00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol20009Ool3
003dOol001ioo`03001oogoo00Moo`D00?=oo`007Woo00<007ooOol01goo1@00lgoo000NOol00`00
Oomoo`07Ool5003cOol001ioo`03001oogoo00Qoo`<00?Aoo`007Woo00<007ooOol0ogoo000NOol0
0`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo0P00ogoo0Goo000NOol00`00Oomoo`3oOol0
01ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001o
ogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`800?moo`5oo`007Woo
00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0
ogoo000NOol00`00Oomoo`3oOol000ioo`03001oogoo009oo`03001oogoo00D000=oo`03001oogoo
0?moo`003Goo00<007oo000027oo00<007ooOol00goo00<007ooOol0ogoo000=Ool00`00Ool00008
Ool00`00Oomoo`03Ool3003oOol000eoo`03001oo`0000Qoo`03001oogoo0?moo`Ioo`003Goo00<0
07oo000027oo00<007ooOol0ogoo1Woo000>Ool00`00Oomoo`06Ool2003oOol8Ool00?moob5oo`00
\
\>"],
  ImageRangeCache->{{{93.5, 380.5}, {448.5, 271.563}} -> {-10.5573, 0.161877, 
  0.0850681, 0.000624232}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problem 3", "Exercise"],

Cell[TextData[{
  "Obtain ",
  Cell[BoxData[
      \(TraditionalForm\`E\_5\)]],
  " using (4) and (5) directly."
}], "ExerciseText"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["PROBLEM SOLUTIONS", "Subtitle"],

Cell[CellGroupData[{

Cell["Problem 1.", "Exercise"],

Cell["\<\
Decrease the pulse width in Example 1 and recalculate the Fourier series \
coefficients. Discuss the effect of changing pulse width while keeping the \
period constant on the FS line spectrum.\
\>", "ExerciseText"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problem 2", "Exercise"],

Cell[TextData[{
  "Plot the reconstruction error signal  ",
  Cell[BoxData[
      \(TraditionalForm\`\(e\_M\)(t)\  = \ x(t) - \(x\_M\)(t)\)]],
  ", for  ",
  Cell[BoxData[
      \(TraditionalForm\`M = 11, 21\)]],
  "."
}], "ExerciseText"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problem 3", "Exercise"],

Cell[TextData[{
  "Obtain ",
  Cell[BoxData[
      \(TraditionalForm\`E\_5\)]],
  " using (4) and (5) directly."
}], "ExerciseText"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Solution:",
    FontWeight->"Bold"],
  " Due to symmetry we only need to integrate over the half interval ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] t \[LessEqual] 0.5\)]],
  ". First obtain the approximation signal,"
}], "ExerciseText"],

Cell[CellGroupData[{

Cell[BoxData[
    \(y = \(x\_5[t]\  // ExpToTrig\) // Chop\)], "Input"],

Cell[BoxData[
    \(\(0.25`\[InvisibleSpace]\) + 0.450158158078553061`\ Cos[2\ \[Pi]\ t] + 
      0.318309886183790702`\ Cos[4\ \[Pi]\ t] + 
      0.150052719359517698`\ Cos[6\ \[Pi]\ t] - 
      0.0900316316157106122`\ Cos[10\ \[Pi]\ t]\)], "Output"]
}, Open  ]],

Cell["Substitute the approximation signal into (4) and evaluate", 
  "ExerciseText"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\ \[ScriptCapitalE]\_5\  = \ 
      2 \(\[Integral]\_0.125\%0.5\( y\^2\) \[DifferentialD]t\)\  + \ 
        2 \(\[Integral]\_0\%0.125\(\((1.  - y)\)\^2\) 
              \[DifferentialD]t\)\)\)], "Input"],

Cell[BoxData[
    \(\(0.0202074678972068388`\[InvisibleSpace]\) + 0.`\ I\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["HOMEWORK PROBLEMS", "Subtitle"],

Cell[CellGroupData[{

Cell["Homework Problem 9.1", "Exercise"],

Cell["\<\
One of the fundamental questions of Fourier theory asks which periodic \
functions posses a FS expansion. Consult your textbook and references for the \
correct answer.\
\>", "ExerciseText"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Homework Problem 9.2", "Exercise"],

Cell["\<\
Obtain the FS coefficients of a periodic pulse train, but one that is shifted \
to the right, so that the pulse begins at t=0. Comment on any similarities \
and differences between the two results.\
\>", "ExerciseText"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Homework Problem 9.3", "Exercise"],

Cell[TextData[
"Determine the Fourier series coefficients for each of the following periodic \
signals:\n(a) see Figure P3.22b, Oppenheim/Willsky, p. 255\n(b) see Figure \
P3.22e, Oppenheim/Willsky, p. 256\n(c) Cos[9 Sin[2 \[Pi] t]]"], "ExerciseText"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Homework Problem 9.4", "Exercise"],

Cell["\<\
Estimate the magnitude of the overshoot in a finite series approximation of \
an ideal pulse. Does this magnitude depend on the number of coefficients \
used?\
\>", "ExerciseText"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Homework Problem 9.5", "Exercise"],

Cell["\<\
Compare the rate of convergence of two periodic signals by plotting the SNR \
as a function of number of FS coefficients M. Vary M from 5 to 35 in steps of \
5.
(a) pulse train used in class example,
(b) pulse train with period T=2, formed from exponentials of the form\
\>", "ExerciseText"],

Cell[BoxData[
    \(g[t_] := Exp[\(-\(t\^2\/0.2\)\)]\)], "Input"]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
AutoGeneratedPackage->None,
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{586, 483},
WindowMargins->{{89, Automatic}, {Automatic, 5}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> "Classroom.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 31, 0, 55, "Title"],
Cell[1743, 51, 30, 0, 41, "Subtitle"],
Cell[1776, 53, 57, 0, 58, "Subsubtitle"],
Cell[1836, 55, 155, 2, 112, "Subsubtitle"],
Cell[1994, 59, 47, 1, 50, "Input"],

Cell[CellGroupData[{
Cell[2066, 64, 31, 0, 56, "Section"],
Cell[2100, 66, 721, 11, 124, "Text"],
Cell[2824, 79, 172885, 2581, 180, 101221, 1692, "GraphicsData", 
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[175746, 2665, 39, 0, 36, "Section"],
Cell[175788, 2667, 171, 3, 48, "Text"],
Cell[175962, 2672, 272, 8, 39, "NumberedEquation"],
Cell[176237, 2682, 1453, 31, 258, "Text"],
Cell[177693, 2715, 336, 10, 48, "NumberedEquation"],
Cell[178032, 2727, 252, 5, 48, "Text"],

Cell[CellGroupData[{
Cell[178309, 2736, 30, 0, 39, "Exercise"],
Cell[178342, 2738, 292, 7, 29, "ExerciseText"]
}, Open  ]],
Cell[178649, 2748, 446, 15, 51, "Text"],
Cell[179098, 2765, 20070, 589, 165, 5663, 407, "GraphicsData", 
"PostScript", "NumberedFigure"],
Cell[199171, 3356, 147, 3, 48, "Text"],

Cell[CellGroupData[{
Cell[199343, 3363, 190, 3, 63, "Input"],
Cell[199536, 3368, 86, 1, 69, "Output"]
}, Open  ]],
Cell[199637, 3372, 195, 8, 32, "Text"],

Cell[CellGroupData[{
Cell[199857, 3384, 181, 4, 92, "Input"],
Cell[200041, 3390, 77, 1, 62, "Output"]
}, Open  ]],
Cell[200133, 3394, 122, 5, 29, "Text"],

Cell[CellGroupData[{
Cell[200280, 3403, 59, 1, 50, "Input"],
Cell[200342, 3406, 39, 1, 49, "Output"]
}, Open  ]],
Cell[200396, 3410, 105, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[200526, 3417, 165, 2, 70, "Input"],
Cell[200694, 3421, 26255, 713, 186, 6789, 468, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[226964, 4137, 865, 21, 108, "Text"],

Cell[CellGroupData[{
Cell[227854, 4162, 30, 0, 39, "Exercise"],
Cell[227887, 4164, 327, 8, 51, "ExerciseText"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[228263, 4178, 40, 0, 36, "Section"],
Cell[228306, 4180, 583, 12, 86, "Text"],
Cell[228892, 4194, 197, 5, 28, "NumberedEquation"],
Cell[229092, 4201, 421, 12, 67, "Text"],
Cell[229516, 4215, 173, 4, 71, "Input"],

Cell[CellGroupData[{
Cell[229714, 4223, 648, 13, 150, "Input"],
Cell[230365, 4238, 69132, 3131, 186, 44116, 2817, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[299512, 7372, 1261, 19, 219, "Text"],
Cell[300776, 7393, 210, 5, 46, "NumberedEquation"],
Cell[300989, 7400, 164, 5, 29, "Text"],
Cell[301156, 7407, 268, 7, 28, "NumberedEquation"],

Cell[CellGroupData[{
Cell[301449, 7418, 29, 0, 39, "Exercise"],
Cell[301481, 7420, 341, 11, 29, "ExerciseText"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[301871, 7437, 31, 0, 36, "Section"],
Cell[301905, 7439, 319, 7, 67, "Text"],
Cell[302227, 7448, 356, 8, 46, "NumberedEquation"],
Cell[302586, 7458, 843, 20, 127, "Text"],
Cell[303432, 7480, 119, 2, 93, "Input"],
Cell[303554, 7484, 256, 9, 48, "Text"],

Cell[CellGroupData[{
Cell[303835, 7497, 55, 1, 50, "Input"],
Cell[303893, 7500, 308, 4, 68, "Output"]
}, Open  ]],
Cell[304216, 7507, 295, 5, 67, "Text"],

Cell[CellGroupData[{
Cell[304536, 7516, 40, 1, 64, "Input"],
Cell[304579, 7519, 306, 4, 68, "Output"]
}, Open  ]],
Cell[304900, 7526, 406, 12, 48, "Text"],

Cell[CellGroupData[{
Cell[305331, 7542, 79, 1, 71, "Input"],
Cell[305413, 7545, 604, 9, 106, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[306054, 7559, 116, 2, 50, "Input"],
Cell[306173, 7563, 10254, 313, 186, 3116, 220, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[316464, 7881, 29, 0, 39, "Exercise"],
Cell[316496, 7883, 132, 5, 29, "ExerciseText"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[316677, 7894, 37, 0, 45, "Subtitle"],

Cell[CellGroupData[{
Cell[316739, 7898, 30, 0, 39, "Exercise"],
Cell[316772, 7900, 224, 4, 48, "ExerciseText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[317033, 7909, 29, 0, 39, "Exercise"],
Cell[317065, 7911, 238, 8, 29, "ExerciseText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[317340, 7924, 29, 0, 39, "Exercise"],
Cell[317372, 7926, 132, 5, 29, "ExerciseText"]
}, Open  ]],
Cell[317519, 7934, 281, 7, 48, "ExerciseText"],

Cell[CellGroupData[{
Cell[317825, 7945, 71, 1, 50, "Input"],
Cell[317899, 7948, 251, 4, 68, "Output"]
}, Open  ]],
Cell[318165, 7955, 84, 1, 29, "ExerciseText"],

Cell[CellGroupData[{
Cell[318274, 7960, 225, 4, 62, "Input"],
Cell[318502, 7966, 86, 1, 49, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[318637, 7973, 37, 0, 45, "Subtitle"],

Cell[CellGroupData[{
Cell[318699, 7977, 40, 0, 39, "Exercise"],
Cell[318742, 7979, 200, 4, 48, "ExerciseText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[318979, 7988, 40, 0, 39, "Exercise"],
Cell[319022, 7990, 229, 4, 48, "ExerciseText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[319288, 7999, 40, 0, 39, "Exercise"],
Cell[319331, 8001, 251, 3, 110, "ExerciseText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[319619, 8009, 40, 0, 39, "Exercise"],
Cell[319662, 8011, 190, 4, 48, "ExerciseText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[319889, 8020, 40, 0, 39, "Exercise"],
Cell[319932, 8022, 301, 6, 102, "ExerciseText"],
Cell[320236, 8030, 65, 1, 64, "Input"]
}, Open  ]]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

