(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    169192,       4794]*)
(*NotebookOutlinePosition[    169954,       4821]*)
(*  CellTagsIndexPosition[    169910,       4817]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["SAVITZKY-GOLAY FILTERS", "Title",
  FontFamily->"Arial"],

Cell["LECTURE 21", "Subtitle",
  Evaluatable->False,
  TextAlignment->-0.5,
  TextJustification->0,
  AspectRatioFixed->True,
  FontFamily->"Arial"],

Cell["ELE486: DIGITAL SIGNAL PROCESSING", "Subsubtitle",
  Evaluatable->False,
  TextAlignment->-0.5,
  TextJustification->0,
  AspectRatioFixed->True,
  FontFamily->"Arial"],

Cell["Mariusz Jankowski", "Subsubtitle",
  Evaluatable->False,
  TextAlignment->-0.5,
  TextJustification->0,
  AspectRatioFixed->True,
  FontFamily->"Arial",
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["\<\
Department of Electrical Engineering
University of Southern Maine
mjkcc@usm.maine.edu\
\>", "Subsubtitle",
  Evaluatable->False,
  TextAlignment->-0.5,
  TextJustification->0,
  AspectRatioFixed->True,
  FontFamily->"Arial",
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[CellGroupData[{

Cell["Introduction", "Section",
  FontFamily->"Arial"],

Cell["\<\
In this notebook a type of FIR low-pass filter, well adapted to data \
smoothing, will be presented. Previously discussed techniques such as \
frequency sampling, windows, and minimax, are all based on a specification of \
a filter in the frequency domain. Savitzky-Golay (SG) filters, on the other \
hand, derive directly from a formulation of the data smoothing problem in the \
time domain. The filter is a generalization of the well-know moving average \
filter (an SG filter of order 0 is an MA filter).

The idea of SG filters is to approximate a noisy data segment of length L by \
the best, in the sense of least-squares, polynomial of order m. The goal is \
to remove the noise without distorting the underlying signal. The higher the \
order of the approximating polynomial, the better the filter preserves high \
frequency content, but at the expense of not removing as much noise as the \
standard MA filter.\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell["References", "Subsection",
  FontFamily->"Times New Roman"],

Cell["\<\
Sophocles J. Orfanidis, \"Introduction to Signal Processing\", Prentice-Hall \
Signal Processing Series, 1996.
Richard W. Hamming,\"Digital Filters\", 2nd Edition, Prentice-Hall Signal \
Processing Series, 1983.\
\>", "Text",
  FontFamily->"Times New Roman"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Fitting Polynomials to Data Points", "Section",
  FontFamily->"Arial"],

Cell["\<\
In this section, we will explore the subject of approximating (smoothing) \
noisy data by fitting low-order polynomials to the data samples. The section \
will conclude with a derivation of the Savitzky-Golay filter coefficients.\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Fit Function"
}], "Subsection",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "Given the 5 data points below, it is of interest to fit polynomials of \
degree 0, 1, 2 to the data. The ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Fit",
    FontWeight->"Bold"],
  " finds a least-squares fit to the given data points. In a smoothing \
operation it is typically of interest to replace the mid-point (i.e, {0,1.2}) \
by a value obtained from the fitting polynomial."
}], "Text",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[BoxData[
    \(data = {{\(-2\), 1.}, {\(-1\), 0.46}, {0, 1.2}, {1, 0.8}, {2, 1.55}}\)],
   "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{\(-2\), ",", 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->1]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\(-1\), ",", 
            StyleBox["0.460000000000000053`",
              StyleBoxAutoDelete->True,
              PrintPrecision->2]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"0", ",", 
            StyleBox["1.19999999999999996`",
              StyleBoxAutoDelete->True,
              PrintPrecision->2]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"1", ",", 
            StyleBox["0.8`",
              StyleBoxAutoDelete->True,
              PrintPrecision->1]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"2", ",", 
            StyleBox["1.55`",
              StyleBoxAutoDelete->True,
              PrintPrecision->3]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(result
       = {Fit[data, {1}, x], \n\ \ \tFit[data, {1, x}, x], \n\t\t\ \ 
        Fit[data, {1, x, x^2}, x], \n\t\t\ \ \ \ \ 
        Fit[data, {1, x, x^2, x^3}, x]}\)], "Input"],

Cell[BoxData[
    \({1.002`, \(1.002`\[InvisibleSpace]\) + 0.143999999999999932`\ x, 
      \(0.796285714285713819`\[InvisibleSpace]\) + 0.144000000000000127`\ x + 
        0.102857142857142824`\ x\^2, 
      \(0.796285714285713819`\[InvisibleSpace]\) + 0.180833333333333072`\ x + 
        0.102857142857142824`\ x\^2 - 0.0108333333333332237`\ x\^3}\)], 
  "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      ListPlot[data, PlotStyle \[Rule] PointSize[0.03], PlotRange -> {0, 2}, 
        \n\t\tDisplayFunction -> Identity], \n\t
      Plot[Evaluate[result], {x, \(-2\), 2}, \ PlotRange -> {0, 2}, \n\t\t
        DisplayFunction -> Identity], \n\t
      DisplayFunction -> $DisplayFunction]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0 0.309017 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 0 m
.02381 .00625 L
s
[(-2)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-1)] .2619 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.03 w
.02381 .30902 Mdot
.2619 .14215 Mdot
.5 .37082 Mdot
.7381 .24721 Mdot
.97619 .47898 Mdot
.5 Mabswid
.02381 .30964 m
.06244 .30964 L
.10458 .30964 L
.14415 .30964 L
.18221 .30964 L
.22272 .30964 L
.26171 .30964 L
.30316 .30964 L
.34309 .30964 L
.3815 .30964 L
.42237 .30964 L
.46172 .30964 L
.49955 .30964 L
.53984 .30964 L
.57861 .30964 L
.61984 .30964 L
.65954 .30964 L
.69774 .30964 L
.73838 .30964 L
.77751 .30964 L
.81909 .30964 L
.85916 .30964 L
.89771 .30964 L
.93871 .30964 L
.97619 .30964 L
s
.02381 .22064 m
.06244 .22786 L
.10458 .23573 L
.14415 .24313 L
.18221 .25024 L
.22272 .25781 L
.26171 .2651 L
.30316 .27285 L
.34309 .28031 L
.3815 .28749 L
.42237 .29513 L
.46172 .30248 L
.49955 .30955 L
.53984 .31708 L
.57861 .32433 L
.61984 .33203 L
.65954 .33945 L
.69774 .34659 L
.73838 .35419 L
.77751 .3615 L
.81909 .36927 L
.85916 .37676 L
.89771 .38396 L
.93871 .39163 L
.97619 .39863 L
s
.02381 .28421 m
.06244 .27163 L
.10458 .25983 L
.14415 .25056 L
.18221 .2433 L
.20342 .23995 L
.22272 .23735 L
.24299 .23507 L
.26171 .23337 L
.28086 .23204 L
.29094 .2315 L
.30164 .23105 L
.31105 .23077 L
.31634 .23065 L
.31885 .23061 L
.32117 .23057 L
.32353 .23055 L
.32566 .23052 L
.32803 .23051 L
.32933 .2305 L
.33056 .2305 L
.33164 .23049 L
.33279 .23049 L
.33377 .23049 L
.33484 .23049 L
.336 .2305 L
.33724 .2305 L
.33841 .23051 L
.33947 .23051 L
.34176 .23053 L
.34428 .23056 L
.34939 .23064 L
.35412 .23073 L
.35856 .23085 L
.36855 .23119 L
.37932 .23168 L
.39936 .23294 L
.42046 .23475 L
.45857 .23928 L
.49913 .2459 L
.53817 .25402 L
.57967 .26452 L
.61965 .27646 L
.65812 .28964 L
.69904 .30548 L
.73844 .32251 L
.77633 .34052 L
.81667 .36147 L
.85549 .38336 L
.89677 .40849 L
Mistroke
.93653 .43449 L
.97478 .46118 L
.97619 .4622 L
Mfstroke
.02381 .28822 m
.06244 .27149 L
.10458 .25626 L
.14415 .24472 L
.18221 .23606 L
.20342 .23225 L
.22272 .22938 L
.24276 .22702 L
.26171 .22533 L
.27141 .22468 L
.28168 .22413 L
.29046 .22379 L
.29545 .22364 L
.30012 .22354 L
.3027 .22349 L
.30509 .22346 L
.30771 .22343 L
.30917 .22342 L
.30982 .22342 L
.3105 .22341 L
.31177 .22341 L
.31294 .22341 L
.3142 .22341 L
.31492 .22341 L
.31558 .22341 L
.31679 .22341 L
.31789 .22342 L
.31917 .22343 L
.32037 .22344 L
.32261 .22346 L
.32498 .22349 L
.32924 .22357 L
.33383 .22369 L
.3389 .22384 L
.34899 .22426 L
.35824 .22477 L
.3791 .22632 L
.39802 .22823 L
.41872 .23083 L
.45928 .23746 L
.49833 .24568 L
.53983 .25629 L
.57981 .26824 L
.61828 .28126 L
.65919 .29664 L
.6986 .31285 L
.73648 .32964 L
.77682 .34874 L
.81565 .36821 L
.85692 .38999 L
Mistroke
.89669 .41191 L
.93493 .4338 L
.97563 .45785 L
.97619 .45818 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000EOol3
000iOol5001dOol5000jOol3000DOol001Eoo`03001oogoo03]oo`03001oogoo07Ioo`03001oogoo
03Yoo`03001oogoo01Aoo`0047oo0`000goo00<007ooOol0=7oo0`000goo00<007ooOol0MWoo00<0
07ooOol0>goo00<007ooOol04goo000FOol00`00Oomoo`0jOol00`00Oomoo`1fOol00`00Oomoo`0k
Ool00`00Oomoo`0COol001Eoo`03001oo`0003]oo`03001oogoo07Ioo`03001oogoo03Yoo`03001o
o`0001Aoo`005Woo00<007ooOol0>Goo0P00Mgoo0P00?Goo00<007ooOol04goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`003Gooo`001P003Woo000DOol00`00Oomoo`09Ool0
0`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool0
0`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool0
0`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool0
0`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0COol0
08moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool2002?Ool008moo`03001oogoo08io
o`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`8008moo`00Sgoo00<007ooOol0
SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo0P00Sgoo002?Ool00`00Oomo
o`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool2002?Ool008moo`03001o
ogoo08ioo`00NWoo00<007ooOol00Woo00@007ooOomoo`<000=oo`03001oogoo00=oo`03001oogoo
08ioo`00NGoo00<007oo00001goo00<007ooOol00Woo00<007oo000017oo00<007ooOol0SWoo001i
Ool00`00Ool00008Ool00`00Oomoo`03Ool00`00Oomoo`02Ool3002>Ool007Uoo`03001oo`0000Qo
o`04001oogooOol20005Ool00`00Oomoo`2>Ool007Uoo`03001oo`0000Moo`03001oo`00009oo`03
001oogoo00Aoo`03001oogoo08ioo`00NWoo00<007ooOol01goo00@007ooOomoo`<000Aoo`03001o
ogoo08ioo`00Sgoo0P00Sgoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<0
07ooOol0SWoo002?Ool2002?Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool0
0`00Oomoo`2>Ool008moo`8008moo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool0051o
o`8003eoo`03001oogoo08ioo`00Cgoo1000?7oo0P00Sgoo001>Ool6000kOol00`00Oomoo`2>Ool0
04ioo`H002]oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo08ioo`00
Cgoo1000:goo00<007oo00001goo00<007oo000017oo00<007ooOol0SWoo001@Ool2000/Ool00`00
Ool00009Ool00`00Oomoo`02Ool3002>Ool007ioo`03001oo`0000Moo`8000Eoo`03001oogoo08io
o`00OWoo00<007oo00001goo00<007ooOol017oo00<007ooOol0SWoo001oOol00`00Oomoo`06Ool3
0004Ool00`00Oomoo`2>Ool008moo`8008moo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>
Ool008moo`03001oogoo08ioo`00Sgoo0P00Sgoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo
08ioo`00Sgoo00<007ooOol0SWoo002?Ool2002?Ool008moo`03001oogoo08ioo`00Sgoo00<007oo
Ool0SWoo002?Ool00`00Oomoo`2>Ool008moo`8008moo`0057oo0`00N7oo00<007ooOol0SWoo000G
Ool5000cOolT0007Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool00`00Oomoo`2>Ool001aoo`D002Aoo`X002Aoo`D00004Ool007oo0008Ool01`00Oomoogoo001o
o`0000Aoo`03001oogoo08ioo`008Goo1P006Goo1@002Woo<0001Goo00<007ooOol00goo00<007oo
Ool00Woo0`00SWoo000WOol5000?Ool50005Ool:000YOol?00000goo00000005Ool00`00Oomoo`2>
Ool002aoo`D000Eoo`D000Eoo`D003Aoo`03001oo`0000=oo`h0009oo`03001oogoo03Uoo`8005=o
o`00<Goo1@001Goo1@00>Woo00<007ooOol01Woo0`0000=oo`0000002000>Goo1000DWoo000_Ool3
0004Ool5001BOol7000eOol6001AOol002]oo`@0009oo`D000Eoo`D004moo`03001oogoo00H0035o
o`H0055oo`00:7oo0`0000=oo`0000000`003goo1@00BWoo00<007ooOol01Goo1@00;Woo1000DWoo
000UOol7000IOol50015Ool00`00Oomoo`09Ool7000YOol2001COol002=oo`D0029oo`D0041oo`80
00ioo`L007Yoo`0087oo1000:goo1@00>goo00<007ooOol04Goo1P00Mgoo000MOol3000dOol6000e
Ool00`00Oomoo`0DOol200000goo00000002001cOol001Yoo`@003aoo`L002ioo`03001oogoo01Io
o`<0009oo`<0071oo`005Woo1P00AGoo20009Woo0P006Woo0P000goo0P00KWoo000DOol20002Ool2
001?Ool5000QOol00`00Oomoo`0KOol30002Ool3001[Ool001Ioo`8005Ioo`D001aoo`03001oogoo
01ioo`8000=oo`8006Uoo`0057oo0P00GGoo1P005Woo00<007ooOol087oo0`000Woo0`00IWoo001i
Ool5000AOol2000TOol20003Ool3001SOol007ioo`D000aoo`03001oogoo02Eoo`<000=oo`80065o
o`004Woo0P00Kgoo2@000goo00<007ooOol0:7oo0P000goo0`00GWoo000AOol4001cOol50002Ool0
0`00Oomoo`0ZOol30003Ool3001KOol0011ooo/001Eoo`0047oo1P00Lgoo00<007ooOol00goo00<0
07ooOol01@00:Woo0`000goo0`00EWoo000AOol4001dOol00`00Oomoo`03Ool00`00Oomoo`05Ool5
000XOol20004Ool2001DOol0019oo`8007Aoo`8000Eoo`03001oogoo00Yoo`D002Eoo`<000=oo`80
059oo`00Sgoo0P0047oo1@008goo0P000goo0P00D7oo002?Ool00`00Oomoo`0DOol6000OOol30002
Ool2001>Ool008moo`03001oogoo01Yoo`D001eoo`80009oo`8004aoo`00Sgoo00<007ooOol07goo
1@006Woo0P000Woo0P00BWoo002?Ool2000UOol5000GOol20002Ool20018Ool008moo`03001oogoo
02Uoo`D001Aoo`80009oo`8004Ioo`00Sgoo00<007ooOol0;Woo1@004Goo0P000Woo0P00A7oo002?
Ool00`00Oomoo`0cOol6000=Ool20002Ool20012Ool008moo`8003Yoo`D000Yoo`80009oo`80041o
o`00Sgoo00<007ooOol0?Woo1@001goo0P000Woo0P00?Woo002>Ool20015Ool50004Ool20002Ool2
000lOol008eoo`@004Uoo`P0009oo`8003Yoo`00S7oo1P00CWoo1`00>Goo002<Ool6001BOol20000
0goo00000006000aOol007Qoo`D0009oo`04001oogooOol30003Ool01000Oomoogoo1000EGoo0P00
00=oo`00000017oo1@00;7oo001jOol00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Ool00003Ool2
001HOol200000goo001oo`07Ool5000WOol007Yoo`03001oogoo00Moo`03001oogoo00=oo`03001o
ogoo009oo`<005Qoo`@000]oo`H0025oo`00NWoo00<007ooOol01goo00@007ooOomoo`8000Eoo`03
001oogoo05Yoo`03001oo`00011oo`D001aoo`00NWoo00<007ooOol01Woo00<007oo00000Woo00<0
07ooOol017oo00<007ooOol0Fgoo10004goo100067oo001iOol20009Ool01000Oomoogoo0`0017oo
00<007ooOol0GGoo10005Goo0`005Goo002?Ool2001POol00`00Ool0000/Ool008moo`03001oogoo
061oo`@002Yoo`00Sgoo00<007ooOol0HWoo0`00:Goo002?Ool00`00Oomoo`1TOol3000WOol008mo
o`8006Ioo`@002Eoo`00Sgoo00<007ooOol0Igoo0`0097oo002?Ool00`00Oomoo`1YOol3000ROol0
08moo`03001oogoo06]oo`<0021oo`00Sgoo0P00KWoo0P007goo002?Ool00`00Oomoo`1_Ool2000M
Ool008moo`03001oogoo075oo`8001]oo`00Sgoo00<007ooOol0LWoo0P006Woo002?Ool2001dOol3
000HOol008moo`03001oogoo07Eoo`<001Ioo`00OGoo1@000Woo00<007ooOol00Woo00<007ooOol0
0goo00<007ooOol0MWoo0`005Goo001oOol00`00Oomoo`06Ool00`00Ool00004Ool00`00Oomoo`1h
Ool00`00Oomoo`0COol007moo`03001oogoo00Qoo`03001oogoo009oo`<007Qoo`03001oogoo01=o
o`00Ogoo00<007ooOol01Woo0P001Goo00<007ooOol0SWoo001oOol00`00Oomoo`06Ool00`00Oomo
o`04Ool00`00Oomoo`1gOol2000EOol007ioo`8000Qoo`<000Aoo`03001oogoo07Ioo`@001Aoo`00
Sgoo0P00MWoo1P004goo002?Ool00`00Oomoo`1eOol6000COol008moo`03001oogoo07Ioo`@001Ao
o`00Sgoo00<007ooOol0Mgoo0P005Goo002?Ool2002?Ool008moo`03001oogoo08ioo`00Sgoo00<0
07ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`8008moo`00Sgoo00<007ooOol0SWoo002?Ool0
0`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo0P00Sgoo002?Ool00`00Oomoo`2>Ool007Qo
o`D0009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo08ioo`00NWoo
00<007ooOol01goo00L007ooOomoo`00Ool00004Ool00`00Oomoo`2>Ool007Yoo`03001oogoo00Mo
o`03001oogoo00=oo`03001oogoo009oo`<008ioo`00NWoo00<007ooOol027oo00<007ooOol00P00
1Goo00<007ooOol0SWoo001jOol00`00Oomoo`06Ool00`00Ool00002Ool00`00Oomoo`04Ool00`00
Oomoo`2>Ool007Uoo`8000Qoo`<0009oo`<000Aoo`03001oogoo08ioo`00Sgoo0P00Sgoo002?Ool0
0`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool2002?Ool008mo
o`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`8008moo`00
Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo0P00Sgoo
002?Ool00`00Oomoo`2>Ool008Qoo`<000Aoo`03001oogoo08ioo`00R7oo00<007ooOol017oo00<0
07ooOol0SWoo0029Ool00`00Oomoo`03Ool3002>Ool008Uoo`03001oogoo09Aoo`00R7oo00<007oo
0000UGoo0029Ool00`00Oomoo`2DOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{86.5, 373.5}, {347.063, 170.125}} -> {-3.7268, 1.97113, 
  0.0162035, 0.0124846}}]
}, Open  ]],

Cell["\<\
The process of fitting polynomials to data in a moving window is \
computationaly expensive if done in the manner shown above. Luckily, since \
the process of least-squares fitting involves only linear matrix inversion \
(as demonstrated later), the coefficients of a fitted polynomial are \
themselves linear in the values of the data. Therefore, we may precompute \
them for a unit impulse data sequence and do the fit to actual data by linear \
combinations.\
\>", "Text",
  FontFamily->"Times New Roman"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Least-Squares Polynomial Fit - background", "Subsection",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "We are interested in replacing a data value x[m] of a noisy sequence by \
the value of its optimal n-th order polynomial approximation ",
  StyleBox["xa[m]=(c[0]+c[1]*m+...+c[n-1]*m^(n-1))",
    FontWeight->"Bold"],
  ". However, in analogy to a moving average filter, we are primarily \
interested in replacing the point at the middle of a finite interval with a \
weighted average of its neighbors. Substituting m=0 we find that the \
approximation to ",
  StyleBox["x[0]",
    FontWeight->"Bold"],
  " is ",
  StyleBox["xa[0] = c[0]",
    FontWeight->"Bold"],
  ". Here we will show how to calculate the optimal value ",
  StyleBox["c[0]",
    FontWeight->"Bold"],
  ". We use a least-squares fit, which chooses the coefficients c[i] that \
minimize the total squared error. The approximation error using a quadratic \
fitting polynomial is "
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(e[m_] := \ x[m] - \((c[0] + c[1]*m + c[2]*m^2)\); \)\)], "Input"],

Cell["The total squared error is ", "Text",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[BoxData[
    \(se = \[Sum]\+\(m = \(-2\)\)\%2 e[m]^2\)], "Input"],

Cell["\<\
(-c[0] + 2*c[1] - 4*c[2] + x[-2])^2 + 
  (-c[0] + c[1] - c[2] + x[-1])^2 + (-c[0] + x[0])^2 + 
  (-c[0] - c[1] - c[2] + x[1])^2 + 
  (-c[0] - 2*c[1] - 4*c[2] + x[2])^2\
\>", "Output"]
}, Open  ]],

Cell[TextData[{
  "To minimize the expression for ",
  StyleBox["se",
    FontWeight->"Bold"],
  " in terms of the coefficients ",
  StyleBox["{c[0],c[1],c[2]}",
    FontWeight->"Bold"],
  ", we must set the derivatives of ",
  StyleBox["se",
    FontWeight->"Bold"],
  " with respect these coefficients to zero and solve the resulting system of \
equations."
}], "Text",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[{\[PartialD]\_\(c[0]\)\ se\  == \ 0, 
        \[PartialD]\_\(c[1]\)\ se\  == \ 0, 
        \[PartialD]\_\(c[2]\)\ se\  == \ 0}, {c[0], c[1], c[2]}]\)], "Input"],

Cell["\<\
{{c[0] -> (-3*x[-2] + 12*x[-1] + 17*x[0] + 12*x[1] - 
       3*x[2])/35, c[1] -> 
    (-2*x[-2] - x[-1] + x[1] + 2*x[2])/10, 
   c[2] -> (2*x[-2] - x[-1] - 2*x[0] - x[1] + 2*x[2])/14}}\
\>", "Output"]
}, Open  ]],

Cell["The desired coefficient are", "Text",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cv = {c[0], c[1], c[2]}\  /. \ %\)], "Input"],

Cell["\<\
{{(-3*x[-2] + 12*x[-1] + 17*x[0] + 12*x[1] - 3*x[2])/35, 
   (-2*x[-2] - x[-1] + x[1] + 2*x[2])/10, 
   (2*x[-2] - x[-1] - 2*x[0] - x[1] + 2*x[2])/14}}\
\>", "Output"]
}, Open  ]],

Cell[TextData[{
  "As mentioned earlier, the coefficient ",
  StyleBox["c[0]",
    FontWeight->"Bold"],
  " is of particular interest, since it is the one that represents the \
smoothed middle value of each data segment. It is clear that, ",
  StyleBox["c[0",
    FontWeight->"Bold"],
  "] is a linear combination of data values weighted by the following \
coefficients."
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(g = {\(-3\), 12, 17, 12, \(-3\)}/35; \)\)], "Input"],

Cell["\<\
These are the coefficients of a length 5, order 2, SG filter. Note that this \
is a linear phase, Type 1 filter. \
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell["Problem 1", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "Calculate the coefficients ",
  StyleBox["{c[0],c[1],c[2]}",
    FontWeight->"Bold"],
  " using the data samples in Section 2. Compare with the coefficients \
obtained with the ",
  StyleBox["Fit",
    FontWeight->"Bold"],
  " function."
}], "Text",
  FontFamily->"Times New Roman"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Least-Squares Polynomial Fit - matrix formulation", "Subsection",
  FontFamily->"Times New Roman"],

Cell["\<\
In this section, the least-squares fitting problem will be presented using a \
more efficient matrix notation. We begin by formulating the necessary vectors \
and matrices. First, the data vector xv of length L=5, with the samples \
positioned symmetrically about the origin.\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[BoxData[
    \(L = 5; \nxv = Table[x[m], {m, \(-\((L - 1)\)\)/2, \((L - 1)\)/2}]\)], 
  "Input"],

Cell[BoxData[
    \({x[\(-2\)], x[\(-1\)], x[0], x[1], x[2]}\)], "Output"]
}, Open  ]],

Cell["\<\
Following the example in the previous section we choose a second-order \
polynomial approximation.\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[BoxData[
    \(p = 2; \ncv = Table[c[i], {i, 0, p}]\)], "Input"],

Cell[BoxData[
    \({c[0], c[1], c[2]}\)], "Output"]
}, Open  ]],

Cell["\<\
The coefficients of the matrix S, which depend on the order of the polynomial \
and the number of samples in the interval are obtained in the following \
way.\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(S = 
      Table[{1, m, m^2}, \n
        \t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ {m, 
          \(-\((L - 1)\)\)/2, \((L - 1)\)/2}]; \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatrixForm[S]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"1", \(-2\), "4"},
            {"1", \(-1\), "1"},
            {"1", "0", "0"},
            {"1", "1", "1"},
            {"1", "2", "4"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "It can be shown that the squared error may be expressed in the following \
way\n\tse  ",
  Cell[BoxData[
      \(\( = \((xv - S.cv)\)\)\^T\ \((xv - S.cv)\)\ \n = \ 
        xv\^T.\ xv\  - \ 2\ cv\^T.\ S\^T.\ xv\  + \ 
          cv\^T.\ \((S\^T.\ S)\).cv\)]],
  "\nTo minimize this expression with respect to c, we must set the gradient \
",
  Cell[BoxData[
      RowBox[{\(\[PartialD]\_cv\), " ", 
        StyleBox["se",
          FontWeight->"Bold"]}]]],
  " to zero and solve for cv. \n\t",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_cv\ se\)]],
  " = - ",
  Cell[BoxData[
      \(TraditionalForm
      \`2\ \ S\^T.\ xv\  + \ 2\ \((S\^T.\ S\ )\)\ .\ cv\ \  = \ \ 0\)]],
  "\nThis results in the so-called normal equations\n\t",
  Cell[BoxData[
      \(S\^T.S.cv\  = \ S\^T\ .\ xv\)]],
  "\nwhich can next be solved for cv resulting in\n\tcv = ",
  Cell[BoxData[
      \(\((S\^T.S)\)\^\(-1\)\ .\ S\^T\ .\ xv\)]]
}], "Text",
  FontFamily->"Times New Roman"],

Cell["Consider the matrix multiplying the data vector xv.", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(G = S.Inverse[Transpose[S].S]; \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatrixForm[G]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {\(-\(3\/35\)\), \(-\(1\/5\)\), \(1\/7\)},
            {\(12\/35\), \(-\(1\/10\)\), \(-\(1\/14\)\)},
            {\(17\/35\), "0", \(-\(1\/7\)\)},
            {\(12\/35\), \(1\/10\), \(-\(1\/14\)\)},
            {\(-\(3\/35\)\), \(1\/5\), \(1\/7\)}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
Note that the first column of G is same as the result obtained in the \
previous section. However the computation shown here is more efficient. The \
package SavitzkyGolay by Arnd Roth from the Max Planck Institute for Medical \
Research uses this approach.\
\>", "Text",
  FontFamily->"Times New Roman"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Savitzky-Golay Filters in Transform Domain", "Section",
  FontFamily->"Arial"],

Cell["Load the SavitzkyGolay package.", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(<< SavitzkyGolay`\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Information[SavitzkyGolayCoefficients, LongForm -> False]; \)\)], 
  "Input"],

Cell[BoxData[
    \("SavitzkyGolayCoefficients[L,order] gives a list of coefficients \
{c[-(L-1)/2], c[-(L-1)/2 + 1], ..., c[(L-1)/2]} of a Savitzky-Golay FIR \
lowpass filter. The output of the filter, g[i], is a linear combination of \
input function values f[i] according to g[i] = Sum[c[n] f[i+n], {n, \
-(L-1)/2,(L-1)/2}]. Typical values for the order are 2 and 4. \
SavitzkyGolayCoefficients[L,order,k]  gives a list of the kth highpass \
coefficients (1 <= k <= order).  These can be used to estimate the kth \
derivative of the data vector."\)], "Print"]
}, Open  ]],

Cell[TextData[{
  "To obtain a length L=5, FIR SG filter of order 2, use ",
  StyleBox["SavitzkyGolayCoefficients",
    FontWeight->"Bold"],
  " function with the following arguments. "
}], "Text",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[BoxData[
    \(fir = SavitzkyGolayCoefficients[5, 2]\)], "Input"],

Cell[BoxData[
    \({\(-\(3\/35\)\), 12\/35, 17\/35, 12\/35, \(-\(3\/35\)\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problem 2", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell["\<\
Obtain the coefficients of an SG filter of order 1. Comment on the result.\
\>", "Text",
  FontFamily->"Times New Roman"]
}, Open  ]],

Cell["Take the z-transform of the SG and plot the poles and zeros.", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(<< SignalProcessing`Master`\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ZTransform[SampledData[fir, \(-2\), n], n, z]\)], "Input"],

Cell["\<\
ZTransformData[(-3 + 12*z + 17*z^2 + 12*z^3 - 3*z^4)/(35*z^2), 
  RegionOfConvergence[0, Infinity], TransformVariables[z]]\
\>", "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PoleZeroPlot[%8]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0765662 0.5 0.0765662 [
[.0406 -0.0125 -6 -9 ]
[.0406 -0.0125 6 0 ]
[.19374 -0.0125 -6 -9 ]
[.19374 -0.0125 6 0 ]
[.34687 -0.0125 -6 -9 ]
[.34687 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65313 -0.0125 -3 -9 ]
[.65313 -0.0125 3 0 ]
[.80626 -0.0125 -3 -9 ]
[.80626 -0.0125 3 0 ]
[.9594 -0.0125 -3 -9 ]
[.9594 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -14 -25 ]
[.5 -0.0125 14 -9 ]
[-0.0125 .0406 -12 -4.5 ]
[-0.0125 .0406 0 4.5 ]
[-0.0125 .19374 -12 -4.5 ]
[-0.0125 .19374 0 4.5 ]
[-0.0125 .34687 -12 -4.5 ]
[-0.0125 .34687 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .65313 -6 -4.5 ]
[-0.0125 .65313 0 4.5 ]
[-0.0125 .80626 -6 -4.5 ]
[-0.0125 .80626 0 4.5 ]
[-0.0125 .9594 -6 -4.5 ]
[-0.0125 .9594 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -28 -14 ]
[-0.01875 .5 -12 14 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -44 0 ]
[.5 1.0125 44 16 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.0406 0 m
.0406 .00625 L
s
[(-6)] .0406 -0.0125 0 1 Mshowa
.19374 0 m
.19374 .00625 L
s
[(-4)] .19374 -0.0125 0 1 Mshowa
.34687 0 m
.34687 .00625 L
s
[(-2)] .34687 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65313 0 m
.65313 .00625 L
s
[(2)] .65313 -0.0125 0 1 Mshowa
.80626 0 m
.80626 .00625 L
s
[(4)] .80626 -0.0125 0 1 Mshowa
.9594 0 m
.9594 .00625 L
s
[(6)] .9594 -0.0125 0 1 Mshowa
.125 Mabswid
.07889 0 m
.07889 .00375 L
s
.11717 0 m
.11717 .00375 L
s
.15545 0 m
.15545 .00375 L
s
.23202 0 m
.23202 .00375 L
s
.2703 0 m
.2703 .00375 L
s
.30858 0 m
.30858 .00375 L
s
.38515 0 m
.38515 .00375 L
s
.42343 0 m
.42343 .00375 L
s
.46172 0 m
.46172 .00375 L
s
.53828 0 m
.53828 .00375 L
s
.57657 0 m
.57657 .00375 L
s
.61485 0 m
.61485 .00375 L
s
.69142 0 m
.69142 .00375 L
s
.7297 0 m
.7297 .00375 L
s
.76798 0 m
.76798 .00375 L
s
.84455 0 m
.84455 .00375 L
s
.88283 0 m
.88283 .00375 L
s
.92111 0 m
.92111 .00375 L
s
.00232 0 m
.00232 .00375 L
s
.99768 0 m
.99768 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -75 -29 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Re) show
81.000000 15.000000 moveto
(z) show
87.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .0406 m
.00625 .0406 L
s
[(-6)] -0.0125 .0406 1 0 Mshowa
0 .19374 m
.00625 .19374 L
s
[(-4)] -0.0125 .19374 1 0 Mshowa
0 .34687 m
.00625 .34687 L
s
[(-2)] -0.0125 .34687 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .65313 m
.00625 .65313 L
s
[(2)] -0.0125 .65313 1 0 Mshowa
0 .80626 m
.00625 .80626 L
s
[(4)] -0.0125 .80626 1 0 Mshowa
0 .9594 m
.00625 .9594 L
s
[(6)] -0.0125 .9594 1 0 Mshowa
.125 Mabswid
0 .07889 m
.00375 .07889 L
s
0 .11717 m
.00375 .11717 L
s
0 .15545 m
.00375 .15545 L
s
0 .23202 m
.00375 .23202 L
s
0 .2703 m
.00375 .2703 L
s
0 .30858 m
.00375 .30858 L
s
0 .38515 m
.00375 .38515 L
s
0 .42343 m
.00375 .42343 L
s
0 .46172 m
.00375 .46172 L
s
0 .53828 m
.00375 .53828 L
s
0 .57657 m
.00375 .57657 L
s
0 .61485 m
.00375 .61485 L
s
0 .69142 m
.00375 .69142 L
s
0 .7297 m
.00375 .7297 L
s
0 .76798 m
.00375 .76798 L
s
0 .84455 m
.00375 .84455 L
s
0 .88283 m
.00375 .88283 L
s
0 .92111 m
.00375 .92111 L
s
0 .00232 m
.00375 .00232 L
s
0 .99768 m
.00375 .99768 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -95 -12 Mabsadd m
1 1 Mabs scale
currentpoint translate
75 12 translate
90 rotate
-75 -12 translate
0 24 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Im) show
81.000000 15.000000 moveto
(z) show
87.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.0406 .99375 m
.0406 1 L
s
.19374 .99375 m
.19374 1 L
s
.34687 .99375 m
.34687 1 L
s
.5 .99375 m
.5 1 L
s
.65313 .99375 m
.65313 1 L
s
.80626 .99375 m
.80626 1 L
s
.9594 .99375 m
.9594 1 L
s
.125 Mabswid
.07889 .99625 m
.07889 1 L
s
.11717 .99625 m
.11717 1 L
s
.15545 .99625 m
.15545 1 L
s
.23202 .99625 m
.23202 1 L
s
.2703 .99625 m
.2703 1 L
s
.30858 .99625 m
.30858 1 L
s
.38515 .99625 m
.38515 1 L
s
.42343 .99625 m
.42343 1 L
s
.46172 .99625 m
.46172 1 L
s
.53828 .99625 m
.53828 1 L
s
.57657 .99625 m
.57657 1 L
s
.61485 .99625 m
.61485 1 L
s
.69142 .99625 m
.69142 1 L
s
.7297 .99625 m
.7297 1 L
s
.76798 .99625 m
.76798 1 L
s
.84455 .99625 m
.84455 1 L
s
.88283 .99625 m
.88283 1 L
s
.92111 .99625 m
.92111 1 L
s
.00232 .99625 m
.00232 1 L
s
.99768 .99625 m
.99768 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .0406 m
1 .0406 L
s
.99375 .19374 m
1 .19374 L
s
.99375 .34687 m
1 .34687 L
s
.99375 .5 m
1 .5 L
s
.99375 .65313 m
1 .65313 L
s
.99375 .80626 m
1 .80626 L
s
.99375 .9594 m
1 .9594 L
s
.125 Mabswid
.99625 .07889 m
1 .07889 L
s
.99625 .11717 m
1 .11717 L
s
.99625 .15545 m
1 .15545 L
s
.99625 .23202 m
1 .23202 L
s
.99625 .2703 m
1 .2703 L
s
.99625 .30858 m
1 .30858 L
s
.99625 .38515 m
1 .38515 L
s
.99625 .42343 m
1 .42343 L
s
.99625 .46172 m
1 .46172 L
s
.99625 .53828 m
1 .53828 L
s
.99625 .57657 m
1 .57657 L
s
.99625 .61485 m
1 .61485 L
s
.99625 .69142 m
1 .69142 L
s
.99625 .7297 m
1 .7297 L
s
.99625 .76798 m
1 .76798 L
s
.99625 .84455 m
1 .84455 L
s
.99625 .88283 m
1 .88283 L
s
.99625 .92111 m
1 .92111 L
s
.99625 .00232 m
1 .00232 L
s
.99625 .99768 m
1 .99768 L
s
.25 Mabswid
1 0 m
1 1 L
s
gsave
.5 1.0125 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Pole) show
87.000000 15.000000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
93.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Zero) show
123.000000 15.000000 moveto
(Plot) show
147.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math1Mono
%%DocumentNeededResources: + font Courier
%%DocumentNeededFonts: Math1Mono
%%DocumentNeededFont: + Courier
%%DocumentFonts: font Math1Mono
%%DocumentFonts: + font Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.003 w
newpath
.5 .5 .07657 0 365.73 arc
s
0 .5 m
1 .5 L
s
.5 0 m
.5 1 L
s
.8 g
.5 Mabswid
1 .68199 m
0 .31801 L
s
1 .72928 m
0 .36531 L
s
1 .77658 m
0 .41261 L
s
1 .82388 m
0 .45991 L
s
1 .87117 m
0 .5072 L
s
1 .91847 m
0 .5545 L
s
1 .96577 m
0 .6018 L
s
.96411 1 m
0 .64909 L
s
.83416 1 m
0 .69639 L
s
.70422 1 m
0 .74369 L
s
.57427 1 m
0 .79098 L
s
.44432 1 m
0 .83828 L
s
.31438 1 m
0 .88558 L
s
.18443 1 m
0 .93287 L
s
.05448 1 m
0 .98017 L
s
1 .01983 m
.94552 0 L
s
1 .06713 m
.81557 0 L
s
1 .11442 m
.68562 0 L
s
1 .16172 m
.55568 0 L
s
1 .20902 m
.42573 0 L
s
1 .25631 m
.29578 0 L
s
1 .30361 m
.16584 0 L
s
1 .35091 m
.03589 0 L
s
1 .3982 m
0 .03423 L
s
1 .4455 m
0 .08153 L
s
1 .4928 m
0 .12883 L
s
1 .54009 m
0 .17612 L
s
1 .58739 m
0 .22342 L
s
1 .63469 m
0 .27072 L
s
0 g
.009 w
newpath
.4458 .44591 .02 0 365.73 arc
s
newpath
.4458 .55409 .02 0 365.73 arc
s
newpath
.51466 .5 .02 0 365.73 arc
s
newpath
.9 .5 .02 0 365.73 arc
s
.53333 .51667 m
.48333 .46667 L
s
.51667 .53333 m
.46667 .48333 L
s
.46667 .51667 m
.51667 .46667 L
s
.48333 .53333 m
.53333 .48333 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00Tgoo0`0000Aoo`00Oomoo`8000Yoo`@0
07Ioo`00U7oo00H007ooOol007oo000=Ool00`00Ool0001fOol009Aoo`<0009oo`<000Yoo`03001o
o`0007Moo`00U7oo00D007ooOol007oo00<000Yoo`@007Ioo`00U7oo00@007ooOol008Qoo`00Tgoo
1000RGoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00<Woo0P0097oo0`00
87oo0`008Goo00<007ooOol087oo0`008goo0`008Goo0P004Woo000bOol00`00Ool0000TOol00`00
Oomoo`0OOol00`00Oomoo`0POol00`00Ool0000QOol00`00Oomoo`0TOol00`00Oomoo`0POol00`00
Ool0000AOol002eoo`<0009oo`03001oo`0001eoo`<0009oo`@001]oo`<000=oo`03001oogoo01mo
o`03001oo`00029oo`03001oogoo025oo`@0025oo`03001oo`00015oo`00<Woo0P008goo00<007oo
00008Woo00<007ooOol07goo00<007oo00008Woo00<007ooOol08Goo00<007oo00008Woo0P004Woo
000bOol00`00Oomoo`0SOol2000QOol00`00Ool0000POol00`00Ool0000QOol00`00Ool0000SOol2
000ROol00`00Oomoo`0AOol003=oo`8002Aoo`03001oogoo021oo`03001oogoo021oo`03001oogoo
025oo`03001oogoo02=oo`03001oogoo025oo`80015oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol002Moo`T0009S61d0009S61d0009S61d0009S61000003O000000000/0009S
61d0009S61d0009S61d0009S60`000Qoo`009goo0P0027oo00@006<HHaQS60Eoo`03001oogoo00Io
o`03001oogoo00Ioo`03001oogoo009oo`=S609oo`03001oogoo00Ioo`03001oogoo00Ioo`03001o
ogoo00Eoo`=S60Moo`03001oogoo00Moo`03001oogoo00Ioo`03001oof<H009S60Aoo`03001oogoo
00Ioo`03O01oogoo00Ioo`03001oogoo00Aoo`=S6003001oogoo00Ioo`03001oogoo00Ioo`03001o
ogoo00Ioo`04001S66<HHaP5Ool00`00Oomoo`07Ool00`00Oomoo`06Ool01000Oomoogoo0V<H0goo
00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Goo0V<H27oo0P0027oo000WOol00`00Oomo
o`07Ool01000Oomoogoo0V<H7Goo0V<H00<007ooOol06Woo0V<H1Goo00<007ooOol05Goo0V<H2goo
00=l07ooOol047oo0V<H47oo00<007ooOol02Woo0V<H5Woo00<007ooOol00goo0f<H6goo00@006<H
HaQS60Ioo`03001oogoo00Ioo`009goo00<007ooOol03Goo0f<H77oo0f<H77oo0f<H77oo0f<H27oo
00=l07ooOol04Woo0f<H77oo0f<H77oo0f<H77oo0f<H0goo00<007ooOol01Woo000WOol00`00Oomo
o`0@Ool3HaPLOol3HaPLOol3HaPLOol3HaP5Ool00g`0Oomoo`0EOol3HaPLOol3HaPLOol2HaPMOol2
HaP00goo001oo`07Ool002Moo`03001oogoo01=oo`9S61eoo`=S61aoo`9S61eoo`9S60=oo`03O01o
ogoo01Qoo`9S61eoo`9S61aoo`=S61aoo`9S60Qoo`009goo00<007ooOol05Goo0f<H7Goo0V<H77oo
0f<H77oo0f<H00=l07ooOol06Woo0f<H77oo0f<H77oo0V<H6goo00<007ooOol01Woo000WOol00`00
Oomoo`0HOol3HaPLOol3HaPLOol3HaPLOol3HaPMOol3HaPLOol3HaPKOol3HaPHOol00`00Oomoo`06
Ool0021oo`8000Eoo`03001oogoo01]oo`=S61aoo`=S61aoo`=S61Uoo`03O01oogoo009S61ioo`=S
61aoo`9S61aoo`9S61Ioo`03001oogoo00Ioo`0087oo00<007oo000017oo0V<H7goo0V<H7Goo0f<H
77oo0V<H5goo00=l07ooOol00Woo0f<H7Woo0V<H77oo0f<H6goo0f<H4goo00<007ooOol01Woo000K
Ool30002Ool00`00Ool00004Ool20003HaPNOol3HaPMOol2HaPLOol3HaPDOol00g`0Oomoo`05Ool3
HaPMOol3HaPLOol3HaPKOol3HaP?Ool20008Ool0021oo`8000Eoo`03001oogoo009oo`9S61moo`=S
61aoo`=S61aoo`=S615oo`03O01oogoo00Qoo`=S61eoo`=S61aoo`9S61aoo`9S60ioo`03001oogoo
00Ioo`0087oo00<007ooOol017oo00<007ooOol017oo0f<H7goo0V<H7Goo0f<H77oo0f<H3Woo00=l
07ooOol02goo0V<H7Woo0V<H77oo0f<H6goo0f<H2goo00<007ooOol01Woo000QOol20004Ool00`00
Oomoo`07Ool3HaPNOol3HaPMOol2HaPMOol2HaP<Ool00g`0Oomoo`0=Ool3HaPMOol3HaPLOol3HaPK
Ool2HaP9Ool00`00Oomoo`06Ool002Moo`03001oogoo00Yoo`=S61ioo`=S61aoo`=S61aoo`=S60Uo
o`03O01oogoo011oo`=S61eoo`=S61aoo`9S61]oo`=S60Ioo`03001oogoo00Ioo`009goo00<007oo
Ool03Goo0V<H7goo0f<H77oo0f<H77oo0f<H1Woo00=l07ooOol04goo0V<H7Woo0f<H6goo0f<H6goo
0f<H0goo00<007ooOol01Woo000WOol00`00Oomoo`0?Ool3HaPOOol2HaPMOol3HaPLOol2HaP4Ool0
0g`0Oomoo`0EOol3HaPNOol2HaPLOol3HaPKOol2HaP00goo001oo`07Ool002Moo`03001oogoo019o
o`=S61ioo`=S61eoo`9S61aoo`=S6003Ooml07oo01Uoo`=S61eoo`=S61aoo`9S61]oo`9S60Qoo`00
9goo00<007ooOol05Goo0f<H7Woo0f<H77oo0f<H77oo0f<H77oo0f<H7Goo0f<H6goo0f<H6Goo00<0
07ooOol01Woo000WOol2000IOol2HaPOOol2HaPMOol3HaPJOol00g`0OomS6002HaPLOol2HaPNOol2
HaPLOol3HaPEOol20008Ool002Moo`9S61]oo`=S61ioo`=S61eoo`=S61Moo`03O01oogoo009oo`9S
61aoo`=S61eoo`=S61aoo`9S61Aoo`03001oogoo00Ioo`009goo00<007ooHaP00V<H6goo0f<H7Woo
0f<H7Goo0V<H5Goo00=l07ooOol017oo0f<H77oo0f<H7Goo0f<H6goo0f<H4Goo00<007ooOol01Woo
000WOol00`00Oomoo`02Ool2HaPLOol3HaPNOol3HaPLOol3HaPBOol00g`0Oomoo`07Ool3HaPLOol2
HaPNOol3HaPKOol3HaP>Ool00`00Oomoo`06Ool002Moo`03001oogoo00Aoo`=S61aoo`9S61moo`9S
61eoo`=S60moo`03O01oogoo00Yoo`=S61]oo`=S61ioo`9S61aoo`9S60aoo`03001oogoo00Ioo`00
9goo00<007ooOol01goo0f<H6goo0f<H7Woo0f<H7Goo0f<H37oo00=l07ooOol03Goo0V<H77oo0f<H
7Goo0f<H6goo0f<H2Goo00<007ooOol01Woo000WOol00`00Oomoo`0:Ool3HaPKOol3HaPNOol3HaPM
Ool2HaP:Ool00g`0Oomoo`0?Ool3HaPLOol2HaPNOol3HaPKOol3HaP6Ool00`00Oomoo`06Ool002Mo
o`03001oogoo00eoo`9S61aoo`=S61ioo`=S61aoo`=S60Moo`03O01oogoo019oo`=S61]oo`=S61io
o`=S61]oo`9S60Aoo`03001oogoo00Ioo`009goo00<007ooOol03goo0f<H77oo0f<H7Woo0V<H7Goo
0f<H17oo00=l07ooOol05Goo0V<H77oo0f<H7Woo0V<H6goo0f<H00=oo`00Ool01goo000WOol00`00
Oomoo`0BOol3HaPLOol2HaPNOol3HaPMOol3HaP00gooO01oo`0HOol3HaPLOol3HaPMOol3HaPKOol2
HaP8Ool002Moo`8001Ioo`=S61]oo`=S61ioo`=S61eoo`9S61aoo`=S61aoo`9S61ioo`=S61Qoo`80
00Qoo`009goo00<007ooOol067oo0V<H77oo0f<H7Woo0V<H77oo00Al06<HHaQS61aoo`=S61]oo`=S
61ioo`9S61Moo`03001oogoo00Ioo`009goo0V<H6goo0f<H77oo0f<H7Goo0f<H6Goo00Al07ooOomo
o`=S61aoo`9S61aoo`=S61eoo`=S61Aoo`03001oogoo00Ioo`009goo00<007ooHaP00V<H6goo0f<H
77oo0V<H7Woo0f<H5Woo00=l07ooOol017oo0f<H6goo0f<H77oo0V<H7Woo0f<H4Goo00<007ooOol0
1Woo000WOol00`00Oomoo`02Ool2HaPLOol3HaPKOol3HaPNOol3HaPCOol00g`0Oomoo`07Ool2HaPL
Ool3HaPKOol3HaPNOol3HaP>Ool00`00Oomoo`06Ool002Moo`03001oogoo00Aoo`=S61aoo`9S61ao
o`=S61ioo`9S615oo`03O01oogoo00Uoo`=S61aoo`=S61]oo`=S61ioo`9S60aoo`03001oogoo00Io
o`009goo00<007ooOol01goo0f<H6goo0f<H77oo0f<H7Goo0f<H3Woo00=l07ooOol037oo0f<H77oo
0V<H77oo0f<H7Goo0f<H2Goo00<007ooOol01Woo000WOol00`00Oomoo`0:Ool2HaPLOol3HaPLOol2
HaPNOol3HaP;Ool00g`0Oomoo`0?Ool2HaPLOol3HaPLOol2HaPNOol3HaP6Ool00`00Oomoo`06Ool0
02Moo`03001oogoo00aoo`=S61aoo`=S61]oo`=S61ioo`9S60Uoo`03O01oogoo015oo`=S61aoo`=S
61]oo`=S61ioo`9S60Aoo`03001oogoo00Ioo`009goo0P0047oo0f<H77oo0f<H6goo0f<H7Goo0f<H
1Woo00=l07ooOol057oo0f<H77oo0V<H77oo0f<H7Goo0f<H0P0027oo000WOol00`00Oomoo`0BOol3
HaPLOol2HaPLOol3HaPMOol3HaP3Ool00g`0Oomoo`0GOol3HaPKOol3HaPLOol2HaPNOol2HaP8Ool0
02Moo`03001oogoo01Eoo`9S61aoo`=S61aoo`9S61ioo`=S6003O01oogoo01Yoo`9S61aoo`=S61]o
o`=S61aoo`03001oogoo00Ioo`009goo00<007ooOol05goo0f<H77oo0f<H6goo0f<H7Woo0V<H7Goo
0f<H77oo0f<H6goo0f<H6Goo00<007ooOol01Woo000WOol00`00Oomoo`0JOol3HaPLOol3HaPKOol3
HaPKOol00g`0OomS6002HaPMOol3HaPLOol2HaPLOol2HaPGOol00`00Oomoo`06Ool002Moo`9S61io
o`=S61aoo`9S61aoo`=S61Qoo`03O01oogoo009oo`=S61eoo`=S61]oo`=S61]oo`=S61Aoo`03001o
ogoo00Ioo`009goo00<007ooHaP00V<H7Woo0V<H77oo0f<H77oo0V<H5Woo00=l07ooOol01Goo0V<H
7Woo0V<H77oo0f<H6goo0f<H4Goo00<007ooOol01Woo000QOol30003Ool00`00Oomoo`02Ool2HaPN
Ool3HaPLOol3HaPKOol3HaPCOol00g`0Oomoo`07Ool3HaPMOol3HaPLOol3HaPKOol3HaP>Ool00`00
Oomoo`06Ool0029oo`03001oogoo009oo`03001oogoo00Aoo`=S61ioo`=S61aoo`=S61]oo`=S611o
o`03O01oogoo00Yoo`=S61eoo`=S61aoo`9S61aoo`9S60aoo`03001oogoo00Ioo`006goo0`000Woo
10000goo0`001goo0f<H7Woo0V<H7Goo0V<H77oo0f<H3Goo00=l07ooOol03Goo0f<H7Goo0f<H6goo
0f<H6goo0f<H27oo0P0027oo000POol00`00Ool00004Ool00`00Oomoo`0:Ool3HaPMOol3HaPLOol3
HaPLOol2HaP;Ool00g`0Oomoo`0@Ool2HaPNOol2HaPLOol3HaPKOol3HaP6Ool00`00Oomoo`06Ool0
025oo`8000Aoo`03001oogoo00eoo`9S61ioo`=S61aoo`=S61]oo`=S60Qoo`03O01oogoo019oo`=S
61eoo`=S61aoo`9S61aoo`9S60Aoo`03001oogoo00Ioo`008Woo00<007ooOol00Woo00<007ooOol0
3goo0f<H7Woo0f<H77oo0f<H6goo0f<H1Goo00=l07ooOol05Goo0f<H7Goo0f<H6goo0f<H6goo0f<H
00=oo`00Ool01goo000WOol00`00Oomoo`0BOol3HaPNOol2HaPMOol2HaPLOol3HaP2Ool00g`0Oomo
o`0HOol2HaPNOol3HaPKOol3HaPKOol2HaP8Ool002Moo`03001oogoo01Eoo`=S61eoo`=S61aoo`=S
61aoo`9S6003O01oogoo01Yoo`=S61ioo`9S61aoo`=S61Uoo`03001oogoo00Ioo`009goo00<007oo
Ool067oo0V<H7Woo0f<H77oo0f<H6goo0f<H7Goo0f<H7Goo0f<H77oo0V<H5goo00<007ooOol01Woo
000WOol2HaPKOol3HaPNOol3HaPLOol3HaPHOol00g`0Oomoo`03HaPMOol3HaPMOol3HaPKOol3HaPD
Ool00`00Oomoo`06Ool002Moo`03001oof<H009S61]oo`=S61ioo`9S61eoo`9S61Ioo`03O01oogoo
00=oo`=S61eoo`9S61ioo`=S61]oo`=S615oo`03001oogoo00Ioo`009goo0P000goo0V<H77oo0f<H
7Goo0f<H77oo0f<H4goo00=l07ooOol01Woo0f<H77oo0f<H7Woo0V<H77oo0f<H3Goo0P0027oo000W
Ool00`00Oomoo`04Ool3HaPLOol2HaPNOol3HaPLOol3HaP@Ool00g`0Oomoo`09Ool2HaPMOol3HaPM
Ool3HaPLOol2HaP<Ool00`00Oomoo`06Ool002Moo`03001oogoo00Moo`=S61]oo`=S61ioo`9S61eo
o`=S60eoo`03O01oogoo00]oo`=S61eoo`9S61ioo`=S61]oo`=S60Uoo`03001oogoo00Ioo`009goo
00<007ooOol02Woo0f<H6goo0f<H7Goo0f<H7Goo0V<H2goo00=l07ooOol03Woo0f<H77oo0f<H7Woo
0f<H6goo0f<H1Woo00<007ooOol01Woo000WOol00`00Oomoo`0=Ool2HaPLOol3HaPMOol3HaPLOol3
HaP8Ool00g`0Oomoo`0AOol3HaPLOol3HaPNOol2HaPLOol2HaP4Ool00`00Oomoo`06Ool002Moo`03
001oogoo00moo`=S61aoo`=S61eoo`=S61aoo`=S60Eoo`03O01oogoo01Aoo`9S61eoo`=S61eoo`=S
61]oo`=S6003Ool007oo00Moo`009goo00<007ooOol04Woo0f<H77oo0V<H7Woo0V<H7Goo0f<H0Woo
00=l07ooOol05Woo0f<H7Goo0V<H7Woo0f<H6goo0V<H27oo000WOol00`00Oomoo`0EOol3HaPKOol3
HaPMOol3HaPMOol2HaP00g`0Oomoo`0IOol3HaPLOol3HaPNOol2HaPJOol00`00Oomoo`06Ool002Mo
o`03001oogoo01Qoo`9S61aoo`=S61eoo`=S61aoo`=S61aoo`=S61aoo`=S61eoo`=S61Moo`03001o
ogoo00Ioo`009goo0V<H6goo0f<H77oo0f<H7Goo0f<H6Goo00=l07ooOol00f<H77oo0V<H7Goo0f<H
7Goo0f<H4goo0P0027oo000WOol00`00OomS6002HaPKOol3HaPLOol2HaPNOol2HaPGOol00g`0Oomo
o`03Ool3HaPKOol3HaPMOol2HaPNOol3HaPAOol00`00Oomoo`06Ool002Moo`03001oogoo009oo`9S
61aoo`=S61]oo`=S61eoo`=S61Aoo`03O01oogoo00Ioo`=S61]oo`=S61aoo`=S61ioo`9S60moo`03
001oogoo00Ioo`009goo00<007ooOol017oo0f<H77oo0V<H77oo0f<H7Goo0f<H4Goo00=l07ooOol0
2Goo0V<H77oo0f<H77oo0f<H7Goo0f<H37oo00<007ooOol01Woo000WOol00`00Oomoo`07Ool3HaPK
Ool3HaPLOol3HaPMOol2HaP?Ool00g`0Oomoo`0;Ool3HaPLOol2HaPMOol2HaPNOol3HaP9Ool00`00
Oomoo`06Ool002Moo`03001oogoo00Yoo`9S61aoo`=S61aoo`9S61eoo`=S60aoo`03O01oogoo00io
o`=S61]oo`=S61aoo`=S61ioo`=S60Ioo`03001oogoo00Ioo`009goo00<007ooOol037oo0f<H77oo
0f<H6goo0f<H7Goo0f<H2Goo00=l07ooOol04Goo0f<H6goo0f<H77oo0f<H7Woo0V<H17oo00<007oo
Ool01Woo000WOol00`00Oomoo`0?Ool3HaPLOol3HaPKOol3HaPMOol3HaP6Ool00g`0Oomoo`0DOol2
HaPLOol3HaPLOol3HaPMOol3HaP00goo001oo`07Ool002Moo`03001oogoo019oo`=S61aoo`9S61ao
o`=S61eoo`9S60Aoo`03O01oogoo01Ioo`=S61aoo`9S61eoo`9S61ioo`9S60Qoo`009goo00<007oo
Ool05Goo0V<H77oo0f<H77oo0V<H7Goo0f<H00=oog`0Ool06Woo0f<H6goo0f<H77oo0f<H77oo00<0
07ooOol01Woo000WOol2000HOol3HaPLOol3HaPKOol3HaPMOol3HaPMOol3HaPKOol3HaPLOol3HaPH
Ool20008Ool002Moo`03001oogoo01Yoo`=S61aoo`=S61]oo`=S61]oo`03O01oof<H009S61eoo`9S
61aoo`=S61aoo`9S61Moo`03001oogoo00Ioo`009goo0V<H7Woo0f<H77oo0V<H77oo0f<H67oo00=l
07ooOol00Woo0V<H7Goo0f<H77oo0V<H77oo0f<H57oo00<007ooOol01Woo000WOol00`00OomS6002
HaPNOol2HaPLOol3HaPLOol2HaPFOol00g`0Oomoo`04Ool3HaPMOol3HaPKOol3HaPLOol3HaPAOol0
0`00Oomoo`06Ool002Moo`03001oogoo009oo`9S61ioo`=S61aoo`=S61]oo`=S61=oo`03O01oogoo
00Moo`=S61eoo`=S61]oo`=S61aoo`=S60ioo`03001oogoo00Ioo`009goo00<007ooOol017oo0f<H
7Woo0f<H77oo0f<H6goo0f<H47oo00=l07ooOol02Woo0V<H7Woo0V<H77oo0f<H77oo0V<H37oo00<0
07ooOol01Woo000WOol00`00Oomoo`07Ool3HaPNOol2HaPMOol2HaPLOol3HaP=Ool00g`0Oomoo`0<
Ool3HaPMOol3HaPLOol2HaPLOol3HaP9Ool00`00Oomoo`06Ool0021oo`<000Aoo`03001oogoo00Yo
o`=S61eoo`=S61aoo`=S61aoo`9S60]oo`03O01oogoo00moo`=S61eoo`=S61]oo`=S61aoo`=S60Io
o`03001oogoo00Ioo`0087oo00<007ooOol017oo00<007ooOol03Goo0V<H7Woo0f<H77oo0f<H6goo
0f<H27oo00=l07ooOol04Woo0f<H7Goo0f<H6goo0f<H77oo0V<H17oo00<007ooOol01Woo000KOol3
0003Ool00`00Oomoo`03Ool3000?Ool3HaPNOol3HaPLOol3HaPKOol3HaP5Ool00g`0Oomoo`0EOol2
HaPNOol2HaPLOol3HaPKOol3HaP20008Ool0025oo`03001oogoo00=oo`03001oogoo019oo`=S61io
o`9S61eoo`9S61aoo`=S609oo`03O01oogoo01Moo`=S61eoo`=S61aoo`=S61]oo`9S60Qoo`0087oo
00<007oo000017oo00<007ooOol05Goo0f<H7Goo0f<H77oo0f<H77oo0V<H00=l07ooOol06Woo0f<H
7Goo0f<H77oo0V<H6Woo00<007ooOol01Woo000QOol00`00Oomoo`03Ool00`00Oomoo`0HOol2HaPN
Ool3HaPLOol3HaPKOol3HaPMOol3HaPMOol3HaPKOol3HaPGOol00`00Oomoo`06Ool002Moo`9S61]o
o`=S61ioo`=S61aoo`=S61Qoo`03O01oogoo00=S61eoo`9S61ioo`9S61aoo`=S61Aoo`03001oogoo
00Ioo`009goo00<007ooHaP00V<H6goo0f<H7Woo0V<H7Goo0V<H5Woo00=l07ooOol00goo0f<H77oo
0f<H7Goo0f<H77oo0f<H4Goo00<007ooOol01Woo000WOol00`00Oomoo`02Ool2HaPLOol3HaPMOol3
HaPLOol3HaPCOol00g`0Oomoo`06Ool3HaPLOol3HaPMOol3HaPLOol2HaP?Ool00`00Oomoo`06Ool0
02Moo`03001oogoo00Aoo`=S61aoo`9S61ioo`=S61aoo`=S611oo`03O01oogoo00Uoo`9S61eoo`9S
61ioo`=S61]oo`=S60aoo`03001oogoo00Ioo`009goo00<007ooOol01goo0f<H6goo0f<H7Woo0V<H
7Goo0f<H3Goo00=l07ooOol02goo0f<H77oo0f<H7Woo0V<H77oo0f<H2Goo00<007ooOol01Woo000W
Ool2000;Ool2HaPLOol3HaPMOol3HaPMOol2HaP;Ool00g`0Oomoo`0>Ool3HaPLOol3HaPMOol3HaPL
Ool3HaP5Ool20008Ool002Moo`03001oogoo00aoo`=S61aoo`=S61eoo`=S61aoo`=S60Qoo`03O01o
ogoo015oo`=S61aoo`=S61eoo`=S61aoo`9S60Aoo`03001oogoo00Ioo`009goo00<007ooOol03goo
0f<H77oo0f<H7Goo0f<H77oo0f<H1Goo00=l07ooOol057oo0V<H7Goo0V<H7Woo0f<H6goo0f<H00=o
o`00Ool01goo000WOol00`00Oomoo`0BOol3HaPLOol2HaPNOol2HaPMOol3HaP2Ool00g`0Oomoo`0F
Ool3HaPLOol3HaPNOol3HaPKOol2HaP8Ool002Moo`03001oogoo01Eoo`9S61aoo`=S61eoo`=S61eo
o`9S6003O01oogoo01Uoo`=S61aoo`=S61ioo`9S61Yoo`03001oogoo00Ioo`009goo00<007ooOol0
5goo0f<H77oo0f<H7Goo0f<H77oo0f<H77oo0f<H77oo0f<H7Goo0f<H5goo00<007ooOol01Woo000W
Ool00`00Oomoo`0JOol3HaPLOol3HaPMOol3HaPIOol00g`0Oomoo`03HaPLOol2HaPMOol2HaPNOol3
HaPDOol00`00Oomoo`06Ool002Moo`9S61ioo`=S61aoo`9S61ioo`9S61Moo`03O01oogoo00=oo`=S
61]oo`=S61aoo`=S61ioo`=S615oo`03001oogoo00Ioo`009goo00<007ooHaP00V<H7Woo0V<H77oo
0f<H7Goo0f<H57oo00=l07ooOol01Woo0f<H6goo0f<H77oo0f<H7Woo0V<H3goo00<007ooOol01Woo
000WOol20003Ool2HaPNOol3HaPLOol3HaPMOol3HaP?Ool6O008Ool2HaPLOol3HaPLOol2HaPNOol3
HaP;Ool20008Ool002Moo`03001oogoo00Aoo`=S61ioo`=S61aoo`=S61eoo`T0009oo`Al009oo`04
O01oogooOol4O006Ool3HaPLOol2HaPLOol3HaPNOol3HaP9Ool00`00Oomoo`06Ool002Moo`03001o
ogoo00Moo`=S61ioo`9S61eoo`9S61]oo`T00003Ooml07oo00Eoo`03O01oogoo00Eoo`9l00Moo`=S
61]oo`=S61aoo`=S61ioo`=S60Ioo`03001oogoo00Ioo`009goo00<007ooOol02Woo0f<H7Goo0f<H
77oo0f<H5goo0P0017oo0f<H00<007`0Ool01Woo00=l07ooOol01goo00=l07ooOol01goo0f<H6goo
0f<H77oo0f<H7Woo0V<H17oo00<007ooOol01Woo000WOol00`00Oomoo`0=Ool2HaPNOol3HaPLOol3
HaPDOol20005Ool2O00200000f<HOomoo`04Ool00g`0Oomoo`08Ool2O00:Ool2HaPLOol3HaPLOol2
HaPNOol3HaP00goo001oo`07Ool002Moo`03001oogoo00moo`=S61ioo`=S61aoo`=S611oo`8000Eo
o`03O01oogoo00800003OomS66<H00Aoo`03O01oogoo00Yoo`03O01oogoo00Uoo`=S61aoo`9S61ao
o`=S61ioo`9S60Qoo`009goo00<007ooOol04Woo0f<H7Woo0V<H7Goo0V<H3goo00<007ooOol00Woo
00Al07ooOomoo`8000=oo`=S6003Ooml07oo00]oo`03O01oogoo00aoo`=S61]oo`=S61aoo`=S61ao
o`03001oogoo00Ioo`009goo00<007ooOol05Goo0f<H7Goo0f<H77oo0f<H37oo0P000Woo00=l07oo
Ool00Woo0P001Woo0f<H37oo00=l07ooOol03Woo0f<H6goo0f<H77oo0f<H6Goo00<007ooOol01Woo
000WOol00`00Oomoo`0HOol2HaPNOol3HaPLOol3HaP:Ool200000g`0Oomoo`03Ool20007Ool00g`0
OomS6002HaP:Ool00g`0Oomoo`0@Ool2HaPLOol3HaPLOol2HaPGOol00`00Oomoo`06Ool000aoo`03
001oogoo009oo`03001oogoo01=oo`9S61]oo`=S61ioo`=S61aoo`=S60Moo`800003O01oogoo00@0
00Aoo`05001oogooOoml0002Ool20002HaP8Ool00g`0Oomoo`0BOol3HaPLOol2HaPLOol3HaPCOol2
0008Ool000aoo`H001Eoo`03001oof<H009S61]oo`=S61ioo`9S61eoo`9S60Ioo`P000=oo`<0009o
o`03O01oo`000080009oo`=S60Ioo`03O01oogoo01Aoo`=S61]oo`=S61aoo`=S615oo`03001oogoo
00Ioo`0037oo00<007ooOol00Woo00<007ooOol04goo00<007ooOol00Woo0V<H77oo0f<H7Goo0f<H
77oo0f<H0goo1P001Woo0`0000=oog`000000P001Woo0f<H17oo00=l07ooOol05Woo0f<H6goo0f<H
77oo0V<H3goo00<007ooOol01Woo000WOol00`00Oomoo`04Ool3HaPLOol2HaPNOol3HaPLOol3HaP=
Ool6000:Ool2HaP3Ool00g`0Oomoo`0HOol2HaPLOol3HaPKOol3HaP<Ool00`00Oomoo`06Ool000io
o`04001oogoo000EOol00`00Oomoo`07Ool3HaPKOol3HaPNOol2HaPKOol00g`0OomS6002HaP5Ool0
0`00Oomoo`03Ool50003Ool30006Ool3HaP00g`0Oomoo`0JOol3HaPLOol2HaPLOol3HaP9Ool00`00
Oomoo`06Ool000ioo`@001Eoo`03001oogoo00Yoo`=S61]oo`=S61eoo`=S61Qoo`03O01oogoo009o
o`9S609oo`<000Aoo`/000Uoo`=S61eoo`=S61]oo`=S60Uoo`T000Yoo`=S60Ioo`03001oogoo00Io
o`003Woo00<007ooOol05Woo00<007ooOol03Goo0V<H77oo0f<H7Goo0f<H5Goo00=l07ooOol017oo
0f<H0`000goo2P002Woo00=l07ooOol00f<H7Goo0f<H6goo0f<H1Woo2@003Goo0V<H17oo00<007oo
Ool01Woo000?Ool3000?Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool3HaPLOol3HaPMOol3HaPBOol0
0g`0Oomoo`07Ool01F<H00000000Ool01P0000=oo`0000000P002Woo00=l07ooOol00goo0V<H7Woo
0V<H77oo0f<H0Woo0P001goo00<007ooOol03Goo0f<H00=oo`00Ool01goo000>Ool00`00Oomoo`0?
Ool00`00Ool00004Ool00`00Oomoo`0BOol3HaPLOol2HaPNOol2HaP@Ool00g`0Oomoo`09Ool60000
0g`0Ool0000300000goo00000009Ool00g`0Oomoo`05Ool3HaPMOol3HaPLOol2HaP20007Ool2000A
Ool2HaP8Ool000moo`<000ioo`03001oo`0000AooaQl00=S61]l00=S61el00=S61Yl00D0009l00<0
009l00<001=l00=S61el00=S61Yl0080009S60Il008001=l00Qoo`0087oo00<007oo000017oo00<0
07ooOol067oo0V<H77oo0f<H7Goo0f<H2Woo00=l07ooOol02Goo1P000V<H100000=oo`0000002Goo
0W`037oo0f<H7Goo0f<H67oo00<007ooOol00f<H0goo0P004Woo00<007ooOol01Woo000POol00`00
Ool00004Ool2HaPKOol3HaPLOol3HaPMOol3HaP7Ool00g`0Oomoo`08Ool300001Goo00000000O000
0P0000=S600000000`002Goo00=l07ooOol03Woo0V<H7Woo0V<H5Woo0P0017oo0f<H0P004Woo00<0
07ooOol01Woo000QOol00`00Oomoo`03Ool00`00OomS6002HaPKOol3HaPLOol2HaPNOol2HaP5Ool0
0g`0Oomoo`07Ool30003Ool50002Ool300000f<HOomoo`07Ool00g`0Oomoo`0@Ool3HaPMOol3HaPD
Ool20006Ool200000f<HOomoo`0?Ool00`00Oomoo`06Ool002Moo`03001oogoo009oo`9S61aoo`=S
61]oo`=S61eoo`=S609oo`03O01oogoo00Ioo`<000Aoo`D00003Ool0000000<000=S60Ioo`03O01o
ogoo01=oo`=S61eoo`=S615oo`8000=oo`@0009oo`9S60moo`03001oogoo00Ioo`009goo00<007oo
Ool017oo0f<H77oo0V<H77oo0f<H7Goo0f<H2Goo00<007ooOol00goo2`000goo0V<H17oo00=l07oo
Ool05Woo0V<H7Woo0f<H3goo200017oo0f<H37oo00<007ooOol01Woo000WOol00`00Oomoo`07Ool3
HaPKOol3HaPLOol3HaPMOol2HaP<Ool90008Ool3HaP00gooO01oo`0IOol3HaPNOol2HaP=Ool60009
Ool3HaP9Ool00`00Oomoo`06Ool002Moo`03001oogoo00Yoo`9S61aoo`=S61aoo`9S61]oo`03O01o
of<H009S60Qoo`<00003Ooml0000008000eoo`=S61aoo`=S61eoo`=S61aoo`=S60Ioo`03001oogoo
00Ioo`003Woo0P0000=oo`00Ool057oo00<007ooOol037oo0f<H77oo0f<H6goo0f<H6Goo00Al07oo
Oomoo`=S60Aoo`<0009oo`03O01oo`00008000aoo`03O01oogoo00=S61aoo`=S61eoo`=S61aoo`9S
60Aoo`03001oogoo00Ioo`003Woo00@007oo000001Eoo`03001oogoo00moo`=S61aoo`=S61]oo`=S
61Eoo`T0009S609oo`05001oogooOoml0002Ool2000;Ool00g`0Oomoo`04Ool2HaPMOol2HaPNOol3
HaPKOol3HaP00goo001oo`07Ool000ioo`800003Ool007oo01Aoo`8001=oo`=S61aoo`9S61aoo`=S
619oo`T0009oo`9S60Aoo`03O01oogoo00aoo`03O01oogoo00Moo`=S61aoo`=S61ioo`=S61]oo`9S
60Qoo`003Woo00@007oo000001Eoo`03001oogoo01Eoo`9S61aoo`=S61aoo`9S60moo`80009oo`03
O01oogoo009oo`03001oogoo009oo`=S6003Ooml07oo00eoo`03O01oogoo00Yoo`=S61aoo`=S61io
o`9S61Yoo`03001oogoo00Ioo`009goo00<007ooOol05goo0f<H77oo0f<H6goo0f<H37oo0P000Woo
00=l07ooOol00Woo0P001Woo0f<H37oo00=l07ooOol03Woo0f<H77oo0f<H7Goo0f<H5goo00<007oo
Ool01Woo000WOol00`00Oomoo`0JOol3HaPLOol3HaPKOol3HaP8Ool20004Ool017`0Oomoogoo0P00
1goo00=l07ooHaP00V<H2Goo00=l07ooOol04Goo0V<H7Goo0V<H7Woo0f<H57oo00<007ooOol01Woo
000WOol2HaPNOol3HaPLOol2HaPLOol3HaP6Ool00`00Oomoo`03Ool00g`0Oomoo`020007Ool00g`0
Oomoo`02Ool2HaP6Ool00g`0Oomoo`0DOol3HaPLOol3HaPNOol3HaPAOol00`00Oomoo`06Ool002Mo
o`03001oof<H009S61ioo`9S61aoo`=S61aoo`9S60Aoo`8000Eoo`04O01oo`000007Ool00g`0Oomo
o`04Ool3HaP00gooO01l000JOol3HaPLOol3HaPNOol2HaP?Ool00`00Oomoo`06Ool002Moo`03001o
ogoo009oo`9S61ioo`=S61aoo`=S61]oo`=S609oo`8000Eoo`03O000000000Moo`03O01oogoo00Mo
o`=S61eoo`=S61aoo`9S61ioo`=S60aoo`03001oogoo00Ioo`009goo00<007ooOol017oo0f<H7Woo
0f<H77oo0f<H6goo0V<H0P000goo10000W`01Woo00=l07ooOol01Woo00Al07ooOomoo`9S61ioo`9S
61aoo`=S61ioo`=S60Uoo`03001oogoo00Ioo`009goo00<007ooOol01goo0f<H7Woo0V<H7Goo0V<H
77oo20000Woo0g`00goo00=l07ooOol00Woo17`01Woo0f<H7Goo0f<H77oo0f<H7Woo0f<H1Woo00<0
07ooOol01Woo000WOol2000;Ool3HaPMOol3HaPLOol3HaPIOol60007Ool8O00=Ool3HaPMOol3HaPL
Ool3HaPNOol2HaP3Ool20008Ool002Moo`03001oogoo00eoo`9S61ioo`=S61aoo`=S61]oo`=S60Qo
o`03O01oogoo019oo`=S61eoo`=S61aoo`9S61ioo`=S6003Ool007oo00Moo`009goo00<007ooOol0
3goo0f<H7Woo0f<H77oo0f<H6goo0f<H1Goo00=l07ooOol05Goo0V<H7Woo0V<H77oo0f<H7Woo0V<H
27oo000WOol00`00Oomoo`0BOol3HaPNOol2HaPMOol2HaPLOol3HaP2Ool00g`0Oomoo`0GOol3HaPM
Ool3HaPLOol3HaPLOol00`00Oomoo`06Ool002Moo`03001oogoo01Eoo`=S61eoo`=S61aoo`=S61ao
o`9S6003O01oogoo01Yoo`=S61eoo`=S61aoo`=S61Uoo`03001oogoo00Ioo`009goo00<007ooOol0
67oo0V<H7Woo0f<H77oo0f<H6goo0f<H7Goo0f<H7Goo0f<H77oo0V<H5goo00<007ooOol01Woo000W
Ool2HaPKOol3HaPNOol3HaPLOol3HaPHOol00g`0Oomoo`03HaPMOol2HaPNOol2HaPLOol3HaPDOol0
0`00Oomoo`06Ool002Moo`03001oof<H009S61]oo`=S61ioo`9S61eoo`9S61Ioo`03O01oogoo00=o
o`=S61aoo`=S61eoo`=S61aoo`=S615oo`03001oogoo00Ioo`009goo00<007ooOol00Woo0V<H77oo
0f<H7Goo0f<H77oo0f<H4goo00=l07ooOol01Woo0f<H77oo0f<H7Goo0f<H77oo0V<H3goo00<007oo
Ool01Woo000WOol20005Ool3HaPLOol2HaPNOol3HaPLOol3HaP@Ool00g`0Oomoo`09Ool2HaPMOol2
HaPNOol3HaPKOol3HaP;Ool20008Ool002Moo`03001oogoo00Moo`=S61]oo`=S61ioo`9S61eoo`=S
60eoo`03O01oogoo00]oo`=S61aoo`=S61ioo`9S61aoo`=S60Uoo`03001oogoo00Ioo`009goo00<0
07ooOol02Woo0f<H6goo0f<H7Goo0f<H7Goo0V<H2goo00=l07ooOol03Woo0f<H77oo0f<H7Goo0f<H
77oo0f<H1Woo00<007ooOol01Woo000WOol00`00Oomoo`0=Ool2HaPLOol3HaPMOol3HaPLOol3HaP8
Ool00g`0Oomoo`0AOol3HaPLOol3HaPMOol3HaPLOol2HaP4Ool00`00Oomoo`06Ool002Moo`03001o
ogoo00moo`=S61aoo`=S61eoo`=S61aoo`=S60Eoo`03O01oogoo01Aoo`9S61eoo`9S61ioo`=S61]o
o`=S6003Ool007oo00Moo`009goo00<007ooOol04Woo0f<H77oo0V<H7Woo0V<H7Goo0f<H0Woo00=l
07ooOol05Woo0f<H77oo0f<H7Woo0f<H6goo0V<H27oo000WOol00`00Oomoo`0EOol3HaPKOol3HaPM
Ool3HaPMOol2HaP00g`0Oomoo`0IOol3HaPLOol3HaPNOol2HaPJOol00`00Oomoo`06Ool0021oo`<0
00Aoo`03001oogoo01Qoo`9S61aoo`=S61eoo`=S61aoo`=S61aoo`=S61aoo`=S61eoo`=S61Moo`03
001oogoo00Ioo`0087oo00<007ooOol017oo0V<H6goo0f<H77oo0f<H7Goo0f<H6Goo00=l07ooOol0
0f<H77oo0V<H7Goo0V<H7Woo0f<H57oo00<007ooOol01Woo000QOol00`00Oomoo`03Ool20003HaPK
Ool3HaPLOol2HaPNOol2HaPGOol00g`0Oomoo`03Ool3HaPKOol3HaPLOol3HaPNOol3HaP@Ool20008
Ool0025oo`03001oogoo00=oo`03001oogoo009oo`9S61aoo`=S61]oo`=S61eoo`=S61Aoo`03O01o
ogoo00Ioo`=S61]oo`=S61aoo`=S61ioo`9S60moo`03001oogoo00Ioo`0087oo00<007oo000017oo
00<007ooOol017oo0f<H77oo0V<H77oo0f<H7Goo0f<H4Goo00=l07ooOol02Goo0V<H77oo0f<H77oo
0V<H7Woo0f<H37oo00<007ooOol01Woo000QOol00`00Oomoo`03Ool00`00Oomoo`07Ool3HaPKOol3
HaPLOol3HaPMOol2HaP?Ool00g`0Oomoo`0;Ool3HaPLOol2HaPLOol3HaPNOol3HaP9Ool00`00Oomo
o`06Ool002Moo`03001oogoo00Yoo`=S61]oo`=S61aoo`9S61eoo`=S60aoo`03O01oogoo00ioo`=S
61]oo`=S61aoo`=S61ioo`=S60Ioo`03001oogoo00Ioo`009goo00<007ooOol03Goo0V<H77oo0f<H
6goo0f<H7Goo0f<H2Goo00=l07ooOol04Goo0f<H6goo0f<H77oo0f<H7Woo0V<H17oo00<007ooOol0
1Woo000WOol00`00Oomoo`0?Ool3HaPLOol3HaPKOol3HaPMOol3HaP6Ool00g`0Oomoo`0DOol2HaPL
Ool3HaPLOol2HaPNOol3HaP00goo001oo`07Ool002Moo`03001oogoo019oo`=S61aoo`9S61aoo`=S
61eoo`9S60Aoo`03O01oogoo01Ioo`=S61aoo`9S61aoo`=S61ioo`9S60Qoo`009goo00<007ooOol0
5Goo0f<H6goo0f<H77oo0V<H7Goo0f<H00=oog`0Ool06Woo0f<H6goo0f<H77oo0f<H77oo00<007oo
Ool01Woo000WOol2000IOol2HaPLOol3HaPKOol3HaPMOol3HaPMOol3HaPKOol3HaPLOol3HaPHOol2
0008Ool002Moo`03001oogoo01Yoo`=S61aoo`=S61]oo`=S61]oo`03O01oof<H009S61eoo`9S61ao
o`=S61aoo`9S61Moo`03001oogoo00Ioo`009goo0V<H7Woo0f<H77oo0V<H77oo0f<H67oo00=l07oo
Ool00Woo0V<H7Goo0f<H77oo0V<H77oo0f<H57oo00<007ooOol01Woo000WOol00`00OomS6002HaPN
Ool3HaPKOol3HaPLOol2HaPFOol00g`0Oomoo`04Ool3HaPMOol3HaPKOol3HaPLOol3HaPAOol00`00
Oomoo`06Ool002Moo`03001oogoo009oo`9S61moo`=S61]oo`=S61]oo`=S61=oo`03O01oogoo00Mo
o`=S61eoo`=S61]oo`=S61aoo`9S60moo`03001oogoo00Ioo`009goo00<007ooOol017oo0f<H7goo
0V<H77oo0f<H6goo0f<H47oo00=l07ooOol02Woo0V<H7Woo0V<H77oo0f<H6goo0f<H37oo00<007oo
Ool01Woo000WOol00`00Oomoo`07Ool3HaPNOol3HaPLOol2HaPLOol3HaP=Ool00g`0Oomoo`0<Ool3
HaPMOol3HaPLOol2HaPLOol3HaP9Ool00`00Oomoo`06Ool002Moo`03001oogoo00Yoo`=S61ioo`=S
61]oo`=S61aoo`9S60]oo`03O01oogoo00moo`=S61eoo`=S61]oo`=S61aoo`=S60Ioo`03001oogoo
00Ioo`009goo00<007ooOol03Goo0f<H7Woo0f<H6goo0f<H6goo0f<H27oo00=l07ooOol04Woo0f<H
7Goo0f<H6goo0f<H77oo0V<H17oo00<007ooOol01Woo000WOol00`00Oomoo`0@Ool2HaPOOol2HaPL
Ool3HaPKOol3HaP5Ool00g`0Oomoo`0EOol2HaPNOol2HaPLOol3HaPKOol3HaP00goo001oo`07Ool0
02Moo`8001=oo`=S61ioo`=S61aoo`9S61aoo`=S609oo`03O01oogoo01Moo`=S61eoo`=S61aoo`=S
61]oo`9S60Qoo`009goo00<007ooOol05Goo0f<H7Woo0f<H6goo0f<H77oo0V<H00=l07ooOol06Woo
0f<H7Goo0f<H77oo0V<H6Woo00<007ooOol01Woo000WOol00`00Oomoo`0HOol3HaPNOol3HaPKOol3
HaPKOol3HaPMOol3HaPMOol3HaPKOol3HaPGOol00`00Oomoo`06Ool002Moo`9S61aoo`9S61moo`9S
61aoo`=S61Qoo`03O01oogoo00=S61eoo`9S61ioo`9S61aoo`=S61Aoo`03001oogoo00Ioo`009goo
00<007ooHaP00V<H6goo0f<H7Woo0f<H77oo0V<H5Woo00=l07ooOol00goo0f<H77oo0f<H7Goo0f<H
77oo0f<H4Goo00<007ooOol01Woo000WOol00`00Oomoo`02Ool2HaPLOol3HaPNOol3HaPKOol3HaPC
Ool00g`0Oomoo`06Ool3HaPLOol3HaPMOol3HaPLOol2HaP?Ool00`00Oomoo`06Ool002Moo`03001o
ogoo00Aoo`=S61aoo`=S61ioo`=S61]oo`=S611oo`03O01oogoo00Uoo`9S61eoo`9S61ioo`=S61]o
o`=S60aoo`03001oogoo00Ioo`009goo00<007ooOol01goo0f<H77oo0f<H7Woo0V<H77oo0f<H3Goo
00=l07ooOol02goo0f<H77oo0f<H7Woo0V<H77oo0f<H2Goo00<007ooOol01Woo000WOol00`00Oomo
o`0:Ool3HaPLOol2HaPNOol3HaPLOol2HaP;Ool00g`0Oomoo`0>Ool3HaPLOol3HaPMOol3HaPLOol3
HaP6Ool00`00Oomoo`06Ool002Moo`8000ioo`=S61]oo`=S61ioo`=S61]oo`=S60Qoo`03O01oogoo
015oo`=S61aoo`=S61eoo`=S61aoo`9S60=oo`8000Qoo`009goo00<007ooOol047oo0V<H77oo0f<H
7Woo0f<H6goo0f<H1Goo00=l07ooOol057oo0V<H7Goo0V<H7Woo0f<H6goo0f<H00=oo`00Ool01goo
000WOol00`00Oomoo`0BOol3HaPLOol3HaPNOol2HaPLOol3HaP2Ool00g`0Oomoo`0FOol3HaPLOol3
HaPNOol3HaPKOol2HaP8Ool002Moo`03001oogoo01Eoo`=S61aoo`9S61ioo`=S61aoo`9S6003O01o
ogoo01Uoo`=S61aoo`=S61ioo`9S61Yoo`03001oogoo00Ioo`009goo00<007ooOol067oo0f<H6goo
0f<H7Woo0f<H6goo0f<H77oo0f<H77oo0f<H7Goo0f<H5goo00<007ooOol01Woo000WOol2HaPLOol2
HaPLOol3HaPNOol3HaPHOol00g`0Oomoo`03HaPLOol2HaPMOol2HaPNOol3HaPDOol00`00Oomoo`06
Ool002Moo`03001oof<H009S61]oo`=S61aoo`=S61ioo`=S61Eoo`03O01oogoo00=oo`=S61]oo`=S
61aoo`=S61ioo`=S615oo`03001oogoo00Ioo`008Goo0`000goo00<007ooOol00Woo0V<H77oo0f<H
77oo0f<H7Woo0V<H4goo00=l07ooOol01Woo0f<H6goo0f<H77oo0f<H7Woo0V<H3goo00<007ooOol0
1Woo000ROol00`00Oomoo`02Ool00`00Oomoo`04Ool3HaPLOol3HaPLOol2HaPNOol3HaP@Ool00g`0
Oomoo`09Ool2HaPLOol3HaPLOol2HaPNOol3HaP<Ool00`00Oomoo`06Ool0021oo`@000=oo`<000Mo
o`=S61aoo`9S61aoo`=S61ioo`=S60eoo`03O01oogoo00]oo`=S61aoo`9S61aoo`=S61ioo`=S60Qo
o`8000Qoo`0087oo00<007oo000017oo00<007ooOol02Woo0f<H6goo0f<H77oo0f<H7Woo0f<H2Woo
00=l07ooOol03Woo0f<H6goo0f<H77oo0f<H7Woo0f<H1Woo00<007ooOol01Woo000QOol20004Ool0
0`00Oomoo`0=Ool2HaPLOol3HaPLOol3HaPNOol2HaP8Ool00g`0Oomoo`0AOol3HaPKOol3HaPLOol3
HaPNOol2HaP4Ool00`00Oomoo`06Ool0029oo`03001oogoo009oo`03001oogoo00moo`=S61aoo`=S
61aoo`9S61ioo`=S60Eoo`03O01oogoo01Aoo`9S61aoo`=S61aoo`9S61ioo`=S6003Ool007oo00Mo
o`009goo00<007ooOol04Woo0f<H77oo0f<H6goo0f<H7Woo0f<H0Woo00=l07ooOol05Woo0f<H77oo
0V<H77oo0f<H7Woo0V<H27oo000WOol00`00Oomoo`0EOol3HaPLOol2HaPLOol3HaPNOol3HaPKOol3
HaPKOol3HaPLOol3HaPLOol00`00Oomoo`06Ool002Moo`03001oogoo01Qoo`9S61aoo`=S61aoo`=S
61eoo`03O01S66<H01aoo`=S61]oo`=S61aoo`=S61Uoo`03001oogoo00Ioo`009goo00<007ooOol0
6Woo0f<H77oo0f<H77oo0f<H6Woo00=l07ooOol00f<H77oo0V<H77oo0f<H77oo0V<H5goo00<007oo
Ool01Woo000WOol2HaPNOol3HaPLOol3HaPLOol2HaPHOol00g`0Oomoo`03Ool3HaPKOol3HaPLOol2
HaPLOol3HaPDOol00`00Oomoo`06Ool002Moo`8000=S61ioo`=S61aoo`9S61aoo`=S61Eoo`03O01o
ogoo00Ioo`=S61]oo`=S61]oo`=S61aoo`=S611oo`8000Qoo`009goo00<007ooOol00Woo0f<H7Woo
0f<H6goo0f<H77oo0f<H4Woo00=l07ooOol02Goo0V<H77oo0f<H6goo0f<H77oo0V<H3goo00<007oo
Ool01Woo000WOol00`00Oomoo`05Ool2HaPOOol2HaPLOol3HaPLOol3HaP?Ool00g`0Oomoo`0;Ool3
HaPLOol2HaPLOol3HaPKOol3HaP<Ool00`00Oomoo`06Ool002Moo`03001oogoo00Moo`=S61ioo`=S
61aoo`=S61aoo`9S60eoo`03O01oogoo00ioo`=S61]oo`=S61aoo`9S61aoo`=S60Uoo`03001oogoo
00Ioo`009goo00<007ooOol02Woo0f<H7Woo0f<H77oo0V<H77oo0f<H2Woo00=l07ooOol04Goo0f<H
6goo0f<H6goo0f<H77oo0f<H1Woo00<007ooOol01Woo000WOol00`00Oomoo`0=Ool3HaPNOol3HaPK
Ool3HaPLOol3HaP7Ool00g`0Oomoo`0DOol2HaPLOol3HaPKOol3HaPLOol2HaP4Ool00`00Oomoo`06
Ool002Moo`03001oogoo011oo`=S61ioo`9S61aoo`=S61aoo`=S60Aoo`03O01oogoo01Ioo`=S61ao
o`9S61aoo`=S61]oo`=S6003Ool007oo00Moo`009goo00<007ooOol04goo0V<H7Woo0f<H77oo0f<H
77oo0f<H00=oog`0Ool06Woo0f<H6goo0f<H77oo0f<H6goo0V<H27oo000WOol00`00Oomoo`0EOol3
HaPNOol3HaPLOol3HaPLOol2HaPNOol3HaPKOol3HaPLOol2HaPJOol00`00Oomoo`06Ool002Moo`80
01Uoo`=S61ioo`=S61aoo`9S61]oo`04O01S66<HHaPNOol3HaPKOol3HaPKOol3HaPFOol20008Ool0
02Moo`9S61aoo`=S61ioo`9S61aoo`=S61Qoo`04O01oogooOol3HaPNOol2HaPLOol2HaPLOol3HaPD
Ool00`00Oomoo`06Ool002Moo`03001oof<H009S61aoo`=S61eoo`=S61aoo`=S61Eoo`03O01oogoo
00Aoo`=S61eoo`=S61]oo`=S61aoo`=S615oo`03001oogoo00Ioo`009goo00<007ooOol00Woo0f<H
77oo0f<H7Goo0f<H77oo0f<H4Woo00=l07ooOol01goo0V<H7Woo0f<H6goo0f<H77oo0V<H3goo00<0
07ooOol01Woo000WOol00`00Oomoo`05Ool2HaPMOol2HaPNOol3HaPLOol2HaP@Ool00g`0Oomoo`09
Ool3HaPNOol3HaPKOol3HaPKOol3HaP<Ool00`00Oomoo`06Ool002Moo`03001oogoo00Moo`=S61ao
o`=S61ioo`9S61aoo`=S60eoo`03O01oogoo00aoo`=S61ioo`9S61aoo`9S61aoo`=S60Uoo`03001o
ogoo00Ioo`009goo00<007ooOol02Woo0f<H77oo0f<H7Goo0f<H77oo0f<H2Woo00=l07ooOol03goo
0f<H7Goo0f<H6goo0f<H77oo0f<H1Woo00<007ooOol01Woo000WOol00`00Oomoo`0=Ool3HaPLOol3
HaPMOol3HaPLOol3HaP7Ool00g`0Oomoo`0BOol3HaPMOol3HaPKOol3HaPLOol2HaP4Ool00`00Oomo
o`06Ool002Moo`03001oogoo011oo`=S61aoo`=S61eoo`=S61aoo`9S60Eoo`03O01oogoo01Eoo`9S
61ioo`=S61]oo`=S61]oo`=S6003Ool007oo00Moo`009goo00<007ooOol04goo0V<H7Goo0V<H7Woo
0V<H77oo0f<H0Woo00=l07ooOol05goo0f<H7Woo0V<H77oo0f<H6goo0V<H27oo000WOol2000FOol3
HaPLOol3HaPMOol3HaPLOol3HaPLOol3HaPMOol3HaPLOol2HaPIOol20008Ool002Moo`03001oogoo
01Qoo`=S61aoo`=S61eoo`=S61]oo`04O01S66<HHaPLOol3HaPMOol3HaPKOol3HaPGOol00`00Oomo
o`06Ool002Moo`9S61aoo`=S61aoo`=S61eoo`=S61Qoo`04O01oogooOol3HaPLOol2HaPNOol3HaPK
Ool3HaPDOol00`00Oomoo`06Ool002Moo`03001oof<H009S61aoo`=S61aoo`=S61eoo`9S61Ioo`03
O01oogoo00Aoo`9S61aoo`=S61ioo`9S61aoo`=S615oo`03001oogoo00Ioo`009goo00<007ooOol0
0Woo0V<H7Goo0V<H7Goo0V<H7Goo0f<H4goo00=l07ooOol01Woo0f<H77oo0f<H7Goo0f<H77oo0V<H
3goo00<007ooOol01Woo000WOol00`00Oomoo`04Ool3HaPLOol3HaPLOol3HaPMOol3HaP@Ool00g`0
Oomoo`09Ool3HaPLOol3HaPMOol3HaPKOol3HaP<Ool00`00Oomoo`06Ool002Moo`03001oogoo00Mo
o`=S61aoo`=S61aoo`=S61eoo`=S60eoo`03O01oogoo00aoo`=S61aoo`=S61eoo`=S61]oo`=S60Uo
o`03001oogoo00Ioo`0087oo0P001Goo00<007ooOol02Woo0f<H77oo0f<H77oo0f<H7Goo0f<H2Woo
00=l07ooOol03goo0V<H7Goo0V<H7Woo0V<H77oo0f<H1Woo00<007ooOol01Woo000POol00`00Ool0
0004Ool00`00Oomoo`0=Ool2HaPMOol3HaPLOol3HaPMOol2HaP8Ool00g`0Oomoo`0AOol3HaPLOol3
HaPMOol3HaPLOol2HaP4Ool00`00Oomoo`06Ool0021oo`03001oo`0000Aoo`<000moo`=S61eoo`=S
61aoo`=S61aoo`=S60Eoo`03O01oogoo01Aoo`=S61aoo`=S61eoo`=S61]oo`=S608000Qoo`0087oo
0P001Goo00<007ooOol04Woo0f<H7Goo0V<H7Goo0V<H7Goo0f<H0Woo00=l07ooOol05goo0f<H77oo
0f<H7Goo0f<H6goo0V<H27oo000POol00`00Oomoo`04Ool00`00Oomoo`0EOol3HaPLOol3HaPLOol3
HaPMOol3HaPLOol2HaPMOol2HaPNOol3HaPIOol00`00Oomoo`06Ool0025oo`8000Aoo`03001oogoo
01Qoo`9S61eoo`=S61aoo`=S61aoo`03O01S66<H01aoo`=S61aoo`=S61ioo`9S61Moo`03001oogoo
00Ioo`009goo00<007ooOol06Woo0f<H7Goo0f<H77oo0f<H6Goo00=l07ooOol00f<H77oo0f<H77oo
0f<H7Goo0f<H57oo00<007ooOol01Woo000WOol2HaPNOol3HaPMOol3HaPLOol3HaPFOol00g`0Oomo
o`03Ool3HaPLOol3HaPLOol3HaPMOol3HaPAOol00`00Oomoo`06Ool002Moo`03001oof<H009S61io
o`=S61eoo`9S61eoo`9S61Aoo`03O01oogoo00Ioo`=S61aoo`=S61aoo`=S61eoo`=S60ioo`03001o
ogoo00Ioo`009goo00<007ooOol00Woo16<H7Goo0V<H7Goo0f<H77oo0f<H4Goo00=l07ooOol02Goo
0V<H7Goo0V<H7Goo0V<H7Woo0V<H37oo00<007ooOol01Woo000WOol00`00Oomoo`06Ool3HaPLOol3
HaP4Ool00`00Oomoo`0FOol3HaP8Ool00`00Oomoo`0AOol3HaP>Ool00g`0Oomoo`0;Ool3HaPDOol0
0`00Oomoo`05Ool3HaPJOol00`00OomS6002HaPMOol3HaP9Ool00`00Oomoo`06Ool002Moo``0009S
61d0009S61h0009S61d0009S60`00003O000000000h0009S61d0009S61d0009S61h0009S60P000Qo
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol007Eoo`<000Aoo`80009oo`<000=oo`8000aoo`@0009oo`80009oo`<000=oo`8000]oo`<0
00=oo`<000=oo`8000=oo`8005aoo`00MWoo00<007ooOol00Woo00@007ooOol0009oo`05001oogoo
Ool00008Ool40002Ool01P00Oomoo`00Ool000Eoo`05001oogooOol00002Ool00`00Oomoo`09Ool0
0`00Oomoo`03Ool01@00Oomoogoo00000Woo00<007oo00000Woo00<007ooOol0FGoo001fOol30002
Ool01000Oomoo`000Woo00@007ooOomoo`<000eoo`04001oogooOol30003Ool01@00Oomoogoo0000
0Woo00<007ooOol02Goo0`000goo00D007ooOomoo`00009oo`03001oo`0005ioo`00MWoo00@007oo
Ool0009oo`8000=oo`04001oogooOol3000>Ool00`00Oomoo`030002Ool40002Ool2000<Ool01000
Oomoo`000Woo00<007ooOol00Woo0P0000=oo`0000000P00G7oo001fOol01000Oomoo`001goo00<0
07ooOol047oo00@007ooOol001Yoo`04001oogoo0002Ool00`00Oomoo`06Ool00`00Oomoo`1LOol0
07Eoo`@000Moo`80019oo`@001Uoo`@0009oo`8006Moo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{86.5, 373.5}, {633.625, 346.625}} -> {-13.3974, 10.8091,
   0.0544197, 0.0544197}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problem 3", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell["\<\
Plot the frequency response of the SG filter of length 5 and order 2. Compare \
with the length 5 MA filter as to bandwidth and peak attenuation.\
\>", "Text",
  FontFamily->"Times New Roman"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Data Smoothing with Savitzky-Golay Filters", "Section",
  FontFamily->"Arial"],

Cell["\<\
We conclude the notebook with an example of smoothing a noise corrupted \
signal with the SG filter.The example signal is a synthetic ECG signal plus a \
Gaussian distributed zero mean, noise signal of variance 0.2.\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(<< Statistics`NormalDistribution`\)], "Input"],

Cell[BoxData[
    \(\(signal = ECG[256] + Table[Random[NormalDistribution[0, 0.2]], {256}]; 
    \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[signal, PlotRange -> All, PlotJoined -> True]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0200747 0.00373483 0.260521 0.290564 [
[.20682 .24802 -6 -9 ]
[.20682 .24802 6 0 ]
[.39356 .24802 -9 -9 ]
[.39356 .24802 9 0 ]
[.5803 .24802 -9 -9 ]
[.5803 .24802 9 0 ]
[.76704 .24802 -9 -9 ]
[.76704 .24802 9 0 ]
[.95378 .24802 -9 -9 ]
[.95378 .24802 9 0 ]
[.00757 .11524 -24 -4.5 ]
[.00757 .11524 0 4.5 ]
[.00757 .4058 -18 -4.5 ]
[.00757 .4058 0 4.5 ]
[.00757 .55108 -6 -4.5 ]
[.00757 .55108 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.20682 .26052 m
.20682 .26677 L
s
[(50)] .20682 .24802 0 1 Mshowa
.39356 .26052 m
.39356 .26677 L
s
[(100)] .39356 .24802 0 1 Mshowa
.5803 .26052 m
.5803 .26677 L
s
[(150)] .5803 .24802 0 1 Mshowa
.76704 .26052 m
.76704 .26677 L
s
[(200)] .76704 .24802 0 1 Mshowa
.95378 .26052 m
.95378 .26677 L
s
[(250)] .95378 .24802 0 1 Mshowa
.125 Mabswid
.05742 .26052 m
.05742 .26427 L
s
.09477 .26052 m
.09477 .26427 L
s
.13212 .26052 m
.13212 .26427 L
s
.16947 .26052 m
.16947 .26427 L
s
.24416 .26052 m
.24416 .26427 L
s
.28151 .26052 m
.28151 .26427 L
s
.31886 .26052 m
.31886 .26427 L
s
.35621 .26052 m
.35621 .26427 L
s
.43091 .26052 m
.43091 .26427 L
s
.46825 .26052 m
.46825 .26427 L
s
.5056 .26052 m
.5056 .26427 L
s
.54295 .26052 m
.54295 .26427 L
s
.61765 .26052 m
.61765 .26427 L
s
.655 .26052 m
.655 .26427 L
s
.69234 .26052 m
.69234 .26427 L
s
.72969 .26052 m
.72969 .26427 L
s
.80439 .26052 m
.80439 .26427 L
s
.84174 .26052 m
.84174 .26427 L
s
.87908 .26052 m
.87908 .26427 L
s
.91643 .26052 m
.91643 .26427 L
s
.99113 .26052 m
.99113 .26427 L
s
.25 Mabswid
0 .26052 m
1 .26052 L
s
.02007 .11524 m
.02632 .11524 L
s
[(-0.5)] .00757 .11524 1 0 Mshowa
.02007 .4058 m
.02632 .4058 L
s
[(0.5)] .00757 .4058 1 0 Mshowa
.02007 .55108 m
.02632 .55108 L
s
[(1)] .00757 .55108 1 0 Mshowa
.125 Mabswid
.02007 .14429 m
.02382 .14429 L
s
.02007 .17335 m
.02382 .17335 L
s
.02007 .20241 m
.02382 .20241 L
s
.02007 .23146 m
.02382 .23146 L
s
.02007 .28958 m
.02382 .28958 L
s
.02007 .31863 m
.02382 .31863 L
s
.02007 .34769 m
.02382 .34769 L
s
.02007 .37675 m
.02382 .37675 L
s
.02007 .43486 m
.02382 .43486 L
s
.02007 .46392 m
.02382 .46392 L
s
.02007 .49297 m
.02382 .49297 L
s
.02007 .52203 m
.02382 .52203 L
s
.02007 .08618 m
.02382 .08618 L
s
.02007 .05713 m
.02382 .05713 L
s
.02007 .02807 m
.02382 .02807 L
s
.02007 .58014 m
.02382 .58014 L
s
.02007 .6092 m
.02382 .6092 L
s
.25 Mabswid
.02007 0 m
.02007 .61803 L
s
.5 Mabswid
.02381 .24797 m
.02754 .18845 L
.03128 .30739 L
.03501 .26514 L
.03875 .30873 L
.04248 .27218 L
.04622 .2712 L
.04995 .29625 L
.05369 .28431 L
.05742 .25999 L
.06116 .24376 L
.06489 .22004 L
.06863 .28291 L
.07236 .38439 L
.0761 .35152 L
.07983 .30107 L
.08357 .33304 L
.0873 .47346 L
.09104 .33322 L
.09477 .38454 L
.09851 .33244 L
.10224 .26938 L
.10598 .46776 L
.10971 .38968 L
.11345 .3449 L
.11718 .43046 L
.12092 .35651 L
.12465 .40409 L
.12838 .36489 L
.13212 .38654 L
.13585 .4461 L
.13959 .32871 L
.14332 .37638 L
.14706 .46806 L
.15079 .36394 L
.15453 .43149 L
.15826 .31154 L
.162 .36522 L
.16573 .37667 L
.16947 .35668 L
.1732 .29478 L
.17694 .29257 L
.18067 .28375 L
.18441 .28962 L
.18814 .25017 L
.19188 .25469 L
.19561 .32229 L
.19935 .28361 L
.20308 .1499 L
.20682 .36965 L
Mistroke
.21055 .19116 L
.21429 .35046 L
.21802 .33543 L
.22176 .22642 L
.22549 .24973 L
.22923 .313 L
.23296 .27532 L
.23669 .25407 L
.24043 .29197 L
.24416 .19494 L
.2479 .21039 L
.25163 .16902 L
.25537 .29069 L
.2591 .24307 L
.26284 .33672 L
.26657 .28421 L
.27031 .23907 L
.27404 .35057 L
.27778 .25144 L
.28151 .19238 L
.28525 .28545 L
.28898 .2959 L
.29272 .1723 L
.29645 .19331 L
.30019 .21858 L
.30392 .24609 L
.30766 .26039 L
.31139 .24337 L
.31513 .3369 L
.31886 .20682 L
.3226 .29858 L
.32633 .37403 L
.33007 .39376 L
.3338 .39729 L
.33754 .45825 L
.34127 .58554 L
.345 .55111 L
.34874 .5993 L
.35247 .575 L
.35621 .49791 L
.35994 .60332 L
.36368 .50178 L
.36741 .47227 L
.37115 .39774 L
.37488 .37783 L
.37862 .37086 L
.38235 .2446 L
.38609 .21818 L
.38982 .17932 L
.39356 .20452 L
Mistroke
.39729 .07813 L
.40103 .10021 L
.40476 .01472 L
.4085 .14405 L
.41223 .16575 L
.41597 .08639 L
.4197 .03997 L
.42344 .11785 L
.42717 .17742 L
.43091 .24302 L
.43464 .30055 L
.43838 .35281 L
.44211 .22422 L
.44585 .20008 L
.44958 .27359 L
.45331 .21666 L
.45705 .34363 L
.46078 .31104 L
.46452 .23841 L
.46825 .1309 L
.47199 .25305 L
.47572 .20568 L
.47946 .211 L
.48319 .2146 L
.48693 .27062 L
.49066 .35525 L
.4944 .17565 L
.49813 .24793 L
.50187 .12697 L
.5056 .28487 L
.50934 .33317 L
.51307 .28023 L
.51681 .16148 L
.52054 .27806 L
.52428 .31506 L
.52801 .18559 L
.53175 .25792 L
.53548 .14317 L
.53922 .2573 L
.54295 .26639 L
.54669 .25757 L
.55042 .29737 L
.55415 .19566 L
.55789 .26243 L
.56162 .36998 L
.56536 .30218 L
.56909 .31493 L
.57283 .19599 L
.57656 .22436 L
.5803 .33492 L
Mistroke
.58403 .35227 L
.58777 .22028 L
.5915 .21926 L
.59524 .21596 L
.59897 .31773 L
.60271 .2496 L
.60644 .29104 L
.61018 .27824 L
.61391 .24259 L
.61765 .31385 L
.62138 .2956 L
.62512 .39442 L
.62885 .33644 L
.63259 .30876 L
.63632 .27036 L
.64006 .25666 L
.64379 .32437 L
.64753 .32776 L
.65126 .33809 L
.655 .36368 L
.65873 .25391 L
.66246 .40994 L
.6662 .33489 L
.66993 .36185 L
.67367 .35104 L
.6774 .42454 L
.68114 .27859 L
.68487 .28949 L
.68861 .27713 L
.69234 .42592 L
.69608 .27185 L
.69981 .30645 L
.70355 .39362 L
.70728 .38921 L
.71102 .2973 L
.71475 .32003 L
.71849 .26572 L
.72222 .33996 L
.72596 .33573 L
.72969 .25665 L
.73343 .22006 L
.73716 .25207 L
.7409 .30028 L
.74463 .30021 L
.74837 .31142 L
.7521 .32279 L
.75584 .2256 L
.75957 .30792 L
.76331 .27252 L
.76704 .37312 L
Mistroke
.77077 .22468 L
.77451 .15617 L
.77824 .37284 L
.78198 .3385 L
.78571 .32247 L
.78945 .31197 L
.79318 .25987 L
.79692 .42129 L
.80065 .21066 L
.80439 .33288 L
.80812 .18695 L
.81186 .30122 L
.81559 .29712 L
.81933 .25792 L
.82306 .30366 L
.8268 .27027 L
.83053 .36161 L
.83427 .23557 L
.838 .25815 L
.84174 .1866 L
.84547 .2683 L
.84921 .22185 L
.85294 .21804 L
.85668 .22185 L
.86041 .22329 L
.86415 .23369 L
.86788 .1613 L
.87162 .28141 L
.87535 .24507 L
.87908 .27756 L
.88282 .24104 L
.88655 .21822 L
.89029 .22245 L
.89402 .27029 L
.89776 .37159 L
.90149 .19432 L
.90523 .18619 L
.90896 .29658 L
.9127 .36872 L
.91643 .28911 L
.92017 .16563 L
.9239 .3488 L
.92764 .30802 L
.93137 .2079 L
.93511 .25449 L
.93884 .19213 L
.94258 .24245 L
.94631 .26692 L
.95005 .32765 L
.95378 .34042 L
Mistroke
.95752 .35565 L
.96125 .31249 L
.96499 .24655 L
.96872 .36412 L
.97246 .18261 L
.97619 .24384 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`006goo00<007ooOol0ogoo0goo000KOol0
0`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol0
0`00Oomoo`1SOol00`00Oomoo`2LOol001]oo`03001oogoo06=oo`03001oogoo09aoo`006goo00<0
07ooOol0Hgoo00<007ooOol0W7oo000KOol00`00Oomoo`1SOol00`00Oomoo`2LOol001]oo`8006Ao
o`03001oogoo09aoo`006goo00<007ooOol0Hgoo00<007ooOol0W7oo000KOol00`00Oomoo`1SOol0
0`00Oomoo`2LOol001]oo`03001oogoo06=oo`05001oogooOol0002JOol001]oo`03001oogoo06=o
o`05001oogooOol0002JOol001]oo`03001oogoo06=oo`05001oogooOol0002JOol001]oo`03001o
ogoo06=oo`05001oogooOol0002JOol001]oo`8006Aoo`05001oogooOol0002JOol001]oo`03001o
ogoo069oo`8000=oo`03001oogoo09Qoo`006goo00<007ooOol0HWoo0P000Woo0P00VWoo000KOol0
0`00Oomoo`1ROol20002Ool2002JOol001]oo`03001oogoo069oo`80009oo`8009Yoo`006goo00<0
07ooOol0HWoo0P000Woo0P00VWoo000KOol00`00Oomoo`1QOol200001Woo001oo`00Ool009Uoo`00
6goo00<007ooOol0HGoo0P0000Ioo`00Ool007oo002IOol001]oo`80069oo`800006Ool007oo001o
o`00VGoo000KOol00`00Oomoo`1QOol200001Woo001oo`00Ool009Uoo`006goo00<007ooOol0HGoo
0P0000Ioo`00Ool007oo002IOol001]oo`03001oogoo065oo`800006Ool007oo001oo`00VGoo000K
Ool00`00Oomoo`1QOol200001Woo001oo`00Ool009Uoo`006goo00<007ooOol0HGoo00P007ooOol0
07oo001oo`00VGoo000;Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`1QOol02000Oomoo`00Ool007oo002IOol000Yoo`03001oo`0000Moo`03001oo`0000Aoo`03001o
ogoo065oo`08001oogoo001oo`00Ool009Uoo`001Goo0`000Woo00<007oo00002Goo00<007ooOol0
0Woo0P00HWoo00P007ooOol007oo001oo`00VGoo000:Ool00`00Ool00007Ool20005Ool00`00Oomo
o`1QOol02000Oomoo`00Ool007oo002IOol000Yoo`03001oo`0000Moo`03001oogoo00Aoo`03001o
ogoo065oo`08001oogoo001oo`00Ool009Uoo`002goo00<007ooOol01Woo0`0017oo00<007ooOol0
HGoo00<007ooOol00P000Woo00<007ooOol04Goo00<007ooOol0Pgoo000KOol00`00Oomoo`1QOol0
0`00Oomoo`020002Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`23Ool001]oo`03001o
ogoo065oo`03001oogoo0080009oo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo08=oo`00
6goo00<007ooOol0HGoo00<007ooOol00P000Woo00<007ooOol02Goo00<007ooOol01Goo00<007oo
Ool0Pgoo000KOol2001QOol01000Oomoogoo0P000Woo00<007ooOol02Goo00<007ooOol01Goo00<0
07ooOol01Woo00<007ooOol0NWoo000KOol00`00Oomoo`1POol01000Oomoogoo0P000goo00<007oo
Ool027oo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol0NWoo000KOol00`00Oomoo`0]Ool0
0`00Oomoo`0`Ool01000Oomoogoo0P000goo00<007ooOol027oo00<007ooOol01Goo00<007ooOol0
1Woo00<007ooOol0NWoo000KOol00`00Oomoo`0]Ool00`00Oomoo`0`Ool00`00Oomoo`02Ool01@00
Oomoogoo00002Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol0NWoo000KOol00`00Oomo
o`0]Ool00`00Oomoo`0`Ool00`00Oomoo`02Ool01@00Oomoogoo00002Woo00<007ooOol01Goo00<0
07ooOol01Woo00<007ooOol0?Goo00<007ooOol0>Woo000KOol00`00Oomoo`0]Ool00`00Oomoo`0`
Ool00`00Oomoo`02Ool01@00Oomoogoo00002Woo00<007ooOol01Goo00D007ooOomoo`0000Aoo`03
001oogoo03eoo`03001oogoo01Eoo`03001oogoo029oo`006goo00<007ooOol0;Goo00<007ooOol0
<7oo00<007ooOol00Woo00D007ooOomoo`0000Yoo`03001oogoo00Eoo`05001oogooOol00004Ool0
0`00Oomoo`0mOol00`00Oomoo`0EOol00`00Oomoo`0;Ool00`00Oomoo`0DOol001]oo`03001oogoo
02eoo`03001oogoo00Yoo`03001oogoo02=oo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo
00Eoo`05001oogooOol00004Ool00`00Oomoo`0mOol00`00Oomoo`0EOol00`00Oomoo`0;Ool00`00
Oomoo`0DOol001]oo`8002ioo`03001oogoo00Yoo`03001oogoo00Qoo`03001oogoo01Qoo`03001o
ogoo00Ioo`03001oogoo00Qoo`03001oogoo00Eoo`05001oogooOol00004Ool00`00Oomoo`0mOol0
0`00Oomoo`0EOol00`00Oomoo`0;Ool00`00Oomoo`0DOol001]oo`03001oogoo02eoo`03001oogoo
00Yoo`03001oogoo00Qoo`03001oogoo01Qoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo
00Aoo`8000=oo`03001oogoo009oo`03001oogoo03eoo`03001oogoo01Eoo`03001oogoo00]oo`03
001oogoo01Aoo`006goo00<007ooOol0;Goo00<007ooOol02Woo00<007ooOol027oo00<007ooOol0
5goo0P0027oo00<007ooOol027oo00<007ooOol017oo0P000goo00<007ooOol00Woo00<007ooOol0
?Goo00<007ooOol05Goo00<007ooOol02goo00<007ooOol057oo000KOol00`00Oomoo`0]Ool00`00
Oomoo`0:Ool00`00Oomoo`08Ool2000HOol20008Ool00`00Oomoo`07Ool20006Ool20003Ool01P00
Oomoo`00Ool003moo`03001oogoo01Eoo`03001oogoo00Moo`05001oogooOol0000=Ool00`00Oomo
o`06Ool001]oo`03001oo`0002eoo`03001oogoo00Yoo`03001oogoo00Qoo`8001Qoo`8000Qoo`03
001oogoo00Moo`8000Ioo`8000=oo`06001oogoo001oo`00?goo00<007ooOol01Woo00<007ooOol0
1Woo00<007ooOol00goo00<007ooOol01goo00D007ooOomoo`0000eoo`03001oogoo00Ioo`006goo
00<007oo0000;Goo00<007oo00002Goo0P001goo00<007ooOol00P0067oo0P0027oo00<007ooOol0
1goo00<007oo00001Goo0P000goo00H007ooOol007oo000nOol20008Ool00`00Oomoo`06Ool00`00
Oomoo`03Ool00`00Oomoo`06Ool20003Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`06
Ool001]oo`03001oo`0002eoo`03001oo`0000Qoo`<000Moo`03001oogoo008001Qoo`8000Qoo`03
001oogoo00Moo`03001oo`0000Eoo`8000=oo`06001oogoo001oo`0017oo00<007ooOol00Woo00<0
07ooOol0<Woo0P0027oo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01Woo0P000goo00<0
07ooOol00Woo00<007ooOol01Woo00<007ooOol01Woo000KOol00`00Ool0000]Ool00`00Ool00008
Ool30007Ool00`00Oomoo`02000GOol00`00Ool00008Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Ool00005Ool20003Ool00`00Oomoo`0200000goo001oo`02Ool00`00Oomoo`02Ool00`00Oomo
o`0bOol20008Ool00`00Oomoo`06Ool00`00Oomoo`02Ool20008Ool20003Ool00`00Oomoo`02Ool0
0`00Oomoo`06Ool00`00Oomoo`06Ool001]oo`<002eoo`03001oo`0000Qoo`<000Moo`03001oogoo
008001Moo`03001oo`0000Qoo`03001oogoo009oo`03001oogoo009oo`03001oo`0000Eoo`8000=o
o`03001oogoo00800003Ool007oo009oo`03001oogoo009oo`03001oogoo039oo`8000Qoo`03001o
ogoo00Ioo`03001oogoo009oo`8000Qoo`8000=oo`03001oogoo009oo`03001oogoo00Ioo`03001o
ogoo00Ioo`006goo00<007oo0000;Goo00<007oo000027oo0`001goo00H007ooOol007oo0004Ool0
0`00Oomoo`0?Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Ool0000017oo
0`000Woo00<007ooOol00P0000=oo`00Ool00Woo00<007ooOol00Woo00<007ooOol0<Woo0P0027oo
00<007ooOol01Woo00<007ooOol00Woo0P0027oo0P000goo00H007ooOol007oo0008Ool00`00Oomo
o`06Ool001]oo`03001oo`0002eoo`03001oo`0000Qoo`<000Moo`06001oogoo001oo`0017oo00<0
07ooOol03goo00<007ooOol02Goo00D007ooOomoo`0000Aoo`03001oo`00008000=oo`<0009oo`03
001oogoo00800003Ool007oo009oo`03001oogoo009oo`8003=oo`8000Ioo`03001oo`0000Qoo`03
001oogoo009oo`8000Qoo`8000=oo`06001oogoo001oo`0027oo00<007ooOol01Woo000KOol00`00
Ool0000]Ool00`00Ool00008Ool00`00Ool00007Ool01P00Oomoo`00Ool000Aoo`03001oogoo00mo
o`03001oogoo00Uoo`03001oogoo008000Aoo`06001oo`00001oo`000Woo0`000Woo00<007ooOol0
0P0000=oo`00Ool00Woo00<007ooOol00Woo0P0017oo00<007ooOol0;7oo0P001Woo00<007oo0000
27oo00<007ooOol00Woo0P0027oo0P000goo00H007ooOol007oo0008Ool20007Ool001]oo`<000Uo
o`03001oogoo01moo`<00003Ool0000000Moo`03001oo`0000Moo`06001oogoo001oo`0017oo00<0
07ooOol02Goo1@0000=oo`00000017oo00<007ooOol00goo00<007ooOol00P0000Ioo`00Oomoo`00
Ool2000017oo001oogoo0`000Woo00<007ooOol00P0000=oo`00Ool00Woo20000Woo0`008goo00<0
07oo00000P000goo00H007oo000007oo0004Ool00`00Ool00008Ool01@00Oomoo`00Ool00P0017oo
00@007ooOomoo`8000=oo`03001oogoo00@0009oo`03001oogoo009oo`8000Moo`006goo0`002Goo
00<007ooOol07Woo00P007oo000007oo001oo`001Woo00<007oo00001Woo0P000Woo00<007oo0000
17oo00<007ooOol02goo00L007ooOomoo`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`020000
1Woo001oogoo001oo`800004Ool007ooOol300001Goo001oo`00Ool00P0000=oo`00Ool00Woo00<0
07oo00000Woo0P0000Moo`00001oo`00Ool0000ROol00`00Ool00004Ool00`00Ool0000300000goo
001oo`02Ool00`00Ool00008Ool01000Ool007oo0P0000=oo`00Ool00Woo0P000Woo0P000goo00D0
07ooOol007oo00800004Ool007oo0002Ool30007Ool001]oo`<000Uoo`03001oogoo021oo`800003
Ool007oo008000Eoo`03001oo`0000Ioo`80009oo`03001oo`0000Aoo`03001oogoo00]oo`07001o
ogooOol007oo00000Woo00<007oo000017oo00<007ooOol00P0000Ioo`00Oomoo`00Ool2000017oo
001oogoo0`0000Eoo`00Ool007oo00800003Ool007oo009oo`03001oo`00009oo`800007Ool00000
Ool007oo00008Woo00@007ooOol0009oo`800003Ool0000000800003Ool007oo009oo`03001oo`00
00Moo`800007Ool007ooOol007oo00000goo0P000Woo0P000goo00<007ooOol00P0000=oo`00Ool0
0Woo00<007ooOol00`001goo000KOol30009Ool00`00Oomoo`0NOol400000goo001oo`020005Ool0
1000Oomoo`001Goo0P000Woo00<007oo000017oo00<007ooOol02goo00L007ooOomoo`00Ool00002
Ool00`00Ool00004Ool00`00Oomoo`0200001goo001oogoo001oo`00009oo`03001oogoo00<00005
Ool007oo001oo`0200000goo001oo`02Ool30002Ool300001Woo001oo`00Ool0029oo`04001oogoo
0002Ool200000goo0000000200000goo001oo`02Ool00`00Ool00007Ool01000Ool000000Woo00<0
07oo00000Woo00<007oo00000Woo0P000Woo0P000Woo0P0000=oo`00Ool00P000goo0`001goo000K
Ool30008Ool2000POol01`00Ool00000Ool007oo008000Eoo`04001oogoo0005Ool20002Ool01000
Oomoo`000goo00<007ooOol02goo00<007ooOol00P0000Moo`00Oomoo`00Ool00004Ool00`00Oomo
o`0200001goo001oogoo001oo`00009oo`03001oogoo00<00005Ool007oo001oo`0200000goo001o
o`02Ool30002Ool20002Ool01@00Ool007oo00008Woo00H007oo001oo`00Ool200000goo00000002
00000goo001oo`02Ool00`00Ool00007Ool01000Ool000000Woo00<007oo00000Woo00<007oo0000
0Woo0P000Woo0P000Woo100000=oo`00Ool00goo0`001goo000KOol30008Ool2000POol4000017oo
000007oo0P0017oo00@007ooOol000=oo`06001oo`00001oo`000goo00D007ooOomoo`0000aoo`80
009oo`03001oo`0000Aoo`03001oogoo00=oo`05001oogoo001oo`020002Ool00`00Ool00002Ool0
0`00Oomoo`0300001Goo001oo`00Ool00P0000=oo`00Ool00Woo0`000Woo1@0000=oo`0000008Woo
00D007oo001oo`00009oo`04001oo`00Ool200000goo001oo`03Ool00`00Ool00006Ool200000goo
00000004Ool01P00Oomoo`00Ool0009oo`80009oo`80009oo`800003Ool007oo00<000=oo`8000Mo
o`006goo0`0027oo0P008Woo0P0000Aoo`00Oomoo`8000Aoo`04001oogoo0003Ool01000Ool007oo
0P000goo00D007ooOomoo`00011oo`03001oogoo00Yoo`05001oogoo001oo`020002Ool00`00Ool0
0002Ool00`00Oomoo`0300001Goo001oo`00Ool00P0000=oo`00Ool00Woo0P000goo0P000Woo00<0
07oo000017oo00<007ooOol077oo00<007oo000017oo00@007ooOomoo`8000Ioo`03001oo`0000Io
o`800003Ool0000000Aoo`06001oogoo001oo`000Woo00@007oo001oo`80009oo`800003Ool007oo
00Ioo`8000Moo`006goo0`0027oo0P008Woo0P0000Aoo`00Oomoo`8000=oo`04001oogooOol20002
Ool01000Ool007oo0P000goo00D007oo001oo`00011oo`03001oogoo00Yoo`05001oogoo001oo`02
0002Ool00`00Ool00003Ool00`00Ool0000200001Goo001oo`00Ool00P0000=oo`00Ool00Woo0P00
0goo0P000Woo00<007oo000017oo00<007ooOol077oo00<007oo000017oo00@007ooOomoo`8000Io
o`04001oo`000005Ool200000goo001oo`04Ool2000017oo001oo`000Woo00@007oo001oo`80009o
o`800003Ool007oo00Aoo`04001oo`000007Ool001]oo`800003Ool007oo00Ioo`8001moo`03001o
ogoo00800004Ool007ooOol20003Ool01000Oomoogoo0P000Woo00@007oo001oo`8000=oo`05001o
o`00Ool0000@Ool00`00Oomoo`0:Ool01@00Oomoo`00Ool00P000Woo00<007oo00000goo00<007oo
00000P0000Eoo`00Ool007oo00800007Ool007ooOol007oo00000goo0P000Woo00D007oo001oo`00
009oo`03001oogoo01aoo`03001oo`0000Aoo`04001oogooOol20006Ool01000Ool000001Goo0P00
00=oo`00Ool017oo0P0000Yoo`00Oomoo`00Ool007oo001oo`80009oo`800003Ool007oo00Aoo`03
001oo`0000Qoo`006goo00@007ooOol000Ioo`04001oogoo000NOol200001Goo000007oo00000Woo
0P000Woo0P000goo0P000Woo00@007oo001oo`8000Aoo`800003Ool0000000moo`03001oogoo00Yo
o`05001oogoo001oo`020002Ool00`00Ool00003Ool02000Ool007oo001oo`00Ool2000017oo001o
o`000Woo00<007oo00000goo0P000Woo00D007oo001oo`00009oo`03001oogoo00Uoo`03001oogoo
011oo`03001oo`0000Aoo`04001oogooOol20006Ool01000Ool000001Goo0P0000=oo`00Ool017oo
0P0000Yoo`00Oomoo`00Ool007oo001oo`80009oo`800003Ool007oo00Aoo`03001oo`0000Qoo`00
6goo00@007ooOol000Ioo`04001oogoo000NOol200001Goo000007oo00000Woo0P000Woo0P000goo
0P000Woo00@007oo001oo`8000Aoo`800003Ool0000000moo`03001oogoo00Yoo`05001oogoo001o
o`020002Ool00`00Oomoo`03Ool02000Ool007oo001oo`00Ool200001Goo001oo`00Ool00P0000Mo
o`00Oomoo`00Ool00002Ool01@00Ool007oo00000Woo00<007ooOol017oo00<007ooOol00Woo00<0
07ooOol047oo00<007oo000017oo00@007ooOomoo`8000Ioo`06001oo`00001oo`000goo0P0000=o
o`00Ool017oo0P0000Yoo`00Oomoo`00Ool007oo001oo`80009oo`80009oo`03001oogoo009oo`03
001oo`0000Qoo`005Gooo`003000000KOol00`00Oomoo`020005Ool01000Oomoo`001Woo00<007oo
Ool01goo00<007ooOol01Woo00<007ooOol00Woo0P0000=oo`00Ool00P000Woo0P0000=oo`000000
0P000Woo0P0000Aoo`00001oo`@000Eoo`04001oo`000008Ool00`00Oomoo`04Ool01000Oomoo`00
2Goo00D007ooOol007oo0080009oo`8000Aoo`08001oo`00Ool007oo001oo`8000Aoo`<00006Ool0
07ooOol007oo0P0000Moo`00Ool007oo001oo`030004Ool20003Ool20008Ool00`00Oomoo`07Ool0
0`00Ool00004Ool00`00Oomoo`030004Ool02000Ool00000Ool007oo0003Ool01000Ool000001Goo
00<007oo00000goo00P007oo001oo`00Ool007oo0P0017oo00<007oo00000Woo00<007oo000017oo
00<007ooOol00Goo000KOol00`00Oomoo`020005Ool01000Oomoo`007Woo0P0000=oo`00Ool00P00
0Woo0P0000Aoo`00000000=oo`800006Ool00000Ool007oo0P001Goo00@007oo000000moo`04001o
ogoo0009Ool01@00Oomoo`00Ool00P000Woo00<007ooOol00goo0P000Woo00@007oo001oo`8000Ao
o`<00006Ool007ooOol007oo0P0000Aoo`00Oomoo`800003Ool0000000Eoo`8000Aoo`03001oogoo
00eoo`06001oogoo001oo`0017oo0P0000Eoo`00001oo`0000=oo`08001oo`00001oo`00Ool000=o
o`04001oogoo0005Ool00`00Ool00003Ool02000Ool007oo001oo`00Ool20004Ool00`00Ool00002
Ool00`00Ool00008Ool001]oo`03001oogoo00800005Ool00000Ool00003Ool00`00Oomoo`06Ool0
0`00Oomoo`0BOol01P00Ool007oo001oo`<00004Ool00000Ool30003Ool200001Woo000007oo001o
o`8000Eoo`800003Ool007oo00ioo`03001oogoo00Yoo`05001oogoo001oo`020002Ool00`00Oomo
o`03Ool20002Ool01000Ool007oo0P001Goo0P0000Moo`00Oomoo`00Ool00002Ool00`00Oomoo`05
0005Ool20004Ool00`00Oomoo`07Ool00`00Oomoo`03Ool01P00Oomoo`00Ool000Aoo`<00004Ool0
07oo0003Ool03000Ool00000Ool007oo001oo`00Ool000Qoo`03001oo`0000=oo`08001oo`00Ool0
07oo001oo`8000Aoo`03001oogoo009oo`03001oo`0000Qoo`006goo00<007ooOol00P0000Eoo`00
001oo`0000=oo`03001oogoo00Ioo`03001oogoo019oo`06001oo`00Ool007oo0`0000Moo`00001o
o`00Ool00003Ool200001Woo000007oo001oo`8000Eoo`800003Ool007oo00ioo`03001oogoo00]o
o`04001oo`00Ool200000goo001oo`05Ool20002Ool01000Ool007oo0P001Goo0P0000Moo`00Oomo
o`00Ool00002Ool00`00Oomoo`050005Ool20004Ool00`00Oomoo`07Ool00`00Oomoo`03Ool01P00
Oomoo`00Ool000=oo`08001oo`00001oo`00Ool000=oo`0<001oo`00001oo`00Ool007oo001oo`00
27oo00<007oo00000goo00P007oo001oo`00Ool007oo0P0017oo00<007ooOol00Woo0P002Goo000K
Ool00`00Oomoo`0200001Goo000007oo00000goo00<007ooOol01Woo00<007ooOol04Woo00H007oo
001oo`00Ool300001goo000007oo001oo`0000=oo`800006Ool00000Ool007oo0P001Goo0P0000=o
o`00Ool03Woo00<007ooOol02goo00<007oo00000Woo00<007oo00001Woo0P000Woo00@007oo001o
o`8000Ioo`03001oo`00009oo`03001oo`00009oo`03001oogoo00@00003Ool007oo00=oo`8000Ao
o`03001oogoo00=oo`05001oo`00Ool00005Ool01000Oomoo`000Woo00D007ooOol007oo00800004
Ool007oo0003Ool01@00Ool00000Ool00`0000Aoo`00Ool000Qoo`03001oo`0000=oo`08001oo`00
Ool007oo001oo`8000Aoo`04001oogooOol30009Ool001]oo`03001oogoo00800005Ool00000Ool0
0003Ool00`00Oomoo`06Ool00`00Oomoo`0AOol200001goo001oo`00Ool007oo0080009oo`800003
Ool007oo009oo`800006Ool00000Ool007oo0P001Goo0P0000=oo`00Ool03Woo00<007ooOol02goo
00<007oo00000goo0P001Woo0P000Woo00@007oo001oo`8000Ioo`03001oo`00009oo`06001oogoo
001oo`000Woo00H007oo000007oo0004Ool20004Ool00`00Oomoo`03Ool01@00Ool007oo00001Goo
00@007ooOol0009oo`05001oogoo001oo`02000017oo001oo`000goo00D007oo000007oo00800005
Ool00000Ool00008Ool00`00Oomoo`03Ool02000Ool007oo001oo`00Ool20004Ool01000Oomoogoo
0`002Goo000KOol01@00Oomoo`00Ool00P0000=oo`0000000goo00<007ooOol01Woo00<007ooOol0
4Goo0P0000Moo`00Ool007oo001oo`020002Ool200000goo001oo`02Ool200001Woo000007oo001o
o`8000Eoo`800003Ool007oo00ioo`03001oogoo00]oo`03001oo`0000=oo`8000Ioo`80009oo`04
001oo`00Ool20006Ool00`00Ool00002Ool00`00Oomoo`020003Ool00`00Ool00002Ool00`00Oomo
o`02Ool20004Ool00`00Oomoo`03Ool300000goo001oo`04Ool01000Oomoo`000Woo00D007ooOol0
07oo00800004Ool007oo0002Ool2000017oo000007oo0P0000Eoo`00001oo`0000ioo`80009oo`04
001oo`00Ool20004Ool01000Oomoogoo0`002Goo000KOol2000017oo001oo`000Woo00<007ooOol0
0Woo00<007ooOol01Woo00<007ooOol047oo00<007oo00000Woo0P0000=oo`00Ool00P000Woo0P00
00=oo`00Ool00Woo00<007oo00000P0000=oo`00Ool00P001Woo00<007oo00003goo00<007ooOol0
2goo0P0017oo0P001Woo0P000Woo00@007oo001oo`8000Ioo`03001oo`00009oo`03001oogoo0080
00=oo`03001oo`00009oo`05001oogooOol00002Ool01@00Oomoogoo00001Goo0`0000=oo`000000
17oo00@007ooOol0009oo`05001oogoo001oo`02000017oo001oo`000Woo0P0000Aoo`00001oo`80
0005Ool00000Ool0000>Ool20002Ool01000Ool007oo0P0017oo00@007ooOomoo`<000Uoo`006goo
00H007ooOol007oo0002Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0?Ool20004Ool2
00000goo001oo`020002Ool01000Oomoo`001Goo0P0000=oo`0000000Woo00<007ooOol017oo00<0
07oo00003goo00<007ooOol02goo0P0017oo0P001Woo0P000Woo00@007oo001oo`8000Ioo`03001o
o`00009oo`03001oogoo008000=oo`03001oogoo009oo`80009oo`04001oogoo0003Ool00`00Oomo
o`03Ool01000Ool007oo0P000goo0P000Woo00@007ooOol0009oo`08001oo`00001oo`00Ool0009o
o`800004Ool00000Ool200001Goo000007oo00003Woo0P000Woo00@007oo001oo`8000Aoo`04001o
ogooOol30009Ool001]oo`06001oogoo001oo`000Woo00<007ooOol00Woo00<007ooOol01Woo00<0
07ooOol03goo00<007ooOol00goo0P0000=oo`00Ool00P000Woo00<007ooOol01Woo0P0000=oo`00
00000Woo00<007ooOol017oo00<007oo00003goo00<007ooOol02goo0P0017oo0P001Woo0P000Woo
00<007oo00000Woo00<007ooOol017oo00<007oo00000Woo00<007ooOol00P000goo00<007ooOol0
0Woo0P000Woo00@007ooOol000=oo`03001oogoo00=oo`04001oo`00Ool20002Ool300000goo001o
o`02Ool01@00Oomoo`00Ool00P0000Aoo`00Ool0009oo`800004Ool00000Ool200001Goo000007oo
00003Woo0P000Woo00@007oo001oo`8000Eoo`03001oogoo00<000Uoo`006goo00H007ooOol007oo
0007Ool01000Oomoo`0017oo0P004Goo00<007ooOol00goo0P0000=oo`00Ool00P000Woo00<007oo
Ool01Woo0P0000=oo`00Ool02Goo00<007oo00003goo00<007ooOol02goo0P0017oo0P001Woo0P00
0Woo00<007oo00000Woo00<007ooOol01Woo00@007oo0000009oo`8000=oo`03001oogoo009oo`80
009oo`04001oogoo0003Ool00`00Oomoo`03Ool01000Ool007oo0P000Woo0`0000=oo`00Ool00Woo
0P0000=oo`00Ool00`000Woo00<007ooOol00P0000Eoo`00001oo`00009oo`<000moo`80009oo`04
001oo`00Ool20005Ool00`00Oomoo`030009Ool001]oo`06001oogoo001oo`001goo00@007ooOol0
00Aoo`80015oo`03001oogoo00=oo`05001oogoo001oo`020002Ool00`00Oomoo`06Ool200000goo
001oo`09Ool00`00Ool0000?Ool00`00Oomoo`0;Ool20004Ool20006Ool20002Ool20003Ool00`00
Oomoo`06Ool01000Ool000000Woo0P000goo00<007ooOol00Woo0P000Woo00@007ooOol000=oo`03
001oogoo00=oo`04001oo`00Ool20002Ool200000goo00000004Ool01000Ool007oo0`000Woo00<0
07ooOol00P0000=oo`00000017oo0`003goo0P000Woo00@007oo001oo`8000Eoo`06001oogoo001o
o`002Goo000KOol01P00Oomoo`00Ool000Moo`04001oogoo0004Ool2000AOol00`00Oomoo`03Ool0
1@00Oomoo`00Ool00P000Woo00<007ooOol01Woo00@007ooOol000Yoo`03001oo`0000ioo`03001o
ogoo00aoo`8000Aoo`8000Ioo`8000=oo`05001oogooOol00008Ool01000Ool000000Woo0P000goo
00<007ooOol00Woo0P000Woo00@007ooOol0009oo`8000Eoo`04001oo`00Ool20002Ool200000goo
00000005Ool2000017oo000000000Woo00<007ooOol00P0000=oo`0000001Goo0P003goo0P000Woo
00@007oo001oo`8000Eoo`06001oogoo001oo`002Goo000KOol00`00Oomoo`0:Ool01000Oomoo`00
17oo0P003Goo00D007ooOomoo`0000Eoo`05001oogoo001oo`020002Ool00`00Oomoo`06Ool01000
Oomoo`002Woo00<007oo00003Woo00<007ooOol037oo0P0017oo0P001goo00D007ooOomoo`0000=o
o`03001oogoo00Ioo`04001oo`000002Ool20003Ool00`00Oomoo`02Ool20002Ool01000Oomoo`00
0Woo0P001Goo00@007oo001oo`80009oo`800003Ool0000000Eoo`80009oo`80009oo`03001oogoo
00800003Ool0000000Eoo`8000moo`80009oo`04001oo`00Ool20005Ool01P00Oomoo`00Ool000Uo
o`006goo00<007ooOol02Woo00<007ooOol00P000goo0P003Goo00D007ooOomoo`0000Eoo`05001o
ogoo001oo`02000;Ool01000Oomoo`002Woo00<007oo00003Woo00<007ooOol037oo0P0017oo0P00
1goo00D007ooOomoo`0000=oo`03001oogoo00Moo`<0009oo`8000=oo`03001oogoo00=oo`04001o
ogoo0002Ool00`00Oomoo`020005Ool01000Ool007oo0P000Woo0P0000=oo`0000001Goo0P000Woo
0P000Woo00<007ooOol00`0000=oo`00Ool01Goo00<007ooOol03Goo0P000Woo00@007oo001oo`80
00Eoo`06001oogoo001oo`002Goo000KOol2000;Ool00`00Oomoo`020003Ool2000=Ool01@00Oomo
ogoo00001Goo00D007ooOol007oo008000]oo`04001oogoo000:Ool00`00Ool0000>Ool00`00Oomo
o`0<Ool20004Ool20007Ool01@00Oomoogoo00003Goo0P000goo0P002Goo00@007ooOol0009oo`03
001oogoo008000Eoo`04001oo`00Ool20002Ool200000goo00000006Ool00`00Oomoo`020002Ool0
1000Ool007oo0P0000=oo`00Ool01Goo00<007ooOol03Goo0P000Woo00@007oo001oo`8000Eoo`06
001oogoo001oo`002Goo000KOol00`00Oomoo`0:Ool00`00Oomoo`020003Ool2000=Ool01@00Oomo
ogoo00001Goo00D007ooOol007oo008000]oo`04001oogoo000:Ool00`00Ool0000>Ool00`00Oomo
o`0<Ool20004Ool20007Ool01@00Oomoogoo00003Goo0P000goo0P002Goo00<007oo00000goo00<0
07ooOol00P001Goo00@007oo001oo`80009oo`03001oogoo008000Ioo`05001oogooOol00002Ool0
1000Ool007oo0P0000=oo`00Ool01Goo00<007ooOol03Woo00L007ooOol007oo001oo`020005Ool0
1P00Oomoo`00Ool000Uoo`006goo00<007ooOol02Woo00D007oo001oo`0000=oo`8000Qoo`03001o
ogoo009oo`04001oogoo0009Ool01000Ool000002goo00@007ooOol000Yoo`03001oo`0000ioo`03
001oogoo00eoo`03001oogoo009oo`03001oogoo00Ioo`05001oogooOol0000=Ool20003Ool20009
Ool00`00Ool00004Ool01000Ool000001Goo00@007oo001oo`80009oo`03001oogoo008000Yoo`07
001oogoo001oo`00Ool00P0000=oo`00Ool01Goo00<007ooOol03Woo00L007ooOol007oo001oo`02
0005Ool01P00Oomoo`00Ool000Uoo`006goo00<007ooOol02Woo00P007oo001oo`00Ool007oo0P00
27oo00<007ooOol00Woo00@007ooOol000Uoo`04001oo`00000;Ool01000Oomoo`002Woo00<007oo
00003Woo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol01Woo00D007ooOomoo`0000eoo`80
00=oo`8000Uoo`03001oo`0000Aoo`05001oo`00Ool00004Ool01000Ool007oo0P000Woo00<007oo
Ool00P002Woo00<007ooOol00P000Woo0P0000=oo`00Ool01Goo00<007ooOol03Woo00<007ooOol0
0P000Woo00<007ooOol017oo00H007ooOol007oo0009Ool001]oo`03001oogoo00]oo`800005Ool0
07oo001oo`020008Ool00`00Oomoo`02Ool01000Oomoo`002Goo00@007oo000000]oo`04001oogoo
000:Ool01000Oomoo`003Goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol01Woo00<007oo
Ool03goo00<007ooOol00Woo0P002Goo00<007oo00001Goo0P0000=oo`0000000goo00@007oo001o
o`80009oo`03001oogoo008000Yoo`03001oogoo0080009oo`8000Qoo`03001oogoo00ioo`05001o
ogooOol00002Ool00`00Oomoo`05Ool20002Ool00`00Oomoo`07Ool001]oo`03001oogoo00]oo`80
0005Ool007oo001oo`020008Ool00`00Oomoo`02Ool200000goo001oo`08Ool01000Ool000003Woo
00<007ooOol02goo00<007ooOol02goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol01Woo
00<007ooOol03goo00<007ooOol00Woo0P002Goo00<007oo00001Goo0P0000=oo`0000000goo00@0
07oo001oo`80009oo`04001oogoo000;Ool00`00Oomoo`020002Ool20008Ool00`00Oomoo`0>Ool0
1@00Oomoogoo00000Woo00<007ooOol01Goo0P000Woo00<007ooOol01goo000KOol00`00Oomoo`0;
Ool200001Goo001oo`00Ool00P0027oo00<007ooOol00Woo0P0000=oo`00Ool027oo00<007oo0000
3goo00<007ooOol02goo00<007ooOol02goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol0
1Woo00<007ooOol03goo00<007ooOol00goo00<007ooOol01goo00<007oo00001Goo0P0000=oo`00
00000goo00@007oo001oo`800003Ool007oo00ioo`03001oogoo008000=oo`03001oogoo00Ioo`03
001oogoo00ioo`05001oogooOol00002Ool00`00Oomoo`05Ool20002Ool00`00Oomoo`07Ool001]o
o`8000aoo`800005Ool007oo001oo`020002Ool00`00Oomoo`03Ool00`00Oomoo`02Ool200000goo
001oo`08Ool00`00Ool0000?Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0=Ool00`00
Oomoo`0;Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool00`00Oomoo`08Ool20005Ool200000goo0000
0003Ool01000Ool007oo0P0000=oo`00Ool03Woo00<007ooOol00P000goo00<007ooOol01Woo00<0
07ooOol03Woo00D007ooOomoo`00009oo`03001oogoo00Ioo`04001oogoo0009Ool001]oo`03001o
ogoo00]oo`800005Ool007oo001oo`020002Ool00`00Oomoo`03Ool00`00Oomoo`02Ool200000goo
001oo`08Ool00`00Ool0000?Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0=Ool00`00
Oomoo`0;Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool00`00Oomoo`08Ool20005Ool200000goo0000
000200000goo001oo`020002Ool2000?Ool00`00Oomoo`020003Ool00`00Oomoo`06Ool00`00Oomo
o`0>Ool01@00Oomoogoo00000Woo00<007ooOol01Woo00@007ooOol000Uoo`006goo00<007ooOol0
2goo0P0000Eoo`00Ool007oo0080009oo`03001oogoo00=oo`8000=oo`800003Ool007oo00Qoo`03
001oogoo01eoo`03001oogoo00]oo`03001oogoo00eoo`03001oogoo00]oo`03001oogoo00moo`03
001oogoo00ioo`8000Ioo`03001oo`0000@000=oo`03001oogoo008000moo`03001oogoo008000=o
o`03001oogoo00Ioo`03001oogoo00ioo`05001oogooOol0000;Ool01000Oomoo`002Goo000KOol0
0`00Oomoo`0;Ool200000goo001oo`0200001goo001oogoo001oo`0000=oo`8000=oo`800003Ool0
07oo00Qoo`03001oogoo01eoo`03001oogoo00]oo`03001oogoo02eoo`03001oogoo00ioo`8000Io
o`03001oo`0000@000=oo`03001oogoo008000moo`04001oogoo0004Ool00`00Oomoo`06Ool00`00
Oomoo`0>Ool01@00Oomoogoo00003Woo00<007ooOol01goo000KOol00`00Oomoo`0;Ool200000goo
001oo`0200001goo001oogoo001oo`0000=oo`8000=oo`800003Ool007oo00Qoo`03001oogoo01eo
o`03001oogoo00]oo`03001oogoo02eoo`03001oogoo00ioo`8000Ioo`03001oo`0000@000=oo`03
001oogoo008000moo`04001oogoo0004Ool00`00Oomoo`06Ool00`00Oomoo`0>Ool01@00Oomoogoo
00003Woo00<007ooOol01goo000KOol00`00Oomoo`0;Ool200000goo001oo`0200002Woo001oogoo
001oo`00Ool007oo0P0000=oo`00Ool00P0000=oo`00Ool027oo00<007ooOol07Goo00<007ooOol0
2goo00<007ooOol0;Goo00<007ooOol03Woo00<007ooOol01Goo00D007oo000007oo008000=oo`03
001oogoo008000moo`04001oogoo0004Ool00`00Oomoo`0GOol01@00Oomoogoo00003Woo00<007oo
Ool01goo000KOol00`00Oomoo`0;Ool01@00Oomoo`00Ool00P000Woo0`0000Eoo`00Ool007oo0080
0003Ool007oo00<000Yoo`03001oogoo01eoo`03001oogoo00]oo`03001oogoo02eoo`03001oogoo
00ioo`03001oogoo00Moo`800003Ool0000000=oo`03001oogoo008000moo`04001oogoo0004Ool0
0`00Oomoo`0GOol01@00Oomoogoo000067oo000KOol00`00Oomoo`0;Ool01@00Oomoo`00Ool00P00
0Woo0`0000Eoo`00Ool007oo00800003Ool00000009oo`03001oogoo02Qoo`03001oogoo00Yoo`03
001oogoo03moo`03001oogoo00Moo`03001oogoo008000=oo`03001oogoo008000moo`04001oogoo
0004Ool00`00Oomoo`0GOol00`00Oomoo`0JOol001]oo`8000aoo`05001oogoo001oo`020002Ool3
00000goo001oo`0400000goo00000002Ool00`00Oomoo`0XOol00`00Oomoo`0:Ool00`00Oomoo`0o
Ool00`00Oomoo`07Ool00`00Oomoo`020003Ool00`00Oomoo`02000GOol00`00Oomoo`0dOol001]o
o`03001oogoo00]oo`05001oogoo001oo`020002Ool300000goo0000000400000goo0000000]Ool0
0`00Oomoo`0:Ool00`00Oomoo`0oOol00`00Oomoo`07Ool00`00Oomoo`020003Ool00`00Oomoo`02
000GOol00`00Oomoo`0dOol001]oo`03001oogoo00]oo`05001oogoo001oo`020002Ool3000017oo
000007oo0`0000=oo`000000;Woo00<007ooOol02Goo00<007ooOol0?goo00<007ooOol01goo00<0
07ooOol00P000goo00<007ooOol00P005goo00<007ooOol0=7oo000KOol00`00Oomoo`0>Ool00`00
Ool00003Ool200002Goo00000000Ool007oo001oo`02000^Ool00`00Oomoo`08Ool00`00Oomoo`10
Ool00`00Oomoo`07Ool01@00Oomoogoo00000goo00<007ooOol00P005goo00<007ooOol0=7oo000K
Ool00`00Oomoo`0>Ool00`00Ool00003Ool200002Goo00000000Ool007oo001oo`02000^Ool00`00
Oomoo`08Ool00`00Oomoo`10Ool00`00Oomoo`07Ool01@00Oomoogoo00000goo00@007ooOol001Qo
o`03001oogoo03Aoo`006goo00<007ooOol03Woo00<007oo00000goo0P0000Uoo`00Ool007oo001o
o`00Ool00P00;goo00<007ooOol01goo00<007ooOol0@7oo00<007ooOol01goo00D007ooOomoo`00
00=oo`03001oogoo01Uoo`03001oogoo03Aoo`002goo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol03Woo00<007oo00000goo0P0000Uoo`00Ool007oo001oo`00Ool00P00
;goo00<007ooOol01goo00<007ooOol0BWoo00D007ooOomoo`0000=oo`03001oogoo01Uoo`03001o
ogoo03Aoo`002Woo00<007oo00001goo00<007oo000017oo00<007ooOol03goo00<007ooOol00Woo
0P0000Uoo`00Ool007oo001oo`00Ool00P00;goo00<007ooOol01goo00<007ooOol0BWoo00D007oo
Oomoo`0000=oo`03001oogoo01Uoo`03001oogoo03Aoo`002Woo00<007oo00002Goo00<007ooOol0
0Woo0P0047oo00<007ooOol00Woo0P0000=oo`00Ool00Woo00@007oo001oo`8002moo`03001oogoo
00Moo`03001oogoo04Yoo`05001oogooOol00003Ool00`00Oomoo`0IOol00`00Oomoo`0dOol000Yo
o`03001oo`0000Moo`8000Eoo`03001oogoo00moo`03001oogoo009oo`800003Ool007oo009oo`04
001oo`00Ool2000_Ool00`00Oomoo`07Ool00`00Oomoo`1:Ool01@00Oomoogoo00000goo00<007oo
Ool06Goo00<007ooOol0=7oo000:Ool00`00Ool00007Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool0
0`00Oomoo`02Ool200000goo001oo`02Ool01000Ool007oo0P00;goo00<007ooOol01goo00<007oo
Ool0CWoo00D007ooOomoo`0001]oo`03001oogoo03Aoo`002goo00<007ooOol01Woo0`0017oo00<0
07ooOol03goo00<007ooOol00Woo0P0000=oo`00Ool00Woo00H007oo000007oo000_Ool00`00Oomo
o`07Ool00`00Oomoo`1>Ool01@00Oomoogoo00006goo00<007ooOol0=7oo000KOol00`00Oomoo`0?
Ool00`00Oomoo`02Ool200000goo001oo`02Ool01P00Oomoo`00Ool002moo`03001oogoo00Moo`03
001oogoo04ioo`05001oogooOol0000KOol00`00Oomoo`0dOol001]oo`03001oogoo00moo`03001o
ogoo009oo`800003Ool007oo009oo`06001oogoo001oo`00;goo00<007ooOol01goo00<007ooOol0
CWoo00D007ooOomoo`00059oo`006goo00<007ooOol03goo00<007ooOol00Woo00@007ooOol000=o
o`06001oogoo001oo`00<7oo00<007ooOol01Woo00<007ooOol0YGoo000KOol2000@Ool00`00Oomo
o`02Ool00`00Oomoo`04Ool01000Oomoo`00<Woo00<007ooOol01Woo00<007ooOol0YGoo000KOol0
0`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`04Ool01000Oomoo`00<Woo00<007ooOol01Goo
00<007ooOol0YWoo000KOol00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`04Ool01000Oomo
o`00<Woo00<007ooOol01Goo00<007ooOol0YWoo000KOol00`00Oomoo`0?Ool00`00Oomoo`02Ool0
0`00Oomoo`04Ool01000Oomoo`00<Woo00<007ooOol01Goo00<007ooOol0YWoo000KOol00`00Oomo
o`0?Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`0`Ool00`00Oomoo`05Ool00`00Oomo
o`2VOol001]oo`03001oogoo00moo`03001oogoo009oo`03001oogoo00Moo`03001oogoo031oo`03
001oogoo00Eoo`03001oogoo0:Ioo`006goo00<007ooOol03goo00<007ooOol00Woo00<007ooOol0
1goo00<007ooOol0<7oo00<007ooOol01Goo00<007ooOol0YWoo000KOol00`00Oomoo`0?Ool00`00
Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`0`Ool00`00Oomoo`05Ool00`00Oomoo`2VOol001]o
o`80011oo`03001oogoo009oo`03001oogoo00Moo`03001oogoo031oo`03001oogoo00Eoo`03001o
ogoo0:Ioo`006goo00<007ooOol03goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0<7oo
00<007ooOol01Goo00<007ooOol0YWoo000KOol00`00Oomoo`0?Ool00`00Oomoo`0oOol00`00Oomo
o`05Ool00`00Oomoo`2VOol001]oo`03001oogoo00moo`03001oogoo03moo`03001oogoo00Eoo`03
001oogoo0:Ioo`006goo00<007ooOol0DGoo00<007ooOol01Goo00<007ooOol0YWoo000KOol00`00
Oomoo`1AOol00`00Oomoo`05Ool00`00Oomoo`2VOol001]oo`03001oogoo055oo`03001oogoo00Ao
o`03001oogoo0:Moo`006goo00<007ooOol0DGoo00<007ooOol017oo00<007ooOol0Ygoo000KOol2
001BOol00`00Oomoo`04Ool00`00Oomoo`2WOol001]oo`03001oogoo055oo`03001oogoo009oo`03
001oo`000:Uoo`006goo00<007ooOol0DGoo00<007ooOol00Woo00<007oo0000ZGoo000KOol00`00
Oomoo`1AOol00`00Oomoo`02Ool00`00Ool0002YOol001]oo`03001oogoo055oo`03001oogoo009o
o`03001oo`000:Uoo`006goo00<007ooOol0DGoo00<007ooOol00Woo00<007oo0000ZGoo000KOol0
0`00Oomoo`1AOol00`00Oomoo`02Ool00`00Ool0002YOol001]oo`80059oo`03001oogoo009oo`03
001oo`000:Uoo`006goo00<007ooOol0DWoo00L007ooOomoo`00Ool0002YOol001]oo`03001oogoo
059oo`07001oogooOol007oo0000ZGoo000KOol00`00Oomoo`1BOol01`00Oomoogoo001oo`000:Uo
o`006goo00<007ooOol0DWoo00L007ooOomoo`00Ool0002YOol001]oo`03001oogoo059oo`03001o
ogoo00800003Ool007oo0:Qoo`004goo1@000goo00<007ooOol0DWoo00<007ooOol00P0000=oo`00
Ool0Z7oo000EOol00`00Oomoo`03Ool00`00Oomoo`1BOol00`00Oomoo`0200000goo001oo`2XOol0
01Eoo`03001oogoo00=oo`8005=oo`800003Ool007oo00800:Uoo`005Goo00<007ooOol00goo00<0
07ooOol0DWoo0P0000Aoo`00Ool00:Yoo`005Goo00<007ooOol00goo00<007ooOol0DWoo0P0000Ao
o`00Ool00:Yoo`0057oo0P001Goo00<007ooOol0DWoo0P0000Aoo`00Ool00:Yoo`006goo00<007oo
Ool0DWoo0P0000Aoo`00Ool00:Yoo`006goo00<007ooOol0DWoo0P0000Aoo`00Ool00:Yoo`006goo
00<007ooOol0DWoo0P0000Aoo`00Ool00:Yoo`006goo00<007ooOol0DWoo00H007oo000007oo002Z
Ool001]oo`8005=oo`06001oo`00001oo`00ZWoo000KOol00`00Oomoo`1BOol01P00Ool00000Ool0
0:Yoo`006goo00<007ooOol0E7oo00@007ooOol00:Yoo`006goo00<007ooOol0E7oo00@007ooOol0
0:Yoo`006goo00<007ooOol0E7oo00@007ooOol00:Yoo`006goo00<007ooOol0E7oo00@007ooOol0
0:Yoo`006goo00<007ooOol0Egoo00<007ooOol0Z7oo000KOol00`00Oomoo`3oOol3Ool001]oo`80
0?moo`Aoo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{86.5, 373.5}, {538.813, 361.875}} -> {-114.995, 3.71761,
   1.01036, 0.0129869}}]
}, Open  ]],

Cell[BoxData[
    \(\(y = 
      SavitzkyGolayFilter[\n\t\tJoin[Table[0, {4}], signal, Table[0, {4}]], 
        N[fir]]; \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[y, PlotRange -> All, PlotJoined -> True]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0201324 0.00367715 0.245758 0.319843 [
[.20399 .23326 -6 -9 ]
[.20399 .23326 6 0 ]
[.38785 .23326 -9 -9 ]
[.38785 .23326 9 0 ]
[.5717 .23326 -9 -9 ]
[.5717 .23326 9 0 ]
[.75556 .23326 -9 -9 ]
[.75556 .23326 9 0 ]
[.93942 .23326 -9 -9 ]
[.93942 .23326 9 0 ]
[.00763 .00588 -30 -4.5 ]
[.00763 .00588 0 4.5 ]
[.00763 .08584 -24 -4.5 ]
[.00763 .08584 0 4.5 ]
[.00763 .1658 -30 -4.5 ]
[.00763 .1658 0 4.5 ]
[.00763 .32572 -24 -4.5 ]
[.00763 .32572 0 4.5 ]
[.00763 .40568 -18 -4.5 ]
[.00763 .40568 0 4.5 ]
[.00763 .48564 -24 -4.5 ]
[.00763 .48564 0 4.5 ]
[.00763 .5656 -6 -4.5 ]
[.00763 .5656 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.20399 .24576 m
.20399 .25201 L
s
[(50)] .20399 .23326 0 1 Mshowa
.38785 .24576 m
.38785 .25201 L
s
[(100)] .38785 .23326 0 1 Mshowa
.5717 .24576 m
.5717 .25201 L
s
[(150)] .5717 .23326 0 1 Mshowa
.75556 .24576 m
.75556 .25201 L
s
[(200)] .75556 .23326 0 1 Mshowa
.93942 .24576 m
.93942 .25201 L
s
[(250)] .93942 .23326 0 1 Mshowa
.125 Mabswid
.0569 .24576 m
.0569 .24951 L
s
.09368 .24576 m
.09368 .24951 L
s
.13045 .24576 m
.13045 .24951 L
s
.16722 .24576 m
.16722 .24951 L
s
.24076 .24576 m
.24076 .24951 L
s
.27753 .24576 m
.27753 .24951 L
s
.3143 .24576 m
.3143 .24951 L
s
.35108 .24576 m
.35108 .24951 L
s
.42462 .24576 m
.42462 .24951 L
s
.46139 .24576 m
.46139 .24951 L
s
.49816 .24576 m
.49816 .24951 L
s
.53493 .24576 m
.53493 .24951 L
s
.60848 .24576 m
.60848 .24951 L
s
.64525 .24576 m
.64525 .24951 L
s
.68202 .24576 m
.68202 .24951 L
s
.71879 .24576 m
.71879 .24951 L
s
.79233 .24576 m
.79233 .24951 L
s
.8291 .24576 m
.8291 .24951 L
s
.86588 .24576 m
.86588 .24951 L
s
.90265 .24576 m
.90265 .24951 L
s
.97619 .24576 m
.97619 .24951 L
s
.25 Mabswid
0 .24576 m
1 .24576 L
s
.02013 .00588 m
.02638 .00588 L
s
[(-0.75)] .00763 .00588 1 0 Mshowa
.02013 .08584 m
.02638 .08584 L
s
[(-0.5)] .00763 .08584 1 0 Mshowa
.02013 .1658 m
.02638 .1658 L
s
[(-0.25)] .00763 .1658 1 0 Mshowa
.02013 .32572 m
.02638 .32572 L
s
[(0.25)] .00763 .32572 1 0 Mshowa
.02013 .40568 m
.02638 .40568 L
s
[(0.5)] .00763 .40568 1 0 Mshowa
.02013 .48564 m
.02638 .48564 L
s
[(0.75)] .00763 .48564 1 0 Mshowa
.02013 .5656 m
.02638 .5656 L
s
[(1)] .00763 .5656 1 0 Mshowa
.125 Mabswid
.02013 .02187 m
.02388 .02187 L
s
.02013 .03786 m
.02388 .03786 L
s
.02013 .05385 m
.02388 .05385 L
s
.02013 .06984 m
.02388 .06984 L
s
.02013 .10183 m
.02388 .10183 L
s
.02013 .11782 m
.02388 .11782 L
s
.02013 .13381 m
.02388 .13381 L
s
.02013 .14981 m
.02388 .14981 L
s
.02013 .18179 m
.02388 .18179 L
s
.02013 .19778 m
.02388 .19778 L
s
.02013 .21377 m
.02388 .21377 L
s
.02013 .22977 m
.02388 .22977 L
s
.02013 .26175 m
.02388 .26175 L
s
.02013 .27774 m
.02388 .27774 L
s
.02013 .29373 m
.02388 .29373 L
s
.02013 .30973 m
.02388 .30973 L
s
.02013 .34171 m
.02388 .34171 L
s
.02013 .3577 m
.02388 .3577 L
s
.02013 .3737 m
.02388 .3737 L
s
.02013 .38969 m
.02388 .38969 L
s
.02013 .42167 m
.02388 .42167 L
s
.02013 .43766 m
.02388 .43766 L
s
.02013 .45366 m
.02388 .45366 L
s
.02013 .46965 m
.02388 .46965 L
s
.02013 .50163 m
.02388 .50163 L
s
.02013 .51762 m
.02388 .51762 L
s
.02013 .53362 m
.02388 .53362 L
s
.02013 .54961 m
.02388 .54961 L
s
.02013 .58159 m
.02388 .58159 L
s
.02013 .59759 m
.02388 .59759 L
s
.02013 .61358 m
.02388 .61358 L
s
.25 Mabswid
.02013 0 m
.02013 .61803 L
s
.5 Mabswid
.02381 .24694 m
.02749 .24782 L
.03116 .20743 L
.03484 .21974 L
.03852 .242 L
.0422 .28981 L
.04587 .27225 L
.04955 .27041 L
.05323 .26256 L
.0569 .27682 L
.06058 .27234 L
.06426 .24858 L
.06794 .21696 L
.07161 .2146 L
.07529 .2822 L
.07897 .35477 L
.08264 .34751 L
.08632 .29737 L
.09 .36475 L
.09368 .39889 L
.09735 .39817 L
.10103 .34572 L
.10471 .30795 L
.10838 .33196 L
.11206 .3939 L
.11574 .408 L
.11942 .37514 L
.12309 .37896 L
.12677 .39759 L
.13045 .37021 L
.13412 .37674 L
.1378 .40258 L
.14148 .39749 L
.14516 .36451 L
.14883 .3845 L
.15251 .41692 L
.15619 .42816 L
.15986 .36599 L
.16354 .35636 L
.16722 .33962 L
.1709 .37562 L
.17457 .34104 L
.17825 .29932 L
.18193 .27277 L
.1856 .279 L
.18928 .2637 L
.19296 .24098 L
.19664 .25712 L
.20031 .29671 L
.20399 .22992 L
Mistroke
.20767 .23723 L
.21134 .22552 L
.21502 .28717 L
.2187 .28886 L
.22238 .31445 L
.22605 .23829 L
.22973 .23846 L
.23341 .27915 L
.23708 .26909 L
.24076 .261 L
.24444 .23872 L
.24812 .21289 L
.25179 .15386 L
.25547 .19714 L
.25915 .21831 L
.26282 .28297 L
.2665 .28803 L
.27018 .27223 L
.27386 .27088 L
.27753 .28657 L
.28121 .24884 L
.28489 .20348 L
.28856 .25591 L
.29224 .25356 L
.29592 .18818 L
.2996 .15872 L
.30327 .20086 L
.30695 .23012 L
.31063 .23052 L
.3143 .2718 L
.31798 .25628 L
.32166 .25114 L
.32534 .2689 L
.32901 .36326 L
.33269 .3892 L
.33637 .40241 L
.34004 .48577 L
.34372 .55896 L
.3474 .60332 L
.35108 .60218 L
.35475 .57158 L
.35843 .56601 L
.36211 .56003 L
.36578 .54869 L
.36946 .4584 L
.37314 .41014 L
.37682 .38343 L
.38049 .33406 L
.38417 .2595 L
.38785 .18134 L
Mistroke
.39152 .18394 L
.3952 .13546 L
.39888 .09746 L
.40256 .01472 L
.40623 .03603 L
.40991 .08651 L
.41359 .12942 L
.41726 .05811 L
.42094 .02506 L
.42462 .07295 L
.4283 .15791 L
.43197 .2249 L
.43565 .30665 L
.43933 .30386 L
.443 .23336 L
.44668 .20011 L
.45036 .20896 L
.45404 .25954 L
.45771 .29356 L
.46139 .31216 L
.46507 .19695 L
.46874 .1657 L
.47242 .17891 L
.4761 .21149 L
.47978 .18101 L
.48345 .20257 L
.48713 .28226 L
.49081 .27371 L
.49448 .24303 L
.49816 .14536 L
.50184 .17995 L
.50552 .23512 L
.50919 .32317 L
.51287 .24238 L
.51655 .19486 L
.52022 .24355 L
.5239 .26285 L
.52758 .23472 L
.53126 .16696 L
.53493 .18733 L
.53861 .20248 L
.54229 .25416 L
.54596 .26672 L
.54964 .23913 L
.55332 .21565 L
.557 .2562 L
.56067 .32171 L
.56435 .33578 L
.56803 .2593 L
.5717 .20719 L
Mistroke
.57538 .21636 L
.57906 .3164 L
.58274 .31501 L
.58641 .24048 L
.59009 .17764 L
.59377 .23278 L
.59744 .25642 L
.60112 .27556 L
.6048 .26094 L
.60848 .25598 L
.61215 .2568 L
.61583 .26644 L
.61951 .32971 L
.62318 .34966 L
.62686 .35085 L
.63054 .29165 L
.63422 .25458 L
.63789 .26061 L
.64157 .29557 L
.64525 .32571 L
.64892 .34614 L
.6526 .30726 L
.65628 .32322 L
.65996 .33193 L
.66363 .37224 L
.66731 .33259 L
.67099 .38558 L
.67466 .36214 L
.67834 .31815 L
.68202 .24326 L
.6857 .32522 L
.68937 .33766 L
.69305 .31745 L
.69673 .29708 L
.7004 .37829 L
.70408 .36873 L
.70776 .3234 L
.71144 .27378 L
.71511 .29041 L
.71879 .31333 L
.72247 .31782 L
.72614 .25011 L
.72982 .20863 L
.7335 .2376 L
.73718 .27782 L
.74085 .29612 L
.74453 .311 L
.74821 .27687 L
.75188 .26254 L
.75556 .24595 L
Mistroke
.75924 .31924 L
.76292 .30234 L
.76659 .21798 L
.77027 .20085 L
.77395 .2934 L
.77762 .35821 L
.7813 .3172 L
.78498 .27388 L
.78866 .32436 L
.79233 .30097 L
.79601 .31408 L
.79969 .21885 L
.80336 .25034 L
.80704 .24698 L
.81072 .28257 L
.8144 .2697 L
.81807 .25853 L
.82175 .308 L
.82543 .29022 L
.8291 .27573 L
.83278 .1969 L
.83646 .21428 L
.84014 .21166 L
.84381 .22261 L
.84749 .19664 L
.85117 .20118 L
.85484 .21451 L
.85852 .1816 L
.8622 .19544 L
.86588 .21457 L
.86955 .26301 L
.87323 .2437 L
.87691 .23086 L
.88058 .1989 L
.88426 .20449 L
.88794 .28877 L
.89162 .29445 L
.89529 .2199 L
.89897 .17395 L
.90265 .28137 L
.90632 .34398 L
.91 .25434 L
.91368 .22444 L
.91736 .27733 L
.92103 .29413 L
.92471 .2314 L
.92839 .19409 L
.93206 .20446 L
.93574 .20693 L
.93942 .26661 L
Mistroke
.9431 .30695 L
.94677 .34421 L
.95045 .34137 L
.95413 .28686 L
.9578 .29538 L
.96148 .26314 L
.96516 .23822 L
.96884 .19766 L
.97251 .24681 L
.97619 .24733 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
37oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
o7oo000;Ool00`00Ool00008Ool01`00Oomoogoo001oo`0000Aoo`03001oogoo0?aoo`001Woo0`00
0Woo00<007oo000027oo00<007ooOol00goo00<007ooOol00Woo0P00oGoo000;Ool00`00Ool00009
Ool00`00Oomoo`020005Ool00`00Oomoo`3lOol000]oo`03001oo`0000Moo`03001oo`00009oo`03
001oogoo00Aoo`03001oogoo061oo`03001oogoo09Uoo`0037oo00<007ooOol01Woo0`000Woo0`00
17oo00<007ooOol0H7oo00<007ooOol0VGoo000QOol2001QOol00`00Oomoo`2IOol0025oo`03001o
ogoo061oo`8000=oo`03001oogoo09Aoo`008Goo00<007ooOol0H7oo0P000goo00<007ooOol0U7oo
000QOol00`00Oomoo`1POol20003Ool00`00Oomoo`2DOol0025oo`80065oo`8000=oo`03001oogoo
09Aoo`008Goo00<007ooOol0H7oo0P000goo00<007ooOol0U7oo000QOol00`00Oomoo`1POol20002
Ool2002FOol0025oo`03001oogoo061oo`80009oo`8009Ioo`008Goo0P00HGoo0P000Woo0P00UWoo
000QOol00`00Oomoo`1OOol00`00Ool00002Ool2002FOol0025oo`03001oogoo05moo`03001oo`00
009oo`8009Ioo`008Goo00<007ooOol0Ggoo00D007ooOol007oo008009Ioo`008Goo00<007ooOol0
Ggoo00D007ooOol007oo008009Ioo`008Goo0P00H7oo00D007ooOol007oo008009Ioo`008Goo00<0
07ooOol0Ggoo00D007ooOol007oo008009Ioo`004Goo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol0Ggoo00D007ooOol007oo008009Ioo`0047oo00<007oo00001goo00<0
07oo000017oo00<007ooOol0Ggoo00D007ooOol007oo008009Ioo`002goo0`000Woo00<007oo0000
2Goo00<007ooOol00Woo0P00H7oo00D007ooOol007oo008009Ioo`0047oo00<007oo00001goo0P00
1Goo00<007ooOol0Ggoo00D007ooOol007oo008009Ioo`0047oo00<007oo00001goo00<007ooOol0
17oo00<007ooOol0Ggoo00<007ooOol00P0000=oo`00Ool0UGoo000AOol00`00Oomoo`06Ool30004
Ool00`00Oomoo`1OOol00`00Oomoo`0200000goo001oo`2EOol0025oo`80061oo`03001oogoo0080
0003Ool007oo09Eoo`008Goo00<007ooOol0Ggoo00<007ooOol00P0000=oo`00Ool0UGoo000QOol0
0`00Oomoo`1OOol01`00Oomoogoo001oo`0009Ioo`008Goo00<007ooOol0Ggoo00D007ooOomoo`00
009oo`03001oogoo09=oo`008Goo0P00Ggoo00<007ooOol00Woo00@007ooOol009Eoo`008Goo00<0
07ooOol0GWoo00<007ooOol00Woo00@007ooOol009Eoo`008Goo00<007ooOol0GWoo00<007ooOol0
0Woo00@007ooOol009Eoo`008Goo00<007ooOol0GWoo00<007ooOol00Woo00@007ooOol009Eoo`00
8Goo0P00Ggoo00<007ooOol01Goo00<007ooOol0Tgoo000QOol00`00Oomoo`1NOol00`00Oomoo`05
Ool00`00Oomoo`2COol0025oo`03001oogoo05ioo`03001oogoo00Eoo`03001oogoo09=oo`008Goo
00<007ooOol0GWoo00<007ooOol01Goo00<007ooOol047oo00<007ooOol0P7oo000QOol2001OOol0
0`00Oomoo`05Ool00`00Oomoo`0@Ool00`00Oomoo`20Ool0025oo`03001oogoo03Uoo`03001oogoo
029oo`03001oogoo00Eoo`03001oogoo011oo`03001oogoo081oo`0037oo00<007ooOol00Woo00@0
07ooOomoo`<000=oo`03001oogoo00=oo`03001oogoo03Uoo`03001oogoo029oo`03001oogoo00Eo
o`03001oogoo011oo`03001oogoo081oo`002goo00<007oo00001goo00<007ooOol00Woo00<007oo
000017oo00<007ooOol0>Goo00<007ooOol02Goo00<007ooOol05Goo00<007ooOol01Woo00<007oo
Ool047oo00<007ooOol0P7oo0006Ool30002Ool00`00Ool00008Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool2000jOol00`00Oomoo`09Ool00`00Oomoo`0EOol00`00Oomoo`06Ool00`00Oomoo`08Ool0
0`00Oomoo`05Ool00`00Oomoo`20Ool000]oo`03001oo`0000Qoo`04001oogooOol20005Ool00`00
Oomoo`0iOol00`00Oomoo`09Ool00`00Oomoo`0EOol00`00Oomoo`06Ool00`00Oomoo`08Ool00`00
Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`1hOol000]oo`03001oo`0000Moo`03001oo`00009o
o`03001oogoo00Aoo`03001oogoo03Uoo`03001oogoo00Uoo`03001oogoo01Eoo`03001oogoo00Io
o`03001oogoo00Qoo`8000Ioo`03001oogoo00Eoo`03001oogoo07Qoo`0037oo00<007ooOol01goo
00@007ooOomoo`<000Aoo`03001oogoo03Uoo`8000Uoo`8001Moo`03001oogoo00Ioo`03001oogoo
00Qoo`8000Ioo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo04eoo`03001oogoo01Uoo`00
8Goo00<007ooOol0>Goo0P002Goo0P005Woo0P0027oo00<007ooOol01goo00D007oo001oo`0000Ao
o`03001oogoo00Eoo`8000eoo`03001oogoo04eoo`03001oogoo01Uoo`008Goo0P00>Goo00<007oo
00002Goo00<007oo00005Goo0P0027oo00<007ooOol01goo00D007oo001oo`0000Aoo`03001oogoo
00Eoo`8000eoo`03001oogoo04=oo`03001oogoo00Moo`03001oogoo01Uoo`008Goo00<007ooOol0
>7oo00<007oo00002Goo00<007oo00005Goo00<007ooOol01goo00<007ooOol01goo00D007oo001o
o`0000Aoo`03001oogoo00Eoo`8000eoo`03001oogoo04=oo`03001oogoo00Moo`03001oogoo01Uo
o`008Goo00<007ooOol0>7oo00<007oo00002Goo00<007oo00005Goo00<007ooOol027oo00<007oo
Ool01Woo00@007oo001oo`8000=oo`03001oogoo00Eoo`8000eoo`03001oogoo04=oo`8000Qoo`03
001oogoo01Uoo`008Goo00<007ooOol0>7oo00<007oo00002Goo00<007oo00005Goo00<007ooOol0
27oo00<007ooOol01Woo00H007ooOol007oo0002Ool20003Ool01`00Oomoogoo001oo`0000aoo`03
001oogoo03aoo`05001oogooOol00002Ool20008Ool00`00Oomoo`05Ool00`00Oomoo`0AOol0025o
o`8003Uoo`03001oo`0000Uoo`03001oo`0001Eoo`03001oogoo00Qoo`05001oogooOol00004Ool0
1P00Oomoo`00Ool0009oo`8000=oo`07001oogooOol007oo000037oo00<007ooOol0?7oo00@007oo
Oomoo`<00003Ool007oo00=oo`03001oogoo008000Moo`8000Qoo`03001oogoo00Moo`008Goo00<0
07ooOol0:Goo00<007ooOol00Woo00<007ooOol01goo00<007oo00001Woo00H007ooOol007oo000=
Ool50002Ool20003Ool00`00Oomoo`04Ool01@00Oomoogoo000017oo00H007ooOol007oo0002Ool2
0003Ool01000Oomoo`000Woo1P000Woo00<007ooOol00Woo00<007ooOol08Woo0`000goo00@007oo
Oomoo`8000ioo`04001oogooOol300000goo001oo`03Ool200000goo00000003Ool3000017oo0000
000017oo00@007ooOol000Uoo`008Goo00@007ooOol002Moo`03001oo`00009oo`03001oo`0000Qo
o`03001oo`0000Ioo`06001oogoo001oo`003goo00L007ooOomoo`00Ool00002Ool00`00Ool00005
Ool01000Oomoogoo0P000goo00H007ooOol007oo0002Ool00`00Ool00002Ool01000Oomoo`000Woo
00@007ooOol000=oo`03001oo`00009oo`<002=oo`03001oogoo009oo`03001oo`00009oo`03001o
o`0000eoo`80009oo`<0009oo`04001oogooOol200000goo00000003Ool01000Oomoogoo10000Woo
00D007oo001oo`0000Uoo`008Goo00@007ooOol002Uoo`06001oogoo001oo`0027oo00@007ooOol0
00Eoo`06001oogoo001oo`003goo00L007ooOomoo`00Ool00002Ool00`00Ool00005Ool01000Oomo
ogoo0P000goo00H007ooOol007oo0002Ool00`00Ool00002Ool01000Oomoo`000Woo00@007ooOol0
00Eoo`06001oogoo001oo`008goo0P000goo00@007oo001oo`800003Ool007oo00aoo`@0009oo`04
001oogoo0003Ool200000goo00000004Ool01@00Oomoo`00Ool00P000Woo00D007oo001oo`0000Uo
o`008Goo0P0000=oo`00000027oo00<007ooOol06goo0P000goo00<007oo000027oo00@007ooOol0
00Eoo`06001oogoo001oo`003goo00L007ooOomoo`00Ool00002Ool00`00Ool00005Ool01000Oomo
ogoo0P000goo00<007ooOol00Woo00H007ooOol007oo0002Ool01000Oomoo`000Woo00<007ooOol0
0P000Woo100000Aoo`00Ool002=oo`8000=oo`04001oo`00Ool200000goo001oo`0<Ool40002Ool0
1000Oomoo`000Woo00@007oo001oo`8000Aoo`04001oo`00Ool20003Ool01@00Ool007oo00002Goo
000QOol00`00Oomoo`020007Ool2000MOol00`00Oomoo`02Ool00`00Ool00008Ool01000Oomoo`00
1Goo00@007ooOol0009oo`03001oogoo00aoo`07001oogooOol007oo00000Woo00<007oo00001Goo
00H007ooOol007oo0003Ool00`00Oomoo`02Ool01`00Oomoo`00Ool007oo0080009oo`04001oogoo
0002Ool20002Ool02000Ool00000Ool007oo000SOol00`00Ool00002Ool01000Ool007oo0P0000=o
o`00Ool017oo00<007ooOol01Goo00@007ooOol000Eoo`07001oogoo001oo`00Ool00P000goo00D0
07oo000007oo008000=oo`03001oo`00008000Uoo`008Goo00<007ooOol00P001goo0P007Goo0`00
0goo00<007ooOol01goo00@007ooOol000Eoo`03001oo`0000=oo`03001oogoo00]oo`8000Aoo`03
001oogoo009oo`03001oogoo00Aoo`06001oogoo001oo`000goo00<007ooOol00Woo00`007ooOol0
07oo001oo`00Ool007oo0002Ool00`00Ool000020002Ool4000017oo000000008goo0P0017oo00<0
07ooOol00`001Woo00<007ooOol01Goo00@007ooOol000Eoo`07001oogoo001oo`00Ool00P0017oo
00@007oo001oo`<000=oo`05001oo`00Ool00008Ool0025oo`03001oogoo008000Moo`8002=oo`03
001oogoo00Ioo`05001oogooOol00004Ool200000goo001oo`02Ool00`00Oomoo`0AOol00`00Oomo
o`09Ool01P00Oomoo`00Ool000=oo`03001oogoo009oo`0<001oogoo001oo`00Ool007oo001oo`00
0Woo00<007ooOol00P0017oo0P0000Aoo`00Ool002=oo`03001oogoo00Ioo`8000Moo`03001oogoo
00Eoo`03001oogoo00Ioo`07001oogoo001oo`00Ool00P000goo00@007ooOol0009oo`03001oogoo
00Aoo`03001oo`0000Qoo`008Goo0`000Woo00<007ooOol017oo0P008Goo00<007oo000027oo00D0
07ooOomoo`0000Aoo`04001oo`000003Ool2000BOol00`00Oomoo`09Ool01P00Oomoo`00Ool000=o
o`03001oogoo009oo`0<001oogoo001oo`00Ool007oo001oo`000goo00@007oo000000Aoo`800004
Ool007oo000ROol20008Ool20007Ool00`00Oomoo`05Ool00`00Oomoo`06Ool02P00Oomoo`00Ool0
07oo001oo`000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oo`0000Qoo`008Goo00<007oo
00000Woo00<007ooOol00goo00<007oo00008Goo0`0027oo00D007ooOomoo`0000Aoo`04001oo`00
0004Ool00`00Oomoo`0@Ool00`00Oomoo`09Ool01P00Oomoo`00Ool000=oo`03001oogoo009oo`0<
001oogoo001oo`00Ool007oo001oo`000goo00@007oo000000=oo`07001oo`00Ool007oo00008Woo
0P0027oo0P001goo0P001Woo00<007ooOol01Woo00X007ooOol007oo001oo`00Ool0009oo`04001o
ogoo0002Ool00`00Oomoo`04Ool00`00Ool00008Ool0025oo`03001oo`00009oo`03001oogoo00=o
o`03001oo`00025oo`<000=oo`8000=oo`05001oogooOol00004Ool01000Ool0000017oo00<007oo
Ool047oo00<007ooOol02Goo00@007ooOol0009oo`04001oogoo0004Ool03000Oomoo`00Ool007oo
001oo`00Ool000=oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`00029oo`8000Qoo`8000Mo
o`8000Eoo`03001oogoo00Moo`03001oo`00009oo`05001oo`00Ool00002Ool01000Oomoo`000goo
00<007ooOol00goo00<007oo000027oo000QOol00`00Ool00002Ool00`00Oomoo`03Ool00`00Ool0
000NOol01P00Oomoo`00Ool000=oo`8000=oo`05001oogooOol00004Ool01000Ool0000017oo00<0
07ooOol047oo00<007ooOol02Goo00@007ooOol0009oo`04001oogoo0004Ool03000Oomoo`00Ool0
07oo001oo`00Ool000=oo`05001oo`00Ool00002Ool01`00Ool007oo001oo`0001Ioo`03001oogoo
00Uoo`8000Qoo`8000Moo`8000Eoo`03001oogoo00Qoo`80009oo`06001oo`00Ool007oo0P000Woo
00D007ooOomoo`0000Eoo`03001oo`0000Qoo`0077ooo`001@00000QOol00`00Ool00002Ool01`00
Oomoogoo001oo`00009oo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo
00=oo`800004Ool007oo0003Ool20002Ool00`00Oomoo`02Ool01000Oomoogoo0P0000=oo`000000
17oo0P0027oo00<007ooOol01Woo0P0027oo00<007oo00000Woo00D007ooOol007oo008000Eoo`03
001oo`0000800003Ool007oo0080009oo`07001oo`00Ool007oo00000Woo0`0000Eoo`00Oomoo`00
009oo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`04001oo`000005Ool01P00Oomo
o`00Ool000Aoo`03001oo`00008000Aoo`03001oogoo00Moo`<0009oo`06001oo`00Ool007oo0P00
0Woo00D007ooOomoo`0000Eoo`04001oogoo0007Ool0025oo`03001oogoo009oo`03001oogoo00=o
o`04001oogoo000MOol2000017oo001oo`000goo0P000Woo00<007ooOol00goo00H007ooOomoo`00
Ool20005Ool00`00Ool0000?Ool2000:Ool01000Oomoo`000Woo00<007oo00001Woo00P007oo001o
o`00Ool007oo0P0017oo0P000Woo00<007ooOol00`0000Eoo`00Oomoo`0000Uoo`03001oogoo00Uo
o`03001oogoo00Uoo`8000Aoo`80009oo`03001oo`0000Ioo`03001oo`0000Aoo`03001oogoo00Qo
o`80009oo`0;001oo`00Ool007oo001oo`00Ool00003Ool00`00Oomoo`03Ool00`00Oomoo`08Ool0
025oo`03001oogoo009oo`03001oogoo00=oo`04001oogoo000MOol200001Goo001oogoo00000Woo
0P000Woo00<007ooOol00goo00L007ooOomoo`00Ool00006Ool3000?Ool00`00Oomoo`09Ool01000
Oomoo`000Woo00<007oo00001Woo0P000Woo00<007oo00000Woo00<007ooOol00Woo0P000Woo00P0
07ooOol007oo001oo`000Woo00<007ooOol00P001Goo0P002Woo00<007ooOol02Goo00<007oo0000
0goo0P000Woo00<007oo00001Woo00D007oo001oo`00009oo`03001oogoo00Qoo`04001oogooOol2
0002Ool01`00Ool007oo001oo`0000=oo`03001oogoo00=oo`03001oogoo00Qoo`008Goo0P000goo
00H007ooOol007oo0003Ool00`00Oomoo`0KOol200001Goo001oogoo00000Woo00D007oo001oo`00
00Eoo`05001oogooOol00008Ool200000goo001oo`0=Ool00`00Oomoo`09Ool01000Oomoo`000Woo
00<007oo00001Woo0P000Woo00<007oo00000Woo00<007ooOol00goo00@007ooOol0009oo`05001o
o`00Ool00002Ool00`00Ool00002Ool00`00Oomoo`02Ool2000:Ool00`00Oomoo`09Ool00`00Ool0
0003Ool200001Goo001oogoo00001Woo00D007oo001oo`00009oo`03001oogoo00Qoo`04001oogoo
Ool20002Ool01`00Ool007oo001oo`0000=oo`03001oogoo00=oo`03001oogoo00Qoo`008Goo00<0
07ooOol00Woo00H007ooOol007oo0003Ool00`00Oomoo`0KOol30003Ool01@00Oomoo`00Ool00P00
1Woo00D007ooOomoo`0000Qoo`04001oogoo000>Ool00`00Oomoo`09Ool01000Oomoo`000Woo00<0
07oo00001Woo0P000Woo00<007oo00000Woo00<007ooOol00goo00@007ooOol0009oo`05001oo`00
Ool00002Ool00`00Ool00002Ool00`00Oomoo`02Ool2000:Ool00`00Oomoo`09Ool00`00Ool00003
Ool200001Goo001oogoo00001Woo00<007oo00000P000Woo00<007ooOol027oo00@007ooOomoo`80
009oo`04001oo`00Ool20004Ool00`00Oomoo`03Ool00`00Oomoo`08Ool0025oo`03001oogoo009o
o`04001oo`00Ool20003Ool00`00Oomoo`0KOol30003Ool01@00Oomoo`00Ool00P001Woo00@007oo
Ool000Uoo`04001oogoo000>Ool00`00Oomoo`0:Ool20003Ool00`00Ool00006Ool20002Ool00`00
Ool00008Ool01000Oomoo`000Woo00D007oo001oo`0000=oo`05001oogooOol00004Ool2000:Ool0
0`00Oomoo`09Ool00`00Ool00002Ool01@00Ool007oo00000Woo00<007ooOol00goo00<007ooOol0
0`000Woo00<007ooOol037oo0P000Woo00@007oo001oo`8000Aoo`03001oogoo00=oo`03001oogoo
00Qoo`008Goo00<007ooOol00Woo0`0000=oo`0000000goo00<007ooOol06Goo0P0000=oo`000000
0goo00D007ooOol007oo008000Ioo`@000Uoo`04001oogoo000>Ool00`00Oomoo`0:Ool20003Ool0
0`00Ool00006Ool20002Ool00`00Ool0000;Ool02000Oomoo`00Ool007oo0003Ool01@00Oomoogoo
00000goo00<007oo00002Woo00<007ooOol01Goo00L007ooOomoo`00Ool00002Ool01@00Ool007oo
00000Woo00@007ooOol0009oo`03001oogoo00<0009oo`03001oogoo00aoo`80009oo`04001oo`00
Ool20004Ool00`00Oomoo`03Ool00`00Oomoo`08Ool0025oo`8000=oo`80009oo`03001oogoo009o
o`03001oogoo01Uoo`80009oo`07001oogooOol007oo00000Woo00<007ooOol01Goo100037oo00<0
07ooOol037oo00<007ooOol02Woo0P000goo00<007oo00001Woo0P000Woo00<007oo00002goo00P0
07ooOol007oo001oo`000goo00D007ooOomoo`0000=oo`03001oo`0000Yoo`03001oogoo00Eoo`07
001oogooOol007oo00000Woo00D007oo001oo`00009oo`04001oogoo0002Ool01P00Oomoo`00Ool0
009oo`03001oogoo00aoo`80009oo`04001oo`00Ool20004Ool00`00Oomoo`03Ool00`00Oomoo`08
Ool0025oo`03001oogoo009oo`8000Moo`03001oogoo01Uoo`80009oo`07001oogooOol007oo0000
0Woo00<007ooOol01Goo0P0000=oo`00Ool02goo00<007ooOol037oo00<007ooOol02Woo0P0017oo
0P001Woo00<007ooOol00Woo0P002goo00D007ooOol007oo008000Qoo`05001oogooOol00002Ool0
0`00Oomoo`06Ool20007Ool01`00Oomoogoo001oo`00009oo`05001oo`00Ool00002Ool01000Oomo
o`000Woo00H007ooOol007oo0002Ool00`00Oomoo`0<Ool20002Ool01000Ool007oo0P0017oo00<0
07ooOol00Woo00<007ooOol02Goo000QOol00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0I
Ool01@00Oomoogoo00000goo00<007oo00002Woo0P0000=oo`00Ool02goo00<007ooOol037oo00<0
07ooOol02Woo0P0017oo0P001Woo00<007ooOol00Woo00<007ooOol02Woo00D007ooOol007oo0080
00Qoo`05001oogooOol00002Ool00`00Oomoo`06Ool00`00Ool00006Ool200001Goo001oogoo0000
0Woo00<007ooOol00P000Woo00@007ooOol0009oo`04001oogoo0002Ool2000?Ool20002Ool01000
Ool007oo0P0017oo00<007ooOol00Woo00<007ooOol02Goo000QOol00`00Oomoo`02Ool00`00Oomo
o`06Ool00`00Oomoo`0HOol00`00Oomoo`02Ool01000Oomoogoo0`002goo00<007oo000037oo00<0
07ooOol037oo00<007ooOol02Woo0P0017oo0P002goo00<007ooOol02Woo00D007ooOol007oo0080
00Qoo`05001oogooOol00002Ool00`00Oomoo`06Ool00`00Ool00006Ool200000goo001oo`02Ool0
0`00Ool00002Ool20002Ool01000Oomoo`000Woo00<007ooOol00goo0P003goo0P000Woo00<007oo
00000Woo00<007ooOol00goo00<007ooOol00P002goo000QOol00`00Oomoo`02Ool00`00Oomoo`06
Ool00`00Oomoo`0HOol00`00Oomoo`02Ool00`00Oomoo`02Ool2000JOol00`00Oomoo`0<Ool00`00
Oomoo`0:Ool20004Ool2000;Ool00`00Oomoo`0;Ool01000Ool007oo0P0027oo00D007ooOomoo`00
009oo`03001oogoo00Ioo`03001oo`0000Ioo`800003Ool007oo009oo`03001oo`00009oo`80009o
o`04001oogoo0002Ool00`00Oomoo`03Ool2000@Ool01P00Oomoo`00Ool0009oo`03001oogoo00=o
o`03001oogoo008000]oo`008Goo0P0037oo00<007ooOol067oo00<007ooOol00Woo00<007ooOol0
0Woo0P006Woo00<007ooOol037oo00<007ooOol02Woo0P0017oo0P002goo00<007ooOol02goo00@0
07oo001oo`8000Qoo`05001oogooOol00002Ool00`00Oomoo`06Ool00`00Ool00002Ool01000Oomo
ogoo0P0000=oo`00Ool00Woo0P000goo0P000Woo00@007oo0000009oo`03001oogoo00=oo`80011o
o`06001oogoo001oo`000Woo00<007ooOol00goo00<007ooOol00P002goo000QOol00`00Oomoo`0;
Ool01000Oomoo`005goo00<007ooOol01goo0P006Woo00<007ooOol02goo00<007ooOol02goo0P00
17oo0P002goo00<007ooOol02goo0P000Woo0P002Goo00@007ooOol0009oo`03001oogoo00Ioo`03
001oo`00009oo`08001oogoo001oo`00Ool000=oo`8000=oo`80009oo`04001oo`00Ool30005Ool0
0`00Oomoo`0BOol20009Ool01000Oomoo`0037oo000QOol00`00Oomoo`0;Ool01000Oomoo`005goo
00<007ooOol027oo00<007ooOol067oo00<007ooOol02goo00<007ooOol02goo0P001Goo00<007oo
Ool02Goo00<007ooOol02goo0P000Woo0P002Goo00@007ooOol0009oo`03001oogoo00Ioo`03001o
o`00009oo`04001oogoo0002Ool20004Ool01000Oomoogoo0P000Woo00@007oo001oo`<000Eoo`03
001oogoo019oo`8000Uoo`04001oogoo000<Ool0025oo`03001oogoo00]oo`04001oogoo0004Ool0
0`00Oomoo`0@Ool00`00Oomoo`08Ool00`00Oomoo`0HOol00`00Oomoo`0;Ool00`00Oomoo`0;Ool0
0`00Oomoo`04Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool20002Ool20009Ool01000Oomoo`000Woo
00@007ooOol000Eoo`04001oo`00Ool20002Ool00`00Oomoo`020004Ool01000Oomoogoo0P000Woo
00@007oo001oo`<000Eoo`03001oogoo019oo`8000Uoo`04001oogoo000<Ool0025oo`8000aoo`04
001oogoo0004Ool00`00Oomoo`0@Ool00`00Oomoo`08Ool00`00Oomoo`0HOol00`00Oomoo`0;Ool0
0`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`0;Ool20002Ool20009Ool01000Oomoo`000goo
00<007oo00001Goo00@007oo001oo`80009oo`03001oogoo008000Aoo`05001oogooOol00003Ool0
1`00Ool007oo001oo`0001Yoo`8000Uoo`04001oogoo000<Ool0025oo`03001oogoo00]oo`04001o
ogoo0004Ool00`00Oomoo`0@Ool00`00Oomoo`08Ool00`00Oomoo`0HOol00`00Oomoo`0;Ool00`00
Oomoo`0NOol00`00Oomoo`0;Ool20002Ool20009Ool01000Oomoo`000goo00<007oo00001Goo00@0
07oo001oo`80009oo`03001oogoo008000Qoo`0;001oogooOol007oo001oo`00Ool0000KOol00`00
Oomoo`07Ool00`00Ool0000=Ool000aoo`03001oogoo009oo`04001oogooOol30003Ool00`00Oomo
o`03Ool00`00Oomoo`0<Ool00`00Ool00004Ool2000AOol00`00Oomoo`0TOol00`00Oomoo`0:Ool0
0`00Oomoo`0NOol00`00Oomoo`0;Ool2000=Ool01000Oomoo`000goo00<007oo00001Goo00@007oo
001oo`80009oo`05001oogooOol00008Ool02@00Oomoogoo001oo`00Ool0000MOol00`00Oomoo`07
Ool00`00Ool0000=Ool000]oo`03001oo`0000Moo`03001oogoo009oo`03001oo`0000Aoo`03001o
ogoo00aoo`<000Aoo`80011oo`03001oogoo02Eoo`03001oogoo00Yoo`03001oogoo01ioo`03001o
ogoo00]oo`8000eoo`03001oo`0000Aoo`03001oo`0000Eoo`04001oo`00Ool20002Ool00`00Oomo
o`0>Ool01@00Ool007oo00007Goo00<007ooOol01goo00<007oo00003Goo000;Ool00`00Ool00008
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool2000=Ool30003Ool00`00Ool0000@Ool00`00Oomoo`0U
Ool00`00Oomoo`0:Ool00`00Oomoo`0/Ool2000=Ool00`00Ool00004Ool200000goo001oo`03Ool0
1000Ool007oo0P000Woo00<007ooOol03goo0P007goo00<007ooOol027oo0P003Goo000;Ool00`00
Ool00008Ool01000Oomoogoo0P001Goo00<007ooOol037oo0`000goo00<007oo000047oo00<007oo
Ool09Goo00<007ooOol02Woo00<007ooOol0;Goo00<007ooOol02goo00<007oo000017oo0P0000=o
o`00Ool00goo00H007oo000007oo0002Ool00`00Oomoo`0?Ool2000OOol00`00Oomoo`08Ool2000=
Ool000]oo`03001oo`0000Moo`03001oo`00009oo`03001oogoo00Aoo`03001oogoo00aoo`800007
Ool007ooOol007oo000047oo00<007ooOol09Goo00<007ooOol02Woo00<007ooOol0;Goo00<007oo
Ool02goo00<007oo000017oo0P0000Aoo`00Ool0009oo`06001oogoo001oo`000Woo00<007ooOol0
3goo0P007goo00<007ooOol027oo0P003Goo000<Ool00`00Oomoo`07Ool01000Oomoogoo0`0017oo
00<007ooOol037oo0P0000Moo`00Oomoo`00Ool0000>Ool00`00Ool0000WOol00`00Oomoo`0:Ool0
0`00Oomoo`0kOol00`00Ool00005Ool01@00Ool007oo00000Woo00@007ooOol0009oo`03001oo`00
015oo`03001oogoo01ioo`03001oogoo00Qoo`8000eoo`008Goo0P003Goo0P0000Moo`00Oomoo`00
Ool0000>Ool00`00Ool0000WOol00`00Oomoo`0:Ool00`00Oomoo`0lOol20005Ool01`00Ool007oo
001oo`0000Ioo`03001oo`00015oo`03001oogoo01ioo`03001oogoo00Qoo`8000eoo`008Goo00<0
07ooOol037oo0P0000Moo`00Oomoo`00Ool0000>Ool00`00Ool0000WOol00`00Oomoo`0:Ool00`00
Oomoo`0lOol20005Ool01`00Ool007oo001oo`0000Ioo`80019oo`03001oogoo01ioo`03001oogoo
00Qoo`03001oogoo00aoo`008Goo00<007ooOol037oo00@007ooOol0009oo`03001oo`0000eoo`80
0003Ool007oo02Ioo`03001oogoo00Yoo`03001oogoo03aoo`8000Moo`05001oo`00Ool00006Ool2
000BOol00`00Oomoo`0hOol0025oo`03001oogoo00aoo`04001oogoo0002Ool00`00Ool0000=Ool2
00000goo001oo`0VOol00`00Oomoo`0:Ool00`00Oomoo`16Ool200000goo001oo`05Ool2000BOol0
0`00Oomoo`0hOol0025oo`80011oo`06001oogoo001oo`003Goo00@007oo000002Moo`03001oogoo
00Yoo`03001oogoo04Ioo`800003Ool007oo00Eoo`80019oo`03001oogoo03Qoo`008Goo00<007oo
Ool03goo00H007ooOol007oo000<Ool01000Oomoo`00:7oo00<007ooOol02Goo00<007ooOol0Agoo
00@007oo000000Ioo`8004eoo`008Goo00<007ooOol03goo00@007ooOol0009oo`03001oogoo00Eo
o`05001oogooOol00002Ool00`00Oomoo`0VOol00`00Oomoo`09Ool00`00Oomoo`17Ool01000Ool0
00001Woo0P00CGoo000QOol00`00Oomoo`0?Ool01000Oomoo`000Woo00D007ooOomoo`0000=oo`05
001oogooOol00002Ool00`00Oomoo`0VOol00`00Oomoo`09Ool00`00Oomoo`17Ool01000Ool00000
1Woo0P00CGoo000QOol2000@Ool00`00Ool00003Ool01000Oomoogoo0P000Woo00D007ooOomoo`00
009oo`03001oogoo02Ioo`03001oogoo00Uoo`03001oogoo04Moo`03001oo`0000Moo`03001oogoo
04aoo`008Goo00<007ooOol03goo00<007oo00000goo0P000Woo0P000Woo0P000Woo00@007ooOol0
02Uoo`03001oogoo00Qoo`03001oogoo04Uoo`03001oogoo00Eoo`03001oogoo04aoo`008Goo00<0
07ooOol03goo00<007oo00000goo0`0000Moo`00001oo`00Ool00002Ool00`00Oomoo`0ZOol00`00
Oomoo`08Ool00`00Oomoo`19Ool00`00Oomoo`1DOol0025oo`03001oogoo011oo`8000=oo`@00006
Ool007oo001oo`000Woo00<007ooOol0:Woo00<007ooOol027oo00<007ooOol0BGoo00<007ooOol0
E7oo000QOol2000AOol20003Ool2000027oo001oo`00Ool007oo0002Ool00`00Oomoo`0ZOol00`00
Oomoo`08Ool00`00Oomoo`2POol0025oo`03001oogoo011oo`8000=oo`800004Ool007ooOol20000
1Goo001oogoo0000;7oo00<007ooOol027oo00<007ooOol0X7oo000QOol00`00Oomoo`0@Ool20003
Ool2000017oo001oogoo0P0000Aoo`00Ool002ioo`03001oogoo00Moo`03001oogoo0:1oo`004Goo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol047oo0P000goo0P0017oo
00@007ooOomoo`8002ioo`03001oogoo00Ioo`03001oogoo0:5oo`0047oo00<007oo00001goo00<0
07oo000017oo00<007ooOol05Woo00<007ooOol00Woo00@007ooOomoo`8002ioo`03001oogoo00Io
o`03001oogoo0:5oo`0047oo00<007oo00002Goo00<007ooOol00Woo0P005goo00<007ooOol01Woo
0P00;Woo00<007ooOol01Woo00<007ooOol0XGoo000@Ool00`00Ool00007Ool20005Ool00`00Oomo
o`0OOol2000^Ool00`00Oomoo`06Ool00`00Oomoo`2QOol0011oo`03001oo`0000Moo`03001oogoo
00Aoo`03001oogoo01moo`8002ioo`03001oogoo00Ioo`03001oogoo0:5oo`004Goo00<007ooOol0
1Woo0`0017oo00<007ooOol07goo0P00;Woo00<007ooOol01Woo00<007ooOol0XGoo000QOol2000Q
Ool00`00Oomoo`0/Ool00`00Oomoo`06Ool00`00Oomoo`2QOol0025oo`03001oogoo021oo`03001o
ogoo02aoo`03001oogoo00Ioo`03001oogoo0:5oo`008Goo00<007ooOol0Cgoo00<007ooOol01Woo
00<007ooOol0XGoo000QOol00`00Oomoo`1?Ool00`00Oomoo`05Ool00`00Oomoo`2ROol0025oo`80
051oo`03001oogoo00Eoo`03001oogoo0:9oo`008Goo00<007ooOol0Cgoo00<007ooOol01Goo00<0
07ooOol0XWoo000QOol00`00Oomoo`1@Ool00`00Oomoo`04Ool00`00Oomoo`2ROol0025oo`03001o
ogoo051oo`03001oogoo00Aoo`03001oogoo0:9oo`008Goo0P00DGoo00<007ooOol017oo00<007oo
Ool0XWoo000QOol00`00Oomoo`1@Ool00`00Oomoo`04Ool00`00Oomoo`2ROol0025oo`03001oogoo
051oo`03001oogoo00Aoo`03001oogoo0:9oo`008Goo00<007ooOol0D7oo00<007ooOol017oo00<0
07ooOol0XWoo000QOol2001AOol00`00Oomoo`04Ool00`00Oomoo`2ROol0025oo`03001oogoo051o
o`03001oogoo00Aoo`03001oogoo0:9oo`0037oo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol00goo00<007ooOol0D7oo00<007ooOol017oo00<007ooOol0XWoo000;Ool0
0`00Ool00008Ool01`00Oomoogoo001oo`0000Aoo`03001oogoo051oo`03001oogoo00Aoo`03001o
ogoo0:9oo`002goo00<007oo000027oo00<007ooOol00goo00<007ooOol00Woo0P00DGoo00<007oo
Ool017oo00<007ooOol0XWoo000;Ool00`00Ool00009Ool00`00Oomoo`020005Ool00`00Oomoo`1@
Ool00`00Oomoo`04Ool00`00Oomoo`2ROol000]oo`03001oo`0000Moo`03001oo`00009oo`03001o
ogoo00Aoo`03001oogoo051oo`03001oogoo00Aoo`03001oogoo0:9oo`0037oo00<007ooOol01Woo
0`000Woo0`0017oo00<007ooOol0D7oo00<007ooOol017oo00<007ooOol0XWoo000QOol2001AOol0
0`00Oomoo`04Ool00`00Oomoo`2ROol0025oo`03001oogoo051oo`03001oogoo00=oo`03001oogoo
0:=oo`008Goo00<007ooOol0D7oo00<007ooOol00goo00<007ooOol0Xgoo000QOol00`00Oomoo`1@
Ool00`00Oomoo`03Ool00`00Oomoo`2SOol0025oo`03001oogoo051oo`03001oogoo00=oo`03001o
ogoo0:=oo`008Goo0P00DGoo00<007ooOol00goo00<007ooOol0Xgoo000QOol00`00Oomoo`1AOol0
0`00Oomoo`02Ool00`00Oomoo`2SOol0025oo`03001oogoo055oo`03001oogoo009oo`03001oogoo
0:=oo`008Goo00<007ooOol0DGoo00<007ooOol00Woo00<007ooOol0Xgoo000QOol2001BOol00`00
Oomoo`02Ool00`00Oomoo`2SOol0025oo`03001oogoo055oo`03001oogoo009oo`03001oogoo0:=o
o`008Goo00<007ooOol0DGoo00<007ooOol00Woo00<007ooOol0Xgoo000QOol00`00Oomoo`1AOol0
0`00Oomoo`02Ool00`00Oomoo`2SOol0025oo`80059oo`03001oogoo009oo`03001oogoo0:=oo`00
8Goo00<007ooOol0DGoo00<007ooOol00Woo00<007ooOol0Xgoo000IOol50003Ool00`00Oomoo`1A
Ool01@00Oomoogoo0000YWoo000KOol00`00Oomoo`03Ool00`00Oomoo`1AOol01@00Oomoogoo0000
YWoo000KOol00`00Oomoo`03Ool2001BOol01000Oomoo`00Ygoo000KOol00`00Oomoo`03Ool00`00
Oomoo`1AOol00`00Ool0002XOol001]oo`03001oogoo00=oo`03001oogoo055oo`03001oo`000:Qo
o`006Woo0P001Goo00<007ooOol0DGoo00<007oo0000Z7oo000QOol2001BOol00`00Ool0002XOol0
025oo`03001oogoo055oo`03001oo`000:Qoo`008Goo00<007ooOol0DGoo0P00ZGoo000QOol00`00
Oomoo`1AOol2002YOol0025oo`80059oo`800:Uoo`008Goo00<007ooOol0DGoo0P00ZGoo000QOol0
0`00Oomoo`1AOol00`00Oomoo`2XOol0025oo`03001oogoo0?aoo`008Goo0P00oGoo000QOol00`00
Oomoo`3lOol0025oo`03001oogoo0?aoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{86.5, 373.5}, {262.375, 85.4375}} -> {-125.739, 
  0.143208, 1.05011, 0.0120728}}]
}, Open  ]],

Cell["\<\
Increase the amount of smoothing by extending the length of the filter.\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(y = 
      SavitzkyGolayFilter[\n\t\tJoin[Table[0, {30}], signal, Table[0, {30}]], 
        N[SavitzkyGolayCoefficients[31, 3]]]; \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[y, PlotRange -> All, PlotJoined -> True]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0204678 0.00334169 0.212691 0.481538 [
[.18755 .20019 -6 -9 ]
[.18755 .20019 6 0 ]
[.35464 .20019 -9 -9 ]
[.35464 .20019 9 0 ]
[.52172 .20019 -9 -9 ]
[.52172 .20019 9 0 ]
[.68881 .20019 -9 -9 ]
[.68881 .20019 9 0 ]
[.85589 .20019 -9 -9 ]
[.85589 .20019 9 0 ]
[.00797 .02008 -24 -4.5 ]
[.00797 .02008 0 4.5 ]
[.00797 .11638 -24 -4.5 ]
[.00797 .11638 0 4.5 ]
[.00797 .309 -18 -4.5 ]
[.00797 .309 0 4.5 ]
[.00797 .40531 -18 -4.5 ]
[.00797 .40531 0 4.5 ]
[.00797 .50161 -18 -4.5 ]
[.00797 .50161 0 4.5 ]
[.00797 .59792 -18 -4.5 ]
[.00797 .59792 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.18755 .21269 m
.18755 .21894 L
s
[(50)] .18755 .20019 0 1 Mshowa
.35464 .21269 m
.35464 .21894 L
s
[(100)] .35464 .20019 0 1 Mshowa
.52172 .21269 m
.52172 .21894 L
s
[(150)] .52172 .20019 0 1 Mshowa
.68881 .21269 m
.68881 .21894 L
s
[(200)] .68881 .20019 0 1 Mshowa
.85589 .21269 m
.85589 .21894 L
s
[(250)] .85589 .20019 0 1 Mshowa
.125 Mabswid
.05388 .21269 m
.05388 .21644 L
s
.0873 .21269 m
.0873 .21644 L
s
.12072 .21269 m
.12072 .21644 L
s
.15414 .21269 m
.15414 .21644 L
s
.22097 .21269 m
.22097 .21644 L
s
.25439 .21269 m
.25439 .21644 L
s
.2878 .21269 m
.2878 .21644 L
s
.32122 .21269 m
.32122 .21644 L
s
.38805 .21269 m
.38805 .21644 L
s
.42147 .21269 m
.42147 .21644 L
s
.45489 .21269 m
.45489 .21644 L
s
.4883 .21269 m
.4883 .21644 L
s
.55514 .21269 m
.55514 .21644 L
s
.58855 .21269 m
.58855 .21644 L
s
.62197 .21269 m
.62197 .21644 L
s
.65539 .21269 m
.65539 .21644 L
s
.72222 .21269 m
.72222 .21644 L
s
.75564 .21269 m
.75564 .21644 L
s
.78906 .21269 m
.78906 .21644 L
s
.82247 .21269 m
.82247 .21644 L
s
.88931 .21269 m
.88931 .21644 L
s
.92272 .21269 m
.92272 .21644 L
s
.95614 .21269 m
.95614 .21644 L
s
.98956 .21269 m
.98956 .21644 L
s
.25 Mabswid
0 .21269 m
1 .21269 L
s
.02047 .02008 m
.02672 .02008 L
s
[(-0.4)] .00797 .02008 1 0 Mshowa
.02047 .11638 m
.02672 .11638 L
s
[(-0.2)] .00797 .11638 1 0 Mshowa
.02047 .309 m
.02672 .309 L
s
[(0.2)] .00797 .309 1 0 Mshowa
.02047 .40531 m
.02672 .40531 L
s
[(0.4)] .00797 .40531 1 0 Mshowa
.02047 .50161 m
.02672 .50161 L
s
[(0.6)] .00797 .50161 1 0 Mshowa
.02047 .59792 m
.02672 .59792 L
s
[(0.8)] .00797 .59792 1 0 Mshowa
.125 Mabswid
.02047 .04415 m
.02422 .04415 L
s
.02047 .06823 m
.02422 .06823 L
s
.02047 .09231 m
.02422 .09231 L
s
.02047 .14046 m
.02422 .14046 L
s
.02047 .16454 m
.02422 .16454 L
s
.02047 .18861 m
.02422 .18861 L
s
.02047 .23677 m
.02422 .23677 L
s
.02047 .26084 m
.02422 .26084 L
s
.02047 .28492 m
.02422 .28492 L
s
.02047 .33308 m
.02422 .33308 L
s
.02047 .35715 m
.02422 .35715 L
s
.02047 .38123 m
.02422 .38123 L
s
.02047 .42938 m
.02422 .42938 L
s
.02047 .45346 m
.02422 .45346 L
s
.02047 .47754 m
.02422 .47754 L
s
.02047 .52569 m
.02422 .52569 L
s
.02047 .54977 m
.02422 .54977 L
s
.02047 .57384 m
.02422 .57384 L
s
.25 Mabswid
.02047 0 m
.02047 .61803 L
s
.5 Mabswid
.02381 .21354 m
.02715 .21814 L
.03049 .21292 L
.03383 .21185 L
.03718 .20799 L
.04052 .20785 L
.04386 .20803 L
.0472 .20672 L
.05054 .20702 L
.05388 .20944 L
.05723 .21279 L
.06057 .21718 L
.06391 .21618 L
.06725 .20875 L
.07059 .20646 L
.07393 .20951 L
.07728 .2109 L
.08062 .20397 L
.08396 .21111 L
.0873 .21551 L
.09064 .22534 L
.09398 .23986 L
.09733 .23965 L
.10067 .2483 L
.10401 .26132 L
.10735 .26854 L
.11069 .28273 L
.11404 .29355 L
.11738 .30791 L
.12072 .32046 L
.12406 .32898 L
.1274 .34556 L
.13074 .35105 L
.13409 .35861 L
.13743 .37161 L
.14077 .38247 L
.14411 .39909 L
.14745 .40888 L
.15079 .41836 L
.15414 .42701 L
.15748 .43557 L
.16082 .43844 L
.16416 .4348 L
.1675 .43085 L
.17084 .43506 L
.17419 .43366 L
.17753 .42013 L
.18087 .40985 L
.18421 .4194 L
.18755 .39905 L
Mistroke
.19089 .39592 L
.19424 .37432 L
.19758 .34783 L
.20092 .3453 L
.20426 .33445 L
.2076 .31451 L
.21094 .30512 L
.21429 .29169 L
.21763 .27931 L
.22097 .27142 L
.22431 .26282 L
.22765 .2622 L
.23099 .24278 L
.23434 .23176 L
.23768 .22389 L
.24102 .21575 L
.24436 .21904 L
.2477 .20638 L
.25104 .20813 L
.25439 .21661 L
.25773 .21759 L
.26107 .21476 L
.26441 .22153 L
.26775 .22435 L
.27109 .2248 L
.27444 .21939 L
.27778 .21284 L
.28112 .21369 L
.28446 .20589 L
.2878 .19704 L
.29114 .19833 L
.29449 .18165 L
.29783 .17956 L
.30117 .18134 L
.30451 .17386 L
.30785 .16341 L
.31119 .16809 L
.31454 .17314 L
.31788 .18477 L
.32122 .21041 L
.32456 .22359 L
.3279 .24851 L
.33124 .27219 L
.33459 .31068 L
.33793 .3454 L
.34127 .38675 L
.34461 .43132 L
.34795 .46842 L
.35129 .5118 L
.35464 .53948 L
Mistroke
.35798 .5637 L
.36132 .58403 L
.36466 .60332 L
.368 .59288 L
.37135 .57382 L
.37469 .55457 L
.37803 .53192 L
.38137 .49603 L
.38471 .44783 L
.38805 .39851 L
.3914 .3319 L
.39474 .26717 L
.39808 .21874 L
.40142 .17314 L
.40476 .1224 L
.4081 .08301 L
.41145 .04921 L
.41479 .02366 L
.41813 .01551 L
.42147 .02028 L
.42481 .01472 L
.42815 .02908 L
.4315 .04251 L
.43484 .05988 L
.43818 .07316 L
.44152 .08525 L
.44486 .11708 L
.4482 .13578 L
.45155 .16246 L
.45489 .17332 L
.45823 .18474 L
.46157 .19106 L
.46491 .20572 L
.46825 .19997 L
.4716 .1998 L
.47494 .21045 L
.47828 .20584 L
.48162 .20134 L
.48496 .18871 L
.4883 .17812 L
.49165 .17298 L
.49499 .17069 L
.49833 .18291 L
.50167 .18016 L
.50501 .1678 L
.50835 .16884 L
.5117 .16562 L
.51504 .18309 L
.51838 .19668 L
.52172 .19706 L
Mistroke
.52506 .18813 L
.5284 .19893 L
.53175 .20439 L
.53509 .20836 L
.53843 .20356 L
.54177 .20906 L
.54511 .21979 L
.54845 .218 L
.5518 .22376 L
.55514 .21257 L
.55848 .21515 L
.56182 .21682 L
.56516 .22247 L
.5685 .22087 L
.57185 .23082 L
.57519 .24521 L
.57853 .24354 L
.58187 .24733 L
.58521 .24036 L
.58855 .24008 L
.5919 .24928 L
.59524 .24559 L
.59858 .25287 L
.60192 .2499 L
.60526 .25287 L
.6086 .26118 L
.61195 .27788 L
.61529 .29438 L
.61863 .30052 L
.62197 .29564 L
.62531 .31235 L
.62865 .32801 L
.632 .32644 L
.63534 .32472 L
.63868 .32817 L
.64202 .33626 L
.64536 .34148 L
.64871 .34219 L
.65205 .34155 L
.65539 .34195 L
.65873 .34756 L
.66207 .34636 L
.66541 .34867 L
.66876 .34702 L
.6721 .34205 L
.67544 .33229 L
.67878 .32667 L
.68212 .31781 L
.68546 .31158 L
.68881 .29865 L
Mistroke
.69215 .30022 L
.69549 .29517 L
.69883 .28461 L
.70217 .27365 L
.70551 .26778 L
.70886 .26342 L
.7122 .27085 L
.71554 .25573 L
.71888 .25828 L
.72222 .24863 L
.72556 .26291 L
.72891 .25544 L
.73225 .25092 L
.73559 .25748 L
.73893 .26222 L
.74227 .2635 L
.74561 .26041 L
.74896 .26339 L
.7523 .26979 L
.75564 .28126 L
.75898 .27865 L
.76232 .2747 L
.76566 .27081 L
.76901 .26877 L
.77235 .26568 L
.77569 .26216 L
.77903 .26456 L
.78237 .24825 L
.78571 .24125 L
.78906 .22912 L
.7924 .22925 L
.79574 .21918 L
.79908 .20014 L
.80242 .19421 L
.80576 .18119 L
.80911 .18344 L
.81245 .18516 L
.81579 .1741 L
.81913 .1744 L
.82247 .16755 L
.82581 .18016 L
.82916 .16641 L
.8325 .16669 L
.83584 .17581 L
.83918 .17793 L
.84252 .18864 L
.84586 .1926 L
.84921 .20377 L
.85255 .20242 L
.85589 .20393 L
Mistroke
.85923 .20007 L
.86257 .20748 L
.86591 .21657 L
.86926 .21591 L
.8726 .22928 L
.87594 .23539 L
.87928 .23971 L
.88262 .23624 L
.88596 .24104 L
.88931 .24255 L
.89265 .24628 L
.89599 .24661 L
.89933 .24384 L
.90267 .23986 L
.90602 .23881 L
.90936 .24697 L
.9127 .24098 L
.91604 .23202 L
.91938 .2309 L
.92272 .23695 L
.92607 .23795 L
.92941 .22777 L
.93275 .23186 L
.93609 .23408 L
.93943 .22787 L
.94277 .22434 L
.94612 .21443 L
.94946 .20701 L
.9528 .20093 L
.95614 .20024 L
.95948 .20212 L
.96282 .20727 L
.96617 .21076 L
.96951 .2094 L
.97285 .21872 L
.97619 .21383 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`006goo00<007ooOol0ogoo0goo000KOol0
0`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`002goo00<007ooOol00Woo00<007ooOol0
0Woo0`000goo00<007ooOol0ogoo0goo000:Ool00`00Ool00009Ool00`00Oomoo`02Ool00`00Oomo
o`1VOol00`00Ool0002IOol000Eoo`<0009oo`03001oo`0000Moo`@000=oo`8006Ioo`04001oo`00
002IOol000Yoo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo06Eoo`05001oogooOol0002H
Ool000Yoo`03001oo`0000Qoo`8000Aoo`03001oogoo06Eoo`05001oogooOol0002HOol000]oo`03
001oogoo00Qoo`03001oogoo009oo`03001oogoo06Eoo`05001oogooOol0002HOol001]oo`03001o
ogoo06Eoo`05001oogooOol0002HOol001]oo`03001oogoo06Aoo`03001oogoo00=oo`03001oogoo
09Eoo`006goo00<007ooOol0I7oo00<007ooOol00goo00<007ooOol0UGoo000KOol2001UOol00`00
Oomoo`03Ool00`00Oomoo`2EOol001]oo`03001oogoo06Aoo`03001oogoo00=oo`03001oogoo09Eo
o`006goo00<007ooOol0I7oo00<007ooOol017oo00<007ooOol0U7oo000KOol00`00Oomoo`1TOol0
0`00Oomoo`04Ool00`00Oomoo`2DOol001]oo`03001oogoo06Aoo`03001oogoo00Aoo`03001oogoo
09Aoo`006goo00<007ooOol0I7oo00<007ooOol017oo00<007ooOol0U7oo000KOol2001UOol00`00
Oomoo`05Ool00`00Oomoo`2COol001]oo`03001oogoo06Aoo`03001oogoo00Eoo`03001oogoo09=o
o`006goo00<007ooOol0I7oo00<007ooOol01Goo00<007ooOol0Tgoo000KOol00`00Oomoo`1TOol0
0`00Oomoo`05Ool00`00Oomoo`2COol001]oo`03001oogoo06Aoo`03001oogoo00Eoo`03001oogoo
09=oo`006goo00<007ooOol0I7oo00<007ooOol01Goo00<007ooOol0Tgoo000KOol00`00Oomoo`1T
Ool00`00Oomoo`05Ool00`00Oomoo`2COol001]oo`8006Eoo`03001oogoo00Eoo`03001oogoo09=o
o`006goo00<007ooOol0I7oo00<007ooOol01Goo00<007ooOol0Tgoo000KOol00`00Oomoo`1TOol0
0`00Oomoo`06Ool00`00Oomoo`2BOol001]oo`03001oogoo06=oo`03001oogoo00Moo`03001oogoo
099oo`002goo00<007ooOol00Woo00@007ooOomoo`<000Aoo`03001oogoo06=oo`03001oogoo00Mo
o`03001oogoo099oo`002Woo00<007oo00001goo00<007ooOol017oo00<007ooOol0Hgoo00<007oo
Ool01goo00<007ooOol0TWoo0005Ool30002Ool00`00Ool00008Ool00`00Oomoo`03Ool2001TOol0
0`00Oomoo`07Ool00`00Oomoo`2BOol000Yoo`03001oo`0000Qoo`03001oogoo00=oo`03001oogoo
06=oo`03001oogoo00Moo`03001oogoo099oo`002Woo00<007oo00001goo00<007oo000017oo00<0
07ooOol0Hgoo00<007ooOol01goo00<007ooOol0TWoo000;Ool00`00Oomoo`07Ool00`00Oomoo`03
Ool00`00Oomoo`1SOol00`00Oomoo`08Ool00`00Oomoo`2AOol001]oo`03001oogoo06=oo`03001o
ogoo00Qoo`03001oogoo095oo`006goo00<007ooOol0Hgoo00<007ooOol027oo00<007ooOol0TGoo
000KOol2001TOol00`00Oomoo`08Ool00`00Oomoo`2AOol001]oo`03001oogoo06=oo`03001oogoo
00Qoo`03001oogoo095oo`006goo00<007ooOol0Hgoo00<007ooOol027oo00<007ooOol0TGoo000K
Ool00`00Oomoo`1ROol00`00Oomoo`0:Ool00`00Oomoo`2@Ool001]oo`03001oogoo069oo`03001o
ogoo00Yoo`03001oogoo091oo`006goo00<007ooOol0HWoo00<007ooOol02Woo00<007ooOol0T7oo
000KOol00`00Oomoo`19Ool00`00Oomoo`0FOol00`00Oomoo`0:Ool00`00Oomoo`2@Ool001]oo`80
04Yoo`8001Moo`03001oogoo00Yoo`03001oogoo00eoo`03001oogoo055oo`8002eoo`006goo00<0
07ooOol09Woo00<007ooOol00Woo00<007ooOol06Woo00<007oo00000goo1@000Woo00<007ooOol0
0Woo00<007ooOol01Goo00<007ooOol02goo00<007ooOol01goo1P0000=oo`00Ool00goo00<007oo
Ool07goo0`000goo00<007ooOol00Woo00<007ooOol06goo00<007oo00000`000goo00<007ooOol0
0Woo00<007ooOol087oo000KOol00`00Oomoo`0UOol00`00Ool00002Ool00`00Ool0000KOol01000
Oomoo`0017oo00L007ooOomoo`00Ool00002Ool00`00Ool00006Ool00`00Oomoo`0;Ool00`00Oomo
o`07Ool400001Goo000007oo00000Woo00<007oo000087oo00<007ooOol00Woo00<007oo00000Woo
00<007oo00006goo0`0000=oo`0000000goo00<007oo00000Woo00<007oo00008Goo000KOol00`00
Oomoo`0WOol01P00Oomoo`00Ool001Yoo`05001oogooOol00004Ool01`00Oomoogoo001oo`00009o
o`03001oo`0000Ioo`03001oogoo00]oo`03001oogoo00Ioo`04001oogoo0003Ool00`00Ool00002
Ool00`00Ool0000QOol01`00Oomoogoo001oo`00009oo`03001oo`0001]oo`03001oo`00009oo`80
00Aoo`06001oogoo001oo`008Goo000KOol00`00Oomoo`0UOol20003Ool00`00Ool0000HOol30004
Ool01@00Oomoogoo00000goo00<007oo00000Woo00<007oo00001Woo00<007ooOol037oo00<007oo
Ool01Goo00@007ooOol000=oo`8000=oo`03001oo`00025oo`07001oogooOol007oo00000Woo00<0
07oo000067oo00<007oo00000Woo00<007ooOol00P000Woo0P000goo00<007oo00008Goo000KOol0
0`00Oomoo`0UOol00`00Oomoo`02Ool00`00Ool0000HOol00`00Oomoo`04Ool01@00Oomoogoo0000
0goo00<007oo00000Woo00<007oo00001Woo00<007ooOol037oo00<007ooOol017oo00D007ooOomo
o`0000=oo`03001oogoo009oo`03001oo`00021oo`03001oo`00009oo`03001oo`00009oo`03001o
o`0001Qoo`<000Aoo`06001oo`00001oo`0017oo00<007oo00008Goo000KOol2000VOol30003Ool0
0`00Oomoo`0GOol00`00Oomoo`04Ool00`00Oomoo`020004Ool00`00Oomoo`02Ool00`00Oomoo`05
Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool00`00Oomoo`020003Ool40002Ool00`00Oomoo`0POol0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0FOol00`00Oomoo`06Ool01000Ool007oo0`00
0goo00<007ooOol087oo000KOol00`00Oomoo`15Ool00`00Oomoo`04Ool00`00Oomoo`0COol00`00
Oomoo`0=Ool00`00Oomoo`03Ool00`00Oomoo`06Ool30018Ool00`00Oomoo`09Ool00`00Oomoo`0W
Ool001]oo`03001oogoo04Aoo`8000Ioo`03001oogoo019oo`03001oogoo00ioo`03001oogoo009o
o`03001oogoo00Moo`<004Qoo`03001oogoo00Uoo`03001oogoo02Moo`006goo00<007ooOol0A7oo
0P001goo00<007ooOol04Goo00<007ooOol03goo0P000Woo00<007ooOol02Goo00<007ooOol0AGoo
00<007ooOol02goo00<007oo000067oo0P0037oo000KOol00`00Oomoo`0=Ool00`00Oomoo`0cOol0
0`00Oomoo`07Ool00`00Oomoo`0AOol00`00Oomoo`0?Ool200000goo001oo`0<Ool00`00Ool00014
Ool00`00Oomoo`0;Ool200000goo001oo`0EOol01000Oomoo`002goo000KOol01000Oomoogoo1@00
0goo0P0000Aoo`00Ool002Yoo`8000Qoo`03001oogoo00Moo`03001oogoo015oo`03001oogoo00mo
o`04001oo`00000>Ool00`00Ool00013Ool00`00Oomoo`0>Ool00`00Oomoo`0DOol01@00Oomoogoo
00002Woo000EOooo000<000001]oo`<000Ioo`<000Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03
001oogoo00Ioo`03001oogoo00Ioo`03001oogoo009oo`80009oo`03001oo`0000=oo`800003Ool0
07oo00Moo`03001oogoo00Eoo`03001oogoo00Ioo`04001oogoo0005Ool00`00Oomoo`06Ool00`00
Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`03Ool01000Oomoo`001goo00<007ooOol01Woo00<0
07ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo0P00
1Woo00<007ooOol01Woo00<007ooOol00P0017oo00<007ooOol01Woo00<007ooOol00goo00@007oo
Ool000=oo`8000=oo`03001oogoo005oo`006goo00<007oo00001goo00<007ooOol01Goo00<007oo
Ool05goo00<007ooOol02Woo00<007oo00000Woo0`000Woo00<007ooOol02Woo00<007ooOol01Goo
00<007ooOol02Goo00<007ooOol07Woo00<007ooOol00goo0`0000=oo`00Ool087oo00<007ooOol0
6Goo00<007ooOol03Goo00<007ooOol00P004goo00<007ooOol017oo00<007ooOol01Woo000KOol0
0`00Oomoo`0?Ool00`00Oomoo`0TOol00`00Oomoo`04Ool00`00Ool0000=Ool00`00Oomoo`0AOol0
0`00Oomoo`0VOol00`00Oomoo`02000kOol00`00Oomoo`0BOol00`00Oomoo`0?Ool00`00Oomoo`0>
Ool001]oo`03001oogoo00moo`03001oogoo02Aoo`03001oogoo00Eoo`8000eoo`03001oogoo015o
o`03001oogoo02]oo`03001oogoo03Moo`03001oogoo01=oo`03001oogoo00aoo`04001oogoo000@
Ool001]oo`03001oogoo00moo`03001oogoo02Aoo`03001oogoo01Aoo`03001oogoo015oo`03001o
ogoo02]oo`03001oogoo03Moo`03001oogoo01=oo`03001oogoo00Uoo`03001oogoo00<0015oo`00
6goo00<007ooOol047oo00<007ooOol08goo00<007ooOol057oo00<007ooOol04Goo00<007ooOol0
:goo00<007ooOol0=goo00<007ooOol057oo00<007ooOol01goo00D007oo000007oo0080015oo`00
6goo0P004Goo00<007ooOol08Woo00<007ooOol05Woo00<007ooOol047oo00<007ooOol0;7oo00<0
07ooOol0=Goo00<007ooOol05Goo0P001Woo0P000Woo0P0057oo000KOol00`00Oomoo`0@Ool2000S
Ool00`00Oomoo`0FOol00`00Oomoo`0@Ool00`00Oomoo`0/Ool01000Oomoo`00=7oo00<007ooOol0
5Goo00@007oo000000=oo`<001Qoo`006goo00<007ooOol04Woo00<007ooOol087oo00<007ooOol0
5Woo00<007ooOol03goo00<007ooOol0;Goo0`0000=oo`000000<Goo00<007ooOol06Woo0`0000=o
o`00Ool067oo000KOol00`00Oomoo`0BOol00`00Oomoo`0POol00`00Oomoo`0FOol00`00Oomoo`0?
Ool00`00Oomoo`0_Ool01000Ool007oo0P007goo00<007ooOol03Goo00<007ooOol07Woo00<007oo
Ool05goo000KOol00`00Oomoo`0BOol00`00Oomoo`0OOol00`00Oomoo`0GOol00`00Oomoo`0?Ool0
0`00Oomoo`0cOol00`00Ool0000NOol01000Oomoo`0037oo00<007ooOol0>7oo000KOol00`00Oomo
o`0COol00`00Oomoo`0NOol00`00Oomoo`0GOol00`00Oomoo`0?Ool00`00Oomoo`0fOol00`00Oomo
o`0IOol2000017oo000000002goo00<007ooOol0>Goo000KOol2000DOol00`00Oomoo`0NOol00`00
Oomoo`0HOol00`00Oomoo`0>Ool00`00Oomoo`0fOol00`00Oomoo`0IOol200001goo001oogoo001o
o`0000Qoo`03001oogoo03Uoo`006goo00<007ooOol057oo00<007ooOol077oo0P006Woo00<007oo
Ool03Woo00<007ooOol0=Woo00<007ooOol05goo0P000goo00<007ooOol00P0000=oo`00Ool01Goo
0P00>goo000KOol00`00Oomoo`0DOol00`00Oomoo`0KOol00`00Oomoo`0JOol00`00Oomoo`0>Ool0
0`00Oomoo`0fOol00`00Oomoo`0FOol00`00Ool0000:Ool01000Oomoogoo0P00?Goo000KOol00`00
Oomoo`0DOol00`00Oomoo`0KOol00`00Oomoo`0JOol00`00Oomoo`0>Ool00`00Oomoo`0gOol00`00
Oomoo`0EOol00`00Ool0000:Ool01000Oomoo`00?goo000KOol00`00Oomoo`0EOol00`00Oomoo`0I
Ool00`00Oomoo`0KOol00`00Oomoo`0>Ool00`00Oomoo`0gOol00`00Oomoo`0EOol00`00Oomoo`0:
Ool00`00Ool00010Ool001]oo`03001oogoo01Eoo`03001oogoo01Uoo`03001oogoo01]oo`03001o
ogoo00ioo`03001oogoo03Moo`03001oogoo01Eoo`03001oogoo00]oo`80041oo`006goo00<007oo
Ool05Goo00<007ooOol06Goo00<007ooOol06goo00<007ooOol03Woo00<007ooOol0=goo00<007oo
Ool057oo00<007ooOol037oo00<007ooOol0?goo000KOol2000FOol00`00Oomoo`0HOol00`00Oomo
o`0LOol00`00Oomoo`0>Ool00`00Oomoo`0hOol00`00Oomoo`0COol00`00Oomoo`1>Ool001]oo`03
001oogoo01Ioo`03001oogoo01Moo`03001oogoo01eoo`03001oogoo00eoo`03001oogoo03Qoo`03
001oogoo019oo`03001oogoo04moo`006goo00<007ooOol05Woo00<007ooOol05goo00<007ooOol0
7Goo00<007ooOol03Goo00<007ooOol0>7oo0P004goo00<007ooOol0Cgoo000KOol00`00Oomoo`0F
Ool00`00Oomoo`0FOol00`00Oomoo`0NOol00`00Oomoo`0=Ool00`00Oomoo`0hOol2000AOol2001B
Ool000]oo`03001oogoo009oo`04001oogooOol30004Ool00`00Oomoo`0GOol00`00Oomoo`0EOol0
0`00Oomoo`0NOol00`00Oomoo`0<Ool00`00Oomoo`0iOol2000AOol2001BOol000Yoo`03001oo`00
00Moo`03001oogoo00Aoo`03001oogoo01Moo`03001oogoo01Eoo`03001oogoo01ioo`03001oogoo
00aoo`03001oogoo03]oo`03001oogoo00eoo`03001oogoo059oo`002Woo00<007oo000027oo00<0
07ooOol00goo0P0067oo00<007ooOol057oo00<007ooOol07goo00<007ooOol037oo00<007ooOol0
>goo00<007ooOol03Goo00<007ooOol0DWoo000:Ool00`00Ool00008Ool00`00Oomoo`03Ool00`00
Oomoo`0GOol00`00Oomoo`0DOol00`00Oomoo`0OOol00`00Oomoo`0<Ool00`00Oomoo`0kOol00`00
Oomoo`0=Ool00`00Oomoo`1BOol000Yoo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo01Mo
o`03001oogoo01Aoo`03001oogoo01moo`03001oogoo00aoo`03001oogoo03]oo`03001oogoo00ao
o`03001oogoo05=oo`002goo00<007ooOol01goo00<007ooOol00goo00<007ooOol05goo00<007oo
Ool057oo00<007ooOol07goo00<007ooOol037oo00<007ooOol0?7oo00<007ooOol02goo00<007oo
Ool0Dgoo000KOol00`00Oomoo`0HOol00`00Oomoo`0COol00`00Oomoo`0OOol00`00Oomoo`0<Ool0
0`00Oomoo`0lOol00`00Ool0000:Ool00`00Oomoo`1DOol001]oo`03001oogoo01Qoo`03001oogoo
01=oo`03001oogoo021oo`03001oogoo00]oo`03001oogoo03aoo`800003Ool007oo00Qoo`03001o
ogoo05Aoo`006goo0P006Goo00<007ooOol04goo00<007ooOol087oo00<007ooOol02goo00<007oo
Ool0@7oo00<007ooOol01Goo00<007ooOol0EGoo000KOol00`00Oomoo`0HOol00`00Oomoo`0COol0
0`00Oomoo`0POol00`00Oomoo`0;Ool00`00Oomoo`10Ool00`00Oomoo`05Ool00`00Oomoo`1EOol0
01]oo`03001oogoo01Uoo`03001oogoo019oo`03001oogoo021oo`03001oogoo00]oo`03001oogoo
041oo`03001oogoo00Eoo`03001oogoo05Eoo`006goo00<007ooOol06Goo00<007ooOol04Goo00<0
07ooOol08Goo00<007ooOol02goo00<007ooOol0@7oo100017oo00<007ooOol0EGoo000KOol00`00
Oomoo`0IOol00`00Oomoo`0@Ool2000SOol00`00Oomoo`0;Ool00`00Oomoo`14Ool200000goo001o
o`1GOol001]oo`03001oogoo01Yoo`03001oogoo00moo`03001oogoo029oo`03001oogoo00]oo`03
001oogoo04Ioo`03001oogoo05Moo`006goo00<007ooOol06goo00<007ooOol03Woo00<007ooOol0
8Woo00<007ooOol02goo00<007ooOol0X7oo000KOol2000LOol00`00Oomoo`0>Ool00`00Oomoo`0R
Ool00`00Oomoo`0;Ool00`00Oomoo`2POol001]oo`03001oogoo01]oo`03001oogoo00eoo`03001o
ogoo02=oo`03001oogoo00]oo`03001oogoo0:1oo`006goo00<007ooOol077oo00<007ooOol037oo
00<007ooOol08goo00<007ooOol02Woo00<007ooOol0XGoo000KOol00`00Oomoo`0LOol00`00Oomo
o`0<Ool00`00Oomoo`0TOol00`00Oomoo`09Ool00`00Oomoo`2QOol001]oo`03001oogoo01aoo`03
001oogoo00aoo`03001oogoo02Aoo`03001oogoo00Uoo`03001oogoo0:5oo`006goo00<007ooOol0
77oo00<007ooOol037oo00<007ooOol097oo00<007ooOol02Goo00<007ooOol0XGoo000KOol2000N
Ool00`00Oomoo`0;Ool00`00Oomoo`0TOol00`00Oomoo`09Ool00`00Oomoo`2QOol001]oo`03001o
ogoo01eoo`03001oogoo00Yoo`03001oogoo02Eoo`03001oogoo00Uoo`03001oogoo0:5oo`006goo
00<007ooOol07Goo00<007ooOol02Woo00<007ooOol09Goo00<007ooOol02Goo00<007ooOol0XGoo
000KOol00`00Oomoo`0NOol00`00Oomoo`09Ool00`00Oomoo`0UOol00`00Oomoo`09Ool00`00Oomo
o`2QOol001]oo`03001oogoo01ioo`03001oogoo00Uoo`03001oogoo02Eoo`03001oogoo00Uoo`03
001oogoo0:5oo`002goo00<007ooOol00Woo00<007ooOol00Woo0`000goo00<007ooOol07Woo00<0
07ooOol027oo00<007ooOol09Woo00<007ooOol02Goo00<007ooOol0XGoo000:Ool00`00Ool00009
Ool00`00Oomoo`02Ool00`00Oomoo`0NOol00`00Oomoo`08Ool00`00Oomoo`0VOol00`00Oomoo`09
Ool00`00Oomoo`2QOol000Yoo`03001oo`0000Moo`@000=oo`8001moo`03001oogoo00Qoo`03001o
ogoo02Ioo`03001oogoo00Uoo`03001oogoo0:5oo`002Woo00<007oo00001goo00<007oo000017oo
00<007ooOol07Woo00<007ooOol01Woo0P00:Woo00<007ooOol027oo00<007ooOol0XGoo000:Ool0
0`00Ool00008Ool20004Ool00`00Oomoo`0OOol00`00Oomoo`04Ool00`00Ool0000ZOol00`00Oomo
o`08Ool00`00Oomoo`2QOol000]oo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo01moo`03
001oogoo00Aoo`03001oo`0002Yoo`03001oogoo00Qoo`03001oogoo0:5oo`006goo00<007ooOol0
87oo00<007ooOol00goo00<007ooOol0:Woo00<007ooOol027oo00<007ooOol0XGoo000KOol00`00
Oomoo`0POol00`00Oomoo`03Ool00`00Oomoo`0ZOol00`00Oomoo`07Ool00`00Oomoo`2ROol001]o
o`80025oo`07001oogooOol007oo0000;7oo00<007ooOol01goo00<007ooOol0XWoo000KOol00`00
Oomoo`0QOol01000Ool007oo0P00;7oo00<007ooOol01goo00<007ooOol0XWoo000KOol00`00Oomo
o`0QOol2000`Ool00`00Oomoo`07Ool00`00Oomoo`2ROol001]oo`03001oogoo05=oo`03001oogoo
00Moo`03001oogoo0:9oo`006goo00<007ooOol0Dgoo00<007ooOol01goo00<007ooOol0XWoo000K
Ool00`00Oomoo`1DOol00`00Oomoo`06Ool00`00Oomoo`2ROol001]oo`8005Eoo`03001oogoo00Io
o`03001oogoo0:9oo`006goo00<007ooOol0E7oo00<007ooOol01Woo00<007ooOol0XWoo000KOol0
0`00Oomoo`1DOol00`00Oomoo`06Ool00`00Oomoo`2ROol001]oo`03001oogoo05Aoo`03001oogoo
00Ioo`03001oogoo0:9oo`006goo00<007ooOol0E7oo00<007ooOol01Woo00<007ooOol0XWoo000K
Ool00`00Oomoo`1DOol00`00Oomoo`06Ool00`00Oomoo`2ROol001]oo`03001oogoo05Aoo`03001o
ogoo00Eoo`03001oogoo0:=oo`006goo0P00EGoo00<007ooOol01Goo00<007ooOol0Xgoo000KOol0
0`00Oomoo`1DOol00`00Oomoo`05Ool00`00Oomoo`2SOol001]oo`03001oogoo05Aoo`03001oogoo
00Eoo`03001oogoo0:=oo`006goo00<007ooOol0EGoo00<007ooOol017oo00<007ooOol0Xgoo000;
Ool00`00Oomoo`02Ool01000Oomoogoo0P001Goo00<007ooOol0EGoo00<007ooOol017oo00<007oo
Ool0Xgoo000:Ool00`00Ool00007Ool00`00Ool00004Ool00`00Oomoo`1EOol00`00Oomoo`04Ool0
0`00Oomoo`2SOol000Yoo`03001oo`0000Moo`03001oo`0000Aoo`8005Ioo`03001oogoo00Aoo`03
001oogoo0:=oo`002Woo00<007oo00001goo0P001Goo00<007ooOol0EGoo00<007ooOol017oo00<0
07ooOol0Xgoo000:Ool00`00Ool00007Ool00`00Oomoo`04Ool00`00Oomoo`1EOol00`00Oomoo`04
Ool00`00Oomoo`2SOol000]oo`03001oogoo00Moo`8000Aoo`03001oogoo05Eoo`03001oogoo00Ao
o`03001oogoo0:=oo`006goo00<007ooOol0EGoo00<007ooOol017oo00<007ooOol0Xgoo000KOol0
0`00Oomoo`1EOol00`00Oomoo`04Ool00`00Oomoo`2SOol001]oo`8005Ioo`03001oogoo00Aoo`03
001oogoo0:=oo`006goo00<007ooOol0EGoo00<007ooOol017oo00<007ooOol0Xgoo000KOol00`00
Oomoo`1EOol00`00Oomoo`04Ool00`00Oomoo`2SOol001]oo`03001oogoo05Eoo`03001oogoo00Ao
o`03001oogoo0:=oo`006goo00<007ooOol0EGoo00<007ooOol017oo00<007ooOol0Xgoo000KOol0
0`00Oomoo`1EOol00`00Oomoo`03Ool00`00Oomoo`2TOol001]oo`03001oogoo05Eoo`03001oogoo
00=oo`03001oogoo0:Aoo`006goo0P00EWoo00<007ooOol00goo00<007ooOol0Y7oo000KOol00`00
Oomoo`1FOol00`00Oomoo`02Ool00`00Oomoo`2TOol001]oo`03001oogoo05Ioo`03001oogoo009o
o`03001oogoo0:Aoo`006goo00<007ooOol0EWoo00<007ooOol00Woo00<007ooOol0Y7oo000KOol0
0`00Oomoo`1FOol01@00Oomoogoo0000Ygoo000KOol00`00Oomoo`1FOol01@00Oomoogoo0000Ygoo
000KOol2001GOol01@00Oomoogoo0000Ygoo000KOol00`00Oomoo`1GOol01000Oomoo`00Ygoo000K
Ool00`00Oomoo`1GOol01000Oomoo`00Ygoo000KOol00`00Oomoo`1GOol00`00Ool0002XOol001]o
o`03001oogoo05Moo`03001oo`000:Qoo`002goo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol0Egoo00<007oo0000Z7oo000:Ool00`00Ool00007Ool00`00Ool00004Ool0
0`00Oomoo`1HOol2002XOol000Yoo`03001oo`0000Moo`03001oo`0000Aoo`8005Uoo`03001oogoo
0:Moo`002Woo00<007oo000027oo00<007ooOol00goo00<007ooOol0F7oo00<007ooOol0Ygoo000:
Ool00`00Ool00007Ool00`00Ool00004Ool00`00Oomoo`3oOol3Ool000]oo`03001oogoo00Moo`03
001oogoo00=oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3o
Ool3Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{86.5, 373.5}, {262.375, 85.4375}} -> {-128.471, 
  0.176289, 1.12877, 0.00783327}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["PROBLEM SOLUTIONS", "Subtitle",
  FontFamily->"Arial"],

Cell[CellGroupData[{

Cell["Problem 1", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "Calculate the coefficients ",
  StyleBox["{c[0],c[1],c[2]}",
    FontWeight->"Bold"],
  " using the data samples in Section 2. Compare with the coefficients \
obtained with the ",
  StyleBox["Fit",
    FontWeight->"Bold"],
  " function."
}], "Text",
  FontFamily->"Times New Roman"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Solution.",
    FontWeight->"Bold"],
  " Repeating the calculations from section 2."
}], "Text",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[BoxData[
    \(data = {{\(-2\), 1.}, {\(-1\), 0.46}, {0, 1.2}, {1, 0.8}, {2, 1.55}}; \n
    Fit[data, {1, m, m^2}, m]\)], "Input"],

Cell["\<\
0.7962857142857138 + 0.1440000000000001*m + 0.1028571428571428*m^2\
\>", "Output"]
}, Open  ]],

Cell["\<\
Equivalently, the three coefficients may be obtained directly from\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transpose[G].Last[Transpose[data]]\)], "Input"],

Cell["{0.7962857142857141, 0.144, 0.1028571428571428}", "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problem 2", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell["\<\
Obtain the coefficients of an SG filter of order 1. Comment on the result.\
\>", "Text",
  FontFamily->"Times New Roman"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Solution. ",
    FontWeight->"Bold"],
  "A SG filter of order 1 is equivalent to an MA filter of the same length."
}], "Text",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SavitzkyGolayCoefficients[5, 1]\)], "Input"],

Cell["{1/5, 1/5, 1/5, 1/5, 1/5}", "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problem 3", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell["\<\
Plot the frequency response of the SG filter of length 5 and order 2. Compare \
with the length 5 MA filter as to bandwidth and peak attenuation.\
\>", "Text",
  FontFamily->"Times New Roman"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["HOMEWORK PROBLEMS", "Subtitle",
  FontFamily->"Arial"],

Cell["Homework Problem 1", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell["\<\
Analyze the frequency domain and pole-zero characteristics of SG filters as a \
function of length and order.\
\>", "Text",
  FontFamily->"Times New Roman"]
}, Closed]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{532, 571},
WindowMargins->{{273, Automatic}, {Automatic, 6}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 62, 1, 105, "Title"],
Cell[1774, 52, 148, 5, 64, "Subtitle",
  Evaluatable->False],
Cell[1925, 59, 174, 5, 53, "Subsubtitle",
  Evaluatable->False],
Cell[2102, 66, 307, 11, 53, "Subsubtitle",
  Evaluatable->False],
Cell[2412, 79, 383, 15, 89, "Subsubtitle",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2820, 98, 54, 1, 53, "Section"],
Cell[2877, 101, 977, 16, 223, "Text"],

Cell[CellGroupData[{
Cell[3879, 121, 65, 1, 43, "Subsection"],
Cell[3947, 124, 268, 6, 40, "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[4264, 136, 76, 1, 33, "Section"],
Cell[4343, 139, 286, 5, 71, "Text"],

Cell[CellGroupData[{
Cell[4654, 148, 138, 5, 48, "Subsection"],
Cell[4795, 155, 485, 12, 54, "Text"],

Cell[CellGroupData[{
Cell[5305, 171, 104, 2, 22, "Input"],
Cell[5412, 175, 944, 27, 22, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6393, 207, 201, 4, 60, "Input"],
Cell[6597, 213, 366, 6, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7000, 224, 332, 6, 72, "Input"],
Cell[7335, 232, 13401, 528, 148, 5977, 432, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[20751, 763, 518, 9, 69, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21306, 777, 96, 1, 43, "Subsection"],
Cell[21405, 780, 909, 21, 97, "Text"],
Cell[22317, 803, 87, 1, 22, "Input"],
Cell[22407, 806, 76, 1, 26, "Text"],

Cell[CellGroupData[{
Cell[22508, 811, 70, 1, 38, "Input"],
Cell[22581, 814, 193, 5, 52, "Output"]
}, Open  ]],
Cell[22789, 822, 404, 13, 40, "Text"],

Cell[CellGroupData[{
Cell[23218, 839, 186, 3, 22, "Input"],
Cell[23407, 844, 210, 5, 52, "Output"]
}, Open  ]],
Cell[23632, 852, 76, 1, 26, "Text"],

Cell[CellGroupData[{
Cell[23733, 857, 65, 1, 22, "Input"],
Cell[23801, 860, 177, 4, 41, "Output"]
}, Open  ]],
Cell[23993, 867, 416, 11, 40, "Text"],
Cell[24412, 880, 74, 1, 22, "Input"],
Cell[24489, 883, 170, 4, 26, "Text"],

Cell[CellGroupData[{
Cell[24684, 891, 67, 1, 34, "Subsubsection"],
Cell[24754, 894, 301, 10, 40, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[25104, 910, 104, 1, 43, "Subsection"],
Cell[25211, 913, 332, 6, 54, "Text"],

Cell[CellGroupData[{
Cell[25568, 923, 101, 2, 34, "Input"],
Cell[25672, 927, 74, 1, 22, "Output"]
}, Open  ]],
Cell[25761, 931, 155, 4, 26, "Text"],

Cell[CellGroupData[{
Cell[25941, 939, 69, 1, 34, "Input"],
Cell[26013, 942, 52, 1, 22, "Output"]
}, Open  ]],
Cell[26080, 946, 215, 5, 40, "Text"],
Cell[26298, 953, 182, 4, 34, "Input"],

Cell[CellGroupData[{
Cell[26505, 961, 46, 1, 22, "Input"],
Cell[26554, 964, 264, 9, 67, "Output"]
}, Open  ]],
Cell[26833, 976, 987, 27, 138, "Text"],
Cell[27823, 1005, 100, 1, 26, "Text"],
Cell[27926, 1008, 68, 1, 22, "Input"],

Cell[CellGroupData[{
Cell[28019, 1013, 46, 1, 22, "Input"],
Cell[28068, 1016, 375, 9, 82, "Output"]
}, Open  ]],
Cell[28458, 1028, 314, 6, 54, "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[28821, 1040, 84, 1, 33, "Section"],
Cell[28908, 1043, 80, 1, 33, "Text"],
Cell[28991, 1046, 50, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[29066, 1051, 99, 2, 30, "Input"],
Cell[29168, 1055, 562, 8, 71, "Print"]
}, Open  ]],
Cell[29745, 1066, 230, 6, 26, "Text"],

Cell[CellGroupData[{
Cell[30000, 1076, 70, 1, 22, "Input"],
Cell[30073, 1079, 90, 1, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30200, 1085, 67, 1, 34, "Subsubsection"],
Cell[30270, 1088, 131, 3, 26, "Text"]
}, Open  ]],
Cell[30416, 1094, 109, 1, 26, "Text"],
Cell[30528, 1097, 60, 1, 22, "Input"],

Cell[CellGroupData[{
Cell[30613, 1102, 78, 1, 22, "Input"],
Cell[30694, 1105, 148, 3, 31, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30879, 1113, 55, 1, 22, "Input"],
Cell[30937, 1116, 41030, 1072, 236, 9410, 677, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[72004, 2193, 67, 1, 34, "Subsubsection"],
Cell[72074, 2196, 202, 4, 40, "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[72325, 2206, 84, 1, 33, "Section"],
Cell[72412, 2209, 272, 5, 71, "Text"],
Cell[72687, 2216, 66, 1, 22, "Input"],
Cell[72756, 2219, 112, 2, 22, "Input"],

Cell[CellGroupData[{
Cell[72893, 2225, 93, 1, 22, "Input"],
Cell[72989, 2228, 37215, 849, 148, 6942, 471, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[110219, 3080, 136, 3, 34, "Input"],

Cell[CellGroupData[{
Cell[110380, 3087, 88, 1, 22, "Input"],
Cell[110471, 3090, 31850, 841, 148, 7926, 541, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[142336, 3934, 128, 3, 26, "Text"],
Cell[142467, 3939, 167, 3, 34, "Input"],

Cell[CellGroupData[{
Cell[142659, 3946, 88, 1, 22, "Input"],
Cell[142750, 3949, 23955, 733, 148, 7912, 531, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[166754, 4688, 60, 1, 53, "Subtitle"],

Cell[CellGroupData[{
Cell[166839, 4693, 67, 1, 43, "Subsubsection"],
Cell[166909, 4696, 301, 10, 52, "Text"]
}, Open  ]],
Cell[167225, 4709, 157, 5, 33, "Text"],

Cell[CellGroupData[{
Cell[167407, 4718, 135, 2, 50, "Input"],
Cell[167545, 4722, 92, 2, 29, "Output"]
}, Open  ]],
Cell[167652, 4727, 123, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[167800, 4734, 67, 1, 30, "Input"],
Cell[167870, 4737, 65, 0, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[167972, 4742, 67, 1, 43, "Subsubsection"],
Cell[168042, 4745, 131, 3, 33, "Text"]
}, Open  ]],
Cell[168188, 4751, 187, 5, 33, "Text"],

Cell[CellGroupData[{
Cell[168400, 4760, 64, 1, 30, "Input"],
Cell[168467, 4763, 43, 0, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[168547, 4768, 67, 1, 43, "Subsubsection"],
Cell[168617, 4771, 202, 4, 52, "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[168868, 4781, 60, 1, 53, "Subtitle"],
Cell[168931, 4784, 76, 1, 43, "Subsubsection"],
Cell[169010, 4787, 166, 4, 52, "Text"]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

