(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    220603,       4709]*)
(*NotebookOutlinePosition[    221573,       4742]*)
(*  CellTagsIndexPosition[    221529,       4738]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["BINARY MORPHOLOGY", "Title"],

Cell["ELE489: DIGITAL IMAGE PROCESSING", "Subsubtitle"],

Cell["\<\
Mariusz Jankowski \[Copyright]
Department of Electrical Engineering
University of Southern Maine
mjkcc@usm.maine.edu\
\>", "Subsubtitle"],

Cell[BoxData[{
    \(<< ImageProcessing`\), 
    \(<< LinearAlgebra`MatrixManipulation`\)}], "Input"],

Cell[CellGroupData[{

Cell["INTRODUCTION", "Section"],

Cell["\<\
Mathematical morphology provides an approach to the processing of digital \
images which is based on shape. The operations of mathematical morphology \
relate directly to shape, therefore, for selected applications in image \
processing, they may be more useful than convolution operations. In this \
document, the basic operators of binary morphology are presented.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["BINARY EROSION AND DILATION", "Section"],

Cell["\<\
The fundamental operators of binary morphology are erosion and dilation. \
These operators will be implemented from their set-theoretic definitions.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Set Description of a Binary Image", "Subsection"],

Cell["\<\
The language of mathematical morphology is that of set theory. Sets in \
mathematical morphology represent the shapes which are visible on binary or \
gray tone images. Here we will restrict the discussion to binary images. The \
set of all the white (or black) pixels in a binary image constitutes a \
complete description of the image. Each element of the set is a 2-tuple of \
integer values identifying the cartesian coordinates of each white (or black) \
pixel.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(A = {{0, 1, 0, 0, 0}, {0, 1, 1, 0, 0}, {0, 1, 1, 1, 0}, {0, 1, 0, 0, 
          0}, {0, 0, 0, 0, 0}}; \nMatrixForm[A]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"0", "1", "0", "0", "0"},
            {"0", "1", "1", "0", "0"},
            {"0", "1", "1", "1", "0"},
            {"0", "1", "0", "0", "0"},
            {"0", "0", "0", "0", "0"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell["Here is the set description of the above image.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Position[A, 1]\)], "Input"],

Cell[BoxData[
    \({{1, 2}, {2, 2}, {2, 3}, {3, 2}, {3, 3}, {3, 4}, {4, 2}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The complement set can be obtained by selecting the zeros or by computing \
the set complement which in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can also be easily done."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Position[A, 0]\)], "Input"],

Cell[BoxData[
    \({{1, 1}, {1, 3}, {1, 4}, {1, 5}, {2, 1}, {2, 4}, {2, 5}, {3, 1}, {3, 
        5}, {4, 1}, {4, 3}, {4, 4}, {4, 5}, {5, 1}, {5, 2}, {5, 3}, {5, 4}, {
        5, 5}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Now define the global set, which is the set of all coordinate pairs of an \
",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalN]\_1\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalN]\_2\)]],
  " image."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(s = Flatten[Outer[{#1, #2}&, Range[5], Range[5]], 1]\)], "Input"],

Cell[BoxData[
    \({{1, 1}, {1, 2}, {1, 3}, {1, 4}, {1, 5}, {2, 1}, {2, 2}, {2, 3}, {2, 
        4}, {2, 5}, {3, 1}, {3, 2}, {3, 3}, {3, 4}, {3, 5}, {4, 1}, {4, 2}, {
        4, 3}, {4, 4}, {4, 5}, {5, 1}, {5, 2}, {5, 3}, {5, 4}, {5, 5}}\)], 
  "Output"]
}, Open  ]],

Cell["The set complement is then", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Complement[s, Position[A, 1]]\)], "Input"],

Cell[BoxData[
    \({{1, 1}, {1, 3}, {1, 4}, {1, 5}, {2, 1}, {2, 4}, {2, 5}, {3, 1}, {3, 
        5}, {4, 1}, {4, 3}, {4, 4}, {4, 5}, {5, 1}, {5, 2}, {5, 3}, {5, 4}, {
        5, 5}}\)], "Output"]
}, Open  ]],

Cell["Here we view the complement image.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FromSets[%, {5, 5}]\  // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"1", "0", "1", "1", "1"},
            {"1", "0", "0", "1", "1"},
            {"1", "0", "0", "0", "1"},
            {"1", "0", "1", "1", "1"},
            {"1", "1", "1", "1", "1"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
A translation of a set is the vector sum of the elements of a set with a \
translation vector. Consider a translation of image A by the vector {1,1}.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FromSets[\((\ #1 + {1, 1}\ &)\)\ /@\ Position[A, 1], \ {5, 5}]\  // 
      MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "0", "0", "0"},
            {"0", "0", "1", "0", "0"},
            {"0", "0", "1", "1", "0"},
            {"0", "0", "1", "1", "1"},
            {"0", "0", "1", "0", "0"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problem 1", "Exercise"],

Cell["Obtain the set description of the following binary image.", 
  "ExerciseText"],

Cell[BoxData[
    \(\(X = {{0, 0, 0, 0, 0}, {0, 1, 1, 1, 0}, {0, 0, 1, 0, 0}, {0, 0, 1, 0, 
          0}, {0, 0, 0, 0, 0}}; \)\)], "Input"]
}, Open  ]],

Cell["\<\
Now, the fundamental operators of binary morphology: dilation and erosion, \
can be defined. The set theoretic formulations will be used (see Gonzalez and \
Woods, pp. 518-524, and p. 568 (Problems 8.19, 8.20) and Haralick, Sternberg \
and Zhuang, \"Image analysis using mathematical morphology\", IEEE-PAMI, 9, \
July 1987, pp. 532-550).\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Binary Dilation", "Subsection"],

Cell["\<\
Dilation is the morphological transformation that combines two sets by using \
vector addition of set elements. Following common practice, we use the \
definition that is equivalent to Minkowski addition (reference).  \
\>", "Text"],

Cell[TextData[
"Binary dilation of set A by set B (called the structuring element), denoted \
A \[CirclePlus] B, is the union of all sets of vector sums of pairs of \
elements, one coming from A, the other from B. "], "Definition"],

Cell["\<\
The output of a dilation operation is an image C that is the set of all \
displacements x of the structuring element B such that B and A overlap by at \
least one nonzero element. In this sense dilation is similar to convolution, \
since a small kernel (i.e. the structuring element) is scanned over an image \
and the resulting value at position {i, j} is determined based on a local \
operation. The algebraic operations of summation and multiplication are \
however replaced by the logical operations OR and AND, respectively.\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm
    \`C(n, \ m)\  = \ 
      \(\[Union]\_\(i = \(-1\)\)\%1\(\[Union]\_\(j = \(-1\)\)\%1\ 
            B(i, \ j)\)\)\  \[Intersection] \ A(n - i, \ m - j)\)]]], 
  "NumberedEquation"],

Cell[CellGroupData[{

Cell["Problem 2", "Exercise"],

Cell["\<\
Use hand calculation to obtain the dilation of the image A by the structuring \
element B given below.\
\>", "ExerciseText"],

Cell[BoxData[
    \(\(B = {{0, 0, 0}, {0, 1, 1}, {0, 1, 0}}; \)\)], "Input"]
}, Open  ]],

Cell["Here is the result.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dilate[A, B]\  // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"0", "1", "1", "0", "0"},
            {"0", "1", "1", "1", "0"},
            {"0", "1", "1", "1", "1"},
            {"0", "1", "1", "1", "0"},
            {"0", "1", "0", "0", "0"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Binary Erosion", "Subsection"],

Cell["\<\
Erosion is a morphological dual to dilation. The erosion of image A with \
structuring element B, is a set of all elements x for which the reflection of \
B translated to x is contained in A.\
\>", "Text"],

Cell[TextData[
"The erosion of set A by set B, denoted A \[CircleMinus] B, is the set \
intersection of all sets of  vector sums of pairs of elements coming from A \
and B."], "Definition"],

Cell["\<\
Equivalently, erosion may be defined by the following \"convolution\" like \
formulation.\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm
    \`C(n, \ m)\  = \ 
      \(\[Intersection]\_\(i = \(-1\)\)\%1
            \(\[Intersection]\_\(j = \(-1\)\)\%1\ B(\(-i\), \ \(-j\))\)\)\  
        \[Union] \ A(n - i, \ m - j)\)]]], "NumberedEquation"],

Cell["\<\
where the AND operation is performed over only those indeces i,j for which \
elements of B that are equal to 1, meaning that only the logical ones of B \
have to match the logical ones of A, as B is scanned over A. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Erode[A, B]\  // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "0", "0", "0"},
            {"0", "1", "0", "0", "0"},
            {"0", "1", "0", "0", "0"},
            {"0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
Duality between erosion and dilation is defined by the following \
relationship:\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\ 
    \(A\[CircleMinus]B\)\&_ = \ A\&_\ \[CirclePlus]\ \(B\&\[Vee]\)\)\)]]], 
  "Definition"],

Cell[TextData[{
  "where the symbol ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Placeholder]\&\[Vee]\)\)]],
  " denotes reflection. The operation ",
  Cell[BoxData[
      \(TraditionalForm\`\(( . )\)\&_\)]],
  " represents a binary complement of the elements of the array."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((1 - Erode[A, B])\)\  == \ Dilate[1 - \ A\ , \ Reflect[B]]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Real Image Examples", "Subsection"],

Cell["Read a data file,", "Text"],

Cell[BoxData[
    \(\(A = 
      SubMatrix[
        Partition[ReadImage["\<coke128.bin\>", "\<RAW\>"], 128], {25, 50}, {
          40, 40}]; \)\)], "Input"],

Cell["and threshold the data array.", "Text"],

Cell[BoxData[
    \(\(B = Threshold[A, 60]; \)\)], "Input"],

Cell["\<\
Choose a 3x3 structuring element of ones. Note how it will \"grow\" the white \
regions in the image, hence the use of the word dilation for this operator. \
The operation of erosion on the other hand, will \"decrease\" or shrink the \
area occupied by white pixels in the example image.\
\>", "Text"],

Cell[BoxData[
    \(\(S = {{1, 1, 1}, {1, 1, 1}, {1, 1, 1}}; \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        \((ListDensityPlot[#1, Mesh \[Rule] False, FrameTicks \[Rule] None, 
                DisplayFunction \[Rule] Identity]\ &)\)\ /@
          \ {B, Dilate[B, S], Erode[B, S]}]]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3125 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00744048 0.31746 [
[ 0 0 0 0 ]
[ 1 .3125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .3125 L
0 .3125 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00744048 0.321429 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0240385 0.0192308 0.0240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
40 string
40 40 8 [40 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FF00FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFF00000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF00000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF0000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF0000000000
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF0000000000
00000000FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFF00FF0000FFFFFF
FFFF0000FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFF0000FFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFF0000FFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFF0000FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFF00FFFFFFFFFFFFFF
FF000000FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFFFF0000FFFFFFFFFFFF
00000000FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000000000FFFFFF0000FFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000000000FFFFFF0000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFF0000FFFFFFFF00000000000000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFF00FFFFFFFF00000000000000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFF00FFFFFFFFFF000000000000
00FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFF000000FFFFFFFFFFFF00000000FF
FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF0000
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000FFFFFFFFFFFF0000000000
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000000000000000FF0000FF00000000000000
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000000000FFFFFFFF00000000000000000000
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFF00FF00000000000000000000
0000FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFF0000000000000000000000000000
00FFFFFFFF00FFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00744048 0.64881 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0240385 0.0192308 0.0240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
40 string
40 40 8 [40 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00000000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF00000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF000000000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00744048 0.97619 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0240385 0.0192308 0.0240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
40 string
40 40 8 [40 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFF00
00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FF000000FFFFFFFFFFFFFFFF00
00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00000000000000000000000000FFFF00
00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00000000000000000000000000FFFF00
00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00000000000000000000000000FFFF00
00FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF00000000
0000000000FFFFFFFFFFFFFFFFFFFF00
00FFFF0000000000FFFF000000FFFFFFFFFFFFFFFF000000
0000000000FFFFFFFFFFFFFFFFFFFF00
00FFFF0000000000FFFF000000FFFFFFFFFFFFFFFF000000
0000000000FFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF00
0000000000FFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF00
0000000000FFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF0000
0000000000FFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF00000000
00000000FFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFF0000000000FFFFFFFFFFFF0000000000
00000000FFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFF0000000000FFFFFFFFFF000000000000
00000000FFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFF0000000000FFFFFFFFFF000000000000
0000000000FFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFF0000000000FFFFFFFFFF000000000000
0000000000000000FFFFFFFFFFFFFF00
00FFFFFFFFFFFFFF000000000000FFFF0000000000000000
0000000000000000FFFFFFFFFFFFFF00
00FFFFFFFFFFFFFF000000000000FFFF0000000000000000
0000000000000000FFFFFFFFFFFFFF00
00FFFFFFFFFFFFFF000000000000FF00000000000000FFFF
FF00000000000000FFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFF0000000000FF0000000000FFFFFFFF
FF00000000000000FFFFFFFFFFFFFF00
00FFFFFFFFFFFFFF0000000000FFFF00000000FFFFFFFFFF
0000000000000000FFFFFFFFFFFFFF00
00FFFFFFFFFFFF00000000000000FF00000000FFFFFFFF00
0000000000000000FFFFFFFFFFFFFF00
00FFFFFFFFFF0000000000000000FF00000000FFFF000000
0000000000000000FFFFFFFFFFFFFF00
00FFFFFFFF000000000000000000FF000000000000000000
0000000000000000FFFFFFFFFFFFFF00
00FFFFFFFF000000000000000000FF000000000000000000
00000000FFFFFFFFFFFFFFFFFFFFFF00
00FFFFFF00000000000000000000FF000000000000000000
00000000FFFFFFFFFFFFFFFFFFFFFF00
00FFFFFF00000000000000000000FFFF0000000000000000
0000000000FFFFFFFFFFFFFFFFFFFF00
00FFFFFF00000000FF0000000000FFFF0000000000000000
0000000000FFFFFFFFFFFFFFFFFFFF00
00FFFFFF00000000000000000000FFFFFF00000000000000
0000000000FFFFFFFFFFFFFFFFFFFF00
00FFFFFF00000000000000000000FFFFFFFF000000000000
0000000000FFFFFFFFFFFFFFFFFFFF00
00FF00000000000000000000000000000000000000000000
0000000000FFFFFFFFFFFFFFFFFFFF00
00FF00000000000000000000000000000000000000000000
0000000000FFFFFFFFFFFFFFFFFFFF00
00FF00000000000000000000000000000000000000000000
00000000000000FFFFFFFFFFFFFFFF00
00FF00000000000000000000000000000000000000000000
00000000000000FFFFFFFFFFFFFFFF00
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{266.563, 83.25},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004:0000Da000`40O003h00Oogoo2goo003oOol;
Ool000Moodl000Moodl000Moodl000Qoo`001goo00<007ooOol0Bgoo00<007ooOol01Goo00<007oo
Ool0Bgoo00<007ooOol01Goo00<007ooOol0Bgoo00<007ooOol01Woo0007Ool00`00Oomoo`1;Ool0
0`00Oomoo`05Ool00`00Oomoo`1;Ool00`00Oomoo`05Ool00`00Oomoo`1;Ool00`00Oomoo`06Ool0
00Moo`03001oogoo03Eoo`8001Aoo`03001oogoo00Eoo`03001oogoo04]oo`03001oogoo00Eoo`03
001oo`0004X00003Ool007oo00Moo`001goo00<007ooOol0=Goo0P0057oo00<007ooOol01Goo00<0
07ooOol0Bgoo00<007ooOol01Goo00<007oo0000BP0000=oo`00Ool01goo0007Ool00`00Oomoo`0e
Ool2000DOol00`00Oomoo`05Ool00`00Oomoo`1;Ool00`00Oomoo`05Ool01000Ool00000<goo1@00
3goo0P0000=oo`00Ool01goo0007Ool00`00Oomoo`0eOol2000DOol00`00Oomoo`05Ool00`00Oomo
o`1;Ool00`00Oomoo`05Ool01000Ool00000<goo1@003goo0P0000=oo`00Ool01goo0007Ool00`00
Oomoo`0eOol2000DOol00`00Oomoo`05Ool00`00Oomoo`1;Ool00`00Oomoo`05Ool01000Ool00000
<goo1@003goo0P0000=oo`00Ool01goo0007Ool00`00Oomoo`0eOol2000DOol00`00Oomoo`05Ool0
0`00Oomoo`1;Ool00`00Oomoo`05Ool01000Ool00000<goo1@003goo0P0000=oo`00Ool01goo0007
Ool00`00Oomoo`0eOol2000DOol00`00Oomoo`05Ool00`00Oomoo`1;Ool00`00Oomoo`05Ool01000
Ool00000<goo1@003goo0P0000=oo`00Ool01goo0007Ool00`00Oomoo`0eOol2000DOol00`00Oomo
o`05Ool00`00Oomoo`1;Ool00`00Oomoo`05Ool01000Ool00000<goo1@003goo0P0000=oo`00Ool0
1goo0007Ool00`00Oomoo`0eOol2000DOol00`00Oomoo`05Ool00`00Oomoo`1;Ool00`00Oomoo`05
Ool01000Ool0000017oo1@0077oo30000Woo1@003goo0P0000=oo`00Ool01goo0007Ool00`00Oomo
o`07Ool00`00Oomoo`0NOol20004Ool20005Ool2000DOol00`00Oomoo`05Ool00`00Oomoo`1;Ool0
0`00Oomoo`05Ool01000Ool000000Woo1`0077oo7P0017oo0P0000=oo`00Ool01goo0007Ool00`00
Oomoo`07Ool00`00Oomoo`0NOol20004Ool20005Ool2000DOol00`00Oomoo`05Ool00`00Oomoo`1;
Ool00`00Oomoo`05Ool01000Ool000000Woo1`0077oo7P0017oo0P0000=oo`00Ool01goo0007Ool0
0`00Oomoo`05Ool3000POol:0003Ool>0008Ool00`00Oomoo`05Ool00`00Oomoo`1;Ool00`00Oomo
o`05Ool01000Ool000000Woo1`006goo7`0017oo0P0000=oo`00Ool01goo0007Ool00`00Oomoo`05
Ool3000POol:0003Ool>0008Ool00`00Oomoo`05Ool00`00Oomoo`1;Ool00`00Oomoo`05Ool01000
Ool000000Woo1`006goo7`0017oo0P0000=oo`00Ool01goo0007Ool00`00Oomoo`0VOol20006Ool4
000IOol00`00Oomoo`05Ool00`00Oomoo`1;Ool00`00Oomoo`05Ool01000Ool000000Woo1`006goo
7`0017oo0P0000=oo`00Ool01goo0007Ool00`00Oomoo`0VOol20006Ool4000IOol00`00Oomoo`05
Ool00`00Oomoo`1;Ool00`00Oomoo`05Ool01000Ool000000Woo1`006goo7`0017oo0P0000=oo`00
Ool01goo0007Ool00`00Oomoo`07Ool00`00Oomoo`0NOol20002Ool6000IOol00`00Oomoo`05Ool0
0`00Oomoo`1;Ool00`00Oomoo`05Ool01000Ool0000017oo2@005goo40004goo0P0000=oo`00Ool0
1goo0007Ool00`00Oomoo`07Ool00`00Oomoo`0NOol20002Ool6000IOol00`00Oomoo`05Ool00`00
Oomoo`1;Ool00`00Oomoo`05Ool01000Ool0000017oo2@005goo40004goo0P0000=oo`00Ool01goo
0007Ool00`00Oomoo`07Ool5000LOol<000GOol00`00Oomoo`05Ool00`00Oomoo`0^Ool2000KOol0
0`00Oomoo`05Ool01000Ool0000017oo2@0017oo1@003goo3`004goo0P0000=oo`00Ool01goo0007
Ool00`00Oomoo`07Ool5000LOol<000GOol00`00Oomoo`05Ool00`00Oomoo`0^Ool2000KOol00`00
Oomoo`05Ool01000Ool0000017oo2@0017oo1@003goo3`004goo0P0000=oo`00Ool01goo0007Ool0
0`00Oomoo`0DOol2000FOol8000GOol00`00Oomoo`05Ool00`00Oomoo`0^Ool4000IOol00`00Oomo
o`05Ool01000Ool0000017oo2@0017oo1@003goo3`004goo0P0000=oo`00Ool01goo0007Ool00`00
Oomoo`0DOol2000FOol8000GOol00`00Oomoo`05Ool00`00Oomoo`0^Ool4000IOol00`00Oomoo`05
Ool01000Ool0000017oo2@0017oo1@003goo3`004goo0P0000=oo`00Ool01goo0007Ool00`00Oomo
o`0DOol2000FOol8000GOol00`00Oomoo`05Ool00`00Oomoo`0`Ool2000IOol00`00Oomoo`05Ool0
1000Ool000003goo1`004goo2`004goo0P0000=oo`00Ool01goo0007Ool00`00Oomoo`0DOol2000F
Ool8000GOol00`00Oomoo`05Ool00`00Oomoo`0`Ool2000IOol00`00Oomoo`05Ool01000Ool00000
3goo1`004goo2`004goo0P0000=oo`00Ool01goo0007Ool00`00Oomoo`0BOol2000JOol6000GOol0
0`00Oomoo`05Ool00`00Oomoo`0`Ool2000IOol00`00Oomoo`05Ool01000Ool000003goo2@004Goo
2`004goo0P0000=oo`00Ool01goo0007Ool00`00Oomoo`0BOol5000GOol6000GOol00`00Oomoo`05
Ool00`00Oomoo`0`Ool2000IOol00`00Oomoo`05Ool01000Ool000003goo2@004goo2@004goo0P00
00=oo`00Ool01goo0007Ool00`00Oomoo`0BOol5000GOol6000GOol00`00Oomoo`05Ool00`00Oomo
o`0`Ool2000IOol00`00Oomoo`05Ool01000Ool000003goo2@004goo2@004goo0P0000=oo`00Ool0
1goo0007Ool00`00Oomoo`0BOol4000HOol6000GOol00`00Oomoo`05Ool00`00Oomoo`1;Ool00`00
Oomoo`05Ool01000Ool000003Goo2`004goo2@004goo0P0000=oo`00Ool01goo0007Ool00`00Oomo
o`0BOol4000HOol6000GOol00`00Oomoo`05Ool00`00Oomoo`1;Ool00`00Oomoo`05Ool01000Ool0
00003Goo2`004goo2@004goo0P0000=oo`00Ool01goo0007Ool00`00Oomoo`0@Ool4000JOol4000I
Ool00`00Oomoo`05Ool00`00Oomoo`1;Ool00`00Oomoo`05Ool01000Ool000003Goo2@004Goo3@00
4goo0P0000=oo`00Ool01goo0007Ool00`00Oomoo`0@Ool4000JOol4000IOol00`00Oomoo`05Ool0
0`00Oomoo`1;Ool00`00Oomoo`05Ool01000Ool000003Goo2@004Goo3@004goo0P0000=oo`00Ool0
1goo0007Ool00`00Oomoo`0@Ool6000DOol8000IOol00`00Oomoo`05Ool00`00Oomoo`1;Ool00`00
Oomoo`05Ool01000Ool000003Goo2@003Woo3`0057oo0P0000=oo`00Ool01goo0007Ool00`00Oomo
o`0@Ool6000DOol8000IOol00`00Oomoo`05Ool00`00Oomoo`1;Ool00`00Oomoo`05Ool01000Ool0
00003Goo2@003Woo3`0057oo0P0000=oo`00Ool01goo0007Ool00`00Oomoo`0@Ool6000@Ool<000I
Ool00`00Oomoo`05Ool00`00Oomoo`0BOol2000HOol4000KOol00`00Oomoo`05Ool01000Ool00000
3Goo2@0037oo4@0057oo0P0000=oo`00Ool01goo0007Ool00`00Oomoo`0@Ool6000@Ool<000IOol0
0`00Oomoo`05Ool00`00Oomoo`0BOol2000HOol4000KOol00`00Oomoo`05Ool01000Ool000003Goo
2@0037oo4@0057oo0P0000=oo`00Ool01goo0007Ool00`00Oomoo`0@Ool6000?Ool=000IOol00`00
Oomoo`05Ool00`00Oomoo`0BOol2000DOol8000KOol00`00Oomoo`05Ool01000Ool000003Goo2@00
2Woo4`0057oo0P0000=oo`00Ool01goo0007Ool00`00Oomoo`0@Ool6000?Ool=000IOol00`00Oomo
o`05Ool00`00Oomoo`0BOol2000DOol8000KOol00`00Oomoo`05Ool01000Ool000003Goo2@002Woo
4`0057oo0P0000=oo`00Ool01goo0007Ool00`00Oomoo`0@Ool6000=Ool?000IOol00`00Oomoo`05
Ool00`00Oomoo`0BOol2000BOol:000KOol00`00Oomoo`05Ool01000Ool000003Goo2@002Woo5000
4goo0P0000=oo`00Ool01goo0007Ool00`00Oomoo`0@Ool6000=Ool?000IOol00`00Oomoo`05Ool0
0`00Oomoo`0BOol2000BOol:000KOol00`00Oomoo`05Ool01000Ool000003Goo2@002Woo50004goo
0P0000=oo`00Ool01goo0007Ool00`00Oomoo`0@Ool6000=OolA000GOol00`00Oomoo`05Ool00`00
Oomoo`0BOol2000AOol;000KOol00`00Oomoo`05Ool01000Ool000003Goo2@002Woo6P003Goo0P00
00=oo`00Ool01goo0007Ool00`00Oomoo`0@Ool6000=OolA0003Ool2000BOol00`00Oomoo`05Ool0
0`00Oomoo`0BOol2000gOol00`00Oomoo`05Ool01000Ool000003Goo2`0017oo7P003Goo0P0000=o
o`00Ool01goo0007Ool00`00Oomoo`0@Ool6000=OolA0003Ool2000BOol00`00Oomoo`05Ool00`00
Oomoo`0BOol2000gOol00`00Oomoo`05Ool01000Ool000003Goo2`0017oo7P003Goo0P0000=oo`00
Ool01goo0007Ool00`00Oomoo`0@Ool70008Ool20002Ool3000:Ool40003Ool2000BOol00`00Oomo
o`05Ool00`00Oomoo`1;Ool00`00Oomoo`05Ool01000Ool000003Goo2`0017oo7P003Goo0P0000=o
o`00Ool01goo0007Ool00`00Oomoo`0@Ool70008Ool20002Ool3000:Ool40003Ool2000BOol00`00
Oomoo`05Ool00`00Oomoo`1;Ool00`00Oomoo`05Ool01000Ool000003Goo2`0017oo7P003Goo0P00
00=oo`00Ool01goo0007Ool00`00Oomoo`0BOol50008Ool4000?Ool2000GOol00`00Oomoo`05Ool0
0`00Oomoo`1;Ool00`00Oomoo`05Ool01000Ool000003Goo2`000Woo3@001Woo3@003Goo0P0000=o
o`00Ool01goo0007Ool00`00Oomoo`0BOol50008Ool4000?Ool2000GOol00`00Oomoo`05Ool00`00
Oomoo`1;Ool00`00Oomoo`05Ool01000Ool000003Goo2`000Woo3@001Woo3@003Goo0P0000=oo`00
Ool01goo0007Ool00`00Oomoo`0BOol40007Ool4000AOol2000GOol00`00Oomoo`05Ool00`00Oomo
o`1;Ool00`00Oomoo`05Ool01000Ool000003goo2@000Woo2P002Goo3@003Goo0P0000=oo`00Ool0
1goo0007Ool00`00Oomoo`0BOol40007Ool4000AOol2000GOol00`00Oomoo`05Ool00`00Oomoo`1;
Ool00`00Oomoo`05Ool01000Ool000003goo2@000Woo2P002Goo3@003Goo0P0000=oo`00Ool01goo
0007Ool00`00Oomoo`0MOol4000?Ool40003Ool2000BOol00`00Oomoo`05Ool00`00Oomoo`1;Ool0
0`00Oomoo`05Ool01000Ool000003Goo2@0017oo20002Goo3`003Goo0P0000=oo`00Ool01goo0007
Ool00`00Oomoo`0MOol4000?Ool40003Ool2000BOol00`00Oomoo`05Ool00`00Oomoo`1;Ool00`00
Oomoo`05Ool01000Ool000003Goo2@0017oo20002Goo3`003Goo0P0000=oo`00Ool01goo0007Ool0
0`00Oomoo`0@Ool60007Ool2000?Ool60003Ool2000BOol00`00Oomoo`05Ool00`00Oomoo`1;Ool0
0`00Oomoo`05Ool01000Ool000002goo3@000Woo20001goo4@003Goo0P0000=oo`00Ool01goo0007
Ool00`00Oomoo`0@Ool60007Ool2000?Ool60003Ool2000BOol00`00Oomoo`05Ool00`00Oomoo`1;
Ool00`00Oomoo`05Ool01000Ool000002goo3@000Woo20001goo4@003Goo0P0000=oo`00Ool01goo
0007Ool00`00Oomoo`0>Ool90006Ool4000;Ool80003Ool2000BOol00`00Oomoo`05Ool00`00Oomo
o`0BOol2000gOol00`00Oomoo`05Ool01000Ool000002Goo3`000Woo20000goo5@003Goo0P0000=o
o`00Ool01goo0007Ool00`00Oomoo`0>Ool90006Ool4000;Ool80003Ool2000BOol00`00Oomoo`05
Ool00`00Oomoo`0BOol2000gOol00`00Oomoo`05Ool01000Ool000002Goo3`000Woo20000goo5@00
3Goo0P0000=oo`00Ool01goo0007Ool00`00Oomoo`0<Ool;0006Ool40007Ool:000IOol00`00Oomo
o`05Ool00`00Oomoo`0@Ool6000HOol2000KOol00`00Oomoo`05Ool01000Ool000001goo4@000Woo
80003Goo0P0000=oo`00Ool01goo0007Ool00`00Oomoo`0:Ool=0006OolE000IOol00`00Oomoo`05
Ool00`00Oomoo`0ZOol4000MOol00`00Oomoo`05Ool01000Ool000001goo4@000Woo6@0057oo0P00
00=oo`00Ool01goo0007Ool00`00Oomoo`0:Ool=0006OolE000IOol00`00Oomoo`05Ool00`00Oomo
o`0ZOol4000MOol00`00Oomoo`05Ool01000Ool000001goo4@000Woo6@0057oo0P0000=oo`00Ool0
1goo0007Ool00`00Oomoo`0:Ool60004Ool30008OolA000KOol00`00Oomoo`05Ool00`00Oomoo`0Q
Ool=000MOol00`00Oomoo`05Ool01000Ool000001Woo4P000Woo6@0057oo0P0000=oo`00Ool01goo
0007Ool00`00Oomoo`0:Ool60004Ool30008OolA000KOol00`00Oomoo`05Ool00`00Oomoo`0QOol=
000MOol00`00Oomoo`05Ool01000Ool000001Woo4P000Woo6@0057oo0P0000=oo`00Ool01goo0007
Ool00`00Oomoo`08Ool4000:Ool00`00Oomoo`06OolA000KOol00`00Oomoo`05Ool00`00Oomoo`0S
Ool9000OOol00`00Oomoo`05Ool01000Ool000001Woo4P0017oo60004goo0P0000=oo`00Ool01goo
0007Ool00`00Oomoo`08Ool4000:Ool00`00Oomoo`06OolA000KOol00`00Oomoo`05Ool00`00Oomo
o`0SOol9000OOol00`00Oomoo`05Ool01000Ool000001Woo4P0017oo60004goo0P0000=oo`00Ool0
1goo0007Ool00`00Oomoo`08Ool4000:Ool00`00Oomoo`08Ool=0004Ool2000GOol00`00Oomoo`05
Ool00`00Oomoo`0UOol3000SOol00`00Oomoo`05Ool01000Ool000001Woo1`000Woo2@0017oo6000
4goo0P0000=oo`00Ool01goo0007Ool00`00Oomoo`08Ool4000:Ool00`00Oomoo`08Ool=0004Ool2
000GOol00`00Oomoo`05Ool00`00Oomoo`0UOol3000SOol00`00Oomoo`05Ool01000Ool000001Woo
1`000Woo2@0017oo60004goo0P0000=oo`00Ool01goo0007Ool00`00Oomoo`08Ool20008Ool5000<
Ool70004Ool6000GOol00`00Oomoo`05Ool00`00Oomoo`1;Ool00`00Oomoo`05Ool01000Ool00000
1Woo4P001Woo5P004goo0P0000=oo`00Ool01goo0007Ool00`00Oomoo`08Ool20008Ool5000<Ool7
0004Ool6000GOol00`00Oomoo`05Ool00`00Oomoo`1;Ool00`00Oomoo`05Ool01000Ool000001Woo
4P001Woo5P004goo0P0000=oo`00Ool01goo0007Ool00`00Oomoo`08Ool?000AOol<000GOol00`00
Oomoo`05Ool00`00Oomoo`0DOol2000JOol2000IOol00`00Oomoo`05Ool01000Ool000001Woo4P00
27oo50004goo0P0000=oo`00Ool01goo0007Ool00`00Oomoo`08Ool?000AOol<000GOol00`00Oomo
o`05Ool00`00Oomoo`0DOol2000JOol2000IOol00`00Oomoo`05Ool01000Ool000001Woo4P0027oo
50004goo0P0000=oo`00Ool01goo0007Ool00`00Oomoo`08Ool?000<OolA000GOol00`00Oomoo`05
Ool00`00Oomoo`0:Ool<000DOol8000IOol00`00Oomoo`05Ool01000Ool000000Woo<P004goo0P00
00=oo`00Ool01goo0007Ool00`00Oomoo`08Ool?000<OolA000GOol00`00Oomoo`05Ool00`00Oomo
o`0:Ool<000DOol8000IOol00`00Oomoo`05Ool01000Ool000000Woo<P004goo0P0000=oo`00Ool0
1goo0007Ool00`00Oomoo`05OolB0002Ool40002OolE000GOol00`00Oomoo`05Ool00`00Oomoo`0:
Ool6000EOol=000IOol00`00Oomoo`05Ool01000Ool000000Woo<P004goo0P0000=oo`00Ool01goo
0007Ool00`00Oomoo`05Ool=0007OolK000GOol00`00Oomoo`05Ool00`00Oomoo`07Ool3000GOol=
000MOol00`00Oomoo`05Ool01000Ool000000Woo=P003goo0P0000=oo`00Ool01goo0007Ool00`00
Oomoo`05Ool=0007OolK000GOol00`00Oomoo`05Ool00`00Oomoo`07Ool3000GOol=000MOol00`00
Oomoo`05Ool01000Ool000000Woo=P003goo0P0000=oo`00Ool01goo0007Ool00`00Oomoo`05Ool7
000:Ool00`00Oomoo`0G0005Ool2000DOol00`00Oomoo`05Ool00`00Oomoo`0KOolA000OOol00`00
Oomoo`05Ool01000Ool000000Woo=P003goo0P0000=oo`00Ool01goo0007Ool00`00Oomoo`05Ool7
000:Ool00`00Oomoo`0G0005Ool2000DOol00`00Oomoo`05Ool00`00Oomoo`0KOolA000OOol00`00
Oomoo`05Ool01000Ool000000Woo=P003goo0P0000=oo`00Ool01goo0007Ool00`00Oomoo`05Ool3
000:OolL0007Ool2000DOol00`00Oomoo`05Ool00`00Oomoo`0KOolA000OOol00`00Oomoo`05Ool0
0`00Ool0001:00000goo001oo`07Ool000Moo`03001oogoo00Eoo`<000Yooa`000Moo`8001Aoo`03
001oogoo00Eoo`03001oogoo01]ooa4001moo`03001oogoo00Eoo`03001oo`0004X00003Ool007oo
00Moo`001gooC`001gooC`001gooC`0027oo003oOol;Ool00?moo`]oo`00\
\>"],
  ImageRangeCache->{{{0, 265.563}, {82.25, 0}} -> {-0.0891532, -0.0234425, 
  0.0119682, 0.0119682}, {{7.4375, 85.75}, {80.25, 
  1.9375}} -> {-4.83035, -1.93264, 0.532911, 0.532911}, {{93.5625, 171.938}, {
  80.25, 1.9375}} -> {-50.6873, -1.9151, 0.532484, 0.532484}, {{179.75, 
  258.063}, {80.25, 1.9375}} -> {-96.6575, -1.93264, 0.532911, 0.532911}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problem 3", "Exercise"],

Cell["\<\
Change the structuring element so that erosion occurs at a smaller scale of \
structures in the example image.\
\>", "ExerciseText"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["OPENING AND CLOSING OPERATIONS", "Section"],

Cell[TextData[{
  "Dilation and erosion are often applied to an image in concatenation. \
Dilation followed by erosion is called a close operation,\n\t",
  Cell[BoxData[
      \(TraditionalForm
      \`A\ \[FilledSmallCircle]\ B\  = \ 
        \((A\[CirclePlus]\ B\ )\)\ \[CircleMinus]\ B\)]],
  "\nClosing of an image with a compact structuring element without holes, \
smoothes contours of objects and eliminates small holes in objects. An open \
operation, consists of erosion followed by dilation. \n\t",
  Cell[BoxData[
      \(TraditionalForm
      \`\(A\ \[EmptySmallCircle]\ B\  = \ 
        \((A\ \[CircleMinus]\ B\ )\)\ \[CirclePlus]\ B\ \)\)]],
  "\nOpening of an image smoothes contours of objects, eliminates small \
objects and breaks narrow strokes."
}], "Text"],

Cell[CellGroupData[{

Cell["Problem 4", "Exercise"],

Cell["\<\
Perform  open and close operations on the example image using a 3x3 square \
structuring element.\
\>", "ExerciseText"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["GRAYSCALE EROSION AND DILATION", "Section"],

Cell["\<\
INTRODUCTION ****Morphological concepts may be extended to gray scale images. \
The common approach is to use a gray scale extremum operation over a small \
neighborhood defined by the structuring element. Choose a 3x3 structuring \
element of ones. Note how it will \"grow\" the white regions in the image, \
hence the use of the word dilation for this operator. The operation of \
erosion with structuring element S will \"decrease\" the area occupied by \
white pixels in the example image.\
\>", "Text"],

Cell[BoxData[
    \(\(S = {{1, 1, 1}, {1, 1, 1}, {1, 1, 1}}; \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        \((ListDensityPlot[#1, Mesh \[Rule] False, FrameTicks \[Rule] None, 
                DisplayFunction \[Rule] Identity]\ &)\)\ /@
          \ {A, GrayscaleDilate[A, S], \ GrayscaleErode[A, S]}]]; \)\)], 
  "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3125 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00744048 0.31746 [
[ 0 0 0 0 ]
[ 1 .3125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .3125 L
0 .3125 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00744048 0.321429 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0240385 0.0192308 0.0240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
40 string
40 40 8 [40 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B1839CBC9595BC8A98A7D5C7B5CEE7F5D8DCD5D1D8D5FCD8
D5D8CAE06E3895E3E0D8E0EAD8D8D8E7
C383B8BCB1C3DCE7D5F5DCD5DCDCD5D1E7FCE0E0D8D8DCDC
E7D1D1C38A3C98D8D8D5D8DCE0D8DCE0
C3C0C0BCBCC0D1D5D8D5E3F8E3D8D8D8DCD8E3E3C7AAA7CE
D8EAD5CAA74091DCD5D8D8DCDCD5DCD8
BCB8D1D5C7E3CAA0957CB183E7FFD8D5D5CA67514E4E4A4A
58CEE0C7B53587CECEDCCED5D8DCD5E0
BC8A835C67788E757178A3CEE3D8EAE36A584A514E514A55
5547CAC0C03880E0CEDCD8D8DCD8DCEA
C38051553C675CB89C8A98D8D8D5B84E4A4E4E514E51404A
4A4360C3A74071C3CACABCC3BCAEA091
BC8E51404367608AD560C0E0D1AE4A4E4E4A4A4E4E4E4031
40433CB8BC402E0A18202E314751586E
C7B855A0A38A7C63788380CED14E4E4E55474A554E434A4A
4738389CBC4751D5CECECAD5CED5D1D1
B8B17847314E78BCB8C0C7D54E514E4E4E4E584A4E4A404A
3C312E60CE5563D5D5D8CED8D8D5D5DC
B8A3AE67274040D1C3D5C76A474A514A5158514A514E4340
3C273138BC6363D1CACED1D8CED5CAD5
AEB5A79858B5C0C0CAD1CA404E4E4E4E515CA3CACAC7C34E
31271C31C06A5CD1CACED1C7D1CECAD5
B5AEB5AE91B5B5B8CECA63434E4E4A55AED1D8F1D1D1CAC7
3C231C2EC37158D5C3D1CAC7CED1CACE
AAB8B8AEAEA3A0C0C3C33C4A4E516AD5D1D1D1D5D8D1C0CA
8E181C27957C58C7C7CECAD8C7D1D1C3
AA9CB5B1B1B1B1A0B88A38404067C3E0D5D1D5D5CEC7D1BC
AE15202E678A60C7C7CAD1CECEC7CED1
A0B598AAB5B5B5B8B5512A404ECECED5D1E7D1D1C7C7B8A3
A71C1C35838E55CAC3CACACACECED5CE
A3B1B19CA3AAB5B5B831384A8ECECAD5D5D1D8DCC7C3BCAE
AA231863838A55CACAC7CEC7CACED1D5
A0B5B5A3AE8AAEB5B1233143D5D1CED1CECECACED8B56035
2A1C189C759555CAC3C7C7C3CED1D1D8
A7AAB1BCAEAE9CA7BC232735CECEEED5CECACACA6A352323
18181C8E83A04AC3C7C7C0CECAD1C7D1
A7AA98B5AAAAB1B5A71C273CCAC3CECEE7CEC34A3C312320
151C20A780A347C7C0C0C7C3C7CEC7CA
A0AAAE87A7AEB1B5AA202031C7C3CACECAD55540382E201C
1C1C18608EA347C7C0BCC0CAC3C7CEC7
A0A7AEB18A9CA7B5BC152023CECACEC0CE80473C382E2723
1C18182EA7A747BCC3C0B5BCBCC7C3C7
A7AAA7AEAAA791B8B82E272A78D8D5C7C04A474338272323
382A1118A3A03CBCB5BCB8C0B8C3C7C7
A3A0A3A7B1AEAEC0BC381C273CAACADC7843473C38608EA0
AAA0311C71A343C3BCC3C3C0C0C3CEC7
A0A3988EAAAAAAB5B858202A2E4A8EC04A404055AAB1A7A3
8EA75C11959C4AB8BCC0C0BCCAC3C7CA
A3AEA7A780AEB8C0B86A232A4A8EBCD1383C58CAB5AEB1AA
AA784A07959C47BCB8C0B8C0BCC7CAC7
A7B1AAA3AA83A0B8B5716EA0AEC7BCB53843B1C0A0A7A7A3
A3981818718A43B8B8BCBCC7C3CAC3C0
AA95A7AAA7A39CAA9140272E95BCCABC3C4EC7B5B1A08AA3
952A181C879543B5B1B8BCC0C0C3C7C3
A0A087A0A3A0A75835271C232AB1B5B53C43C0BCAAAA956A
1C11183895A743B8B1BCBCC7BCC3C3C7
A7A79C958AA3512A2A2720202E87B1B5403851A08E5C2320
111C1887A3A34EB8AAB5C0C7BCC3C7CA
A3A39C9C987811112A2720202775B5AE3C383C312E272018
181123A7A3A34AB1B1B8B8C7C0C0C3C7
AA9C98AAA06307182A4E51232A83B5B551353C2E271C1818
18157187A39C51B5B1B5B8C3C0C0C0C7
AAA08A98A0270E4A9CA7A37C20A3AAA791353C2E23151518
1838A77183915CB1A7B8B5B5BCBCC0BC
A795987C981131AEA7958E512087B19CB558312A11151823
359C8A1CA0836EAEB5AEAEC0BCC0C0B8
AAA09895781178A39C672315206EB8AEB1B5802720152771
83270E20957C75AEB5B1B8B8BCBCC0C0
A79C9C98980E3827201C1C181C60A7AAAEA7B5A38A673518
110E151C957C7CB1B1B8B8B8C0B8C0C7
B191789C630A0E182018181520604AAEA3A0804020110E0E
11110E1C87758AAEB5B1B8B8B5B8C0C0
A09C4E11110A0E1C27151520315138384E3120271C110E18
151511118A6098B1B1AAB5C3C0BCC3BC
A79C4711110E0E18203867839851352335201C1C1C151515
111511188A4EA7AEAAAEAEC3B5BCC0B5
A09847070E111C558A988E71314A382E2A2318201C180A0E
152A5178873CAAB5AEB1B8B8B8B8B8C7
9C874A0018517C87874A1818184038272A1C201C20111511
156AA07C9531AAAAA3B5B8B5BCB8C0C3
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00744048 0.64881 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0240385 0.0192308 0.0240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
40 string
40 40 8 [40 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
BFBFB7B7BFD9E5E5F4F4F4D9D9E5F4F4FCFCFCDDDDFCFCFC
E5E5DDDDDD91E1E1E1DDE9E9E9DDE5E5
BFBFBBBBBFD9E5E5F4F4F8F8F8E5F4F4FCFCFCE1E1FCFCFC
E9E9E9DDDDA0E1E1E1DDE9E9E9DDE5E5
BFCED2D2E1E1E5E5F4F4F8F8FFFFFFE5FCFCFCE1E1D9D9E5
E9E9E9DDC6AFD9D9D9D9D9DDDDDDDDDD
BFCED2D2E1E1E1D5D5E1F8F8FFFFFFE9E1E1E1E1E1C2CAD5
E9E9E9DDC6BBDDDDDDD9D9D9D9D9E9E9
BFCED2D2E1E1E1C6B3ABD5E5FFFFFFE9E1D2C65B4444484C
CADDDDDDC2BBDDDDDDD9D9D9D9D9E9E9
BFBF857A6E85B3D2D2D2DDE1E1E9E9E9E15F4C4444444848
48C6C6C6BFBBDDDDDDD9D9D9D9D9E9E9
C2C2B39C9C9CB3D2D2D2DDDDDDD5D2B3484848484844443D
3D54BFBFBFB7D2D2D2CAD2D2D2D2D2CE
C2C2B39C9C9CB7D2D2D2DDDDDDCEA848484C4C4C4840403D
3D39B3CACACAD2D2D5D5D5D5D5D5D9D9
C2C2B3A89C9CCECED2D2D2D2D2CE44484C4C4C4C4844403D
3D3995CACACAD2D2D5D5D5D5D5D5D9D9
B3B3AFA8AFBBCECED2D2D2D2D2444444509CC6C6C6C6C2BF
402D54CACACAD2D2D5D5D5D5D5D5D9D9
B3B3AFAFAFBBCECED2D2D2C65F4448A8CED5F0F0F0CECEC6
C22D2ABFBFBFD2D2D2CED5D5D5D2D2D2
B3B3B3B3AFBBBBCACECECEC6445FD2D2D2D5F0F0F0D5CEC6
C68522BFBFBFD2D2D2CED5D5D5CED2D2
B3B3B3B3AFAFBBCACACAC6575BBFDDDDDDD5F0F0F0D5CECE
C6A81EBFBFBFD2D2D2CED5D5D5CECECE
B3B3B3B3AFAFBBBFBFBFBF40CACADDDDE5E5E5D5D5D5CECE
C6A8268D8D8DC6C6CACED5D5D5D2D2D2
AFAFAFAFAFAFB3B3B3B38185CACADDDDE5E5E5D9D9CECECE
B7A8577A8585C6C6C6CECECECAD2D2D2
AFAFAFAFAFAFB3B3B3B344D2D2D2D2D2E5E5E5D9D9D5C2B7
A8A49595958DC6C6C6CACACACED2D5D5
AFAFB7B7B7AFAFB7B7B73DD2D2ECECECD2D5D9D9D9D5BFB7
A8A495959898C6C6C6CACACACECED5D5
AFAFB7B7B7ABAFB7B7B735D2D2ECECECE5E5CAD5D5D5AF54
261AA0A0A09CC6C6C6C2CACACECED5D5
A4ABB7B7B7ABAFB7B7B72DCACAECECECE5E5D2C6C65F2613
130FA0A0A09CC2C2C2C2CACACECECECE
A4A8AFAFAFABAFB7B7B72DCACACACAE5E5E5D2BF3D2D2216
130FA0A0A0A0C2C2C2C2C6C6CACACACA
A4A8ABABABABB3B7B7B722CAD5D5D5D2D2D2D248352A1E2A
2A2A54A0A0A0C2C2C2BFC6C6C6CACACA
A4A8ABABABABBBBBBBB72ACAD5D5D9D9D9CA7639548598A4
A4A498A0A0A0BFBFBFBFBFBFC2CACACA
A4A4A8ABABABBBBBBBB74C6ED5D5D9D9D9BB48A4ABABABA4
A4A4A09C9C9CBFBFBFBFBFC6C6CACACA
A8A8A8ABABB3BBBBBBB75F3DA4C6D9D9D96EC6C6C6AFABAB
A4A4A08D9C9CBFBFBFBFBFC6C6CACACA
ABABABA4A8B3BBBBBBB398A8C2C2CECECEABC6C6C6AFABAB
A4A4A08D9595B7B7BBBBC2C6C6C6C6C6
ABABABA4A8B3BBBBBBB398A8C2C6CECECEC2C6C6C6AFABAB
A4A4918D9595B7B7BBBBC2C2C6C6C6C6
ABABABA4A4A4B3B3B3AF98A8C2C6C6C6B7C2C2C2BBABA4A0
9C9C918DA0A0B3B3B7B7C2C2C6C6C6C2
A4A4A4A4A4A0A4A4A489318DB7C6C6C6B7C2C2C2B7ABA49C
9C8D7E9CA0A0B3B3B7BBC2C2C2C2C6C6
A0A0A09C9CA0A0A04C26161EABAFAFAFAFBBBBBBB7A4A48D
5F13A0A0A0A0B3B3B7BBC2C2C2C2C6C6
A4A4A4A4A49C9C44404444447EAFAFAFAF44989898855013
0F67A0A0A09CB3B3B3BBC2C2C2C2C6C6
A4A4A4A4A4986E95A0A0A09C9CAFAFAFAF892D2D221E160F
2AA0A0A0A09CAFAFB3B3C2C2C2BFC2C2
A4A4A4A4A498A8A8A8A0A09C9CAFAFAFAFAF4C2D1E161326
95A0A0A09C9CAFAFB3B3BFBFBFBBC2C2
A4A498989898A8A8A8A0A09C9CB3B3B3AFAFAF761E16677A
95A0A0A09898ABAFB3B3BBBBBBBBBBBB
A4A498959191A8A8A8A08D857EB3B3B3AFAFAFAF9C81677A
959595989898ABAFB3B3BBBBBBBBC2C2
ABAB989595919C9C9C955B1363B3B3B3AFAFAFAF9C81677A
7A7A168D8D8DABAFB3B3B3BBBBBBC2C2
ABAB959595912A2A16160F2254A0A8A8A8AFAFAF9C815B26
07030B8D8D91ABAFB3B3BFBFBFBFC2C2
ABAB959595570B162A5B7A919191A8A8A89C9876310F0707
07030B8181A0ABAFAFB3BFBFBFBFBFBF
A0A09540000B4881919191919191444040402216160B0707
1A446E8181A4AFAFAFB3BFBFBFBFC2C2
A0A0953D44727E81919191919191442A2626130F0F0F0703
5F9898988DA4AFAFAFB3BFBFBFBBC2C2
9898913D44727E8191919185673D3D2A1E1A130F0F0F0703
5F9898988DA4AFAFAFB3B3B7B7BBC2C2
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00744048 0.97619 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0240385 0.0192308 0.0240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
40 string
40 40 8 [40 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
9B9B9BB0B0B0A3A3A3B4C5D6D6D6F3F7F7FBF7F7F7FBFBFB
F7EFE682434343B0FBFBFBFFFFFFFFFF
9B9B9BB0B0B0A3A3A3B4C5D6D6D6F3F7F7FBF7EBC9C5C5C5
F3EFE682434343ACFBFBFBFFFBFBFBFF
9B9B9BD1D1D1BCB09292929B9BFBF7F7EF79605C5C585858
5868E6A33E3E3E9FF3F3F3F3FBFBFBFB
A39B6D6D6D798A8686868E9B9BFFFB7D685858585C585858
535353C53E3E3E97F3F3F3F3FBFBFBFB
9760604747476D6D86868E9B9BDA5C58585858585C4B4B4B
4F4F4F713E3E3E86E6DEDEDECDBCACAC
97604B4747476D6D717171B4CD585858585858585C4B3A3A
3A47474743360C0C0C1D25363A536068
97604B4747476D6D717171975C585858535353584F4B3A3A
3A4343434B360C0C0C1D25363A536068
A7604B3A3A3A5C717171715C5C585858535353584F4B3A3A
3A3636364B360C0C0C1D25363A536068
C164532E2E2E4B4B758E7D5353535858535353584F4B4B47
2E2E2E3643535360EFEFEFEFF3EFEFEF
C18E532E2E2E4B4BDADA4B4B4B535858585C5858584B4B3A
2E2121213A64646DEFEFEBEBEBEFEFEF
C1C1792E2E2E4B4BDA754B4B4B53585858605858584F4B3A
2921212136686868E6E6EBEBEBEFEFEF
C9C5B4686868BCBCDA4747474B5858585C606DC1EBE25C3A
1D1D1D212E686868E6E6EBEBEBEBE6E6
B8B8B8ACACACBCBCA34343434B4B585864CDF7F3EBE2DE47
191919212E686868E6E6EBEBEBEBE6E6
B8B4B4B4C1BCBCBC603232324B4B607DF7F7F7EBEBDAC1A7
191919212E646464E6E6EFEBEBEBE6E6
B8B4B4B4B8C1BCBC3A3232324B4B79E6F7F7F7EBE6DAC1C1
1919191D36646464E6E6EBEBEBEBEBF3
BCB4B4B4A3A3A3CD292929324B5CEFEFF3EFEFEBD6713E32
211D1D1D3E646464E6E6E6E6E6EFF3F3
BCBCB8B8A3A3A3B82929292E3EA7EFEFEFEFEF7D3E29291D
1D1D1D1D75585858E6E2E2E2E6EBEBEB
BCB4B4B4A3A3A3B82121212E3EE6E6F3EFE658473A292519
19191D1D8A535353E2E2E2E2E6EBEBEB
BCB49F9F9FB8B8B8212121253AE6E6EFEF644B4336252119
19191D1D71535353DEDEDEE2E6E6EBEB
BCB49F9F9FA3B8C51919192529E6E2E29753474336252119
19191D1D36535353DED6D6D6DEDEE6E6
BCBC9F9F9FA3ACAC19191925298EE2E2585347432E252121
1D1414141D474747D6D6D6D6DADAE6E6
BCBCBCA3A3A3ACAC191919212947C98E4F4F47432E292921
1D1414141D474747D6D6D6D6DADAE6E6
BCB4A7A7A7ACACAC362121212E3658584B4B47432E292929
2914141414474747D6D6DADADADAE6EB
BCB4A7979797C9C9432121212E36584343434743434371A7
8E3A0808084F4F4FDADADADADEDEE6EB
BCB4A79797979BBC68252525323658434343474B64BCC1A7
8E1D0808084F4F4FDADADADADEDEE2E2
B0B0B09797979BAC4B2929293258A74343434768BCA3A3A3
321D0808084F4F4FD1D1DADADEDEE2E2
B09F9F9F9B9B683E2E2121212932D14343434FBCBCA37D21
1414141D1D4F4F4FD1D1DADEDEDEE2E2
B09F9F9FA36032322E21212125329F47434343606D292514
1414141D214F4F4FC9C9D6DEDEDEE6E6
BC9F9F9F8E14141414212121252E8A4743433A362E251D14
1414141D434F4F4FC9C9D6DADEDEE2E6
B8B4B0A37508080814252525252E8A473E3E362E211D1D14
1414141D9F585858C9C9D6DADEDEE2E2
B8A3A3A32E0808081425252525258A473E3E362919191919
1414142986585858C5C5D6D6D6DEDEDE
B0A39292140808081D32292525259B603E3A321414141919
1919192121606060C5C5CDCDD6DEDADA
B0A3928E1410101058291919192582AC3E3A2E1414141919
1D101010216D6D6DC5C5CDCDD6DEDADA
B0B0928E1010102521211919192171B8683A2E1414141914
1010101021828282CDCDCDCDDADADADA
AC8E8E750C0C0C101D1D191919215858BC972E2514101010
10101010218A8A8ACDD1D1D6D6D6DAE2
AC5C14140C0C0C1019191919192143433A25252114101010
1010101014717192C9C9C9D6D6D6DADE
AC5314140C0C0C1019191919192529292521212114101010
10101010145C5CA3C9C9C9CDD6D6D6D6
B4530808080C0C1019191919253A2929251D1D1D140C0C0C
10141414144747B4C9C9C9CDD6D6D6D6
9F530000001010101D1D1D1D1D1D2929211D1D1D140C0C0C
101414141D3A3AC1C1C1CDCDD6D6D6D6
9F53000000101421581D1D1D1D1D2E2E211D1D1D140C0C0C
101932603A3A3AC1C1C1D1D6D6DADADA
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{266.563, 83.25},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004:0000Da000`40O003h00Oogoo2goo003oOol;
Ool000Moodl000Moodl000Moodl000Qoo`001goo00<007ooOol0Bgoo00<007ooOol01Goo00<007oo
Ool0Bgoo00<007ooOol01Goo00<007ooOol0Bgoo00<007ooOol01Woo0007Ool00`00Oomoo`1;Ool0
0`00Oomoo`05Ool00`00Oomoo`1;Ool00`00Oomoo`05Ool00`00Oomoo`1;Ool00`00Oomoo`06Ool0
00Moo`04001ooe[FF]H2@Q02CW<2G_L3BU82G_L2AS42CW<2DY@2JeX2HaP00e[FIcUW>@02Li`2Nmh4
Kg/4JeX00fmkJeY[FP02Ool2Kg/2JeX2Kg/2IcT2Li`00cF]7>LLi`02BU84Li`2Kg/2Li`2Mkd5Kg/2
Li`00goo001oo`06Ool00`00OomNm`03G_L4F]H00ekgKg]_N`04Li`6Nmh3Kg/2Li`4Nmh6Ool3Kg/6
Ool4Li`5Kg/2BU86Li`2Kg/5Mkd2Kg/4Li`00goo001oo`06Ool00`00Oom>L`05CW<5F]H6DY@2F]H2
HaP5JeX6Nmh2Ool5Nmh6Ool2Nmh2Mkd2Li`2@Q058@P2F]H@Ool00`00Oomoo`06Ool000Moo`04001o
oe[FF]H2@Q02CW<2G_L3BU82G_L2AS42CW<2DY@2JeX2HaP00e[FIcUW>@02Li`2Nmh4Kg/4JeX00fmk
JeY[FP02Ool2Kg/2JeX2Kg/2IcT2Li`00cF]7>LLi`02BU84Li`2Kg/2Li`2Mkd5Kg/2Li`00goo001o
o`06Ool00`00OomNm`03G_L4F]H00ekgKg]_N`04Li`6Nmh3Kg/2Li`4Nmh6Ool3Kg/6Ool4Li`5Kg/2
BU86Li`2Kg/5Mkd2Kg/4Li`00goo001oo`06Ool00`00Oom>L`05CW<5F]H6DY@2F]H2HaP5JeX6Nmh2
Ool5Nmh6Ool2Nmh2Mkd2Li`2@Q058@P2F]H@Ool00`00Oomoo`06Ool000Moo`04001oof<HHaP2@Q04
G_L00e[FHaQS6002Kg/2Li`2JeX2Nmh2Kg/2JeX3Kg/4JeX2Li`2Ool4Li`7Kg/2Li`4JeX2HaP00dHa
7>LLi`02CW<4Kg/2JeX4Kg/00g>LKg]_N`02Kg/2Li`00goo001oo`06Ool00`00OomNm`08G_L2Kg/4
Li`4Nmh5Ool2Li`4Nmh6Ool3Li`6Ool6Mkd3Kg/2DY@6Li`2Kg/5Mkd2Kg/4Li`00goo001oo`06Ool0
0`00Oom>L`05CW<5F]H6DY@2F]H2HaP5JeX6Nmh2Ool2Nmh2Mkd00fLiHaQS6004HaP2Nmh2Mkd2Li`2
@Q058@P2E[D@Ool00`00Oomoo`06Ool000Moo`04001oof<HHaP2@Q04G_L00e[FHaQS6002Kg/2Li`2
JeX2Nmh2Kg/2JeX3Kg/4JeX2Li`2Ool4Li`7Kg/2Li`4JeX2HaP00dHa7>LLi`02CW<4Kg/2JeX4Kg/0
0g>LKg]_N`02Kg/2Li`00goo001oo`06Ool00`00OomNm`08G_L2Kg/4Li`4Nmh5Ool2Li`4Nmh6Ool3
Li`6Ool6Mkd3Kg/2DY@6Li`2Kg/5Mkd2Kg/4Li`00goo001oo`06Ool00`00Oom>L`05CW<5F]H6DY@2
F]H2HaP5JeX6Nmh2Ool2Nmh2Mkd00fLiHaQS6004HaP2Nmh2Mkd2Li`2@Q058@P2E[D@Ool00`00Oomo
o`06Ool000Moo`03001oof<H00ES60=Nm`9S60A[FP9_N`9[FP9cW09oo`03Lia_Nfmk00Q_N`AcW003
HaQF]EJe009BU09W>@9_N`9g_@9[FP9W>@03DY@Q2248009:DP9_N`9[FPM_N`9[FPA_N`03Ool007oo
00Ioo`04001ooekgG_L2IcT4JeX7Li`4Nmh9Ool2Li`6Ool3Li`4Kg/2Li`6Mkd2Kg/00f<HE[EF]@0C
Kg/00goo001oo`06Ool00`00Oom>L`05CW<5JeX2G_L2F]H6BU83CW<2Ool4Nmh2Mkd2?Nl2<H`;;F/2
=Jd2Li`2DY@57>L2CW<8Nmh8Ool00`00Oomoo`06Ool000Moo`03001oof<H00ES60=Nm`9S60A[FP9_
N`9[FP9cW09oo`03Lia_Nfmk00Q_N`AcW003HaQF]EJe009BU09W>@9_N`9g_@9[FP9W>@03DY@Q2248
009:DP9_N`9[FPM_N`9[FPA_N`03Ool007oo00Ioo`04001ooekgG_L2IcT4JeX7Li`4Nmh9Ool2Li`6
Ool3Li`4Kg/2Li`6Mkd2Kg/00f<HE[EF]@0CKg/00goo001oo`06Ool00`00Oom>L`05CW<5JeX2G_L2
F]H6BU83CW<2Ool4Nmh2Mkd2?Nl2<H`;;F/2=Jd2Li`2DY@57>L2CW<8Nmh8Ool00`00Oomoo`06Ool0
00Moo`03001ooekg00=Nm`A[FP03HaQcW7>L009W>@9BU09:DP8mk`9JeP924003Liaoogoo009_N`A[
FP9W>@8aS08YBPLU:@8]J`9W>@9cW09S6003F]HHaQS6009240AW>@9_N`9W>@9[FP=_N`9[FP9cW003
Ool007oo00Ioo`04001ooekgG_L2IcT4JeX5Li`4JeX2Li`9Ool2Mkd9Li`2HaP2IcT2JeX6Mkd2Kg/0
0f<HG_MNm`0?Kg/4Mkd00goo001oo`06Ool01000OomBU5:D0Tic1CF]0Sg_0THa1T8@0THa0dic17oo
0Sg_0SF]3Be[1RU:0V<H1AcW0TYB27_N27oo00<007ooOol01Woo0007Ool00`00OomNm`03G_L4JeX0
0f<HLiacW002IcT2DY@2BU82?Nl2F]H2@Q000g>LOomoo`02Kg/4JeX2IcT2<H`2:DX79BT2;F/2IcT2
Li`2HaP00e[F6<HHaP02@Q04IcT2Kg/2IcT2JeX3Kg/2JeX2Li`00goo001oo`06Ool01000OomNmekg
0VLi16]J1G>L16]J0W>L2Goo0WNm2G>L0V<H0VLi0V]J1WNm0Vmk00=S65kgG_L03fmk17Nm00=oo`00
Ool01Woo00@007ooDYABU09>L`De[@8mk`96<@I24096<@=>L`Aoo`8mk`8e[@d]J`HYBP9S60DLi`9:
DPQkgPQoo`03001oogoo00Ioo`001goo00@007ooG_MNm`96<@92408]J`03<H`mkcg_0096<@@icP8m
k`9BU09W>@03Lia_Nfmk009g_@9cW08e[@8]J`8U:@8YBP039BTYBRU:008U:@@YBP8Q209W>@=S608L
i`92409cW09W>@]_N`9g_@03Ool007oo00Ioo`04001ooekgG_L2IcT4JeX5Li`2HaP2F]H2E[D2JeX2
Li`5Ool2Mkd2Li`2JeX2HaP2;F/38@P49BT2IcT6Kg/00f<HG_MNm`0?Kg/4Mkd00goo001oo`06Ool0
1000Oom:DTYB136<1B4813F]148@0THa0dic0Vmk3Be[32DY0SW>1AcW0T8@0W>L1Vmk00=W>EkgG_L0
15Je00=oo`00Ool01goo0007Ool01000OomS66<H0T8@12U:00<Lic6<<H`00Re[0Ukg0Tic0THa0Tic
0fmk0V]J0Ukg22DY0RU:00<U:BU::DX00R4812DY0R480S6<0V<H00=BU2488@P00SW>0V<H16Li0Ukg
0V<H00=NmeJeE[D00U:D0TYB00=oo`00Ool01Woo00<007ooG_L00ekg0T8@0Sg_00<e[D8@@Q000U[F
1V]J0Vmk0g>L1WNm0W>L0Re[0RDY1B481RDY1V<H0ekg3fmk17Nm00=oo`00Ool01Woo00@007ooBU9:
DP8aS08U:@DQ20@e[@HicP9JeP03IcT]Jbe[00d]J`8U:@HLi`LQ208HaPH48@8<H`8@Q08HaP037>LY
BRU:008aS08e[@03Ool007oo00Moo`001goo00@007ooHaQS609240@YBP037>LaS36<008]J`9Nm`9>
L`96<@9>L`=_N`9[FP9Nm`PU:@8YBP039BTYBRU:008Q20@U:@8Q208aS09S6003DY@Q2248008icP9S
60AW>@9Nm`9S6003G_MF]EJe009BU09:DP03Ool007oo00Ioo`03001ooekg00=Nm`92408mk`03=Je2
448@009JePI[FP9_N`=cW0Ig_@9cW08]J`8U:@DQ20HU:@IS60=Nm`m_N`Ag_@03Ool007oo00Ioo`04
001oodYBBU82<H`29BT58@P4=Jd6>Lh2F]H00fLi;F/]J`0=;F/29BT67>L78@P26<H6124236<248@2
6<H00acW:DXYBP02<H`2=Jd00goo001oo`07Ool000Moo`04001ooekgG_L2AS42:DX38@P4<H`2AS42
JeX2<H`2HaP2Li`00f]JE[EF]@0?9BT28@P26<H48@P27>L3G_L28@P25:D2124236<248@25:D26<H0
0b48:DXYBP02;F/2=Jd00goo001oo`06Ool00`00OomS6003HaP2F]H5CW<2F]H6JeX5Kg/4JeX2F]H9
9BT48@P47>L2:DX5G_L2F]H6JeX2IcT9JeX2IcT00goo001oo`06Ool01000Oom:DTYB0S6<0RDY1B48
13F]1SW>0TYB1be[1RU:0Re[0bDY1QcW1R4800<U:AS66<H01P@Q0PaS0Q240QS600<LibU::DX00S6<
0SF]00=oo`00Ool01goo0007Ool01000OomNmekg0THa0RU:0b48136<0THa0V]J0S6<0V<H0W>L00=[
FUJeE[D03bDY0R480QS612480QcW0ekg0R480QBU0P@Q0PaS0Q240QBU0QS600<Q22U::DX00Re[0SF]
00=oo`00Ool01Woo00<007ooHaP00f<H0U[F1Dic0U[F1V]J1Fmk16]J0U[F2BDY124811cW0RU:1Ekg
0U[F1V]J0VLi2F]J0VLi00=oo`00Ool01Woo00@007ooBU9:DP8aS08U:@DQ20@e[@HicP9:DPL]J`HY
BP8]J`<U:@HLi`HQ20039BTHaQS600H48@8<H`8@Q08HaP037>LYBRU:008aS08e[@03Ool007oo00Mo
o`001goo00@007ooHaQS609Nm`8YBP=BU096<@8mk`8aS08mk`A2409W>@03JeXU:BDY00@U:@8YBP8Q
208U:@8YBP039BTQ224800@U:@8Q20@Li`9>L`03G_LQ2248008YBP9[FPIW>@9[FP03IcU[FV]J00A[
FP03Ool007oo00Ioo`03001oof<H00=S609JePE>L`9JePI[FPE_N`9W>@9F]@/U:@@Q20HLi`9JePEW
>@m[FPA_N`03Ool007oo00Ioo`04001ooe:DDY@2<H`29BT57>L2;F/8>Lh9;F/6:DX2;F/39BT67>L6
6<H00bDY6<HHaP06124236<248@26<H00acW:DXYBP02<H`2=Jd00goo001oo`07Ool000Moo`04001o
of<HHaP2G_L2:DX3DY@2AS42?Nl2<H`2?Nl4@Q02IcT00f]J9BTU:@049BT2:DX28@P29BT2:DX00bDY
8@PQ20049BT28@P47>L2CW<00ekg8@PQ2002:DX2JeX6IcT2JeX00fLiJeY[FP04JeX00goo001oo`06
Ool00`00OomS6003HaP2F]H5CW<2F]H6JeX5Kg/2IcT2E[D;9BT48@P67>L2F]H5IcT?JeX4Kg/00goo
001oo`06Ool01000OomBU5:D0S6<0RDY1AcW0Re[23W>2Be[1RU:0Re[0bDY1QcW1QS600<U:AS66<H0
1P@Q0PaS0Q240QS600<LibU::DX00S6<0SF]00=oo`00Ool01goo0007Ool01000OomNmekg0U[F0Sg_
0R4800<HaRDY9BT00Sg_15kg16<H0V]J00<U:BU::DX022DY0Re[1BDY0R480RDY0QcW0QS60QBU0S6<
00=W>BU::DX00S6<16]J0Vmk0VLi0fmk16]J0Vmk00=oo`00Ool01Woo00<007ooHaP00f<H0U[F0UJe
0dic16Li2F]J0VLi0R482bDY12481QcW0TYB1FLi3f]J16mk00=oo`00Ool01Woo00@007ooHaQS608a
S08YBPDDY@@U:@8icP96<@8mk`DYBP@]J`HYBP8]J`DU:@8Q20HDY@8HaP038@PYBRU:008YBP8aS0Qg
_@03Nmig_GNm00Ag_@03Ool007oo00Moo`001goo00@007ooG_MNm`9JeP8mk`8Q20036<HU:BDY008m
k`ANm`AS609[FP039BTYBRU:00PU:@8]J`DU:@8Q208U:@8Li`8HaP8DY@8aS003IcTYBRU:008aS0A[
FP9_N`9W>@=_N`A[FP9_N`03Ool007oo00Ioo`03001oof<H00=S609JeP9F]@=>L`AW>@U[FP9W>@8Q
20/U:@@Q20HLi`9:DPEW>@m[FPA_N`03Ool007oo00Ioo`04001oof<HHaP2<H`2:DX55:D49BT2>Lh2
AS42?Nl5:DX4;F/6:DX2;F/59BT28@P65:D26<H00b48:DXYBP02:DX2<H`8Mkd00g_NMkeg_@04Mkd0
0goo001oo`07Ool000Moo`04001ooekgG_L2DY@2E[D2<H`00a248@PQ20028@P2JeX2HaP2JeX2HaP2
=Jd00b489BTU:@02:DX29BT2:DX2;F/2:DX29BT00bU:9BTU:@048@P27>L248@26<H27>L00ekg<H`a
S002<H`2JeX4IcT2JeX2Kg/00fLiJeY[FP02IcT2JeX00goo001oo`06Ool00`00OomJeP03F]H5E[D2
G_L4IcT9JeX68@P2:DX2CW<9HaP2G_L28@P25:D2:DX5IcT?JeX4Kg/00goo001oo`06Ool01000OomS
66<H0THa0RU:1ABU12DY16mk1BDY0RU:3Be[12DY0QcW0QBU1Q2400<Lic6<<H`00S6<0SF]3gNm00=o
o`00Ool01goo0007Ool01000OomNmekg0U:D0UJe0S6<00<@Q2488@P00R480V]J0V<H0V]J0V<H0SF]
00<Q22DY9BT00RU:0RDY0RU:0Re[0RU:0RDY00<YBRDY9BT012480QcW0Q240QS60QcW00=Nmc6<<H`0
0S6<0V]J16Li0V]J0Vmk00=W>F]JJeX00VLi0V]J00=oo`00Ool01Woo00<007ooF]H00e[F1EJe0Ukg
16Li2F]J1R480RU:0Tic2F<H0Ukg0R480QBU0RU:1FLi3f]J16mk00=oo`00Ool01Woo00@007ooHaQS
6096<@8YBPDDY@@U:@A_N`DU:@8YBPd]J`@U:@8Li`8DY@H@Q0037>LaS36<008aS08e[@mg_@03Ool0
07oo00Moo`001goo00@007ooE[EF]@9JeP9BU09>L`03;F]JeU[F00AS609W>@9[FP9W>@8Q20LU:@8Y
BP8]J`9BU0=W>@AS608U:@8HaP8@Q08<H`8HaP03HaPe[CF]008]J`9[FPAW>@9[FP9S6003JeYW>FLi
009W>@9[FP03Ool007oo00Ioo`03001ooe[F00=JePEF]@9Nm`AW>@I[FP9S6003;F/Q2248008U:@9F
]@9W>@9[FPEkgPAW>@AS60@DY@ENm`I[FP9W>@][FP03Ool007oo00Ioo`03001oof<H00=S608mk`DD
Y@@U:@9_N`8icPDU:@8YBPH]J`8aS0D]J`@U:@8Li`8DY@H@Q0036<He[CF]00@e[@AcW0]g_@03Ool0
07oo00Moo`001goo00@007ooE[EF]@9JeP9BU09>L`03;F]JeU[F00AS609W>@9[FP9W>@8Q20LU:@8Y
BP8]J`9BU0=W>@AS608U:@8HaP8@Q08<H`8HaP03HaPe[CF]008]J`9[FPAW>@9[FP9S6003JeYW>FLi
009W>@9[FP03Ool007oo00Ioo`03001ooe[F00=JePEF]@9Nm`AW>@I[FP9S6003;F/Q2248008U:@9F
]@9W>@9[FPEkgPAW>@AS60@DY@ENm`I[FP9W>@][FP03Ool007oo00Ioo`03001oof<H00=S608mk`DD
Y@@U:@9_N`8icPDU:@8YBPH]J`8aS0D]J`@U:@8Li`8DY@H@Q0036<He[CF]00@e[@AcW0]g_@03Ool0
07oo00Moo`001goo00@007ooF]IJeP9F]@9JeP9F]@03BU9JeU[F009JeP9Nm`AW>@8aS08Q20DU:@8Y
BP9F]@9[FP9_N`9kgP=[FP9W>@9S608Li`8@Q08<H`8DY@03HaPicSW>008]J`9[FP9S609[FP9W>@9S
6003IcU[FV]J00AW>@03Ool007oo00Ioo`03001ooe[F00MJeP03E[ENmekg009Nm`QW>@9S60038@P]
Jbe[00Q[FPEkgP9[FP9W>@AS6092408@Q0ENm`I[FP9W>@E[FP9W>@A[FP03Ool007oo00Ioo`04001o
ofLiIcT2HaP2F]H5=Jd4G_L2Kg/68@P00bDY;F/]J`06;F/2<H`2=Jd2HaP00gNmLiacW002;F/27>L6
36<248@00aBU=Jde[@04=Jd4Li`7Mkd4Li`00goo001oo`07Ool000Moo`04001ooe[FF]H2E[D2F]H2
E[D00dYBF]IJeP02F]H2G_L4IcT2<H`28@P59BT2:DX2E[D2JeX2Kg/2Nmh3JeX2IcT2HaP27>L248@2
36<25:D00f<H>LhicP02;F/2JeX2HaP2JeX2IcT2HaP00fLiJeY[FP04IcT00goo001oo`06Ool00`00
OomJeP07F]H00eJeG_MNm`02G_L8IcT2HaP00b48;F/]J`08JeX5Nmh2JeX2IcT4HaP2@Q0248@5G_L6
JeX2IcT5JeX2IcT4JeX00goo001oo`06Ool01000OomW>FLi0V<H0U[F1CF]15kg0Vmk1R4800<U:Be[
;F/01Re[0S6<0SF]0V<H00=g_G>LLi`00Re[0QcW1PaS0Q2400<DYCF]=Jd013F]17>L1gNm17>L00=o
o`00Ool01goo0007Ool01000OomF]EJe15kg0eJe15:D1V<H0QcW0bDY0RU:0SF]2V]J00=_Nf]JJeX0
0V<H0VLi0THa10aS0Q2400=:DSg_?Nl00Re[16<H16Li0Vmk00=S66]JJeX00V]J0V<H00=oo`00Ool0
1Woo00<007ooF]H01e[F0eJe0Ukg1VLi0V<H0RU:00<]JekgG_L01Vmk0V]J1G_N0V]J16Li0V<H0UJe
0PaS1Ekg1V]J0VLi1F]J1VLi00=oo`00Ool01Woo00<007ooG_L01Ekg1EJe15kg0U:D1R480bDY12e[
0S6<0VLi17_N00=g_G>LLi`00Vmk0R481PaS0Q2400<DYCF]=Jd013F]17>L1gNm17>L00=oo`00Ool0
1goo0007Ool01000OomF]EJe0Tic2E[F0U:D0Ukg0THa0QcW0b480S6<0V<H0W>L26]J00=W>F<HHaP0
0V]J0Ukg0UJe0PQ20Q240QBU00<aS4HaAS400S6<16<H0VLi0V]J0fLi0V<H0VLi0V]J00=oo`00Ool0
1Woo00<007ooF]H01e[F0eJe2Ukg0R480fLi16mk1W>L1F]J16Li0V<H0UJe0Q241DHa16<H16Li2f]J
00=oo`00Ool01Woo00@007ooG_MNm`IJeP03HaQNmekg00ANm`8aS0HHaP<U:@8aS08mk`IkgP=g_@9_
N`9S609BU0H<H`8@Q0035:DaS36<00@aS0AcW0Mg_@AcW003Ool007oo00Moo`001goo00@007ooE[EF
]@9>L`UJeP9BU09Nm`96<@8Li`<Q208aS09S609cW0Q[FP03IcUS66<H009[FP9Nm`9F]@88@P8@Q08D
Y@03<Ha6<DHa008aS0AS609W>@9[FP=W>@9S609W>@9[FP03Ool007oo00Ioo`03001ooe[F00MJeP=F
]@YNm`8Q20=W>@A_N`IcW0E[FPAW>@9S609F]@8@Q0E6<@AS60AW>@][FP03Ool007oo00Ioo`04001o
oekgG_L6F]H00f<HG_MNm`04G_L2<H`66<H39BT2<H`2?Nl6Nmh3Mkd2Kg/2HaP2DY@636<248@00aBU
<H`aS004<H`4Li`7Mkd4Li`00goo001oo`07Ool000Moo`04001ooe:DDY@2F]H2CW<2E[D5F]H2G_L2
F]H2:DX25:D28@P00bDYIcUW>@02IcT4JeX2Li`4JeX3HaP2G_L4DY@436<26<H00d8@AS56<@02:DX2
IcT2HaP9IcT2JeX2IcT00goo001oo`06Ool00`00OomF]@0:E[D8F]H4@Q03IcT4Kg/6Li`3Kg/6IcT2
F]H2E[D2:DX2?Nl3@Q06HaP7IcT6JeX00goo001oo`06Ool01000OomNmekg1U[F00=Nmf<HHaP015kg
0QcW1QS60bDY0Sg_0W>L1W_N0WNm00=cW6mkKg/016<H20aS00<HaS6<<H`0136<17>L2GNm0W_N00=o
o`00Ool01goo0007Ool01000OomBU5:D0U[F0Tic0UJe1E[F0Ukg0U[F0RU:0QBU0R4800<U:FLiIcT0
0VLi16]J0W>L16]J0f<H0Ukg15:D10aS0QS600=244HaAS400RU:0VLi0V<H2FLi0V]J0VLi00=oo`00
Ool01Woo00<007ooE[D02UJe25[F148@0fLi16mk1W>L0fmk1VLi0U[F0UJe0RU:0Sg_0d8@1V<H1fLi
1V]J00=oo`00Ool01Woo00@007ooG_MNm`IJeP03G_MS66<H00ANm`8Li`HHaP<U:@8mk`9cW0IkgP9g
_@03Lia_Nfmk00AS60P<H`036<HaS36<00@aS0AcW0Ug_@9kgP03Ool007oo00Moo`001goo00@007oo
DYABU0AJeP9>L`03DYAF]EJe00AJeP9Nm`8HaP8Li`8U:@03AS5W>FLi009W>@I[FPA_N`=S609Nm`AF
]@8@Q08<H`8aS003@Q16<DHa008YBPAW>@9S609W>@9S60=W>@A[FP03Ool007oo00Ioo`03001ooeJe
00YF]@QJeP8Q20U[FPIcW0=_N`9[FP9S609JeP9F]@9BU0E:DP96<@IS60MW>@I[FP03Ool007oo00Io
o`04001ooekgG_L6F]H5DY@2IcT65:D26<H00bDY;F/]J`04Mkd2Nmh6Mkd00f]J>LhicP027>L26<H2
48@636<00acW<H`aS004<H`9Li`2Mkd4Nmh00goo001oo`07Ool000Moo`04001ooe:DDY@4F]H2CW<0
0e:DE[EF]@04F]H2G_L26<H27>L29BT00dHaIcUW>@02IcT6JeX4Kg/3HaP2G_L4E[D248@236<2<H`0
0d8@AS56<@02:DX4IcT2HaP2IcT2HaP3IcT4JeX00goo001oo`06Ool00`00OomF]@0:E[D8F]H28@P9
JeX6Li`3Kg/2JeX2HaP2F]H2E[D2DY@5BU82AS46HaP7IcT6JeX00goo001oo`06Ool01000OomNmekg
1U[F1E:D0VLi1QBU0QS600<U:Be[;F/017Nm0W_N1WNm00=[FSW>>Lh00QcW0QS60Q241PaS00<Lic6<
<H`0136<2G>L0WNm17_N00=oo`00Ool01goo0007Ool01000OomBU5:D15[F0U:D00=F]DHaAS400UJe
15[F0Q240QS60R480f]J0VLi0V]J26Li00=_Ne[FF]H00S6<0QS60QBU10aS0Tic00<icTYBBU800RU:
0VLi26<H00=W>F]JJeX00V]J0Vmk00=oo`00Ool01Woo00<007ooE[D00eJe1E[F15Je1U[F0QcW0f]J
1WNm16]J1Fmk0V]J0Ukg0U[F0UJe0U:D14YB0dic1V<H2FLi16]J00=oo`00Ool01Woo00<007ooG_L0
1ekg1E:D0Ukg21BU00<Lie:DDY@02WNm0Sg_00<LiaBU5:D00QBU2PaS00<icRe[;F/012e[2G>L1WNm
00=oo`00Ool01goo0007Ool01000OomBU5:D15[F0U:D00=F]DHaAS400UJe15[F0Q240QS60R480f]J
0VLi0V]J26Li00=_Ne[FF]H00S6<0QS60QBU10aS0Tic00<icTYBBU800RU:0VLi26<H00=W>F]JJeX0
0V]J0Vmk00=oo`00Ool01Woo00<007ooE[D00eJe1E[F15Je1U[F0QcW0f]J1WNm16]J1Fmk0V]J0Ukg
0U[F0UJe0U:D14YB0dic1V<H2FLi16]J00=oo`00Ool01Woo00<007ooG_L01ekg1E:D0Ukg21BU00<L
ie:DDY@02WNm0Sg_00<LiaBU5:D00QBU2PaS00<icRe[;F/012e[2G>L1WNm00=oo`00Ool01goo0007
Ool01000OomBU5:D0UJe0U[F0Ukg0eJe0Tic0U:D0Ukg11240QS60fLi0WNm0V]J26Li00<e[AS66<H0
11241PaS0THa00=245:DDY@00RDY26<H0fLi0V]J0V<H0V]J00=oo`00Ool01Woo00<007ooE[D00eJe
1E[F15Je1U[F0QS60f]J1WNm17>L0VLi1F]J0UJe0RU:0Q240PaS1E:D0Tic26<H1fLi16]J00=oo`00
Ool01Woo00@007ooG_MNm`IJePEBU09Nm`H@Q08DY@037>McW7>L009cW09kgP9g_@9cW08]J`8Q2003
7>LDYABU008@Q0X<H`03AS4YBRU:00@YBPUcW0Ig_@03Ool007oo00Moo`001goo00@007ooDYABU09F
]@9JeP9Nm`=F]@9>L`9BU09Nm`@@Q08HaP=W>@9g_@9[FPQW>@03=JdHaQS600@@Q0H<H`96<@03@Q1B
U5:D008U:@QS60=W>@9[FP9S609[FP03Ool007oo00Ioo`03001ooeJe00=F]@EJePAF]@IJeP8HaP=[
FPIg_@AcW09W>@E[FP9F]@8YBP8@Q08<H`EBU09>L`QS60MW>@A[FP03Ool007oo00Ioo`04001ooekg
G_L6F]H5DY@2G_L648@25:D00acWLiacW002Li`2Nmh2Mkd2Li`2;F/28@P00acW5:DDY@0248@:36<0
0dHa:DXYBP04:DX9Li`6Mkd00goo001oo`07Ool000Moo`04001ooe:DDY@2E[D2CW<2F]H3E[D4F]H2
DY@236<248@27>L00fLiHaQS6004IcT2Li`2IcT2HaP29BT00acW6<HHaP0448@2248236<248@2DY@0
0d8@DYABU0028@P;HaP2IcT2HaP2IcT00goo001oo`06Ool01000OomBU5:D0UJe1E[F15Je1U[F0QBU
0fLi1WNm17>L0V]J0f<H0Re[0Q2410Q20P@Q1E:D0Tic26<H2fLi00=oo`00Ool01Woo00@007ooG_MN
m`9JePE>L`INm`P@Q0037>McW7>L009cW0Ag_@8aS08U:@8Q20036<H@Q124008@Q0X<H`03>LhYBRU:
00@YBPI_N`EcW0Ag_@03Ool007oo00Moo`001goo00@007ooDYABU09F]@9>L`9JeP=F]@AJeP9BU08<
H`8@Q08Li`03IcUS66<H00AW>@9cW09W>@9S608U:@037>LHaQS600@@Q088@P8<H`8@Q09BU003@Q1B
U5:D008Q20]S609W>@9S609W>@03Ool007oo00Ioo`04001ooe:DDY@2E[D5F]H4E[D6F]H25:D3IcT6
Mkd4Li`2JeX3HaP2;F/248@424821245DY@2CW<8HaP;IcT00goo001oo`06Ool01000OomNmekg0U[F
1Dic1Ukg212400<Lig>LLi`00W>L17Nm0S6<0RDY0R4800<HaQ2448@00Q242PaS00<icRU::DX012U:
1Vmk1G>L17Nm00=oo`00Ool01goo0007Ool01000OomBU5:D15Je0T8@00=BU5JeE[D015[F0UJe1124
0QS60f<H1VLi0V]J0RU:0R4800<LiaBU5:D00Q2420aS0S6<00=6<E:DDY@00R4816<H0Ukg0V<H0VLi
0f<H0VLi0V<H00=oo`00Ool01Woo00@007ooDYABU0]F]@IJeP8DY@MW>@IcW09[FP9Nm`037>LDYABU
008@Q0@8@P848@MBU0aS60MW>@03Ool007oo00Ioo`04001ooekgG_L2F]H5CW<2DY@2G_L2HaP636<2
48@00aBULiacW004Li`2BU82:DX48@P00aS648@@Q00248@:36<00aS6:DXYBP04:DX2Kg/6JeX3Kg/4
Li`00goo001oo`07Ool000Moo`04001ooe:DDY@4E[D2@Q000e:DE[EF]@04F]H2E[D448@26<H3HaP6
IcT2JeX2:DX28@P00acW5:DDY@0248@836<2<H`00dHaDYABU0028@P4HaP2G_L2HaP2IcT3HaP2IcT2
HaP00goo001oo`06Ool01000OomBU5:D2eJe1U[F0QBU1fLi1W>L0V]J0Ukg00<LiaBU5:D00Q2410Q2
0P@Q1e:D36<H1fLi00=oo`00Ool01Woo00@007ooG_MNm`9JePE>L`9BU09Nm`9S60H<H`8@Q0035:Ec
W7>L00AcW09:DP8YBP@Q20036<H@Q124008@Q0X<H`036<HYBRU:00@YBP9_N`I[FP=_N`AcW003Ool0
07oo00Moo`001goo00<007ooDY@00e:D0UJe0U[F00=6<DicCW<00U:D0U[F0Ukg0PQ211241FLi0V<H
0VLi0T8@0R480acW0QBU11241PaS0QBU0e:D0R480Ukg16<H0U[F0ekg1V<H00=oo`00Ool01Woo00@0
07ooDYABU0UF]@QJeP8@Q09W>@e[FP8U:@036<HDYABU008<H`HDY@8YBPEBU0IS609Nm`ES60IW>@03
Ool007oo00Ioo`03001ooekg00=Nm`E>L`9BU0AF]@H<H`8@Q0035:E6<DHa00AcW08]J`8YBP@Q2003
5:D@Q12400@@Q08<H`H8@P0336<Q224800@Q20Q[FP=_N`AcW003Ool007oo00Moo`001goo00@007oo
DYABU09F]@9BU0=F]@9BU09:DPANm`8DY@8@Q08DY@03?Nm_Nfmk009[FPAS608U:@@Q20037>L@Q124
00@@Q08Li`8DY@88@P8<H`=BU08Li`9Nm`9JePANm`9S6003G_MS66<H00AS6003Ool007oo00Ioo`04
001ooe:DDY@9E[D6G_L2F]H25:D2IcT3JeX6Kg/2IcT2>Lh27>L00bU:@Q124002CW<6DY@2CW<5DY@<
G_L00f<HIcUW>@04IcT00goo001oo`06Ool00`00OomNm`05G_L5DY@4E[D636<248@00aBU8@PQ2002
IcT2AS449BT48@P55:D248@236<624800`aS8@PQ20048@P8JeX3Kg/4Li`00goo001oo`07Ool000Mo
o`04001ooe:DDY@2E[D2DY@3E[D2DY@2BU84G_L25:D248@25:D00cg_Kg]_N`02JeX4HaP29BT48@P0
0acW48@@Q00448@27>L25:D2248236<3DY@27>L2G_L2F]H4G_L2HaP00ekgHaQS6004HaP00goo001o
o`06Ool01000OomBU5:D2EJe1Ukg0U[F0QBU0VLi0f]J1Vmk0VLi0SW>0QcW00<YBT8@@Q000Tic1U:D
0Tic1E:D35kg00=S66LiIcT016Li00=oo`00Ool01Woo00<007ooG_L01Ekg1E:D15Je1PaS0Q2400<D
YB488@P00VLi0THa12DY12481ABU0Q240PaS1PQ200<<Hb488@P0124826]J0fmk17>L00=oo`00Ool0
1goo0007Ool00`00OomBU007DY@00e[FE[EF]@02E[D2HaP2G_L27>L236<248@00acWE[EF]@02IcT2
Kg/2?Nl48@P37>L2<H`2AS42DY@2E[D2DY@26<H236<00cW>DYABU0028@P2HaP2G_L9HaP2IcT2HaP0
0goo001oo`06Ool00`00OomBU003DY@7E[D6G_L2F]H29BT2=Jd3JeX6Kg/2G_L29BT2DY@5E[D8DY@5
CW<:G_L3HaP6IcT00goo001oo`06Ool01000OomNmekg0U[F1E:D1UJe0QS61Q2400<DYAS66<H012e[
12DY12482ABU1`Q21R4816]J1fmk0W>L0WNm00=oo`00Ool01goo0007Ool00`00OomBU007DY@00e[F
E[EF]@02E[D2HaP2G_L27>L236<248@00acWE[EF]@02IcT2Kg/2?Nl48@P37>L2<H`2AS42DY@2E[D2
DY@26<H236<00cW>DYABU0028@P2HaP2G_L9HaP2IcT2HaP00goo001oo`06Ool00`00OomBU003DY@7
E[D6G_L2F]H29BT2=Jd3JeX6Kg/2G_L29BT2DY@5E[D8DY@5CW<:G_L3HaP6IcT00goo001oo`06Ool0
1000OomNmekg0U[F1E:D1UJe0QS61Q2400<DYAS66<H012e[12DY12482ABU1`Q21R4816]J1fmk0W>L
0WNm00=oo`00Ool01goo0007Ool00`00OomBU003DY@2CW<2AS45E[D2F]H2G_L2;F/248@35:D29BT2
AS42HaP29BT48@P2:DX00eJeF]IJeP04DY@2AS42DY@2;F/224800dYBCW=>L`029BT4G_L4HaP2G_L0
0fLiHaQS6002HaP2IcT00goo001oo`06Ool00`00OomF]@08E[D2F]H6G_L2F]H2;F/27>L00e:DHaQS
6006Kg/2=Jd5HaP6E[D6DY@2AS43CW<:G_L3HaP6IcT00goo001oo`06Ool01000OomNmekg0U[F0U:D
1DYB16Li0R481Q2400<DYAS66<H00Re[3B480SW>0U:D0THa0QcW1@@Q1RDY2fmk0W>L0WNm00=oo`00
Ool01goo0007Ool00`00OomBU003DY@2CW<2AS45E[D2F]H2G_L2;F/248@35:D29BT2AS42HaP29BT4
8@P2:DX00eJeF]IJeP04DY@2AS42DY@2;F/224800dYBCW=>L`029BT4G_L4HaP2G_L00fLiHaQS6002
HaP2IcT00goo001oo`06Ool00`00OomF]@08E[D2F]H6G_L2F]H2;F/27>L00e:DHaQS6006Kg/2=Jd5
HaP6E[D6DY@2AS43CW<:G_L3HaP6IcT00goo001oo`06Ool01000OomNmekg0U[F0U:D1DYB16Li0R48
1Q2400<DYAS66<H00Re[3B480SW>0U:D0THa0QcW1@@Q1RDY2fmk0W>L0WNm00=oo`00Ool01goo0007
Ool01000OomBU5:D0UJe15:D00=245JeE[D00Ukg0V<H0Ukg0SF]0Q240QBU00<U:DHaAS400Ukg0V]J
11cW0Re[0VLi00=JeUJeE[D00U[F15Je0Sg_0RDY0P0000=:DTicCW<00R4815kg0V<H0Ukg0V<H00=N
mf<HHaP00VLi0V<H00=oo`00Ool01Woo00<007ooE[D01EJe0U:D00=F]E[FF]H01Ukg0U[F0Tic0UJe
0f<H1VLi0UJe1F<H1UJe1U:D0THa0dYB15[F15kg2f<H00=oo`00Ool01Woo00@007ooG_MNm`9JeP9B
U0E:DP9>L`9Nm`8e[@H@Q0<HaP8]J`PQ208U:@03<HaNmekg009S609BU096<@8<H`D48@HU:@]_N`Ac
W003Ool007oo00Moo`001goo00@007ooDYABU09F]@ABU003@Q1F]EJe009Nm`9S609Nm`8e[@8@Q08D
Y@039BU6<DHa009Nm`9[FP@Li`8]J`9W>@03F]IF]EJe009JePAF]@8mk`8U:@800003BU9>Ldic008Q
20ANm`9S609Nm`9S6003G_MS66<H009W>@9S6003Ool007oo00Ioo`03001ooeJe00EF]@9BU003E[EJ
eU[F00INm`9JeP9>L`9F]@=S60IW>@9F]@ES60IF]@IBU096<@=:DPAJePANm`]S6003Ool007oo00Io
o`04001ooekgG_L2F]H2DY@5BU82CW<2G_L2=Jd648@36<H2;F/88@P29BT00c6<G_MNm`02HaP2DY@2
AS4236<512469BT;Kg/4Li`00goo001oo`07Ool000Moo`04001ooe:DDY@2F]H2E[D2DY@00eJe@Q12
4002DY@2G_L2F]H2>Lh2=Jd2DY@00eJeHaQS6002G_L2F]H27>L28@P2F]H2HaP9DY@2CW<436<00cW>
AS56<@028@P8G_L3HaP2IcT4HaP00goo001oo`06Ool00`00OomF]@05E[D2DY@00eJeF]IJeP06G_L2
F]H2CW<2E[D3HaP6IcT7HaP6E[D4DY@2BU82AS43BU84F]H4G_L;HaP00goo001oo`06Ool00`00OomJ
eP05F]H5BU82CW<2E[D29BT65:D00aS6;F/]J`02DY@88@P2=Jd00ekgDYABU004DY@26<H236<51246
9BT4JeX7Kg/4Li`00goo001oo`07Ool000Moo`04001ooe:DDY@2F]H2E[D2DY@00eJe@Q124002DY@2
G_L2F]H2>Lh2=Jd2DY@00eJeHaQS6002G_L2F]H27>L28@P2F]H2HaP9DY@2CW<436<00cW>AS56<@02
8@P8G_L3HaP2IcT4HaP00goo001oo`06Ool00`00OomF]@05E[D2DY@00eJeF]IJeP06G_L2F]H2CW<2
E[D3HaP6IcT7HaP6E[D4DY@2BU82AS43BU84F]H4G_L;HaP00goo001oo`06Ool00`00OomJeP05F]H5
BU82CW<2E[D29BT65:D00aS6;F/]J`02DY@88@P2=Jd00ekgDYABU004DY@26<H236<512469BT4JeX7
Kg/4Li`00goo001oo`07Ool000Moo`04001ooeJeE[D2BU82DY@2E[D3DY@2CW<2E[D2BU828@P248@2
5:D00dYBG_MNm`02IcT2G_L27>L29BT2HaP3F]H2DY@2AS42DY@2BU825:D436<00d8@BU9:DP028@P4
F]H4G_L9HaP00goo001oo`06Ool00`00OomF]@05E[D5DY@6F]H2E[D2CW<2E[D7HaP2F]H6HaP00ekg
E[EF]@04DY@4CW<2BU82AS43DY@8F]H;HaP00goo001oo`06Ool01000OomJeU[F2Dic0SF]0QcW0QBU
1Q2400<DYAS66<H00V]J1R480RDY0ekg0U:D0Sg_0Q241PQ20`aS1RDY16]J1fmk17>L00=oo`00Ool0
1goo0007Ool01000OomF]EJe0TYB0U:D0UJe0e:D0Tic0UJe0TYB0R480Q240QBU00=:DUkgG_L00VLi
0Ukg0QcW0RDY0V<H0e[F0U:D0THa0U:D0TYB0QBU10aS00=244YBBU800R4815[F15kg2F<H00=oo`00
Ool01Woo00<007ooE[D01EJe1E:D1U[F0UJe0Tic0UJe1f<H0U[F1V<H00=NmeJeE[D015:D14ic0TYB
0THa0e:D25[F2f<H00=oo`00Ool01Woo00@007ooF]IJePU>L`8e[@8Li`8DY@H@Q0035:DHaQS6009[
FPHQ208U:@=Nm`9BU08mk`8@Q0H8@P<<H`HU:@A[FPM_N`AcW003Ool007oo00Moo`001goo00<007oo
DY@00e:D0T8@1e:D0Re[0QS60Q240PaS0Q2400<DYE[FF]H015[F0QcW0R480V<H0Ukg0eJe0TYB0SF]
0PaS0PQ20PaS0QcW00=:DU:DDY@00R480Ukg0U[F15kg0V<H00=Nmf<HHaP016<H00=oo`00Ool01Woo
00<007ooDY@045:D0THa0QS60THa00=JeV<HHaP016<H0U[F1V<H00=JeUJeE[D00U:D14ic0THa0Sg_
0Tic0e:D1U[F0Ukg2f<H00=oo`00Ool01Woo00@007ooF]IJePI>L`03DY@aS36<00@HaP8DY@L@Q08H
aP9>L`PQ208aS003=JdDYABU008@Q0P8@P8<H`0348@U:BDY00@U:@AW>@9[FPE_N`AcW003Ool007oo
00Moo`001goo00<007ooDY@00e:D0T8@1e:D0Re[0QS60Q240PaS0Q2400<DYE[FF]H015[F0QcW0R48
0V<H0Ukg0eJe0TYB0SF]0PaS0PQ20PaS0QcW00=:DU:DDY@00R480Ukg0U[F15kg0V<H00=Nmf<HHaP0
16<H00=oo`00Ool01Woo00<007ooDY@045:D0THa0QS60THa00=JeV<HHaP016<H0U[F1V<H00=JeUJe
E[D00U:D14ic0THa0Sg_0Tic0e:D1U[F0Ukg2f<H00=oo`00Ool01Woo00@007ooF]IJePI>L`03DY@a
S36<00@HaP8DY@L@Q08HaP9>L`PQ208aS003=JdDYABU008@Q0P8@P8<H`0348@U:BDY00@U:@AW>@9[
FPE_N`AcW003Ool007oo00Moo`001goo00<007ooDY@00e:D0Tic0TYB00=6<E:DDY@00RU:11BU1Q24
00<DYD8@@Q0015[F0R480QcW0RU:0U:D00=6<Be[;F/011240PQ210aS0T8@0e:D0RDY0Ukg0UJe0U[F
16<H00=Nmf<HHaP00V<H0VLi00=oo`00Ool01Woo00<007ooDY@01E:D0dic1U:D0RDY0Q240PQ20PaS
2EJe1Ukg00=JeU:DDY@00U:D0THa0Re[0PQ21e:D1U[F0Ukg2f<H00=oo`00Ool01Woo00@007ooG_MN
m`I>L`03AS48@PQ200H8@PL@Q08DY@96<@HQ208Li`8HaP035:D@Q124008<H`P8@P8<H`038@PU:BDY
00@U:@AW>@9[FPE_N`AcW003Ool007oo00Moo`001goo00<007ooDY@00e:D1Dic0Sg_10Q20QBU1a24
0SW>0U[F0UJe1QcW0QS600<DYA2448@00Q2410aS0PQ20Q241E:D0RDY15[F15kg2F<H00=oo`00Ool0
1Woo00<007ooDY@025:D14ic2R4800<mkeJeE[D01UJe0R481Dic0T8@0RU:0PQ20P@Q0S6<1E:D0Tic
1U[F0Ukg2f<H00=oo`00Ool01Woo00@007ooG_MNm`AJeP9BU003>Lh48@@Q00@48@88@PL@Q08DY@96
<@8Q20@Li`8HaP8DY@0348@<H`aS008<H`P8@P8<H`03CW<]Jbe[00@]J`AW>@9[FPE_N`AcW003Ool0
07oo00Moo`001goo00<007ooDY@00e:D1Dic0Sg_10Q20QBU1a240SW>0U[F0UJe1QcW0QS600<DYA24
48@00Q2410aS0PQ20Q241E:D0RDY15[F15kg2F<H00=oo`00Ool01Woo00<007ooDY@025:D14ic2R48
00<mkeJeE[D01UJe0R481Dic0T8@0RU:0PQ20P@Q0S6<1E:D0Tic1U[F0Ukg2f<H00=oo`00Ool01Woo
00@007ooG_MNm`AJeP9BU003>Lh48@@Q00@48@88@PL@Q08DY@96<@8Q20@Li`8HaP8DY@0348@<H`aS
008<H`P8@P8<H`03CW<]Jbe[00@]J`AW>@9[FPE_N`AcW003Ool007oo00Moo`001goo00@007ooE[EF
]@A>L`9F]@03DY@aS36<0080008<H`8DY@8U:@8YBP8@Q0035:E2448@00AJeP8YBP8HaP8Li`8DY@03
48@<H`aS00H<H`88@P8icP924003DYA>Ldic008YBPIJeP9Nm`US6003Ool007oo00Ioo`03001ooe:D
00QBU09>L`8e[@9:DPIBU0=>L`QF]@96<@@DY@0348@<H`aS0088@P848@8DY@MBU09>L`AF]@AJePES
609Nm`AS6003Ool007oo00Ioo`04001ooekgG_L6DY@00aBU12448@041242248948@2AS428@P47>L2
6<H25:D736<624825:D00d8@;F/]J`04;F/4HaP5JeX6Kg/00goo001oo`07Ool000Moo`04001ooeJe
E[D4CW<2E[D00e:D<H`aS002000236<25:D29BT2:DX248@00aBU@Q124004F]H2:DX26<H27>L25:D0
0a2436<<H`0636<22482>Lh2@Q000e:DCW=>L`02:DX6F]H2G_L9HaP00goo001oo`06Ool00`00OomB
U008DY@2CW<2=Jd2BU86DY@3CW<8E[D2AS445:D00a2436<<H`02248212425:D7DY@2CW<4E[D4F]H5
HaP2G_L4HaP00goo001oo`06Ool01000OomNmekg1U:D00<DY@@Q124010@Q0PQ22A240THa0R4811cW
0QS60QBU1`aS1PQ20QBU00=242e[;F/012e[16<H1F]J1Vmk00=oo`00Ool01goo0007Ool01000OomF
]EJe0U:D0THa0Tic00=BU12448@00P@Q0RDY0Tic15:D0Sg_00<@Q5:DDY@00UJe0U:D0TYB0QS60QcW
0QBU00<@Q0Q224800PQ210aS0QcW0U:D0SW>00=244YBBU800Re[0U[F0U:D0Ukg15[F0ekg0V<H0Ukg
00=oo`00Ool01Woo00<007ooDY@025:D0Tic1UJe15:D0dic2UJe0RDY0QBU00<<H`Q224800PQ20Q24
0TYB1U:D0dic15Je15[F1ekg16<H00=oo`00Ool01Woo00@007ooF]IJeP9BU0A:DP0324848@@Q00@4
8@8<H`8HaP8DY@D@Q09>L`8aS0@Li`8HaPD8@PX<H`<@Q0HaS0AS60AW>@03JeY_Nfmk00A_N`03Ool0
07oo00Moo`001goo00@007ooE[EF]@9BU096<@9>L`03DY@@Q12400848@8U:@9>L`ABU08mk`0348AB
U5:D009F]@9BU09:DP8HaP8Li`8DY@0348@8@PQ20088@P@<H`8Li`9BU08icP03@Q1:DTYB008]J`9J
eP9BU09Nm`AJeP=Nm`9S609Nm`03Ool007oo00Ioo`03001ooe:D00QBU09>L`IF]@ABU0=>L`YF]@8U
:@8DY@0336<8@PQ20088@P8@Q09:DPIBU0=>L`AF]@AJePMNm`AS6003Ool007oo00Ioo`04001ooe[F
F]H2DY@4BU800`Q212448@04124236<26<H25:D548@2CW<2<H`47>L26<H5248:36<348@6<H`4HaP4
IcT00f]JKg]_N`04Kg/00goo001oo`07Ool000Moo`04001ooe:DDY@2BU82CW<2?Nl00dic2488@P02
6<H2E[D2DY@2BU82AS42:DX00a24@Q124002F]H2CW<2F]H2;F/26<H25:D3248236<248@26<H2CW<2
AS4236<00e:D@Q124002=Jd2E[D2F]H4E[D2HaP00ekgHaQS6002HaP2G_L00goo001oo`06Ool00`00
OomBU003DY@7CW<6E[D4DY@3CW<6F]H6E[D2>Lh00`aS2488@P02<H`2?Nl2BU86DY@3CW<4E[D4F]H;
G_L00goo001oo`06Ool01000OomJeU[F0U:D0TYB0THa1`Q20Re[0QBU1@aS0Q240T8@0UJe11cW0QBU
1@Q21PaS1PQ200<@Q3F]=Jd013F]16<H16Li00=[FVmkKg/016mk00=oo`00Ool01goo0007Ool01000
OomBU5:D0TYB0Tic0Sg_00=>L`Q224800QS60UJe0U:D0TYB0THa0RU:00<@Q48@@Q000U[F0Tic0U[F
0Re[0QS60QBU0`Q20PaS0Q240QS60Tic0THa0PaS00=BU48@@Q000SF]0UJe0U[F15Je0V<H00=Nmf<H
HaP00V<H0Ukg00=oo`00Ool01Woo00<007ooDY@00e:D1dic1UJe15:D0dic1U[F1UJe0SW>00<<H`Q2
24800S6<0Sg_0TYB1U:D0dic15Je15[F2ekg00=oo`00Ool01Woo00@007ooF]IJeP9BU09:DP96<@L8
@P8]J`8DY@D<H`8@Q092409F]@@Li`8DY@D8@PH<H`H8@P0348@e[CF]00@e[@AS60AW>@03JeY_Nfmk
00A_N`03Ool007oo00Moo`001goo00@007ooE[EF]@9BU09>L`9:DP03?Nl8@PQ2008mk`9BU09>L`8a
S08@Q088@P0348@e[CF]009Nm`9F]@AJeP9240<@Q088@P8@Q08icP92408@Q0848@8@Q003BU8mkcg_
008icP9F]@AJePMNm`AS6003Ool007oo00Ioo`03001ooe:D00=BU09>L`E:DPIF]@9BU096<@924003
?NmJeU[F00AJePQF]@03CW=2448@008aS08mk`I:DPE>L`AF]@AJePMNm`AS6003Ool007oo00Ioo`03
001ooe[F00=JeP9:DP96<@D8@PH@Q0D<H`8@Q08icP9Nm`8e[@8Li`8DY@D8@P8<H`X8@P0348A2448@
00A240QW>@M_N`03Ool007oo00Moo`001goo00@007ooE[EF]@9BU09>L`9:DP03?Nl8@PQ2008mk`9B
U09>L`8aS08@Q088@P0348@e[CF]009Nm`9F]@AJeP9240<@Q088@P8@Q08icP92408@Q0848@8@Q003
BU8mkcg_008icP9F]@AJePMNm`AS6003Ool007oo00Ioo`03001ooe:D00=BU09>L`E:DPIF]@9BU096
<@924003?NmJeU[F00AJePQF]@03CW=2448@008aS08mk`I:DPE>L`AF]@AJePMNm`AS6003Ool007oo
00Ioo`03001ooe[F00=JeP9:DP96<@D8@PH@Q0D<H`8@Q08icP9Nm`8e[@8Li`8DY@D8@P8<H`X8@P03
48A2448@00A240QW>@M_N`03Ool007oo00Moo`001goo00@007ooDYABU0M>L`848@8Li`@@Q0L<H`8a
S09BU0AF]@9BU09JeP9BU003AS4aS36<008HaP8<H`88@P848@88@P8<H`03BU8mkcg_008mk`AJePIN
m`03HaQNmekg00AS6003Ool007oo00Ioo`03001ooeJe00=F]@9>L`E:DPI>L`9:DP8]J`88@P03<HaJ
eU[F00AJePQF]@03CW=2448@008aS0Hmk`88@PE6<@AF]@IJePENm`AS6003Ool007oo00Ioo`04001o
oeJeE[D4AS42>Lh51242248936<248@4;F/2G_L2BU825:D248@?24800a24AS56<@04AS42IcT9JeX2
Kg/2Li`00goo001oo`07Ool000Moo`04001ooe:DDY@7CW<212427>L448@736<2<H`2DY@4E[D2DY@2
F]H2DY@00dHa<H`aS0026<H236<224821242248236<00dYB?Nlmk`02?Nl4F]H6G_L00f<HG_MNm`04
HaP00goo001oo`06Ool00`00OomF]@03E[D2CW<5BU86CW<2BU82;F/224800c6<F]IJeP04F]H8E[D0
0dic@Q124002<H`6?Nl22485AS44E[D6F]H5G_L4HaP00goo001oo`06Ool01000OomF]EJe14Ha0SW>
1@@Q0PQ22@aS0Q2412e[0Ukg0TYB0QBU0Q243`Q200<@Q4HaAS4014Ha0VLi2F]J0Vmk0W>L00=oo`00
Ool01goo0007Ool01000OomJeU[F0TYB0Sg_0Tic00<aS0@Q12400P@Q0PaS0Q2410aS0PQ200<@Q36<
<H`00RDY0UJe15:D0T8@0R4800<@Q0Q2248010@Q10Q20P@Q0PaS00=243W>>Lh00THa0UJe15[F15kg
00=JeUkgG_L016<H00=oo`00Ool01Woo00<007ooE[D00eJe1dYB11BU10Q20P@Q0Q2400<YBU:DDY@0
35Je00=>Ld8@@Q000Re[0Q2410000P@Q0dHa0TYB15Je15[F1ekg16<H00=oo`00Ool01Woo00@007oo
E[EF]@8]J`@8@PD48@88@PT<H`8@Q0@Q208Li`H@Q108@P@icP9:DPIW>@E[FPA_N`03Ool007oo00Mo
o`001goo00@007ooF]IJeP9:DP8mk`9>L`03<H`48@@Q00848@8<H`8@Q0@<H`88@P0348@aS36<008U
:@9F]@ABU092408Q200348@8@PQ200@48@@8@P848@8<H`03@Q0icSW>0096<@9F]@AJePANm`03F]IN
mekg00AS6003Ool007oo00Ioo`03001ooeJe00=F]@M:DP@DY@@8@P848@8@Q003:DYBU5:D00aF]@03
CW=2448@008]J`8@Q0@000848@=6<@9:DPAF]@AJePMNm`AS6003Ool007oo00Ioo`04001ooeJeE[D2
;F/424851242248936<248@48@P27>L648@@2484>Lh2BU86IcT5JeX4Kg/00goo001oo`07Ool000Mo
o`04001ooe:DDY@2CW<29BT32484124236<248@4248248@00aS6:DXYBP047>L29BT26<H448@00`aS
2488@P02124236<824800dHa<H`aS002CW<4F]H2E[D2F]H3HaP2G_L2HaP2G_L00goo001oo`06Ool0
0`00OomF]@03E[D5BU82:DX2124224825:D2;F/2?Nl5BU86E[D4CW<2>Lh00aS612448@0800021243
@Q02DY@6E[D2F]H;G_L00goo001oo`06Ool01000OomF]EJe0RU:10Q21@@Q0PQ22@aS0Q2411BU2124
40Q212e[0U:D26Li1f]J00=oo`00Ool01goo0007Ool01000OomBU5:D0Tic0R480`Q210@Q0PaS0Q24
0QcW0S6<0T8@00=>LbU::DX00QS60Q240QS60Q241@aS30Q20PaS00=6<BDY9BT00U:D25Je0V<H00=J
eUkgG_L00V<H0U[F00=oo`00Ool01Woo00<007ooDY@00e:D0TYB0R4800<000@Q12400RDY0T8@2dYB
22480Q240`Q20P@Q10000PaS0R480SF]0d8@0U:D1UJe0U[F1ekg16<H00=oo`00Ool01Woo00@007oo
F]IJeP8YBPT48@88@PP<H`0348@LiacW00@DY@8@Q0H<H`0324848@@Q00@48@T8@P@Q209JePQW>@M[
FP03Ool007oo00Moo`001goo00@007ooDYABU09>L`8Q20<8@P@48@8<H`8@Q08Li`8aS0924003CW<Y
BRU:008HaP8@Q08HaP8@Q0D<H``8@P8<H`03AS4U:BDY009BU0QF]@9S6003F]INmekg009S609JeP03
Ool007oo00Ioo`03001ooe:D00=BU09:DP8Q200300048@@Q008U:@9240]:DPPQ208@Q0<8@P848@@0
008<H`8Q208e[@=2409BU0IF]@9JePMNm`AS6003Ool007oo00Ioo`04001ooe[FF]H2:DX912422488
36<00a247>LLi`045:D248@636<00`Q212448@04124924848@P2F]H8IcT7JeX00goo001oo`07Ool0
00Moo`04001ooe:DDY@2CW<28@P200000`@Q2488@P0236<2:DX2AS42CW<2AS42>Lh00aS69BTU:@02
7>L45:D248@236<248@336<4124224825:D2:DX2?Nl00d8@7>LLi`02E[D2F]H2E[D2F]H9G_L2HaP0
0goo001oo`06Ool00`00OomBU003DY@2BU827>L00b48>LhicP02?Nl2@Q0;BU828@P25:D448@22485
12440002;F/6CW<00dHaDYABU006E[D2F]H7G_L4HaP00goo001oo`06Ool01000Oom>Ldic0RU:1@00
1PQ22`aS11BU0Q241PaS00<8@P@Q124010@Q20Q200<<HacW7>L00QcW1V<H16Li1f]J00=oo`00Ool0
1goo0007Ool01000OomBU5:D0Tic0R480P0000<48@Q224800PaS0RU:0THa0Tic0THa0SW>00<HaRDY
9BT00QcW11BU0Q240PaS0Q240`aS10@Q0PQ20QBU0RU:0Sg_00=241cW7>L00UJe0U[F0UJe0U[F2Ekg
0V<H00=oo`00Ool01Woo00<007ooDY@00e:D0TYB0QcW00<Q23W>>Lh00Sg_0T8@2dYB0R480QBU1124
0PQ21@@Q10000Re[1Tic00=6<E:DDY@01UJe0U[F1ekg16<H00=oo`00Ool01Woo00@007ooCW=>L`8Y
BPD000H8@P/<H`@DY@8@Q0H<H`0324848@@Q00@48@P8@P0336<LiacW008Li`IS60AW>@M[FP03Ool0
07oo00Moo`001goo00@007ooCW=>L`92408U:@80000336<YBRU:008mk`A2408U:@D<H`8Q208Li`8@
Q08DY@8<H`8@Q08<H`0348@8@PQ200H8@P8e[@9BU08mk`03BU8HaQS600AF]@9BU09JeP9Nm`9JeP=N
m`AS6003Ool007oo00Ioo`03001oodic00=>L`9:DP8Li`038@PicSW>008mk`9240I:DP924003<H`L
iacW008Li`8DY@@<H`88@PD48@@0008]J`I>L`03AS5BU5:D00IF]@MJeP9Nm`AS6003Ool007oo00Io
o`04001oodicCW<2:DX50004248248@2;F/936<45:D248@636<00`Q212448@041242248236<26<H2
<H`57>L6HaP5JeX6Kg/00goo001oo`07Ool000Moo`04001oodicCW<2@Q029BT200000`aS:DXYBP02
?Nl4@Q029BT536<28@P27>L248@25:D236<248@236<00a242488@P062482=Jd2DY@2?Nl00dYB6<HH
aP04E[D2DY@2F]H2G_L2F]H3G_L4HaP00goo001oo`06Ool00`00Oom>L`03CW<2BU827>L00b48>Lhi
cP02?Nl2@Q06BU82@Q000c6<7>LLi`027>L25:D436<2248512440002;F/6CW<00dHaDYABU006E[D7
F]H2G_L4HaP00goo001oo`06Ool01000Oom>Ldic0RU:1@0010Q20Q240Re[2@aS11BU0Q241PaS00<8
@P@Q124010@Q0PQ20PaS0QS60S6<1AcW1V<H1F]J1Vmk00=oo`00Ool01goo0007Oom?0007Oom?0007
Oom?0008Ool00?moo`]oo`00ogoo2goo0000\
\>"],
  ImageRangeCache->{{{0, 265.563}, {82.25, 0}} -> {-0.0891532, -0.0234425, 
  0.0119682, 0.0119682}, {{7.4375, 85.75}, {80.25, 
  1.9375}} -> {-4.83035, -1.93264, 0.532911, 0.532911}, {{93.5625, 171.938}, {
  80.25, 1.9375}} -> {-50.6873, -1.9151, 0.532484, 0.532484}, {{179.75, 
  258.063}, {80.25, 1.9375}} -> {-96.6575, -1.93264, 0.532911, 0.532911}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["SELECTED MORPHOLOGICAL ALGORITHMS", "Section"],

Cell[CellGroupData[{

Cell["Boundary Extraction", "Subsection"],

Cell["\<\
Boundary extraction is a very useful operation in image segmentation \
algorithms. Frequently the boundary of an objects is of interest in shape \
coding and recognition applications. Morphologically, the boundary may \
defined as the difference between the object and its erosion. \
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Beta](A)\  = \ A\  - \ (\)]],
  "A\[CircleMinus] S)"
}], "NumberedEquation"],

Cell[TextData[{
  "In order to achieve a thin boundary, the structuring element ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " should be a 3-by-3 mask of ones. Here we demonstrate a boundary \
extraction operation as a zero-crossing detector in a Laplacian-of-Gaussian \
edge detection problem. Following the second-derivative operation, the \
resulting image is thrsholded at level 0 to divide the image into negative \
and positive regions. The boundary between these regions is the location of \
the zero-crossings and thus the center of the edges in the original grayscale \
image."
}], "Text"],

Cell[BoxData[
    \(T = Threshold[L = Edge[A, \ LofGKernel[6]], 0]; \n
    S = {{1, 1, 1}, {1, 1, 1}, {1, 1, 1}}; \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        \((ListDensityPlot[#1, Mesh \[Rule] False, FrameTicks \[Rule] None, 
                DisplayFunction \[Rule] Identity]\ &)\)\ /@
          \ {L, \ T, T - Erode[T, S]}]]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3125 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00744048 0.31746 [
[ 0 0 0 0 ]
[ 1 .3125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .3125 L
0 .3125 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00744048 0.321429 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0240385 0.0192308 0.0240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
40 string
40 40 8 [40 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
798F90897F664F4D56606C797B6B594F4944403C37323139
3B2F284C9ECC9D5D55676F7275716463
727B654E45392D313938373C3F3B32241203000105070607
090A14459FD3A158485C686A6C695E5E
6769533F3832324152554F49413B393125222C3946505148
361F183D94CFA55A4658676969655B5A
626D68615B545B76929C8D70503C3B46576D8698A1A9ACA4
89582C3481C5A3563B4B5B5F5E5C5555
6F8AA1AAA4948D98AFBBA2714839486B92ADBDC0BCBDC2C6
BC93533771BAA862455262686B6D6A65
84A0C9DBD1BBA3949EAA8D55394A74A1BDC2BAAEA4A4ACB8
C3B57A4366BBCA9F8B97A4A7A8ABA58E
7F94BECABDAE9F8E919A79444070A6C0C0B4A59893959BA4
B5BB8E4C5DB9E3CCBDC8D1D0CBC8BA98
637AA0AFABA59B8B8685684B6299BDBDB0A6A09D9D9E9D9D
A9B89A5856A4C69F858F9A9A9691866F
596F94B8CBC4A37A6158526490B6BEB4ACAAAAACADABA6A4
AEBEAC6D588D9D64414B5B5F5F5E5A54
66728CBADBCE9A603A324D86B5C3BDB7B2ABA097928F93A2
B9CEC1845F85935F3E4A5B6263625F5F
75757C9AB2A1784C2E3165A7C8C7BFB5A48B6F59504E5A7F
B3D9D2926281976E5260717878757070
8079717B857B654B36498AC3D0C4B094755B4435302B2D4F
96D6DD9E688098765D697A81807B7679
8884767276756C56486AAED7D1B38A614B484847463B2932
74C9E3AF79859778606A797F807B777D
8E90837A77776F5C5B8CCDE2C4905F4445545F6460503329
5FBCE3B885899577616A777E7F7A747D
8F958D857F78675668ABE2DAA3674748576468645D4E382E
5BB3D7AC7F889577606A79808078707A
8B908B8A887F66506EBEEBC67946455A6A6B5F514A4B4D51
77B6C28E6D8597785F6A7B827F756D76
888B848388856A5071C8F0B85D3546636D65544B556E8694
ABC6AF715B829A7B606B7C817D736C75
8A8D837D807F684F73CFF8B85833485E5E56576A89A8BDC4
CBCBA25F4F7E9D7E626C7C807B746F78
8D918A8381795F4A73D3FEBE5C394B554E51719BBAC7CAC7
C8C6A1614C789C80646D7C807C76727B
8E928D8C8B7E5F4670D2FFC05D35444C4C6597BFCAC7C2BE
C2C9B57A53729981656F7F838079737D
8C8E88898D8566476ACAFDC7642E2F3E5787B8CCC9C3BEB8
BACACE9C6170978367718288857C747C
8A8E86828482674661BDF9DB863F25366AABCECEC1B3A493
8CA7CBB273749784676F8088867C737A
8B938D858079604259AFF5F5BC703A4489CBD7BD9D836A51
466BAEB57F789481646B7B8382797078
8A92918E88795B3B4D9CE4F3D08D515CAADDC68F644D3C2A
244E9EB38278907E63697A817F766F77
868B898C8C7D59343F80B8BE9C664063BAD79C583D3C372A
2A5CACBD897C937F646C7B817E767078
868882818276563743779B8B5B2B1F5DB9BF6D3131424135
407EC8C88F849983686E7B7F7D777279
898F877A706457526B98B29E6223155AB3AD521C29434B50
6FAEDCC082809B876C707A7E7E797379
88948D7A655E6D87A4C2D8CF9848235AB1B15E262D4D6984
ACD7D99E637398886E71797C7E7A7277
848F897564729EC2CCD0DEE6BE6A3259B0C58C5B5B7999B6
D3E0BD70456A978A7071777A7D797073
80887D676491D0E5CDB7C1D8C4753653A7D0B89996A7B9C8
D4CA95503B6D9A8B7172787A7C797172
8187785E69ABE2D196707FAEB270334792C6C7B8B4B8BBBF
BB9F6E4647779C8A72747B7D7D7A7374
8388796379B8C8873A1F4287A06B323A73AABFC0BDB9B1A4
8F6D56545F809886727880817F7B7677
8184756682B1994107114C95A971342C4C789CAFB5AE997D
635B6C7A75818F7F717981827F7B7677
7978645677A287432F5491C4BF7C381E23385776898C7E67
627CA2A17E7A85786E767F817F7B7372
706F5B4E70A3A38584A4C9DDC688492416172A4864767E7D
89ADC9B17E737C726C757D7F807B716C
6B7272728EB9C5BABAC6CFCCB6926F5240404F657B8D979C
A8C2D2B38173756D6E797E7F7F7B7068
697B9CB6C7D5D3C5BAB3A89A90939B978F939EA5AAADAEAD
B4C6D0B58C7E756B738083807F7C7168
6A85BDECF5E7D0B39A897C77829EBFCFD2D7D9D2CBC9C9CA
CBCBC3AA948E7B6C79898A878682766A
7192CDFEFEDDB6937E7C879AADC0D4E3EAEEECE3DCDCE1E4
DABD9B8995A388707B8C8F8E8E887A6D
7A99BED8D0AC857172829CB5BEB5ADAFB4B7B5AEA8A6AAAF
A47F5C6398BA956B6E7F84858782736B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00744048 0.64881 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0240385 0.0192308 0.0240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
40 string
40 40 8 [40 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FFFFFF0000000000000000000000000000000000000000
00000000FFFFFF000000000000000000
000000000000000000000000000000000000000000000000
00000000FFFFFF000000000000000000
000000000000000000000000000000000000000000000000
00000000FFFFFF000000000000000000
0000000000000000FFFFFF00000000000000FFFFFFFFFFFF
FF00000000FFFF000000000000000000
00FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFF
FFFF000000FFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFF000000000000000000
0000FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFF000000000000000000
000000FFFFFF0000000000FFFFFFFFFFFFFF000000000000
FFFFFFFF0000FF000000000000000000
00000000FF0000000000FFFFFFFFFFFF0000000000000000
FFFFFFFF0000FF000000000000000000
FFFF0000000000000000FFFFFFFFFF000000000000000000
00FFFFFF00FFFF000000000000000000
FFFFFF000000000000FFFFFFFFFF00000000000000000000
00FFFFFFFFFFFF000000000000000000
FFFFFFFF0000000000FFFFFFFF0000000000000000000000
00FFFFFF00FFFF000000000000000000
FFFFFFFFFF00000000FFFFFF000000000000000000000000
00FFFFFF00FFFF000000000000000000
FFFFFFFFFFFF000000FFFFFF00000000000000000000FFFF
FFFFFF000000FF000000000000000000
FFFFFF000000000000FFFFFF0000000000000000FFFFFFFF
FFFFFF000000FF000000000000000000
FFFFFFFF0000000000FFFFFF00000000000000FFFFFFFFFF
FFFFFF000000FF000000000000000000
FFFFFFFFFF00000000FFFFFF000000000000FFFFFFFFFFFF
FFFFFF000000FF00000000FF00000000
FFFFFFFFFFFF000000FFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFF0000FFFF000000FFFF000000
FFFFFF00FF00000000FFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFF0000FFFF000000FFFF000000
FFFFFFFF0000000000FFFFFFFF000000FFFFFFFFFFFF0000
0000FFFF0000FF00000000FF00000000
FFFFFFFFFF00000000FFFFFFFFFF0000FFFFFFFF00000000
0000FFFFFF00FF000000000000000000
FFFFFFFFFF0000000000FFFFFF000000FFFFFF0000000000
0000FFFFFF00FF000000000000000000
FFFFFF00000000000000FFFF00000000FFFF000000000000
0000FFFFFFFFFFFF0000000000000000
FFFFFF000000000000FFFFFF00000000FFFF000000000000
00FFFFFFFF00FFFF0000000000000000
FFFFFF00000000FFFFFFFFFFFF000000FFFF0000000000FF
FFFFFFFF0000FFFF0000000000000000
FFFFFF000000FFFFFFFFFFFFFF000000FFFFFF000000FFFF
FFFFFF000000FFFF0000000000000000
00FF000000FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF
FFFFFF000000FFFF0000000000000000
00FF000000FFFFFFFF0000FFFF000000FFFFFFFFFFFFFFFF
FFFF00000000FFFF0000000000000000
FFFF000000FFFFFF000000FFFF00000000FFFFFFFFFFFFFF
FF0000000000FFFF0000000000000000
00FF000000FFFF00000000FFFF0000000000FFFFFFFFFF00
000000000000FF000000000000000000
0000000000FFFF000000FFFFFF00000000000000FFFF0000
0000FFFF0000FF000000000000000000
0000000000FFFFFFFFFFFFFFFFFF00000000000000000000
FFFFFFFF000000000000000000000000
00000000FFFFFFFFFFFFFFFFFFFF00000000000000FFFFFF
FFFFFFFF000000000000000000000000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FF0000000000
00FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFF000000
00FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFF0000
00FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFF000000FFFFFF000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00744048 0.97619 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0240385 0.0192308 0.0240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
40 string
40 40 8 [40 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FFFFFF0000000000000000000000000000000000000000
00000000FFFFFF000000000000000000
000000000000000000000000000000000000000000000000
00000000FF00FF000000000000000000
000000000000000000000000000000000000000000000000
00000000FFFFFF000000000000000000
0000000000000000FFFFFF00000000000000FFFFFFFFFFFF
FF00000000FFFF000000000000000000
00FFFFFFFFFFFFFFFF00FF0000000000FFFFFF0000000000
FFFF000000FFFF000000000000000000
FFFF00000000000000FFFF00000000FFFF00000000000000
00FF000000FFFFFFFFFFFFFFFFFFFFFF
00FFFF000000000000FF00000000FFFF0000000000000000
00FFFF0000FF0000000000000000FFFF
0000FF000000FFFFFFFF000000FFFF000000000000000000
0000FF0000FFFFFFFFFFFFFFFFFFFF00
0000FF000000FF0000000000FFFF00000000000000000000
0000FF0000FFFF000000000000000000
0000FFFF00FFFF00000000FFFF00000000FFFFFFFFFFFFFF
FF00FFFF00FFFF000000000000000000
000000FFFFFF0000000000FF000000FFFFFF000000000000
FF0000FF0000FF000000000000000000
00000000FF0000000000FFFF0000FFFF0000000000000000
FFFF00FF0000FF000000000000000000
FFFF0000000000000000FF0000FFFF000000000000000000
00FF00FF00FFFF000000000000000000
FFFFFF000000000000FFFF00FFFF00000000000000000000
00FF00FFFFFFFF000000000000000000
FF00FFFF0000000000FF00FFFF0000000000000000000000
00FF00FF00FFFF000000000000000000
FF0000FFFF00000000FF00FF000000000000000000000000
00FFFFFF00FFFF000000000000000000
FF00FFFFFFFF000000FF00FF00000000000000000000FFFF
FFFFFF000000FF000000000000000000
FF00FF000000000000FF00FF0000000000000000FFFFFF00
0000FF000000FF000000000000000000
FF00FFFF0000000000FF00FF00000000000000FFFF000000
0000FF000000FF000000000000000000
FF0000FFFF00000000FF00FF000000000000FFFF00000000
0000FF000000FF00000000FF00000000
FF00FFFFFFFF000000FF00FF0000000000FFFF0000000000
0000FFFF0000FFFF000000FFFF000000
FF00FF00FF00000000FF00FFFF00000000FF000000FFFFFF
FFFFFFFF0000FFFF000000FFFF000000
FF00FFFF0000000000FF0000FF000000FFFF00FFFFFF0000
0000FFFF0000FF00000000FF00000000
FF0000FFFF00000000FFFF00FFFF0000FF00FFFF00000000
0000FFFFFF00FF000000000000000000
FF00FFFFFF0000000000FFFFFF000000FFFFFF0000000000
0000FF00FF00FF000000000000000000
FF00FF00000000000000FFFF00000000FFFF000000000000
0000FF00FFFFFFFF0000000000000000
FF00FF000000000000FFFFFF00000000FFFF000000000000
00FFFFFFFF00FFFF0000000000000000
FF00FF00000000FFFFFF00FFFF000000FFFF0000000000FF
FFFFFFFF0000FFFF0000000000000000
FFFFFF000000FFFF00000000FF000000FFFFFF000000FFFF
0000FF000000FFFF0000000000000000
00FF000000FFFF00FFFFFFFFFF000000FF00FFFFFFFFFF00
00FFFF000000FFFF0000000000000000
00FF000000FF00FFFF0000FFFF000000FFFF000000000000
FFFF00000000FFFF0000000000000000
FFFF000000FFFFFF000000FFFF00000000FFFF000000FFFF
FF0000000000FFFF0000000000000000
00FF000000FFFF00000000FFFF0000000000FFFFFFFFFF00
000000000000FF000000000000000000
0000000000FFFF000000FFFFFF00000000000000FFFF0000
0000FFFF0000FF000000000000000000
0000000000FFFFFFFFFFFF00FFFF00000000000000000000
FFFFFFFF000000000000000000000000
00000000FFFF00000000000000FF00000000000000FFFFFF
FF0000FF000000000000000000000000
0000FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFF0000000000FF0000000000
00FFFF00000000FFFFFF000000FF00000000000000000000
00000000FFFF000000FFFFFFFF000000
00FF00000000FFFF0000FFFFFFFF00000000000000000000
FFFFFFFFFFFFFF0000FFFF00FFFF0000
00FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFF000000FFFFFF000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{355.438, 111.063},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005S0000Ka000`40O003h00OogooI7oo003oOomT
Ool00?moofAoo`002GooJP002GooJP002WooJ@002Woo0009Ool00`00Oomoo`1VOol00`00Oomoo`07
Ool00`00Oomoo`1VOol00`00Oomoo`08Ool00`00Oomoo`1UOol00`00Oomoo`08Ool000Uoo`03001o
ogoo06Ioo`03001oogoo00Moo`03001oogoo06Ioo`03001oogoo00Qoo`03001oogoo06Eoo`03001o
ogoo00Qoo`002Goo00<007oo?Nl00Sg_0THa0dYB0THa0cg_0S6<1BDY0bU:0S6<0cF]1Cg_0SF]0be[
1BDY1B480QcW21S61AcW1ABU0bDY0Tic0fLi0Tic0be[0RU:0c6<0SF]23W>1C6<0Woo00<007ooOol0
1goo00<007oo00000P001goo?@001goo5`000Woo00<007ooOol027oo00@007oo000000Qooc`000Mo
oaL0009oo`03001oogoo00Qoo`002Goo00<007oo?Nl00Sg_0THa0dYB0THa0cg_0S6<1BDY0bU:0S6<
0cF]1Cg_0SF]0be[1BDY1B480QcW21S61AcW1ABU0bDY0Tic0fLi0Tic0be[0RU:0c6<0SF]23W>1C6<
0Woo00<007ooOol01goo00<007oo00000P001goo?@001goo5`000Woo00<007ooOol027oo00@007oo
000000Qooc`000MooaL0009oo`03001oogoo00Qoo`002Goo00<007oo?Nl00Sg_0THa0dYB0THa0cg_
0S6<1BDY0bU:0S6<0cF]1Cg_0SF]0be[1BDY1B480QcW21S61AcW1ABU0bDY0Tic0fLi0Tic0be[0RU:
0c6<0SF]23W>1C6<0Woo00<007ooOol01goo00<007oo00000P001goo?@001goo5`000Woo00<007oo
Ool027oo00@007oo000000Qooc`000MooaL0009oo`03001oogoo00Qoo`002Goo00<007oo>Lh00SW>
0Sg_0c6<0RDY0b480QcW0aBU0QS61AcW0aS61acW0aS60Q240`Q24P001@@Q0PQ20b480Tic0f]J0U:D
0be[0RDY0be[2SF]1Be[0Woo00<007ooOol01goo00<007oo0000AP001goo5`000Woo00<007ooOol0
27oo00<007oo0000A@000Woo0`000Woo5`000Woo00<007ooOol027oo0009Ool00`00OolicP02>Lh2
?Nl3<H`29BT38@P27>L35:D26<H57>L36<H77>L36<H248@3248B0005124224838@P2CW<3JeX2DY@3
;F/29BT3;F/:=Jd5;F/2Ool00`00Oomoo`07Ool00`00Ool000160007OolG0002Ool00`00Oomoo`08
Ool00`00Ool000150002Ool30002OolG0002Ool00`00Oomoo`08Ool000Uoo`03001ooc6<008aS08e
[@<YBPDLi`DHaP8Q20DYBPDU:@<Q20DLi`8HaPD@Q0<DY@8Li`<Q20DYBP<U:@8HaPD<H`<Li`9:DP=W
>@9BU0<]J`8Q20<]J`8aS0De[@<aS0D]J`9oo`03001oogoo00Moo`03001oo`0004H000MooaL0009o
o`03001oogoo00Qoo`03001oo`0004D000MooaL0009oo`03001oogoo00Qoo`002Goo00<007oo<H`0
0S6<0SF]0bU:1AcW1AS60R481BU:1BDY0b481AcW0QS61A240aBU0QcW0b481BU:0bDY0QS61@aS0acW
0TYB0fLi0U:D0be[0R480be[0S6<1CF]0c6<1Be[0Woo00<007ooOol01goo00<007oo0000AP001goo
5`000Woo00<007ooOol027oo00<007oo0000A@001goo5`000Woo00<007ooOol027oo0009Ool00`00
OolaS002<H`2=Jd3:DX57>L56<H28@P5:DX59BT38@P57>L26<H548@35:D27>L38@P5:DX39BT26<H5
36<37>L2BU83IcT2DY@3;F/28@P3;F/2<H`5=Jd3<H`5;F/2Ool00`00Oomoo`07Ool00`00Ool00016
0007OolG0002Ool00`00Oomoo`08Ool00`00Ool000150007OolG0002Ool00`00Oomoo`08Ool000Uo
o`03001ooc6<008aS0De[@8aS0<]J`8YBP<]J`8icP=:DP9>L`=6<@8icP<YBPDLi`8Q20<YBP8e[@=2
409>L`=BU0EF]@=BU096<@<]J`8DY@<HaP9240=S609BU0<YBP8Li`<U:@X]J`DYBP9oo`03001oogoo
00Moo`03001oo`0001<000Qooa40019oo`X000EooaL0009oo`03001oogoo00Qoo`03001oo`0001<0
00Mooa80015oo`X000EooaL0009oo`03001oogoo00Qoo`002Goo00<007oo<H`00S6<1CF]0S6<0be[
0RU:0be[0SW>0dYB0Tic0dHa0SW>0bU:1AcW0R480bU:0SF]0d8@0Tic0e:D1EJe0e:D0THa0be[0QBU
0aS60T8@0f<H0U:D0bU:0QcW0bDY2Re[1BU:0Woo00<007ooOol01goo00<007oo00004`0027oo4@00
4Woo2P001Goo5`000Woo00<007ooOol027oo00<007oo00004`001goo4P004Goo2P001Goo5`000Woo
00<007ooOol027oo0009Ool00`00Oole[@02=Jd2AS43DY@2E[D3DY@2BU83AS42CW<3E[D2G_L3DY@2
>Lh39BT27>L39BT2=Jd3BU82E[D3G_L2HaP6G_L5HaP2G_L3BU82:DX36<H2>Lh3G_L2E[D3<H`28@P3
:DX2<H`:=Jd3<H`2Ool00`00Oomoo`07Ool00`00Ool00002000IOol<000JOol70005OolG0002Ool0
0`00Oomoo`08Ool01000Ool0000057oo0`000Woo3@001goo3@001Goo1`001Goo5`000Woo00<007oo
Ool027oo0009Ool00`00Oole[@02=Jd2AS43DY@2E[D3DY@2BU83AS42CW<3E[D2G_L3DY@2>Lh39BT2
7>L39BT2=Jd3BU82E[D3G_L2HaP6G_L5HaP2G_L3BU82:DX36<H2>Lh3G_L2E[D3<H`28@P3:DX2<H`:
=Jd3<H`2Ool00`00Oomoo`07Ool00`00Ool00002000IOol<000JOol70005OolG0002Ool00`00Oomo
o`08Ool01000Ool0000057oo0`000Woo3@001goo3@001Goo1`001Goo5`000Woo00<007ooOol027oo
0009Ool00`00Oole[@02=Jd2AS43DY@2E[D3DY@2BU83AS42CW<3E[D2G_L3DY@2>Lh39BT27>L39BT2
=Jd3BU82E[D3G_L2HaP6G_L5HaP2G_L3BU82:DX36<H2>Lh3G_L2E[D3<H`28@P3:DX2<H`:=Jd3<H`2
Ool00`00Oomoo`07Ool00`00Ool00002000IOol<000JOol70005OolG0002Ool00`00Oomoo`08Ool0
1000Ool0000057oo0`000Woo3@001goo3@001Goo1`001Goo5`000Woo00<007ooOol027oo0009Ool0
0`00Oom24002@Q02DY@3IcT2Kg/3JeX2G_L3DY@2BU83CW<2E[D3AS42:DX37>L29BT3>Lh2DY@3G_L2
HaP3G_L2E[D6DY@2E[D3G_L2HaP3F]H2?Nl38@P2<H`3G_L2IcT3CW<2AS43BU85DY@5E[D2DY@3AS42
Ool00`00Oomoo`07Ool00`00Oomoo`0KOol:000LOol7000NOol00`00Oomoo`08Ool00`00Oomoo`04
OolA0005Ool:0005OolD0003Ool7000NOol00`00Oomoo`08Ool000Uoo`03001ood8@0092409BU0=W
>@9_N`=[FP9Nm`=BU09:DP=>L`9F]@=6<@8YBP<Li`8U:@<icP9BU0=Nm`9S60=Nm`9F]@IBU09F]@=N
m`9S60=JeP8mk`<Q208aS0=Nm`9W>@=>L`96<@=:DPEBU0EF]@9BU0=6<@9oo`03001oogoo00Moo`03
001oogoo01]oo`X001aoo`L001ioo`03001oogoo00Qoo`03001oogoo00Aooa4000Eoo`X000Eooa@0
00=oo`L001ioo`03001oogoo00Qoo`002Goo00<007oo?Nl00Sg_0TYB0ekg0VLi0ekg0UJe0dic0THa
0dYB0Tic0cg_1B480SW>0e:D1F<H0U[F0e:D0Tic1TYB0Tic0e:D0U[F0ekg0THa0bDY0Re[0ekg0W>L
0fLi0Ukg0fLi1F]J1FLi0Ukg0dic0Woo00<007ooOol01goo00<007oo00000P005Woo2P008Goo1@00
7Woo00<007ooOol027oo00@007oo000000Eoo`l000=oo`X000EooaH000Eoo`D000=ooa@000Moo`03
001oogoo00Qoo`002Goo00<007oo?Nl00Sg_0TYB0ekg0VLi0ekg0UJe0dic0THa0dYB0Tic0cg_1B48
0SW>0e:D1F<H0U[F0e:D0Tic1TYB0Tic0e:D0U[F0ekg0THa0bDY0Re[0ekg0W>L0fLi0Ukg0fLi1F]J
1FLi0Ukg0dic0Woo00<007ooOol01goo00<007oo00000P005Woo2P008Goo1@007Woo00<007ooOol0
27oo00@007oo000000Eoo`l000=oo`X000EooaH000Eoo`D000=ooa@000Moo`03001oogoo00Qoo`00
2Goo00<007oo?Nl00Sg_0TYB0ekg0VLi0ekg0UJe0dic0THa0dYB0Tic0cg_1B480SW>0e:D1F<H0U[F
0e:D0Tic1TYB0Tic0e:D0U[F0ekg0THa0bDY0Re[0ekg0W>L0fLi0Ukg0fLi1F]J1FLi0Ukg0dic0Woo
00<007ooOol01goo00<007oo00000P005Woo2P008Goo1@007Woo00<007ooOol027oo00@007oo0000
00Eoo`l000=oo`X000EooaH000Eoo`D000=ooa@000Moo`03001oogoo00Qoo`002Goo00<007oo<H`0
0S6<0Sg_0e:D1EJe0U:D0dic0THa1D8@0cF]0RDY0c6<0Tic1Ekg0e[F1E:D3Dic0UJe0ekg0Tic0be[
0RU:0e:D0V<H0dic0T8@0dHa1Dic1DYB0T8@0cF]0Woo00<007ooOol01goo00<007oo0000100057oo
20008goo1@006Goo0`000Woo00<007ooOol027oo00<007oo000010000Woo20002Woo1`001Goo7000
0Woo1@006Goo0`000Woo00<007ooOol027oo0009Ool00`00OolaS002<H`2?Nl3DY@5E[D2DY@3CW<2
AS45@Q03=Jd29BT3<H`2CW<5G_L3F]H5DY@=CW<2E[D3G_L2CW<3;F/2:DX3DY@2HaP3CW<2@Q03AS45
CW<5BU82@Q03=Jd2Ool00`00Oomoo`07Ool00`00Ool00004000DOol8000SOol5000IOol30002Ool0
0`00Oomoo`08Ool00`00Ool000040002Ool8000:Ool70005OolL0002Ool5000IOol30002Ool00`00
Oomoo`08Ool000Uoo`03001oobe[008]J`8e[@=:DP9Nm`=W>@9S60=BU08mk`<aS08]J`<YBP8aS0=:
DP9JeP=Nm`9JeQ1F]@EBU09F]@=Nm`9F]@<e[@8]J`=6<@9>L`<aS08Q20<U:@`]J`<YBP9oo`03001o
ogoo00Moo`03001oo`0000@000eoo``002Ioo`D000EooaL0009oo`03001oogoo00Qoo`03001oo`00
00@0009oo`P0009oo`d000Eooah0009oo`D000EooaL0009oo`03001oogoo00Qoo`002Goo00<007oo
;F/00Re[0SF]0dYB0Ukg0fLi0V<H0e:D0Sg_0c6<0Re[0bU:0S6<0dYB0U[F0ekg0U[F45Je1E:D0UJe
0ekg0UJe0cF]0Re[0dHa0Tic0c6<0R480bDY32e[0bU:0Woo00<007ooOol01goo00<007oo00001000
3Goo30009Woo1@001Goo5`000Woo00<007ooOol027oo00<007oo000010000Woo20000Woo3@001Goo
7P000Woo1@001Goo5`000Woo00<007ooOol027oo0009Ool00`00Ool]J`02;F/2=Jd3BU82G_L3IcT2
HaP3DY@2?Nl3<H`2;F/3:DX2<H`3BU82F]H3G_L2F]H@E[D5DY@2E[D3G_L2E[D3=Jd2;F/3AS42CW<3
<H`28@P39BT<;F/3:DX2Ool00`00Oomoo`07Ool00`00Ool00004000=Ool<000VOol50005OolG0002
Ool00`00Oomoo`08Ool00`00Ool000040002Ool80002Ool=0005OolN0002Ool50005OolG0002Ool0
0`00Oomoo`08Ool000Uoo`03001ooc6<008aS08icP=6<@9Nm`=_N`9W>@=>L`8aS0<Li`8HaP<U:@92
40=JeP9S60=Nm`EJeP9F]@=BU0E:DP=6<@9:DP=BU09Nm`=W>@9S60=2408]J`=2409:DP<]J`8Li`<U
:@8]J`PaS0D]J`9oo`03001oogoo00Moo`03001oo`0000@000eoo`X002]oo`8000EooaL0009oo`03
001oogoo00Qoo`03001oo`0000@000Eoo`8000Eoo`X000Eoo`X001Aoo`<000Eoo`8000EooaL0009o
o`03001oogoo00Qoo`002Goo00<007oo<H`00S6<0SW>0dHa0Ukg0fmk0VLi0dic0S6<0acW0QS60bDY
0T8@0e[F0V<H0ekg1E[F0UJe0e:D1DYB0dHa0TYB0e:D0Ukg0fLi0V<H0d8@0Re[0d8@0TYB0be[0QcW
0bDY0Re[236<1Be[0Woo00<007ooOol01goo00<007oo000010003Goo2P00:goo0P001Goo5`000Woo
00<007ooOol027oo00<007oo000010001Goo0P001Goo2P001Goo2P0057oo0`001Goo0P001Goo5`00
0Woo00<007ooOol027oo0009Ool00`00OolicP04>Lh3?Nl2CW<3F]H2DY@3?Nl29BT35:D26<H3<H`2
DY@3IcT2HaP3G_L2F]H3DY@2AS43=Jd2;F/3:DX39BT2;F/3?Nl2F]H3Kg/2JeX3BU82<H`3@Q02BU83
=Jd2:DX3<H`2>Lh5?Nl8>Lh2Ool00`00Oomoo`07Ool00`00Ool000070007Ool=000AOol@000:Ool5
0002OolG0002Ool00`00Oomoo`08Ool00`00Ool000060008Ool<0003Ool70008Ool?0002Ool50003
Ool50002OolG0002Ool00`00Oomoo`08Ool000Uoo`03001oocW>00@icP<mk`9>L`=JeP9BU0<mk`8U
:@<DY@8HaP<aS09BU0=W>@9S60=Nm`9JeP=BU096<@<e[@8]J`<YBP<U:@8]J`<mk`9JeP=_N`9[FP=:
DP8aS0=2409:DP<e[@8YBP<aS08icPDmk`PicP9oo`03001oogoo00Moo`03001oo`0000L000Moo`d0
015ooa0000Yoo`D0009ooaL0009oo`03001oogoo00Qoo`03001oo`0000H000Qoo``000=oo`L000Qo
o`l0009oo`D000=oo`D0009ooaL0009oo`03001oogoo00Qoo`002Goo00<007oo>Lh013W>0cg_0Tic
0e[F0U:D0cg_0RDY0aBU0QS60c6<0U:D0fLi0V<H0ekg0U[F0e:D0THa0cF]0Re[0bU:0bDY0Re[0cg_
0U[F0fmk0V]J0dYB0S6<0d8@0TYB0cF]0RU:0c6<0SW>1Cg_23W>0Woo00<007ooOol01goo00<007oo
00001`001goo3@004Goo40002Woo1@000Woo5`000Woo00<007ooOol027oo00<007oo00001P0027oo
30000goo1`0027oo3`000Woo1@000goo1@000Woo5`000Woo00<007ooOol027oo0009Ool00`00Oom2
4002@Q02?Nl3>Lh2?Nl3@Q02?Nl3<H`29BT36<H29BT3AS42HaP3JeX2HaP3F]H2BU83>Lh2;F/38@P5
6<H55:D39BT2BU83JeX2Kg/3CW<2=Jd3@Q02CW<3>Lh2;F/3=Jd2?Nl5@Q03?Nl2>Lh3?Nl2Ool00`00
Oomoo`07Ool00`00Ool000090003Ool<000?OolE000:Ool50002OolG0002Ool00`00Oomoo`08Ool0
0`00Ool000090002Ool=0005Ool50005OolD0005Ool20003Ool50002OolG0002Ool00`00Oomoo`08
Ool000Uoo`03001ood8@0092408mk`<icP8mk`=2408mk`<aS08U:@<HaP8U:@=6<@9S60=[FP9S60=J
eP9:DP<icP8]J`<Q20DHaPDDY@<U:@9:DP=[FP9_N`=>L`8e[@=2409>L`<icP8]J`<e[@8mk`E240<m
k`8icP<mk`9oo`03001oogoo00Moo`03001oo`0000T000=oo``000mooaD000Yoo`D0009ooaL0009o
o`03001oogoo00Qoo`03001oo`0000T0009oo`d000Eoo`D000Eooa@000Eoo`8000=oo`D0009ooaL0
009oo`03001oogoo00Qoo`002Goo00<007ooAS400THa0T8@2SW>0cF]0RU:0bDY0SF]0eJe1F]J0U[F
0dHa0S6<22DY1B480acW0QBU0aS60SW>0fLi0W>L0eJe0Sg_0d8@0TYB0cg_0S6<0cF]1Cg_0T8@0cg_
0SW>0cg_0Woo00<007ooOol01goo00<007ooOol017oo50003Goo6@0027oo0P001Goo5`000Woo00<0
07ooOol027oo00<007ooOol017oo50000Woo1@001Goo6@000goo0P000goo0P001Goo5`000Woo00<0
07ooOol027oo0009Ool00`00Oom6<@02AS42@Q0:>Lh3=Jd2:DX39BT2=Jd3E[D5JeX2F]H3AS42<H`8
9BT58@P37>L25:D36<H2>Lh3IcT2Li`3E[D2?Nl3@Q02BU83?Nl2<H`3=Jd5?Nl2@Q03?Nl2>Lh3?Nl2
Ool00`00Oomoo`07Ool00`00Oomoo`04OolD000=OolI0008Ool20005OolG0002Ool00`00Oomoo`08
Ool00`00Oomoo`04OolD0002Ool50005OolI0003Ool20003Ool20005OolG0002Ool00`00Oomoo`08
Ool000Uoo`03001oodHa0096<@9240XicP<e[@8YBP<U:@8e[@=F]@E[FP9JeP=6<@8aS0PU:@DQ20<L
i`8DY@<HaP8icP=W>@9cW0=F]@8mk`=2409:DP<mk`8aS0<e[@Dmk`9240<mk`8icP<mk`9oo`03001o
ogoo00Moo`03001oogoo00Aooa@000eooaT000Qoo`8000EooaL0009oo`03001oogoo00Qoo`03001o
ogoo00Aooa@0009oo`D000EooaT000=oo`8000=oo`8000EooaL0009oo`03001oogoo00Qoo`002Goo
00<007ooAS400THa0TYB0d8@0Sg_1CW>0cF]1Be[0THa0fLi0W>L0f<H0TYB0be[1B480RU:0be[1C6<
0bU:0QS60aBU0Re[0ekg0W>L0ekg0T8@0dHa0TYB0cW>0S6<0cF]0SW>23g_0SW>0cg_0Woo00<007oo
Ool01goo00<007ooOol01goo3`0037oo70003goo5`000Woo00<007ooOol027oo00<007ooOol01Woo
3`001Goo0`001Goo6`000goo0P002Woo5`000Woo00<007ooOol027oo0009Ool00`00Oom6<@02AS42
BU83@Q02?Nl5>Lh3=Jd5;F/2AS43IcT2Li`3HaP2BU83;F/58@P2:DX3;F/5<H`3:DX26<H35:D2;F/3
G_L2Li`3G_L2@Q03AS42BU83>Lh2<H`3=Jd2>Lh8?Nl2>Lh3?Nl2Ool00`00Oomoo`07Ool00`00Oomo
o`07Ool?000<OolL000?OolG0002Ool00`00Oomoo`08Ool00`00Oomoo`06Ool?0005Ool30005OolK
0003Ool2000:OolG0002Ool00`00Oomoo`08Ool000Uoo`03001oodHa0096<@9:DP=6<@9240Dmk`<a
S08YBP<e[@9F]@=cW09_N`=BU08aS0<Q208U:@<YBP8aS0<e[@8aS0<]J`<U:@8Li`<DY@8]J`=JeP9[
FP=F]@8mk`=6<@9:DP<icP8aS0<e[@8mk`E240<mk`8icP<mk`9oo`03001oogoo00Moo`03001oogoo
00Uoo`d000Yooah000Qoo`8000EooaL0009oo`03001oogoo00Qoo`04001oogooOol30005Ool<0003
Ool20005OolN0003Ool20003Ool20005OolG0002Ool00`00Oomoo`08Ool000Uoo`03001oodHa0096
<@9:DP=6<@9240Dmk`<aS08YBP<e[@9F]@=cW09_N`=BU08aS0<Q208U:@<YBP8aS0<e[@8aS0<]J`<U
:@8Li`<DY@8]J`=JeP9[FP=F]@8mk`=6<@9:DP<icP8aS0<e[@8mk`E240<mk`8icP<mk`9oo`03001o
ogoo00Moo`03001oogoo00Uoo`d000Yooah000Qoo`8000EooaL0009oo`03001oogoo00Qoo`04001o
ogooOol30005Ool<0003Ool20005OolN0003Ool20003Ool20005OolG0002Ool00`00Oomoo`08Ool0
00Uoo`03001oodHa0096<@9:DP=6<@9240Dmk`<aS08YBP<e[@9F]@=cW09_N`=BU08aS0<Q208U:@<Y
BP8aS0<e[@8aS0<]J`<U:@8Li`<DY@8]J`=JeP9[FP=F]@8mk`=6<@9:DP<icP8aS0<e[@8mk`E240<m
k`8icP<mk`9oo`03001oogoo00Moo`03001oogoo00Uoo`d000Yooah000Qoo`8000EooaL0009oo`03
001oogoo00Qoo`04001oogooOol30005Ool<0003Ool20005OolN0003Ool20003Ool20005OolG0002
Ool00`00Oomoo`08Ool000Uoo`03001oodHa0096<@9:DPQ6<@8mk`<aS08YBP<e[@9Nm`=g_@9S60<m
k`DQ208]J`De[@<]J`8YBPPU:@<YBP8icP=JeP9S60=6<@8e[@=2409:DP<mk`8]J`<e[@8mk`=2408m
k`<icP8e[@<icP9oo`03001oogoo00Moo`03001oogoo00aoo`X000Moob4000Qoo`8000EooaL0009o
o`03001oogoo00Qoo`04001oogooOol50005Ool:0003Ool20003OolP0008Ool20005OolG0002Ool0
0`00Oomoo`08Ool000Uoo`03001oodHa0096<@9:DPQ6<@8mk`<aS08YBP<e[@9Nm`=g_@9S60<mk`DQ
208]J`De[@<]J`8YBPPU:@<YBP8icP=JeP9S60=6<@8e[@=2409:DP<mk`8]J`<e[@8mk`=2408mk`<i
cP8e[@<icP9oo`03001oogoo00Moo`03001oogoo00aoo`X000Moob4000Qoo`8000EooaL0009oo`03
001oogoo00Qoo`04001oogooOol50005Ool:0003Ool20003OolP0008Ool20005OolG0002Ool00`00
Oomoo`08Ool000Uoo`03001oodHa00A6<@E240=6<@9240<e[@8YBP<icP9W>@=kgP9Nm`<]J`8HaP<Q
208aS0<e[@8aS0<YBP8U:@<YBP<e[@9240=:DP9F]@=S609F]@<icP8]J`=2409>L`<mk`8aS0<e[@8m
k`=2408mk`<icP8e[@<icP9oo`03001oogoo00Moo`03001oogoo00ioo`P000MooaX000aoo`P0009o
oaL0009oo`03001oogoo00Qoo`04001oogooOol3000:Ool70003Ool20003OolI000<Ool80002OolG
0002Ool00`00Oomoo`08Ool000Uoo`03001oodHa00A6<@E240=6<@9240<e[@8YBP<icP9W>@=kgP9N
m`<]J`8HaP<Q208aS0<e[@8aS0<YBP8U:@<YBP<e[@9240=:DP9F]@=S609F]@<icP8]J`=2409>L`<m
k`8aS0<e[@8mk`=2408mk`<icP8e[@<icP9oo`03001oogoo00Moo`03001oogoo00ioo`P000MooaX0
00aoo`P0009ooaL0009oo`03001oogoo00Qoo`04001oogooOol3000:Ool70003Ool20003OolI000<
Ool80002OolG0002Ool00`00Oomoo`08Ool000Uoo`03001oodHa00A6<@E240=6<@9240<e[@8YBP<i
cP9W>@=kgP9Nm`<]J`8HaP<Q208aS0<e[@8aS0<YBP8U:@<YBP<e[@9240=:DP9F]@=S609F]@<icP8]
J`=2409>L`<mk`8aS0<e[@8mk`=2408mk`<icP8e[@<icP9oo`03001oogoo00Moo`03001oogoo00io
o`P000MooaX000aoo`P0009ooaL0009oo`03001oogoo00Qoo`04001oogooOol3000:Ool70003Ool2
0003OolI000<Ool80002OolG0002Ool00`00Oomoo`08Ool000Uoo`03001oodHa00A6<@=2408mk`=2
408mk`<e[@8U:@<icP9W>@=oo`9Nm`<]J`8HaP<U:@D]J`DYBP8e[@=6<@=F]@9Nm`=S60EW>@9BU0<]
J`8U:@<mk`9>L`<mk`8aS0<e[@8mk`=2408mk`<icP8e[@<mk`9oo`03001oogoo00Moo`03001oogoo
00Moo`l000Mooa@0019oo`P0009ooaL0009oo`03001oogoo00Qoo`04001oogooOol30002Ool?0003
Ool20003OolD0007Ool80002Ool80002OolG0002Ool00`00Oomoo`08Ool000Uoo`03001oodHa00A6
<@=2408mk`=2408mk`<e[@8U:@<icP9W>@=oo`9Nm`<]J`8HaP<U:@D]J`DYBP8e[@=6<@=F]@9Nm`=S
60EW>@9BU0<]J`8U:@<mk`9>L`<mk`8aS0<e[@8mk`=2408mk`<icP8e[@<mk`9oo`03001oogoo00Mo
o`03001oogoo00Moo`l000Mooa@0019oo`P0009ooaL0009oo`03001oogoo00Qoo`04001oogooOol3
0002Ool?0003Ool20003OolD0007Ool80002Ool80002OolG0002Ool00`00Oomoo`08Ool000Uoo`03
001oodHa0096<@9:DP=6<@E2408mk`<]J`8U:@<icP9[FP=oo`9Nm`<]J`8Li`<U:@8YBP<U:@8YBP<i
cP9>L`=Nm`=S609W>@=S609W>@=S609BU0<aS08U:@<mk`9>L`=2408aS0<e[@8mk`=2408mk`DicP<m
k`9oo`03001oogoo00Moo`03001oogoo00Uoo`d000Mooa8001Aoo`P0009ooaL0009oo`03001oogoo
00Qoo`04001oogooOol30005Ool<0003Ool20003OolA0005Ool=0002Ool80002OolG0002Ool00`00
Oomoo`08Ool000Uoo`03001oodHa0096<@9:DP=6<@E2408mk`<]J`8U:@<icP9[FP=oo`9Nm`<]J`8L
i`<U:@8YBP<U:@8YBP<icP9>L`=Nm`=S609W>@=S609W>@=S609BU0<aS08U:@<mk`9>L`=2408aS0<e
[@8mk`=2408mk`DicP<mk`9oo`03001oogoo00Moo`03001oogoo00Uoo`d000Mooa8001Aoo`P0009o
oaL0009oo`03001oogoo00Qoo`04001oogooOol30005Ool<0003Ool20003OolA0005Ool=0002Ool8
0002OolG0002Ool00`00Oomoo`08Ool000Uoo`03001oodHa0096<@9:DP=6<@E2408mk`<]J`8U:@<i
cP9[FP=oo`9Nm`<]J`8Li`<U:@8YBP<U:@8YBP<icP9>L`=Nm`=S609W>@=S609W>@=S609BU0<aS08U
:@<mk`9>L`=2408aS0<e[@8mk`=2408mk`DicP<mk`9oo`03001oogoo00Moo`03001oogoo00Uoo`d0
00Mooa8001Aoo`P0009ooaL0009oo`03001oogoo00Qoo`04001oogooOol30005Ool<0003Ool20003
OolA0005Ool=0002Ool80002OolG0002Ool00`00Oomoo`08Ool000Uoo`03001oodHa0096<@9:DPQ6
<@8mk`<]J`8Q20<icP9[FP=oo`9S60<]J`8HaP<Q20DU:@8aS0=:DP9Nm`=W>@ES60=Nm`9S60=W>@9J
eP<mk`8YBP<icP9>L`=2408aS0<e[@8mk`E240<mk`8icP<mk`9oo`03001oogoo00Moo`03001oogoo
00aoo`X000Moo`l001Moo`P0009oo`X000=oo`X0009oo`03001oogoo00Qoo`04001oogooOol50005
Ool:0003Ool20003Ool?0005Ool?0002Ool80002Ool:0003Ool:0002Ool00`00Oomoo`08Ool000Uo
o`03001oodHa0096<@9:DPQ6<@8mk`<]J`8Q20<icP9[FP=oo`9S60<]J`8HaP<Q20DU:@8aS0=:DP9N
m`=W>@ES60=Nm`9S60=W>@9JeP<mk`8YBP<icP9>L`=2408aS0<e[@8mk`E240<mk`8icP<mk`9oo`03
001oogoo00Moo`03001oogoo00aoo`X000Moo`l001Moo`P0009oo`X000=oo`X0009oo`03001oogoo
00Qoo`04001oogooOol50005Ool:0003Ool20003Ool?0005Ool?0002Ool80002Ool:0003Ool:0002
Ool00`00Oomoo`08Ool000Uoo`03001oodHa0096<@9:DPQ6<@8mk`<]J`8Q20<icP9[FP=oo`9S60<]
J`8HaP<Q20DU:@8aS0=:DP9Nm`=W>@ES60=Nm`9S60=W>@9JeP<mk`8YBP<icP9>L`=2408aS0<e[@8m
k`E240<mk`8icP<mk`9oo`03001oogoo00Moo`03001oogoo00aoo`X000Moo`l001Moo`P0009oo`X0
00=oo`X0009oo`03001oogoo00Qoo`04001oogooOol50005Ool:0003Ool20003Ool?0005Ool?0002
Ool80002Ool:0003Ool:0002Ool00`00Oomoo`08Ool000Uoo`03001oodHa00a6<@9240<aS08Q20<e
[@9W>@=oo`9S60<aS0DDY@8Li`<YBP9240=Nm`EW>@=S60MNm`EW>@=>L`8aS0<icP9:DP=2408aS0<i
cP9240=6<@9240<mk`8icP<mk`9oo`03001oogoo00Moo`03001oogoo00ioo`P000Moo`d001aoo`D0
00Eoo`L000Eoo`P0009oo`03001oogoo00Qoo`04001oogooOol3000:Ool70003Ool20003Ool<0005
OolB0005Ool50005Ool70005Ool80002Ool00`00Oomoo`08Ool000Uoo`03001oodHa00a6<@9240<a
S08Q20<e[@9W>@=oo`9S60<aS0DDY@8Li`<YBP9240=Nm`EW>@=S60MNm`EW>@=>L`8aS0<icP9:DP=2
408aS0<icP9240=6<@9240<mk`8icP<mk`9oo`03001oogoo00Moo`03001oogoo00ioo`P000Moo`d0
01aoo`D000Eoo`L000Eoo`P0009oo`03001oogoo00Qoo`04001oogooOol3000:Ool70003Ool20003
Ool<0005OolB0005Ool50005Ool70005Ool80002Ool00`00Oomoo`08Ool000Uoo`03001oodHa00A6
<@Y240<aS08Q20<aS09Nm`=oo`9_N`=2408Li`<@Q08HaP<e[@9F]@EW>@=S60=JeP9BU0=:DP96<@=B
U09W>@=JePDicP9:DP=2408aS0<e[@9240=6<@9240<mk`8icP<mk`9oo`03001oogoo00Moo`03001o
ogoo00Moo`8000=oo`X000Yoo`X001aoo`D000Eoo`L000Eoo`P0009oo`03001oogoo00Qoo`04001o
ogooOol30002Ool30002Ool:0003Ool20005Ool:0003Ool7000BOol50005Ool70005Ool80002Ool0
0`00Oomoo`08Ool000Uoo`03001oodHa00A6<@Y240<aS08Q20<aS09Nm`=oo`9_N`=2408Li`<@Q08H
aP<e[@9F]@EW>@=S60=JeP9BU0=:DP96<@=BU09W>@=JePDicP9:DP=2408aS0<e[@9240=6<@9240<m
k`8icP<mk`9oo`03001oogoo00Moo`03001oogoo00Moo`8000=oo`X000Yoo`X001aoo`D000Eoo`L0
00Eoo`P0009oo`03001oogoo00Qoo`04001oogooOol30002Ool30002Ool:0003Ool20005Ool:0003
Ool7000BOol50005Ool70005Ool80002Ool00`00Oomoo`08Ool000Uoo`03001oodHa00A6<@Y240<a
S08Q20<aS09Nm`=oo`9_N`=2408Li`<@Q08HaP<e[@9F]@EW>@=S60=JeP9BU0=:DP96<@=BU09W>@=J
ePDicP9:DP=2408aS0<e[@9240=6<@9240<mk`8icP<mk`9oo`03001oogoo00Moo`03001oogoo00Mo
o`8000=oo`X000Yoo`X001aoo`D000Eoo`L000Eoo`P0009oo`03001oogoo00Qoo`04001oogooOol3
0002Ool30002Ool:0003Ool20005Ool:0003Ool7000BOol50005Ool70005Ool80002Ool00`00Oomo
o`08Ool000Uoo`03001oodHa0096<@9:DP=6<@E2408mk`<aS08Q20<]J`9F]@EkgP=Nm`8icP<Li`8Q
20=6<@9W>@=[FP9Nm`=>L`=2408e[@<YBP8Q20<e[@9F]@=JePDmk`9:DP=2408aS0<e[@8mk`E240<m
k`8icP<mk`9oo`03001oogoo00Moo`03001oogoo00Uoo`d000Yoo`L0011oo`X000Eoo`D0009oo`X0
00=oo`X0009oo`03001oogoo00Qoo`04001oogooOol30005Ool<0003Ool50002Ool80005Ool20008
Ool:0005Ool50002Ool:0003Ool:0002Ool00`00Oomoo`08Ool000Uoo`03001oodHa0096<@9:DP=6
<@E2408mk`<aS08Q20<]J`9F]@EkgP=Nm`8icP<Li`8Q20=6<@9W>@=[FP9Nm`=>L`=2408e[@<YBP8Q
20<e[@9F]@=JePDmk`9:DP=2408aS0<e[@8mk`E240<mk`8icP<mk`9oo`03001oogoo00Moo`03001o
ogoo00Uoo`d000Yoo`L0011oo`X000Eoo`D0009oo`X000=oo`X0009oo`03001oogoo00Qoo`04001o
ogooOol30005Ool<0003Ool50002Ool80005Ool20008Ool:0005Ool50002Ool:0003Ool:0002Ool0
0`00Oomoo`08Ool000Uoo`03001oodHa0096<@E:DPE6<@8mk`<]J`8Li`<U:@9>L`=cW09kgP=[FP96
<@<YBP8]J`=F]@9_N`=S6096<@<aS0<U:@8Li`<DY@8@Q0<U:@9>L`=JeP9240<mk`9:DP<mk`8aS0<e
[@8mk`=2408mk`<icP8e[@<icP9oo`03001oogoo00Moo`03001oogoo00aoo`X000aoo`D000Yooa00
00Moo`<0009ooaL0009oo`03001oogoo00Qoo`04001oogooOol50005Ool:0005Ool30005Ool50002
Ool30005Ool?0007Ool30002OolG0002Ool00`00Oomoo`08Ool000Uoo`03001oodHa0096<@E:DPE6
<@8mk`<]J`8Li`<U:@9>L`=cW09kgP=[FP96<@<YBP8]J`=F]@9_N`=S6096<@<aS0<U:@8Li`<DY@8@
Q0<U:@9>L`=JeP9240<mk`9:DP<mk`8aS0<e[@8mk`=2408mk`<icP8e[@<icP9oo`03001oogoo00Mo
o`03001oogoo00aoo`X000aoo`D000Yooa0000Moo`<0009ooaL0009oo`03001oogoo00Qoo`04001o
ogooOol50005Ool:0005Ool30005Ool50002Ool30005Ool?0007Ool30002OolG0002Ool00`00Oomo
o`08Ool000Uoo`03001oodHa0096<@E:DPE6<@8mk`<]J`8Li`<U:@9>L`=cW09kgP=[FP96<@<YBP8]
J`=F]@9_N`=S6096<@<aS0<U:@8Li`<DY@8@Q0<U:@9>L`=JeP9240<mk`9:DP<mk`8aS0<e[@8mk`=2
408mk`<icP8e[@<icP9oo`03001oogoo00Moo`03001oogoo00aoo`X000aoo`D000Yooa0000Moo`<0
009ooaL0009oo`03001oogoo00Qoo`04001oogooOol50005Ool:0005Ool30005Ool50002Ool30005
Ool?0007Ool30002OolG0002Ool00`00Oomoo`08Ool000Uoo`03001ood8@009240Y6<@8mk`<]J`8H
aP<Li`9240ENm`=>L`8aS0<Q208aS0=Nm`9[FP=>L`8]J`HLi`8HaPDDY@<]J`9F]@=Nm`96<@<mk`9:
DP<mk`8aS0<e[@8mk`=2408mk`DicP<mk`9oo`03001oogoo00Moo`03001oogoo00aoo``000Qoo`L0
00Qooa8000Moo`<0009ooaL0009oo`03001oogoo00Qoo`04001oogooOol30007Ool=0007Ool80007
OolB0002Ool30002Ool30002OolG0002Ool00`00Oomoo`08Ool000Uoo`03001ood8@009240Y6<@8m
k`<]J`8HaP<Li`9240ENm`=>L`8aS0<Q208aS0=Nm`9[FP=>L`8]J`HLi`8HaPDDY@<]J`9F]@=Nm`96
<@<mk`9:DP<mk`8aS0<e[@8mk`=2408mk`DicP<mk`9oo`03001oogoo00Moo`03001oogoo00aoo``0
00Qoo`L000Qooa8000Moo`<0009ooaL0009oo`03001oogoo00Qoo`04001oogooOol30007Ool=0007
Ool80007OolB0002Ool30002Ool30002OolG0002Ool00`00Oomoo`08Ool000Uoo`03001ood8@0092
4096<@Q2408icP<YBP8HaP<Q208icP=>L`96<@<]J`8DY@<<H`8]J`ENm`<e[@DHaPDQ20<HaP8Q20<m
k`EW>@96<@=2409>L`=240De[@Lmk`DicP<mk`9oo`03001oogoo00Moo`03001oogoo00Mooa4000Eo
o`X000EooaD000mooa@0009oo`03001oogoo00Qoo`04001oogooOol30002OolB0005Ool:0005OolD
0002Ool3000:OolD0002Ool00`00Oomoo`08Ool000Uoo`03001ood8@00924096<@Q2408icP<YBP8H
aP<Q208icP=>L`96<@<]J`8DY@<<H`8]J`ENm`<e[@DHaPDQ20<HaP8Q20<mk`EW>@96<@=2409>L`=2
40De[@Lmk`DicP<mk`9oo`03001oogoo00Moo`03001oogoo00Mooa4000Eoo`X000EooaD000mooa@0
009oo`03001oogoo00Qoo`04001oogooOol30002OolB0005Ool:0005OolD0002Ool3000:OolD0002
Ool00`00Oomoo`08Ool000Uoo`03001ood8@00924096<@Q2408icP<YBP8HaP<Q208icP=>L`96<@<]
J`8DY@<<H`8]J`ENm`<e[@DHaPDQ20<HaP8Q20<mk`EW>@96<@=2409>L`=240De[@Lmk`DicP<mk`9o
o`03001oogoo00Moo`03001oogoo00Mooa4000Eoo`X000EooaD000mooa@0009oo`03001oogoo00Qo
o`04001oogooOol30002OolB0005Ool:0005OolD0002Ool3000:OolD0002Ool00`00Oomoo`08Ool0
00Uoo`03001oodHa00A6<@=2408mk`<icP8aS0DYBP<e[@9>L`=JeP9>L`<aS08@Q0<8@P8]J`=JeP9F
]@<YBP8<H`<DY@<Q208U:@<YBP8e[@=F]@9_N`=S60E2409>L`=2408e[@<icPXmk`8icP<mk`9oo`03
001oogoo00Moo`03001oogoo00Moo`l000Moo`X000Eooa8000Yoo`<000Eooa@0009oo`03001oogoo
00Qoo`04001oogooOol30002Ool?0008Ool:0005OolA000:Ool30005OolD0002Ool00`00Oomoo`08
Ool000Uoo`03001oodHa00A6<@=2408mk`<icP8aS0DYBP<e[@9>L`=JeP9>L`<aS08@Q0<8@P8]J`=J
eP9F]@<YBP8<H`<DY@<Q208U:@<YBP8e[@=F]@9_N`=S60E2409>L`=2408e[@<icPXmk`8icP<mk`9o
o`03001oogoo00Moo`03001oogoo00Moo`l000Moo`X000Eooa8000Yoo`<000Eooa@0009oo`03001o
ogoo00Qoo`04001oogooOol30002Ool?0008Ool:0005OolA000:Ool30005OolD0002Ool00`00Oomo
o`08Ool000Uoo`03001oodHa0096<@9:DP=6<@8mk`<aS08]J`<e[@9240=BU09S60=_N`9W>@=>L`8U
:@<@Q08]J`EJeP<]J`8@Q0<DY@<U:@8e[@=2409F]@=[FP9_N`=>L`8aS0<icP9>L`=6<@8e[@<icPXm
k`DicP9oo`03001oogoo00Moo`03001oogoo00Moo`X000moo`L000Eoo`d000eoo`D000Eooa@0009o
o`03001oogoo00Qoo`04001oogooOol30002Ool:0008Ool20005Ool80005Ool<000=Ool50005OolD
0002Ool00`00Oomoo`08Ool000Uoo`03001oodHa0096<@9:DP=6<@8mk`<aS08]J`<e[@9240=BU09S
60=_N`9W>@=>L`8U:@<@Q08]J`EJeP<]J`8@Q0<DY@<U:@8e[@=2409F]@=[FP9_N`=>L`8aS0<icP9>
L`=6<@8e[@<icPXmk`DicP9oo`03001oogoo00Moo`03001oogoo00Moo`X000moo`L000Eoo`d000eo
o`D000Eooa@0009oo`03001oogoo00Qoo`04001oogooOol30002Ool:0008Ool20005Ool80005Ool<
000=Ool50005OolD0002Ool00`00Oomoo`08Ool000Uoo`03001oodHa0096<@9:DP=6<@8mk`<aS08]
J`<e[@9240=BU09S60=_N`9W>@=>L`8U:@<@Q08]J`EJeP<]J`8@Q0<DY@<U:@8e[@=2409F]@=[FP9_
N`=>L`8aS0<icP9>L`=6<@8e[@<icPXmk`DicP9oo`03001oogoo00Moo`03001oogoo00Moo`X000mo
o`L000Eoo`d000eoo`D000Eooa@0009oo`03001oogoo00Qoo`04001oogooOol30002Ool:0008Ool2
0005Ool80005Ool<000=Ool50005OolD0002Ool00`00Oomoo`08Ool000Uoo`03001ood8@009240E6
<@8icP<aS08icP=>L`9S60=W>@9[FP=_N`9cW0=Nm`8e[@<HaP8]J`=JeP9S60=6<@D]J`<mk`9>L`=J
eP9[FP=cW09Nm`<icP8Q20<e[@9:DP=6<@LicPPmk`DicP9oo`03001oogoo00Moo`03001oogoo00Mo
o`L0019oo`L000Qoo`P000aoo`P000Eooa@0009oo`03001oogoo00Qoo`03001oogoo00Ioo`P000Eo
o`X0009oo`P000Moo`P000Eoo`D0009oo`P000Eooa@0009oo`03001oogoo00Qoo`002Goo00<007oo
@Q000T8@1DHa0SW>0c6<0SW>0dic0V<H0fLi0V]J0fmk0W>L0ekg0SF]0aS60Re[0e[F0V<H0dHa1Be[
0cg_0Tic0e[F0V]J0g>L0Ukg0cW>0R480cF]0TYB0dHa1cW>23g_1CW>0Woo00<007ooOol01goo00<0
07ooOol01goo1`004Woo1`0027oo200037oo20001Goo50000Woo00<007ooOol027oo00<007ooOol0
1Woo20001Goo2P000Woo20001goo20001Goo1@000Woo20001Goo50000Woo00<007ooOol027oo0009
Ool00`00Oom24002@Q02AS43?Nl5<H`2BU83JeX2Li`3IcT2F]H3HaP2Kg/3HaP2>Lh36<H2:DX3DY@2
JeX3G_L2CW<3BU83DY@2G_L3IcT2JeX3IcT2BU83:DX27>L3=Jd2CW<3AS45>Lh:?Nl5>Lh2Ool00`00
Oomoo`07Ool00`00Ool000020002Ool8000DOol7000LOol80005OolD0002Ool00`00Oomoo`08Ool0
1000Ool000000goo1`001Goo0`0037oo20000Woo0`0037oo1@001Goo20001Goo50000Woo00<007oo
Ool027oo0009Ool00`00Oom24002@Q02AS43?Nl5<H`2BU83JeX2Li`3IcT2F]H3HaP2Kg/3HaP2>Lh3
6<H2:DX3DY@2JeX3G_L2CW<3BU83DY@2G_L3IcT2JeX3IcT2BU83:DX27>L3=Jd2CW<3AS45>Lh:?Nl5
>Lh2Ool00`00Oomoo`07Ool00`00Ool000020002Ool8000DOol7000LOol80005OolD0002Ool00`00
Oomoo`08Ool01000Ool000000goo1`001Goo0`0037oo20000Woo0`0037oo1@001Goo20001Goo5000
0Woo00<007ooOol027oo0009Ool00`00Oom24002@Q02AS43?Nl5<H`2BU83JeX2Li`3IcT2F]H3HaP2
Kg/3HaP2>Lh36<H2:DX3DY@2JeX3G_L2CW<3BU83DY@2G_L3IcT2JeX3IcT2BU83:DX27>L3=Jd2CW<3
AS45>Lh:?Nl5>Lh2Ool00`00Oomoo`07Ool00`00Ool000020002Ool8000DOol7000LOol80005OolD
0002Ool00`00Oomoo`08Ool01000Ool000000goo1`001Goo0`0037oo20000Woo0`0037oo1@001Goo
20001Goo50000Woo00<007ooOol027oo0009Ool00`00Oom24004@Q03?Nl2;F/3=Jd2E[D3Li`2JeX3
BU82>Lh3?Nl2E[D3F]H2>Lh36<H28@P3BU85HaP2G_L3F]H:G_L3CW<2=Jd58@P3>Lh2CW<3AS45>Lh:
?Nl5>Lh2Ool00`00Oomoo`07Ool00`00Ool000020002Ool8000:Ool50005Ool7000JOol:0005OolD
0002Ool00`00Oomoo`08Ool01000Ool000000goo1`000goo0P001Goo1@001Goo20001Goo3`001Goo
2P001Goo50000Woo00<007ooOol027oo0009Ool00`00Oom24004@Q03?Nl2;F/3=Jd2E[D3Li`2JeX3
BU82>Lh3?Nl2E[D3F]H2>Lh36<H28@P3BU85HaP2G_L3F]H:G_L3CW<2=Jd58@P3>Lh2CW<3AS45>Lh:
?Nl5>Lh2Ool00`00Oomoo`07Ool00`00Ool000020002Ool8000:Ool50005Ool7000JOol:0005OolD
0002Ool00`00Oomoo`08Ool01000Ool000000goo1`000goo0P001Goo1@001Goo20001Goo3`001Goo
2P001Goo50000Woo00<007ooOol027oo0009Ool00`00Oom24002@Q02AS43?Nl2<H`3?Nl2G_L3IcT2
@Q037>L236<38@P2@Q03DY@2=Jd36<H27>L3>Lh2E[D3G_L2HaP6G_L2F]H3DY@2AS43=Jd5:DX2;F/3
@Q02CW<3@Q02>Lh3?Nl5@Q05?Nl5>Lh2Ool00`00Oomoo`07Ool00`00Oomoo`04Ool80007Ool80005
Ool:000DOol=0005OolD0002Ool00`00Oomoo`08Ool00`00Oomoo`04Ool70008Ool70005Ool:0005
Ool80007Ool=0005OolD0002Ool00`00Oomoo`08Ool000Uoo`03001ood8@00924096<@<mk`8aS0<m
k`9Nm`=W>@9240<Li`8<H`<Q209240=BU08e[@<HaP8Li`<icP9F]@=Nm`9S60INm`9JeP=BU096<@<e
[@DYBP8]J`=2409>L`=2408icP<mk`E240Dmk`DicP9oo`03001oogoo00Moo`03001oogoo00Aoo`P0
00Moo`P000Eoo`X001Aoo`d000Eooa@0009oo`03001oogoo00Qoo`03001oogoo00Aoo`L000Qoo`L0
00Eoo`X000Eoo`P000Moo`d000Eooa@0009oo`03001oogoo00Qoo`002Goo00<007oo@Q000T8@0THa
0cg_0S6<0cg_0Ukg0fLi0T8@0acW0PaS0b480T8@0e:D0SF]0aS60QcW0cW>0UJe0ekg0V<H1Ukg0U[F
0e:D0THa0cF]1BU:0Re[0d8@0Tic0d8@0SW>0cg_1D8@1Cg_1CW>0Woo00<007ooOol01goo00<007oo
Ool017oo20001goo20001Goo2P0057oo3@001Goo50000Woo00<007ooOol027oo00<007ooOol017oo
1`0027oo1`001Goo2P001Goo20001goo3@001Goo50000Woo00<007ooOol027oo0009Ool00`00Oom2
4004@Q03>Lh2<H`3@Q02F]H3CW<28@P3000224839BT2BU83E[D2>Lh36<H25:D39BT2?Nl3CW<2E[D3
F]H3E[D2CW<3?Nl2<H`3;F/2=Jd3?Nl2>Lh3@Q02AS43?Nl2>Lh3?Nl5@Q05?Nl5>Lh2Ool00`00Oomo
o`07Ool00`00Ool000020002Ool80005Ool:0005Ool<000=OolB0002OolG0002Ool00`00Oomoo`08
Ool01000Ool000000goo1`001Goo2P001Goo3@0037oo4P000Woo5`000Woo00<007ooOol027oo0009
Ool00`00Oom24004@Q03>Lh2<H`3@Q02F]H3CW<28@P3000224839BT2BU83E[D2>Lh36<H25:D39BT2
?Nl3CW<2E[D3F]H3E[D2CW<3?Nl2<H`3;F/2=Jd3?Nl2>Lh3@Q02AS43?Nl2>Lh3?Nl5@Q05?Nl5>Lh2
Ool00`00Oomoo`07Ool00`00Ool000020002Ool80005Ool:0005Ool<000=OolB0002OolG0002Ool0
0`00Oomoo`08Ool01000Ool000000goo1`001Goo2P001Goo3@0037oo4P000Woo5`000Woo00<007oo
Ool027oo0009Ool00`00Oolmk`04?Nl3<H`2:DX3>Lh2DY@3@Q028@P35:D2:DX3BU82HaP3G_L2?Nl3
7>L236<348@27>L3:DX2>Lh6AS42?Nl5<H`3?Nl5DY@5?Nl2@Q03?Nl2=Jd3>Lh2?Nl3@Q05?Nl5>Lh2
Ool00`00Oomoo`07Ool00`00Ool0000<0005Ool70008OolA0006Ool:0005Ool50002OolG0002Ool0
0`00Oomoo`08Ool00`00Ool0000;0005Ool80007OolB0005Ool:0005Ool50002OolG0002Ool00`00
Oomoo`08Ool000Uoo`03001oocg_00@mk`<aS08YBP<icP9BU0=2408Q20<DY@8YBP=:DP9S60=Nm`8m
k`<Li`8<H`<@Q08Li`<YBP8icPI6<@8mk`DaS0<mk`EBU0Dmk`9240<mk`8e[@<icP8mk`=240Dmk`Di
cP9oo`03001oogoo00Moo`03001oo`0000`000Eoo`L000Qooa4000Ioo`X000Eoo`D0009ooaL0009o
o`03001oogoo00Qoo`03001oo`0000/000Eoo`P000Mooa8000Eoo`X000Eoo`D0009ooaL0009oo`03
001oogoo00Qoo`002Goo00<007oo?Nl013g_0c6<0RU:0cW>0U:D0d8@0R480aBU0RU:0dYB0V<H0ekg
0Sg_0acW0PaS0a240QcW0bU:0SW>1THa0Sg_1C6<0cg_1E:D1Cg_0T8@0cg_0SF]0cW>0Sg_0d8@1Cg_
1CW>0Woo00<007ooOol01goo00<007oo000030001Goo1`0027oo4@001Woo2P001Goo1@000Woo5`00
0Woo00<007ooOol027oo00<007oo00002`001Goo20001goo4P001Goo2P001Goo1@000Woo5`000Woo
00<007ooOol027oo0009Ool00`00OolicP02>Lh2=Jd3;F/29BT3>Lh5DY@5@Q02DY@3IcT2Kg/3HaP2
AS439BT248@524835:D29BT3<H`3>Lh5?Nl2AS43E[D2IcT3F]H2?Nl3>Lh2?Nl3>Lh2=Jd3>Lh5?Nl2
@Q03?Nl2>Lh3=Jd2Ool00`00Oomoo`07Ool00`00Ool0000<000FOolJ000:OolN0002Ool00`00Oomo
o`08Ool00`00Ool0000;000?Ool30005OolI000:OolN0002Ool00`00Oomoo`08Ool000Uoo`03001o
ocW>008icP8e[@<]J`8U:@<icPEBU0E2409BU0=W>@9_N`=S6096<@<U:@8@Q0D8@P<DY@8U:@<aS0<i
cPDmk`96<@=F]@9W>@=JeP8mk`<icP8mk`<icP8e[@<icPDmk`9240<mk`8icP<e[@9oo`03001oogoo
00Moo`03001oo`0000`001IooaX000Yooah0009oo`03001oogoo00Qoo`03001oo`0000/000moo`<0
00EooaT000Yooah0009oo`03001oogoo00Qoo`002Goo00<007oo=Jd00SF]1cW>0dHa0Ukg0f<H1Ekg
0V<H1FLi0e[F0TYB0cF]0RU:1B480bDY0S6<0cg_0dHa0TYB0dic0UJe0f<H0V]J0e[F0T8@1CW>1CF]
3Cg_0SW>0cF]0Woo00<007ooOol01goo00<007oo00002@006Goo4P004Woo7P000Woo00<007ooOol0
27oo00<007oo00002@001Goo4@000goo4@002Woo1@000goo7P000Woo00<007ooOol027oo0009Ool0
0`00Oole[@02=Jd7>Lh3AS42G_L3HaP5G_L2HaP5IcT3F]H2BU83=Jd2:DX58@P39BT2<H`3?Nl3AS42
BU83CW<2E[D3HaP2JeX3F]H2@Q05>Lh5=Jd=?Nl2>Lh3=Jd2Ool00`00Oomoo`07Ool00`00Ool00009
000IOolB000BOolN0002Ool00`00Oomoo`08Ool00`00Ool000090005OolA0003OolA000:Ool50003
OolN0002Ool00`00Oomoo`08Ool000Uoo`03001oocF]008e[@LicP=6<@9Nm`=S60ENm`9S60EW>@=J
eP9:DP<e[@8YBPDQ20<U:@8aS0<mk`=6<@9:DP=>L`9F]@=S609[FP=JeP9240DicPDe[@dmk`8icP<e
[@9oo`03001oogoo00Moo`03001oo`0000T001Uooa80019ooah0009oo`03001oogoo00Qoo`03001o
o`0000T000Eooa4000=ooa4000Yoo`D000=ooah0009oo`03001oogoo00Qoo`002Goo00<007oo=Jd0
0SF]0Sg_0dic0U[F0f<H1F]J0V<H0ekg0U[F0eJe0Tic1DYB0dic0TYB0dHa0TYB0dic0U:D2eJe0U[F
0f<H0V]J0e[F0THa0cg_0SW>0cF]0SW>248@1Cg_0SW>0cF]0Woo00<007ooOol01goo00<007oo0000
1000A7oo3@000Woo3@000Woo00<007ooOol027oo00<007oo000010001goo2P008Goo30001Goo3@00
0Woo3@000Woo00<007ooOol027oo0009Ool00`00Oole[@02=Jd2?Nl3CW<2F]H3HaP5JeX2HaP3G_L2
F]H3E[D2CW<5BU83CW<2BU83AS42BU83CW<2DY@;E[D2F]H3HaP2JeX3F]H2AS43?Nl2>Lh3=Jd2>Lh8
@Q05?Nl2>Lh3=Jd2Ool00`00Oomoo`07Ool00`00Ool000040014Ool=0002Ool=0002Ool00`00Oomo
o`08Ool00`00Ool000040007Ool:000QOol<0005Ool=0002Ool=0002Ool00`00Oomoo`08Ool000Uo
o`03001oocF]008e[@9240=Nm`9g_@=kgP9cW0=[FP9JeP=>L`96<@<mk`8icP=2409>L`=Nm`9W>@E[
FP=_N`9[FQ1W>@9S60=F]@9:DP=6<@8mk`<e[@8mk`E6<@Q2408icP<e[@9oo`03001oogoo00Moo`03
001oo`00008001Ioo`P002]oo`L000Yoo`P0009oo`03001oogoo00Qoo`04001oo`000005Ool:0008
Ool70003OolS0005Ool7000:Ool80002Ool00`00Oomoo`08Ool000Uoo`03001oocF]008e[@9240=N
m`9g_@=kgP9cW0=[FP9JeP=>L`96<@<mk`8icP=2409>L`=Nm`9W>@E[FP=_N`9[FQ1W>@9S60=F]@9:
DP=6<@8mk`<e[@8mk`E6<@Q2408icP<e[@9oo`03001oogoo00Moo`03001oo`00008001Ioo`P002]o
o`L000Yoo`P0009oo`03001oogoo00Qoo`04001oo`000005Ool:0008Ool70003OolS0005Ool7000:
Ool80002Ool00`00Oomoo`08Ool000Uoo`03001oocF]008e[@9240=Nm`9g_@=kgP9cW0=[FP9JeP=>
L`96<@<mk`8icP=2409>L`=Nm`9W>@E[FP=_N`9[FQ1W>@9S60=F]@9:DP=6<@8mk`<e[@8mk`E6<@Q2
408icP<e[@9oo`03001oogoo00Moo`03001oo`00008001Ioo`P002]oo`L000Yoo`P0009oo`03001o
ogoo00Qoo`04001oo`000005Ool:0008Ool70003OolS0005Ool7000:Ool80002Ool00`00Oomoo`08
Ool000Uoo`03001oocW>008icP9:DP=W>@Eoo`9_N`=JeP9:DPDmk`=2409>L`=F]@9S60=[FP9cW0Qg
_@9cW0I_N`EcW09_N`=Nm`9>L`=6<@9:DP=BU096<@<icP8mk`e6<@8mk`<e[@9oo`03001oogoo00Mo
o`03001oo`000080015oo`D003Eoo`D000eoo`D0009oo`03001oogoo00Qoo`04001oo`000003Ool:
0005Ool5000:OolI000AOol50005Ool30005Ool50002Ool00`00Oomoo`08Ool000Uoo`03001oocW>
008icP9:DP=W>@Eoo`9_N`=JeP9:DPDmk`=2409>L`=F]@9S60=[FP9cW0Qg_@9cW0I_N`EcW09_N`=N
m`9>L`=6<@9:DP=BU096<@<icP8mk`e6<@8mk`<e[@9oo`03001oogoo00Moo`03001oo`000080015o
o`D003Eoo`D000eoo`D0009oo`03001oogoo00Qoo`04001oo`000003Ool:0005Ool5000:OolI000A
Ool50005Ool30005Ool50002Ool00`00Oomoo`08Ool000Uoo`03001oocg_008mk`9>L`=Nm`9_N`=[
FP9F]@=240DicP9240=>L`9JeP=Nm`9JePEF]@QJePEF]@=BU0EF]@9BU0<mk`8]J`<aS09>L`=Nm`9:
DPDe[@<mk`Y2408icP<e[@9oo`03001oogoo00Moo`03001oo`00008000moo`D002Qoo`P000Moo`P0
00Moo`P0009oo`03001oogoo00Qoo`04001oo`00000?Ool5000XOol80007Ool80007Ool80002Ool0
0`00Oomoo`08Ool000Uoo`03001oocg_008mk`9>L`=Nm`9_N`=[FP9F]@=240DicP9240=>L`9JeP=N
m`9JePEF]@QJePEF]@=BU0EF]@9BU0<mk`8]J`<aS09>L`=Nm`9:DPDe[@<mk`Y2408icP<e[@9oo`03
001oogoo00Moo`03001oo`00008000moo`D002Qoo`P000Moo`P000Moo`P0009oo`03001oogoo00Qo
o`04001oo`00000?Ool5000XOol80007Ool80007Ool80002Ool00`00Oomoo`08Ool000Uoo`03001o
ocg_008mk`9>L`=Nm`9_N`=[FP9F]@=240DicP9240=>L`9JeP=Nm`9JePEF]@QJePEF]@=BU0EF]@9B
U0<mk`8]J`<aS09>L`=Nm`9:DPDe[@<mk`Y2408icP<e[@9oo`03001oogoo00Moo`03001oo`000080
00moo`D002Qoo`P000Moo`P000Moo`P0009oo`03001oogoo00Qoo`04001oo`00000?Ool5000XOol8
0007Ool80007Ool80002Ool00`00Oomoo`08Ool000Uoo`03001oogoo06Ioo`03001oogoo00Moo`03
001oogoo06Ioo`03001oogoo00Qoo`03001oogoo06Eoo`03001oogoo00Qoo`002GooJP002GooJP00
2WooJ@002Woo003oOomTOol00?moofAoo`00\
\>"],
  ImageRangeCache->{{{0, 354.438}, {110.063, 0}} -> {-0.0850217, -0.0234425, 
  0.00894388, 0.00894388}, {{9.5, 114.313}, {107.438, 
  2.5625}} -> {-4.62953, -1.90673, 0.397852, 0.397852}, {{124.75, 229.625}, {
  107.438, 2.5625}} -> {-50.4522, -1.89365, 0.397614, 0.397614}, {{240.063, 
  344.875}, {107.438, 2.5625}} -> {-96.3592, -1.90673, 0.397852, 0.397852}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Morphological Gradient Operator", "Subsection"],

Cell[TextData[{
  "Gray scale erosion and dilation may be used to define the ",
  StyleBox["morphological gradient",
    FontSlant->"Italic"],
  " of an image."
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm
    \`\(G\  = \ \((A\ \[CirclePlus]\ S)\)\  - \ \((A\ \[CircleMinus]\ S)\)\ \ 
    \)\)]]], "NumberedEquation"],

Cell["\<\
Here is a result of the morphological gradient operation on the example \
image.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        \((ListDensityPlot[#1, Mesh \[Rule] False, FrameTicks \[Rule] None, 
                DisplayFunction \[Rule] Identity]\ &)\)\ /@
          \ {A, GrayscaleDilate[A, S] - \ GrayscaleErode[A, S]}]]; \)\)], 
  "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0240385 0.0192308 0.0240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
40 string
40 40 8 [40 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B1839CBC9595BC8A98A7D5C7B5CEE7F5D8DCD5D1D8D5FCD8
D5D8CAE06E3895E3E0D8E0EAD8D8D8E7
C383B8BCB1C3DCE7D5F5DCD5DCDCD5D1E7FCE0E0D8D8DCDC
E7D1D1C38A3C98D8D8D5D8DCE0D8DCE0
C3C0C0BCBCC0D1D5D8D5E3F8E3D8D8D8DCD8E3E3C7AAA7CE
D8EAD5CAA74091DCD5D8D8DCDCD5DCD8
BCB8D1D5C7E3CAA0957CB183E7FFD8D5D5CA67514E4E4A4A
58CEE0C7B53587CECEDCCED5D8DCD5E0
BC8A835C67788E757178A3CEE3D8EAE36A584A514E514A55
5547CAC0C03880E0CEDCD8D8DCD8DCEA
C38051553C675CB89C8A98D8D8D5B84E4A4E4E514E51404A
4A4360C3A74071C3CACABCC3BCAEA091
BC8E51404367608AD560C0E0D1AE4A4E4E4A4A4E4E4E4031
40433CB8BC402E0A18202E314751586E
C7B855A0A38A7C63788380CED14E4E4E55474A554E434A4A
4738389CBC4751D5CECECAD5CED5D1D1
B8B17847314E78BCB8C0C7D54E514E4E4E4E584A4E4A404A
3C312E60CE5563D5D5D8CED8D8D5D5DC
B8A3AE67274040D1C3D5C76A474A514A5158514A514E4340
3C273138BC6363D1CACED1D8CED5CAD5
AEB5A79858B5C0C0CAD1CA404E4E4E4E515CA3CACAC7C34E
31271C31C06A5CD1CACED1C7D1CECAD5
B5AEB5AE91B5B5B8CECA63434E4E4A55AED1D8F1D1D1CAC7
3C231C2EC37158D5C3D1CAC7CED1CACE
AAB8B8AEAEA3A0C0C3C33C4A4E516AD5D1D1D1D5D8D1C0CA
8E181C27957C58C7C7CECAD8C7D1D1C3
AA9CB5B1B1B1B1A0B88A38404067C3E0D5D1D5D5CEC7D1BC
AE15202E678A60C7C7CAD1CECEC7CED1
A0B598AAB5B5B5B8B5512A404ECECED5D1E7D1D1C7C7B8A3
A71C1C35838E55CAC3CACACACECED5CE
A3B1B19CA3AAB5B5B831384A8ECECAD5D5D1D8DCC7C3BCAE
AA231863838A55CACAC7CEC7CACED1D5
A0B5B5A3AE8AAEB5B1233143D5D1CED1CECECACED8B56035
2A1C189C759555CAC3C7C7C3CED1D1D8
A7AAB1BCAEAE9CA7BC232735CECEEED5CECACACA6A352323
18181C8E83A04AC3C7C7C0CECAD1C7D1
A7AA98B5AAAAB1B5A71C273CCAC3CECEE7CEC34A3C312320
151C20A780A347C7C0C0C7C3C7CEC7CA
A0AAAE87A7AEB1B5AA202031C7C3CACECAD55540382E201C
1C1C18608EA347C7C0BCC0CAC3C7CEC7
A0A7AEB18A9CA7B5BC152023CECACEC0CE80473C382E2723
1C18182EA7A747BCC3C0B5BCBCC7C3C7
A7AAA7AEAAA791B8B82E272A78D8D5C7C04A474338272323
382A1118A3A03CBCB5BCB8C0B8C3C7C7
A3A0A3A7B1AEAEC0BC381C273CAACADC7843473C38608EA0
AAA0311C71A343C3BCC3C3C0C0C3CEC7
A0A3988EAAAAAAB5B858202A2E4A8EC04A404055AAB1A7A3
8EA75C11959C4AB8BCC0C0BCCAC3C7CA
A3AEA7A780AEB8C0B86A232A4A8EBCD1383C58CAB5AEB1AA
AA784A07959C47BCB8C0B8C0BCC7CAC7
A7B1AAA3AA83A0B8B5716EA0AEC7BCB53843B1C0A0A7A7A3
A3981818718A43B8B8BCBCC7C3CAC3C0
AA95A7AAA7A39CAA9140272E95BCCABC3C4EC7B5B1A08AA3
952A181C879543B5B1B8BCC0C0C3C7C3
A0A087A0A3A0A75835271C232AB1B5B53C43C0BCAAAA956A
1C11183895A743B8B1BCBCC7BCC3C3C7
A7A79C958AA3512A2A2720202E87B1B5403851A08E5C2320
111C1887A3A34EB8AAB5C0C7BCC3C7CA
A3A39C9C987811112A2720202775B5AE3C383C312E272018
181123A7A3A34AB1B1B8B8C7C0C0C3C7
AA9C98AAA06307182A4E51232A83B5B551353C2E271C1818
18157187A39C51B5B1B5B8C3C0C0C0C7
AAA08A98A0270E4A9CA7A37C20A3AAA791353C2E23151518
1838A77183915CB1A7B8B5B5BCBCC0BC
A795987C981131AEA7958E512087B19CB558312A11151823
359C8A1CA0836EAEB5AEAEC0BCC0C0B8
AAA09895781178A39C672315206EB8AEB1B5802720152771
83270E20957C75AEB5B1B8B8BCBCC0C0
A79C9C98980E3827201C1C181C60A7AAAEA7B5A38A673518
110E151C957C7CB1B1B8B8B8C0B8C0C7
B191789C630A0E182018181520604AAEA3A0804020110E0E
11110E1C87758AAEB5B1B8B8B5B8C0C0
A09C4E11110A0E1C27151520315138384E3120271C110E18
151511118A6098B1B1AAB5C3C0BCC3BC
A79C4711110E0E18203867839851352335201C1C1C151515
111511188A4EA7AEAAAEAEC3B5BCC0B5
A09847070E111C558A988E71314A382E2A2318201C180A0E
152A5178873CAAB5AEB1B8B8B8B8B8C7
9C874A0018517C87874A1818184038272A1C201C20111511
156AA07C9531AAAAA3B5B8B5BCB8C0C3
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0240385 0.0192308 0.0240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
40 string
40 40 8 [40 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
52524A353D5A737384736335354235313935391818353535
2129298CCA77CE631814211C1C101818
52524E393D5A73738473675656423531393539294A6B6B6B
292D358CCA88CE671814211C21141C18
5263673142425A679494989098393D2142B5CEB5B5B1B1BD
C2B1356BB59CCA6B1818181C14141414
4A639494A5988880808C9C909835399CA9B9B9B9B598A1AD
C6C6C64AB5A9CE771C18181810102121
569CA1B9CACAA5885A52777B985AD6C2B9A99C290C1C2125
A9BDBD9CB1A9CE88292D2D2D3D4E6F6F
568C635A4E67739490909C5E46C2C2C2B92D18100C1C3131
31ADADADA9B1FFFFFFEBE3D2CEB5B9B1
5A9094808080739490909C77B1ADA988181818141C1C2D25
2535A9A9A1ADF3F3F3DADACAC6ADA194
4A90948C8C8C889090909CB1B1A57B14181C1C181C182925
2525A9C2ADC2F3F3F7E7DECECAB1A9A1
318C8CA59898B1B18C7384ADADA910141C1C1C181C1C1818
312D90C2B5A5ADA11818181814181C1C
215288A5ADB9B1B12929B5B5B51410101C6B9C9C9CA9A5B1
352D56D6BD949C9418181C1C1C181C1C
212163ADADB9B1B1298CB5A93914147BA5A5CACACAADB1B9
C62D29CAB58498981C181C1C1C141414
181C2D7773802D3D25B5B5AD1C2DA9A9A5A5B5633925A1B9
D69025CABD8498981C181C1C1C141C1C
2929293531312D3D56B5B13935A1B5B5A9392D31392521B5
DAB925CABD8498981C181C1C1C141818
292D2D2D1C212D318CB9B931ADADAD902121211C1C2D3D56
DAB92D94885290901418181C1C181C1C
25292929251C2525A5AD777BADAD94292121212125253D3D
CAB96384774A90901018141410181810
2129292939393D14B5B53DCEB5A51414252929213594B1B1
B1B1A1A1805290901014141418141414
21212D2D4239392DB9B935D2C277313114181C8CCADAC2C6
B5B1A1A14E6B9C9C1018181818141C1C
212931314235392DC2C235D2C239392D2931A1BDCADAB55E
2D21ADAD4273A1A11410181818141C1C
142546464621252DC2C22DD2BD39393129B1B5B1BD5E2518
1814ADAD5A739C9C14141C1818181414
14213D3D3D352521CACA35D2CE14183580C2B9A92929211C
1814ADAD94779C9C141C21211C1C1414
1418393939353539CACA29D2DA772521A9ADB92929251C29
2D3563B5AD84A9A91C1821211C211414
14181C3535353D3DCECA31D6DABD427BB9A956184A8498AD
B1B9ADB5AD84A5A51818181818211414
141C2D31312D3D3DB1C24E73D6CEB1B1BD9C258CA9ADADA5
A5B9B5B1B180A5A51818141C1C211410
18212D42424A2121A5C2633DA1BDB1C6C652ADB1B1986731
4294C2ADBD779C9C1414141C181C1410
1C2531393D4A4E2D80B99CADBDB9A5B9B994ADA990211831
42B1C2ADB56F94941010181C18181414
292929393D4A4E3D9CB598A9BD9C56B9B9ADAD8C39393535
9CB1B1ADB56F94941818181818181414
29393931353577A1B1B9A1B1C6C225B1A1ADA1352D3552A9
B1B1A598AD7B90901414181418181410
213131312D6B9C9CA1903194BDC256ADA1ADAD9077ADA9B1
B1A190A9A97B90901C211C1414141010
102D2D2939B5B5B55A25141CB1AD529498A5ADB1B5A9B1A1
6F1CB5AD887B90901C211C1814141410
181C212D5ABDBD5E4E42424280AD52949C298C94A190561C
1877B5AD2D6F888818211C1814141414
182D2D2DA1B98CB5B5A5A5A1A1B552949C73182529251C14
35B5B5A1466F84841C1C1C1C1C101414
212D3D3DB9B9CACAB598A1A1A1B5427B9CA13D392921182D
A5B1B1A9A5677B7B1C1C2121180C1818
212D3135ADB1C2C27BA1B1ADADB95E359CA1AD8829217388
A1B9B9B9A1566B6F1C1C1C1C140C1010
21213131A9A9C2ADB1A99C948CBD6F2973A1ADC6B194738C
ADADADB1A142565A14141C1C10101818
2D4A354AB1ADB9B5A9A167186FBD88882146ADB5B1987B90
909025A5942D4E521410101414141810
2D7BA9A9B1AD3D391C1C14295EA9909098B5B5B9B1986F35
141018A5A14A674A1818251818181814
2D84A9A9B16F1C25316788A1A194A9A9ADA5A17B3D1C1414
14101898946F7B391418252118181818
1877B55A141C5E98A1A1A1A194803D393D462518211C1818
29528094948894291418252118181C1C
2D77BD5E678894989C9C9C9C9C9C3D212529141018211814
73ADADAD9894A11C1C21212118141C1C
256FB95E67889088639C9C906F42311C1C1C141018211814
73A990637B94A11C1C21101010101818
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{249, 118.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003i0000MQ000`40O003h00OnGoo003iOol00?Uo
o`001WooL@002WooL@001goo0006Ool00`00Oomoo`1]Ool00`00Oomoo`08Ool00`00Oomoo`1]Ool0
0`00Oomoo`05Ool000Ioo`03001oogoo06eoo`03001oogoo00Qoo`03001oogoo06eoo`03001oogoo
00Eoo`001Woo00<007ooF]H00U[F0T8@0dic0ekg1DYB0ekg0dHa0Tic0e:D0f]J0V<H0e[F0fLi0g>L
0W_N1Vmk1F]J0fmk0V]J0goo0fmk0f]J0Vmk0fLi0g>L0SF]0acW0dYB1G>L0fmk0g>L0WNm26mk0g>L
0Woo00<007ooOol027oo00<007oo:DX012U:0bDY0aS60acW0Re[1SW>0T8@0cW>0c6<1AS60b481AS6
0acW0aS60QcW1PaS21S60a241ABU0dHa0VLi0cW>0fLi0S6<0`aS0`Q20a241@aS0`Q21@aS0Woo00<0
07ooOol01Goo0006Ool00`00OomJeP02F]H2@Q03CW<3G_L5BU83G_L3AS42CW<3DY@3JeX2HaP3F]H3
IcT3Li`2Nmh6Kg/5JeX3Kg/2JeX3Ool3Kg/3JeX2Kg/3IcT3Li`2=Jd37>L3BU85Li`3Kg/3Li`2Mkd8
Kg/3Li`2Ool00`00Oomoo`08Ool00`00OolYBP04:DX39BT36<H37>L2;F/6>Lh2@Q03>Lh3<H`56<H3
8@P56<H37>L36<H27>L636<86<H348@55:D3AS42IcT3>Lh3IcT2<H`336<3248348@536<3248536<2
Ool00`00Oomoo`05Ool000Ioo`03001ooe[F009JeP9240=>L`=Nm`E:DP=Nm`=6<@9>L`=BU0=[FP9S
60=JeP=W>@=cW09kgPI_N`E[FP=_N`9[FP=oo`=_N`=[FP9_N`=W>@=cW08e[@<Li`=:DPEcW0=_N`=c
W09g_@Q_N`=cW09oo`03001oogoo00Qoo`03001oobU:00@YBP<U:@<HaP<Li`8]J`HicP9240<icP<a
S0DHaP<Q20DHaP<Li`<HaP8Li`H<H`PHaP<@Q0DDY@=6<@9W>@<icP=W>@8aS0<<H`<8@P<@Q0D<H`<8
@PD<H`9oo`03001oogoo00Eoo`001Woo00<007ooHaP00V<H0T8@1Ukg0e[F0V<H0fmk0g>L0V]J0g_N
0fmk0V]J1Vmk1F]J0g>L0goo1G>L2fmk0g>L1F]J0f<H0THa0acW0dic1Fmk0f]J1Fmk0g>L1Fmk0g>L
0Woo00<007ooOol027oo00<007oo:DX012U:0bDY1QcW0Re[1SW>0T8@0cW>0c6<1BU:0b481AS60acW
0aS60QcW0aBU0bDY23F]1ABU0aS60dHa0VLi0dHa0fLi0S6<0`aS0`Q20a240PaS0a240`Q21@aS0Woo
00<007ooOol01Goo0006Ool00`00OomS6002HaP2@Q06G_L3F]H2HaP3Kg/3Li`2JeX3Nmh3Kg/2JeX6
Kg/5JeX3Li`3Ool5Li`;Kg/3Li`5JeX3HaP2AS437>L3CW<5Kg/3JeX5Kg/3Li`5Kg/3Li`2Ool00`00
Oomoo`08Ool00`00OolYBP04:DX39BT67>L2;F/6>Lh2@Q03>Lh3<H`5:DX38@P56<H37>L36<H27>L3
5:D39BT8=Jd55:D36<H3AS42IcT3AS43IcT2<H`336<3248348@236<348@3248536<2Ool00`00Oomo
o`05Ool000Ioo`03001oof<H00MS60INm`9S60I[FP9_N`=[FP=cW09oo`=cW0i_N`EcW0=S609F]@=B
U0=W>@=_N`9g_@=[FP=W>@9BU0<Q20=:DP9_N`=[FP]_N`=[FPE_N`9oo`03001oogoo00Qoo`03001o
obU:008YBPDaS0<HaPDQ20<]J`<aS0E:DP=>L`9:DP=>L`HLi`8@Q0<Q20=JeP9W>@]JeP=Nm`=S609J
eP<HaP<e[@9JeP=>L`=W>@8e[@/<H`/8@P9oo`03001oogoo00Eoo`001Woo00<007ooHaP01f<H1Ukg
0V<H1V]J0Vmk0f]J0g>L0Woo0g>L3Vmk1G>L0f<H0UJe0e:D0fLi0fmk0WNm0f]J0fLi0U:D0b480dYB
0Vmk0f]J2fmk0f]J1Fmk0Woo00<007ooOol027oo00<007oo:DX00RU:1C6<0aS61B480be[0c6<1DYB
0dic0TYB0dic1QcW0Q240b480e[F0VLi2e[F0ekg0f<H0U[F0aS60cF]0U[F0dic0fLi0SF]2`aS2`Q2
0Woo00<007ooOol01Goo0006Ool00`00OomS6007HaP6G_L2HaP6JeX2Kg/3JeX3Li`2Ool3Li`>Kg/5
Li`3HaP2E[D3DY@3IcT3Kg/2Mkd3JeX3IcT2DY@38@P3BU82Kg/3JeX;Kg/3JeX5Kg/2Ool00`00Oomo
o`08Ool00`00OolYBP02:DX5<H`36<H58@P3;F/3<H`5BU83CW<2BU83CW<67>L248@38@P3F]H2IcT;
F]H3G_L3HaP2F]H36<H3=Jd2F]H3CW<3IcT2=Jd;36<;2482Ool00`00Oomoo`05Ool000Ioo`03001o
oekg00ANm`I[FP=S609cW0=W>@=BU09:DP<mk`=JeP9240=cW0=oo`=_N`E[FP=W>@8aS0<YBP/U:@<]
J`9W>@=cW0=S609JeP<HaP=240EW>@=_N`=W>@9[FPI_N`9[FP=cW09oo`03001oogoo00Qoo`03001o
obDY008U:@8aS0I:DP=BU09>L`=6<@E240=6<@=>L`9:DP=>L`<HaP<Li`9>L`=F]@QNm`=JeP9>L`=B
U0=F]@QS60<U:@9JeP=F]@=W>@8icP/<H`H8@PD@Q09oo`03001oogoo00Eoo`001Woo00<007ooG_L0
15kg1V]J0f<H0W>L0fLi0e:D0TYB0cg_0e[F0T8@0g>L0goo0fmk1F]J0fLi0S6<0bU:2bDY0be[0VLi
0g>L0f<H0U[F0aS60d8@1FLi0fmk0fLi0V]J1Vmk0V]J0g>L0Woo00<007ooOol027oo00<007oo9BT0
0RDY0S6<1TYB0e:D0Tic0dHa1D8@0dHa0dic0TYB0dic0aS60acW0Tic0eJe25kg0e[F0Tic0e:D0eJe
26<H0bDY0U[F0eJe0fLi0SW>2`aS1PQ21A240Woo00<007ooOol01Goo0006Ool00`00OomNm`04G_L6
JeX3HaP2Li`3IcT3DY@2BU83?Nl3F]H2@Q03Li`3Ool3Kg/5JeX3IcT2<H`3:DX;9BT3;F/2IcT3Li`3
HaP2F]H36<H3@Q05IcT3Kg/3IcT2JeX6Kg/2JeX3Li`2Ool00`00Oomoo`08Ool00`00OolU:@029BT2
<H`6BU83DY@2CW<3AS45@Q03AS43CW<2BU83CW<36<H37>L2CW<3E[D8G_L3F]H2CW<3DY@3E[D8HaP3
9BT2F]H3E[D3IcT2>Lh;36<6248548@2Ool00`00Oomoo`05Ool000Ioo`03001ooekg009Nm`96<@=2
40<]J`<aS08mk`=6<@DicP<mk`=BU09W>@=cW0=_N`=g_@9cW0<e[@<]J`8U:@<YBP<U:@8YBP<U:@HY
BP8Q20=W>@ES60<Li`=2409cW0=W>A1_N`=g_@9oo`03001oogoo00Qoo`03001oobU:008YBP9>L`=B
U0=Nm`EW>@=BU0=6<@8]J`<YBP<icP8mk`=>L`<]J`=[FP9S60=Nm`=F]@9>L`<DY@<48@8<H`H@Q0=F
]@ENm`=>L`9JeP=F]@=W>@96<@/DY@<Li`<U:@De[@9oo`03001oogoo00Eoo`001Woo00<007ooG_L0
0Ukg0THa0d8@0be[0c6<0Sg_0dHa1CW>0cg_0e:D0VLi0g>L0fmk0gNm0W>L0cF]0be[0RDY0bU:0bDY
0RU:0bDY1RU:0R480fLi1F<H0acW0d8@0W>L0fLi46mk0gNm0Woo00<007ooOol027oo00<007oo:DX0
0RU:0Tic0e:D0ekg1FLi0e:D0dHa0Re[0bU:0cW>0Sg_0dic0be[0f]J0V<H0ekg0eJe0Tic0aBU0`@Q
0PaS1Q240eJe1Ekg0dic0U[F0eJe0fLi0THa2aBU0acW0bDY1CF]0Woo00<007ooOol01Goo0006Ool0
0`00OomS6002HaP2@Q06:DX37>L2<H`3;F/3G_L2CW<3AS43CW<5Kg/3JeX3G_L:9BT3:DX39BT2:DX3
8@P69BT28@P3<H`3HaP2DY@38@P3>Lh2HaP6IcT3G_L2HaP3G_L3E[D2DY@3BU82Ool00`00Oomoo`08
Ool00`00OolYBP02:DX2AS43<H`3;F/39BT2<H`3>Lh8BU83CW<2;F/38@P8HaP3G_L35:D236<32483
124236<96<H:E[D3F]H8Ool3Mkd3Li`2JeX3IcT3F]H2G_L3F]H2Ool00`00Oomoo`05Ool000Ioo`03
001oof<H009S609240HYBP<Li`8aS0<]J`=Nm`9>L`=6<@=>L`E_N`=[FP=Nm`XU:@<YBP<U:@8YBP<Q
20HU:@8Q20<aS0=S609BU0<Q20<icP9S60IW>@=Nm`9S60=Nm`=F]@9BU0=:DP9oo`03001oogoo00Qo
o`03001oobU:008YBP96<@<aS0<]J`<U:@8aS0<icPQ:DP=>L`8]J`<Q20QS60=Nm`<DY@8<H`<8@P<4
8@8<H`THaPYF]@=JePQoo`=g_@=cW09[FP=W>@=JeP9Nm`=JeP9oo`03001oogoo00Eoo`001Woo00<0
07ooHaP00V<H0T8@1RU:0acW0S6<0be[0ekg0Tic0dHa0dic1Fmk0f]J0ekg2RDY0bU:0bDY0RU:0b48
1RDY0R480c6<0f<H0U:D0b480cW>0V<H1VLi0ekg0V<H0ekg0eJe0U:D0dYB0Woo00<007ooOol027oo
00<007oo:DX00RU:0THa0c6<0be[0bDY0S6<0cW>24YB0dic0Re[0b4826<H0ekg0aBU0PaS0`Q20`@Q
0PaS2AS62UJe0e[F27oo0gNm0g>L0V]J0fLi0e[F0Ukg0e[F0Woo00<007ooOol01Goo0006Ool00`00
OomNm`02G_L2AS43:DX68@P5<H`3AS42JeX3<H`3HaP2Li`3JeX3E[DE9BT38@P36<H58@P37>L5G_L3
8@P35:D2124336<348@35:D26<H38@P3:DX2;F/3=Jd2Ool00`00Oomoo`08Ool00`00Ool]J`02;F/5
BU88@Q03>Lh8BU83CW<2>Lh3F]H6E[D2AS4836<3248536<35:D648@26<H6E[D2DY@3E[D8Nmh6Kg/2
IcT3HaP3E[D2DY@3BU82Ool00`00Oomoo`05Ool000Ioo`03001ooekg009Nm`96<@<YBPHQ20DaS0=6
<@9[FP<aS0=S609cW0=[FP=F]ADU:@<Q20<HaPDQ20<Li`ENm`<Q20<DY@848@<<H`<@Q0<DY@8HaP<Q
20<YBP8]J`<e[@9oo`03001oogoo00Qoo`03001oobe[008]J`E:DPQ240<icPQ:DP=>L`8icP=JePIF
]@96<@P<H`<8@PD<H`<DY@H@Q08HaPIF]@9BU0=F]@QkgPI_N`9W>@=S60=F]@9BU0=:DP9oo`03001o
ogoo00Eoo`001Woo00<007ooG_L00Ukg0THa0bU:1R481C6<0dHa0V]J0c6<0f<H0W>L0f]J0eJe5BDY
0b480aS61B480acW1Ekg0b480aBU0P@Q0`aS0a240aBU0QS60b480bU:0Re[0cF]0Woo00<007ooOol0
27oo00<007oo;F/00Re[1DYB248@0cW>24YB0dic0SW>0e[F1UJe0THa20aS0`Q21@aS0aBU1Q240QS6
1UJe0U:D0eJe27_N1Vmk0VLi0f<H0eJe0U:D0dYB0Woo00<007ooOol01Goo0006Ool00`00OomS6002
HaP2G_L3:DX6DY@2AS43?Nl3<H`2?Nl6@Q02IcT3JeX89BT3:DX38@P29BT3:DX39BT28@P69BT38@P5
7>L3CW<2G_L38@P3:DX2JeX9IcT2JeX3IcT8JeX2Ool00`00Oomoo`08Ool00`00OolU:@029BT5BU8;
AS48BU83CW<5F]H3DY@3?Nl2248@36<35:D848@3E[D3HaP2E[D3HaP8Nmh3Li`3Kg/5IcT3F]H2E[D3
DY@2Ool00`00Oomoo`05Ool000Ioo`03001oof<H009S609Nm`<YBPIBU096<@<mk`<aS08mk`I2409W
>@=[FPPU:@<YBP<Q208U:@<YBP<U:@8Q20HU:@<Q20DLi`=>L`9Nm`<Q20<YBP9[FPUW>@9[FP=W>@Q[
FP9oo`03001oogoo00Qoo`03001oobDY008U:@E:DP]6<@Q:DP=>L`EJeP=BU0<mk`88@Q0<H`<DY@P@
Q0=F]@=S609F]@=S60QkgP=cW0=_N`EW>@=JeP9F]@=BU09oo`03001oogoo00Eoo`001Woo00<007oo
G_L00Ukg0U[F0cg_0b480aS60RDY0cg_1Ekg1V<H0V]J0bDY0bU:2bDY0Re[22DY0b480bDY0acW0QS6
0aBU0c6<0VLi0bU:0c6<1F]J0fmk0fLi1Fmk1F]J0fmk0Woo00<007ooOol027oo00<007oo6<H00QS6
1DHa0e:D1Dic1U[F0THa0cW>0d8@25Je1@Q25PaS0aS60QBU0dYB0f<H0U[F0e:D0eJe0U:D2`aS0`Q2
20aS0Woo00<007ooOol01Goo0006Ool00`00OomNm`02G_L2F]H3?Nl38@P36<H29BT3?Nl5G_L6HaP2
JeX39BT3:DX;9BT2;F/89BT38@P39BT37>L26<H35:D3<H`2IcT3:DX3<H`5JeX3Kg/3IcT5Kg/5JeX3
Kg/2Ool00`00Oomoo`08Ool00`00OolHaP026<H5AS43DY@5CW<6F]H2AS43>Lh3@Q08E[D5248F36<3
6<H25:D3BU83HaP2F]H3DY@3E[D2DY@;36<3248836<2Ool00`00Oomoo`05Ool000Ioo`03001ooekg
009Nm`9JeP<mk`<Q20<HaP8U:@<mk`ENm`IS609[FP<U:@<YBP/U:@8]J`PU:@<Q20<U:@<Li`8HaP<D
Y@<aS09W>@<YBP<aS0E[FP=_N`=W>@E_N`E[FP=_N`9oo`03001oogoo00Qoo`03001ooaS6008HaPE6
<@=BU0E>L`IJeP96<@<icP=240QF]@D8@QH<H`<HaP8DY@=:DP=S609JeP=BU0=F]@9BU0/<H`<8@PP<
H`9oo`03001oogoo00Eoo`001Woo00<007ooG_L00Ukg0U:D0eJe0c6<0a241B480f]J0V<H0f]J0f<H
0SF]0b480bDY0bU:0RDY0bU:0be[0RU:0bDY0bU:0RDY1R480acW0Q240aS60acW0Ukg1S6<0V]J1VLi
0f]J0Vmk0fLi0f]J0VLi0f]J0Woo00<007ooOol027oo00<007oo48@00Q240RU:0dHa0e:D0eJe0Ukg
1U[F1ABU25[F20Q20`aS0cF]24ic0UJe0e:D0e[F0aS60QBU0bU:0f]J0Ukg0dYB0dic0TYB5PaS0Woo
00<007ooOol01Goo0006Ool00`00OomNm`02G_L2DY@3E[D3<H`348@58@P3JeX2HaP3JeX3HaP2=Jd3
8@P39BT3:DX29BT3:DX3;F/2:DX39BT3:DX29BT68@P37>L248@36<H37>L2G_L6<H`2JeX6IcT3JeX2
Kg/3IcT3JeX2IcT3JeX2Ool00`00Oomoo`08Ool00`00Ool@Q00248@2:DX3AS43DY@3E[D2G_L6F]H5
5:D8F]H8248336<3=Jd8CW<2E[D3DY@3F]H36<H25:D3:DX3JeX2G_L3BU83CW<2BU8F36<2Ool00`00
Oomoo`05Ool000Ioo`03001ooekg009Nm`9BU0=F]@<aS0<@Q0DQ20=[FP9S60=[FP=S608e[@<Q20<U
:@<YBP8U:@<YBP<]J`8YBP<U:@<YBP8U:@HQ20<Li`8@Q0<HaP<Li`9Nm`HaS09[FPIW>@=[FP9_N`=W
>@=[FP9W>@=[FP9oo`03001oogoo00Qoo`03001ooa24008@Q08YBP=6<@=BU0=F]@9Nm`IJePDDY@QJ
ePP8@P<<H`<e[@Q>L`9F]@=BU0=JeP<HaP8DY@<YBP=[FP9Nm`=:DP=>L`9:DQH<H`9oo`03001oogoo
00Eoo`001Woo00<007ooE[D00UJe0U[F0e:D0dic0be[0U[F1V<H0VLi0f]J0fLi0R482bDY0bU:0be[
0U:D1VLi1F<H0bDY0aS60Q240`aS0aS60V<H0cF]0be[0V]J1VLi0f]J0V<H0f]J1FLi0f]J0Woo00<0
07ooOol027oo00<007oo48@011240c6<1UJe0Ukg1U[F0QBU0dHa0e[F0UJe0acW1PQ20Sg_1U:D26Li
0UJe0e[F0ekg0f<H1ABU0fLi0U[F0d8@1Dic3PaS20Q20Woo00<007ooOol01Goo0006Ool00`00OomF
]@02E[D2F]H3DY@3CW<3;F/2F]H6HaP2IcT3JeX3IcT28@P;9BT3:DX3;F/2DY@6IcT5HaP39BT36<H2
48@336<36<H2HaP3=Jd3;F/2JeX6IcT3JeX2HaP3JeX5IcT3JeX2Ool00`00Oomoo`08Ool00`00Ool@
Q00448@3<H`6E[D2G_L6F]H25:D3AS43F]H2E[D37>L62482?Nl6DY@8IcT2E[D3F]H3G_L3HaP55:D3
IcT2F]H3@Q05CW<>36<82482Ool00`00Oomoo`05Ool000Ioo`03001ooe[F009JeP9F]@=JeP=F]@=:
DPEJeP=Nm`EW>@<aS08Q20TU:@8YBP=F]@=[FP9_N`=kgPE[FP=W>@=S60<Li`8@Q0<<H`<DY@9S60<i
cP<]J`9[FP=S60=[FP=W>@9S60=W>@=[FPEW>@9oo`03001oogoo00Qoo`03001oo`aS00@<H`<DY@Hi
cP9240<DY@<Li`8@Q0IJeP9F]@<<H`<DY@EF]@IBU09JeP<aS0<Li`8@Q0=BU0=Nm`=[FP9:DP<@Q0=W
>@9Nm`=240E>L`h<H`<8@PD<H`9oo`03001oogoo00Eoo`001Woo00<007ooF]H00U[F0UJe0e[F0eJe
0dYB1E[F0ekg1FLi0c6<0R482BDY0RU:0eJe0f]J0Vmk0g_N1F]J0fLi0f<H0acW0Q240`aS0aBU0V<H
0cW>0be[0V]J0f<H0f]J0fLi0V<H0fLi0f]J1FLi0Woo00<007ooOol027oo00<007oo36<010aS0aBU
1SW>0T8@0aBU0acW0Q241U[F0UJe0`aS0aBU1EJe1U:D0U[F0c6<0acW0Q240e:D0ekg0f]J0TYB0a24
0fLi0Ukg0d8@1Dic3PaS0`Q21@aS0Woo00<007ooOol01Goo0006Ool00`00OomJeP02F]H2E[D3F]H3
E[D3BU85F]H3G_L5IcT3<H`28@P99BT2:DX3E[D3JeX2Kg/3Nmh5JeX3IcT3HaP37>L248@336<35:D2
HaP3>Lh3;F/2JeX3HaP3JeX3IcT2HaP3IcT3JeX5IcT2Ool00`00Oomoo`08Ool00`00Ool<H`0436<3
5:D6>Lh2@Q035:D37>L248@6F]H2E[D336<35:D5E[D6DY@2F]H3<H`37>L248@3DY@3G_L3JeX2BU83
48@3IcT2G_L3@Q05CW<>36<3248536<2Ool00`00Oomoo`05Ool000Ioo`03001ooeJe009F]@ENm`IF
]@EBU0QS60<Li`DU:@<YBP<e[@e[FP=_N`9[FP=S60=W>@=6<@D<H`<@Q09:DP<mk`<]J`ES60IW>@9_
N`=S60E[FP=S609oo`03001oogoo00Qoo`03001ooaBU00LDY@PHaP<DY@<Li`8YBPIJeP8Li`<HaP=B
U0EJeP=F]@<Li`8DY@<HaP<Li`D@Q0=JeP=_N`9Nm`<@Q0=W>@9Nm`=240E>L`h<H`<8@PD<H`9oo`03
001oogoo00Eoo`001Woo00<007ooE[D00UJe1Ekg1UJe1E:D26<H0acW1BDY0bU:0cF]3F]J0fmk0V]J
0f<H0fLi0dHa1@aS0a240TYB0cg_0be[1F<H1VLi0Vmk0f<H1F]J0f<H0Woo00<007ooOol027oo00<0
07oo5:D01aBU21S60aBU0acW0RU:1U[F0QcW0aS60e:D1E[F0eJe0acW0QBU0aS60acW1A240e[F0fmk
0Ukg0a240fLi0Ukg0d8@1Dic3PaS0`Q21@aS0Woo00<007ooOol01Goo0006Ool00`00OomF]@02E[D5
G_L6E[D5DY@8HaP37>L59BT3:DX3=Jd=JeX3Kg/2JeX3HaP3IcT3AS4536<348@2BU83?Nl3;F/5HaP6
IcT2Kg/3HaP5JeX3HaP2Ool00`00Oomoo`08Ool00`00OolDY@075:D86<H35:D37>L2:DX6F]H27>L3
6<H3DY@5F]H3E[D37>L25:D36<H37>L548@3F]H3Kg/2G_L348@3IcT2G_L3@Q05CW<>36<3248536<2
Ool00`00Oomoo`05Ool000Ioo`03001ooeJe009F]@9>L`iJeP=BU09Nm`=6<@<Li`DQ20<aS0=S609c
W0][FP=W>@9S60=[FP=Nm`=F]@88@P<@Q0<DY@8aS0=6<@<aS0ES60=W>@=[FPEW>@=S609W>@=[FP9o
o`03001oogoo00Qoo`03001ooaBU00XDY@<<H`8@Q0<DY@<HaP96<@INm`8HaPUF]@9:DPP@Q0H<H`8D
Y@<Li`<YBP=_N`9Nm`<DY@=:DP96<@<YBPE:DP<8@Q<<H`9oo`03001oogoo00Eoo`001Woo00<007oo
E[D00UJe0Tic3U[F0e:D0Ukg0dHa0acW1B480c6<0f<H0W>L2f]J0fLi0V<H0f]J0ekg0eJe0PQ20a24
0aBU0S6<0dHa0c6<1F<H0fLi0f]J1FLi0f<H0VLi0f]J0Woo00<007ooOol027oo00<007oo5:D02QBU
0`aS0Q240aBU0aS60THa1Ukg0QS62EJe0TYB21241PaS0QBU0acW0bU:0fmk0Ukg0aBU0dYB0THa0bU:
1DYB0`Q24`aS0Woo00<007ooOol01Goo0006Ool00`00OomBU002DY@2F]H3CW<3E[D8F]H3G_L2F]H3
:DX35:D28@P39BT6IcT5JeX3Li`5JeX5HaP3G_L6DY@536<36<H2@Q03AS43:DX2IcT3HaP>IcT2JeX3
IcT2Ool00`00Oomoo`08Ool00`00Ool@Q00248@85:D348@236<648@2DY@3E[D3>Lh2?Nl6E[D3BU82
5:D@48@67>L3IcT2G_L3<H`3@Q02>Lh39BT5BU83248336<8248536<32482Ool00`00Oomoo`05Ool0
00Ioo`03001ooe:D009BU09JeP=>L`=F]@QJeP=Nm`9JeP<YBP<DY@8Q20<U:@IW>@E[FP=cW0E[FPES
60=Nm`IBU0D<H`<HaP9240=6<@<YBP9W>@=S60iW>@9[FP=W>@9oo`03001oogoo00Qoo`03001ooa24
008@Q0PDY@<@Q08<H`H@Q09BU0=F]@<icP8mk`IF]@=:DP8DYA0@Q0HLi`=W>@9Nm`<aS0=2408icP<U
:@E:DP<8@P<<H`P8@PD<H`<8@P9oo`03001oogoo00Eoo`001Woo00<007ooDY@00U:D0U[F0dic0eJe
25[F0ekg0U[F0bU:0aBU0R480bDY1VLi1F]J0g>L1F]J1F<H0ekg1U:D1@aS0aS60T8@0dHa0bU:0VLi
0f<H3VLi0V]J0fLi0Woo00<007ooOol027oo00<007oo48@00Q2421BU0a240PaS1Q240U:D0eJe0cW>
0Sg_1UJe0dYB0QBU41241QcW0fLi0Ukg0c6<0d8@0SW>0bDY1DYB0`Q20`aS20Q21@aS0`Q20Woo00<0
07ooOol01Goo0006Ool00`00OomBU002DY@5F]H3CW<3DY@2E[D6F]H2G_L36<H37>L29BT3AS46IcT8
JeX5Kg/5HaP3G_L6E[D248@336<3<H`2@Q03AS43:DX5IcT3HaP3IcT2HaP6IcT5JeX2Ool00`00Oomo
o`08Ool00`00Ool@Q00248@85:D87>L32485F]H37>L2IcT3F]H3DY@5248348@55:D348@36<H2BU8;
F]H6DY@2@Q03:DX5BU8;248336<82482Ool00`00Oomoo`05Ool000Ioo`03001ooe:D009BU0EJeP=>
L`=BU09F]@IJeP9Nm`<HaP<Li`8U:@=6<@IW>@Q[FPE_N`ES60=Nm`IF]@8@Q0<<H`<aS09240=6<@<Y
BPEW>@=S60=W>@9S60IW>@E[FP9oo`03001oogoo00Qoo`03001ooa24008@Q0PDY@PLi`<8@PEJeP<L
i`9W>@=JeP=BU0D8@P<@Q0DDY@<@Q0<HaP9:DP]JePIBU09240<YBPE:DP/8@P<<H`P8@P9oo`03001o
ogoo00Eoo`001Woo00<007ooDY@00U:D1E[F0dic0e:D0UJe1U[F0Ukg0aS60acW0RDY0dHa1VLi26]J
1Fmk1F<H0ekg1UJe0Q240`aS0c6<0T8@0dHa0bU:1FLi0f<H0fLi0V<H1VLi1F]J0Woo00<007ooOol0
27oo00<007oo48@00Q2421BU21cW0`Q21E[F0acW0VLi0e[F0e:D1@Q20a241ABU0a240aS60TYB2e[F
1U:D0T8@0bU:1DYB2`Q20`aS20Q20Woo00<007ooOol01Goo0006Ool00`00OomBU002DY@5F]H3DY@3
E[D2AS43E[D5F]H348@36<H28@P6JeX3IcT2JeX;IcT3Kg/2F]H3<H`36<H35:D536<3CW<2>Lh3BU83
:DX2IcT;HaP3IcT5JeX3Kg/2Ool00`00Oomoo`08Ool00`00Ool@Q00448@65:D38@P57>L35:D5G_L3
6<H2JeX3HaP3>Lh56<H3248536<3AS43IcT2Kg/6HaP5F]H6DY@29BT3=Jd5CW<3248;36<3248536<2
Ool00`00Oomoo`05Ool000Ioo`03001ooe:D009BU0EJeP=BU0=F]@96<@=F]@EJeP<@Q0<HaP8Q20I[
FP=W>@9[FP]W>@=_N`9JeP<aS0<HaP<DY@D<H`=>L`8icP=:DP<YBP9W>@]S60=W>@E[FP=_N`9oo`03
001oogoo00Qoo`03001ooa2400@@Q0HDY@<Q20DLi`<DY@ENm`<HaP9[FP=S60<icPDHaP<8@PD<H`=6
<@=W>@9_N`IS60EJePIBU08U:@<e[@E>L`<8@P/<H`<8@PD<H`9oo`03001oogoo00Eoo`001Woo00<0
07ooDY@00U:D0UJe0e[F0ekg1EJe0dic0e:D0Ukg1Q240QS61VLi0gNm0V]J2fLi0cF]0QS61Q2420aS
0dHa0T8@0e:D0bDY2f<H1FLi0f]J0V<H0f]J0Woo00<007ooOol027oo00<007oo48@00Q240QBU1QS6
0b480QS60acW0aBU1F<H0aS60V]J0f<H1QcW1ABU0aS60U:D0ekg0fLi0Vmk0e[F0be[0aBU0Q241UJe
0R480cW>1E:D1PQ220aS0`Q21@aS0Woo00<007ooOol01Goo0006Ool00`00OomBU002DY@2E[D3F]H3
G_L5E[D3CW<3DY@2G_L648@26<H6IcT3Mkd2JeX;IcT3=Jd26<H648@836<3AS42@Q03DY@39BT;HaP5
IcT3JeX2HaP3JeX2Ool00`00Oomoo`08Ool00`00Ool@Q00248@25:D66<H38@P26<H37>L35:D5HaP3
6<H2JeX3HaP67>L55:D36<H2DY@3G_L3IcT2Kg/3F]H3;F/35:D248@6E[D28@P3>Lh5DY@6248836<3
248536<2Ool00`00Oomoo`05Ool000Ioo`03001ooe:D009BU09F]@=JeP=Nm`EF]@=>L`=BU09Nm`H@
Q08HaPIW>@=g_@9[FP]W>@<e[@8HaPH@Q0P<H`=6<@9240=BU0<U:@]S60EW>@=[FP9S60=[FP9oo`03
001oogoo00Qoo`03001ooa24008@Q08DY@HHaP<Q208HaP<Li`<DY@ES60<HaP9[FP=S60HLi`DDY@<H
aP9BU0=Nm`=W>@9_N`=JeP<]J`<DY@8@Q0IF]@8Q20<icPEBU0H8@PP<H`<8@PD<H`9oo`03001oogoo
00Eoo`001Woo00<007ooDY@00U:D0UJe0dic0e[F1EJe1U[F0U:D0`aS0a240QcW0fLi0f<H1FLi0g>L
0fLi0V<H0bDY0acW0QS61Q240`Q20PaS0a240e:D0T8@0e:D0b4846<H0fLi0V<H0fLi0Woo00<007oo
Ool027oo00<007oo24800PQ20Q242B481A240aBU1F<H0aBU0V]J0ekg1QcW0QS60aBU25[F0ekg0Re[
0a241PaS0PQ21UJe0Re[0cW>1Dic1PQ22`aS1@Q20Woo00<007ooOol01Goo0006Ool00`00OomBU002
DY@2E[D3CW<3F]H5E[D6F]H2DY@336<348@27>L3IcT3HaP5IcT3Li`3IcT2HaP39BT37>L26<H648@3
248236<348@3DY@2@Q03DY@38@P@HaP3IcT2HaP3IcT2Ool00`00Oomoo`08Ool00`00Ool8@P022482
48@98@P548@35:D5HaP35:D2JeX3G_L67>L26<H35:D8F]H3G_L2;F/348@636<22486E[D2;F/3>Lh5
CW<6248;36<52482Ool00`00Oomoo`05Ool000Ioo`03001ooe:D009BU09F]@=>L`=JePEF]@IJeP9B
U0<<H`<@Q08Li`=W>@=S60EW>@=cW0=W>@9S60<U:@<Li`8HaPH@Q0<8@P8<H`<@Q0=BU09240=BU0<Q
211S60=W>@9S60=W>@9oo`03001oogoo00Qoo`03001oo`Q20088@P8@Q0TQ20D@Q0<DY@ES60<DY@9[
FP=Nm`HLi`8HaP<DY@QJeP=Nm`8]J`<@Q0H<H`88@PIF]@8]J`<icPE>L`H8@P/<H`D8@P9oo`03001o
ogoo00Eoo`001Woo00<007ooDY@00U:D1EJe0d8@0e:D0UJe1U[F0UJe1Q240QS61V<H26Li0f]J0RU:
0b480acW0QBU0a242`aS0c6<0THa0e:D0b481F<H0ekg0f<H0VLi1V<H0VLi0f<H0Woo00<007ooOol0
27oo00<007oo24800PQ20Q242AcW0QS61Q241FLi0aS60V]J0fLi0`Q20`aS0QS60d8@0f<H0Ukg0eJe
1ABU0a241PaS0PQ21UJe0TYB0cW>1Dic0`Q20`aS1A241PaS1@Q20Woo00<007ooOol01Goo0006Ool0
0`00OomBU002DY@5E[D3@Q03DY@2E[D6F]H2E[D648@26<H6HaP8IcT3JeX2:DX38@P37>L25:D348@;
36<3<H`2AS43DY@38@P5HaP3G_L3HaP2IcT6HaP2IcT3HaP2Ool00`00Oomoo`08Ool00`00Ool8@P02
248248@97>L26<H648@5IcT36<H2JeX3IcT3248336<26<H3@Q03HaP2G_L3E[D55:D348@636<22486
E[D2BU83>Lh5CW<3248336<548@636<52482Ool00`00Oomoo`05Ool000Ioo`03001ooe:D009BU0EF
]@=240=BU09F]@IJeP9F]@H@Q08HaPIS60QW>@=[FP8YBP<Q20<Li`8DY@<@Q0/<H`<aS096<@=BU0<Q
20ES60=Nm`=S609W>@IS609W>@=S609oo`03001oogoo00Qoo`03001oo`Q20088@P8@Q0TLi`8HaPH@
Q0EW>@<HaP9[FP=W>@<8@P<<H`8HaP=240=S609Nm`=F]@DDY@<@Q0H<H`88@PIF]@9:DP<icPE>L`<8
@P<<H`D@Q0H<H`D8@P9oo`03001oogoo00Eoo`001Woo00<007ooDY@015:D0eJe0e[F0dHa0Tic0e:D
0e[F0Ukg0`Q21A242FLi0V<H0fLi0d8@0R481QcW0QBU1Q2420aS0aBU1E:D0b480Ukg1V<H0e[F1Ekg
26<H0Woo00<007ooOol027oo00<007oo24800PQ20PaS2AcW1AS60acW1FLi0aBU0V]J0fmk0cW>1A24
1UJe0Ukg1QBU0Q240`aS1QBU0QS60c6<0e[F0UJe0d8@1EJe1PaS1A240`aS0a241@Q20Woo00<007oo
Ool01Goo0006Ool00`00OomBU004DY@3E[D3F]H3AS42CW<3DY@3F]H2G_L3248548@9IcT2HaP3IcT3
@Q028@P67>L25:D648@836<35:D5DY@38@P2G_L6HaP3F]H5G_L8HaP2Ool00`00Oomoo`08Ool00`00
Ool8@P02248236<97>L56<H37>L5IcT35:D2JeX3Kg/3>Lh548@6E[D2G_L65:D248@336<65:D26<H3
<H`3F]H2E[D3@Q05E[D636<548@336<348@52482Ool00`00Oomoo`05Ool000Ioo`03001ooe:D009B
U09F]@=BU0IF]@9BU0=:DPENm`<DY@<@Q08DY@<mk`=_N`=[FPES60<U:@DQ20<Li`P@Q0<Li`8DY@<8
@P<<H`EBU0<Li`9Nm`=JePINm`9S60=Nm`QS609oo`03001oogoo00Qoo`03001oo`Q20088@PD<H`PH
aPHLi`EW>@<HaP9[FP=_N`=Nm`<Q208mk`=Nm`=F]@8YBP<<H`<U:@9240=>L`=F]@=JeP9Nm`=F]@=J
eP9F]@=240EBU0h<H`<@Q0D8@P9oo`03001oogoo00Eoo`001Woo00<007ooDY@00U:D0UJe0e:D1UJe
0U:D0dYB1Ekg0aBU0a240QBU0cg_0fmk0f]J1F<H0bDY1B480acW21240acW0QBU0`Q20`aS1E:D0acW
0Ukg0e[F1Ukg0V<H0ekg26<H0Woo00<007ooOol027oo00<007oo24800PQ21@aS21S61QcW1FLi0aS6
0V]J0fmk0ekg0b480Sg_0ekg0eJe0RU:0`aS0bDY0T8@0dic0eJe0e[F0Ukg0eJe0e[F0UJe0d8@1E:D
3PaS0a241@Q20Woo00<007ooOol01Goo0006Ool00`00OomBU002DY@2E[D3DY@6E[D2DY@3BU85G_L3
5:D348@25:D3?Nl3Kg/3JeX5HaP39BT58@P37>L848@37>L25:D3248336<5DY@37>L2G_L3F]H6G_L2
HaP3G_L8HaP2Ool00`00Oomoo`08Ool00`00Ool8@P02248536<86<H67>L5IcT36<H2JeX3Kg/3G_L3
8@P2?Nl3G_L3E[D2:DX336<39BT2@Q03CW<3E[D3F]H2G_L3E[D3F]H2E[D3@Q05DY@>36<348@52482
Ool00`00Oomoo`05Ool000Ioo`03001ooe:D00YBU0=JePEF]@=S609Nm`<Li`<<H`8@Q0<Li`=F]@=W
>@9_N`<mk`DQ20HLi`8aS0=6<@=BU0=F]@9BU0<HaP<<H`8icP=BU0<Q209S60=Nm`iS609W>@=S609o
o`03001oogoo00Qoo`03001oo`Q20088@P8<H`<DY@HHaP8DY@HLi`9JeP=S60<U:@8icP=[FP=W>@EJ
eP=Nm`=>L`8@Q0=6<@QF]@IBU09Nm`QJeP=240EBU0H<H`<8@PD<H`<@Q0D8@P9oo`03001oogoo00Eo
o`001Woo00<007ooDY@02U:D0e[F1EJe0f<H0Ukg0acW0`aS0Q240acW0eJe0fLi0Vmk0cg_1B481QcW
0S6<0dHa0e:D0eJe0U:D0aS60`aS0SW>0e:D0b480V<H0ekg3V<H0VLi0f<H0Woo00<007ooOol027oo
00<007oo24800PQ20PaS0aBU1QS60QBU1QcW0U[F0f<H0bDY0SW>0f]J0fLi1E[F0ekg0dic0Q240dHa
25Je1U:D0Ukg25[F0d8@1E:D1PaS0`Q21@aS0a241@Q20Woo00<007ooOol01Goo0006Ool00`00OomB
U00:DY@3F]H5E[D3HaP2G_L37>L336<248@37>L3E[D3IcT2Kg/3?Nl58@P67>L2<H`3AS43DY@3E[D2
DY@36<H336<2>Lh3DY@38@P2HaP3G_L>HaP2IcT3HaP2Ool00`00Oomoo`08Ool00`00Ool8@P022482
36<35:D66<H25:D67>L2F]H3HaP39BT2>Lh3JeX3IcT5F]H3G_L3CW<248@3AS48E[D6DY@2G_L8F]H3
@Q05DY@636<3248536<348@52482Ool00`00Oomoo`05Ool000Ioo`03001ooe:D00ABU0=>L`=6<@QF
]@=JeP9Nm`<]J`<@Q0DDY@<U:@=6<@9S60<U:@DQ20<YBP=F]@9JePIBU0=6<@9BU0<]J`<8@P9:DP=>
L`<U:@ENm`IS609Nm`=W>@ES60=W>@9oo`03001oogoo00Qoo`03001oo`aS008<H`8@Q0<DY@HQ208U
:@H@Q09BU0=S60<aS08Li`=BU0=Nm`=JePES60<YBP9F]@IJeP9>L`<aS0<HaP<Q209:DP=S60=F]@9N
m`<icPE>L`T8@PP<H`D8@P9oo`03001oogoo00Eoo`001Woo00<007ooDY@015:D0dic0dHa25Je0e[F
0Ukg0be[0a241ABU0bDY0dHa0V<H0bDY1B480bU:0eJe0U[F1U:D0dHa0U:D0be[0`Q20TYB0dic0bDY
1Ekg1V<H0Ukg0fLi1F<H0fLi0Woo00<007ooOol027oo00<007oo36<00PaS0Q240aBU1R480RDY1Q24
0U:D0f<H0c6<0QcW0e:D0ekg0e[F1F<H0bU:0UJe1U[F0Tic0c6<0aS60b480TYB0f<H0eJe0Ukg0cW>
1Dic2@Q220aS1@Q20Woo00<007ooOol01Goo0006Ool00`00OomBU002DY@2E[D6DY@3@Q02E[D3G_L3
HaP2G_L3=Jd348@25:D39BT3AS43G_L2JeX67>L2;F/3IcT3F]H2E[D3F]H6E[D2?Nl39BT30002BU83
CW<38@P5G_L3HaP3G_L2HaP3G_L3HaP2IcT3HaP2Ool00`00Oomoo`08Ool00`00Ool<H`0236<248@3
6<H67>L59BT35:D2@Q03G_L3CW<2E[D6G_L3DY@5G_L3BU85E[D3BU8248@336<36<H38@P2F]H3HaP3
E[D2F]H3=Jd5BU86248;36<52482Ool00`00Oomoo`05Ool000Ioo`03001ooe:D009BU09F]@IBU0=2
409F]@=Nm`=S609Nm`<e[@<@Q08DY@<U:@=6<@=Nm`9[FPHLi`8]J`=W>@=JeP9F]@=JePIF]@8mk`<U
:@<0009:DP=>L`<Q20ENm`=S60=Nm`9S60=Nm`=S609W>@=S609oo`03001oogoo00Qoo`03001oo`aS
008<H`8@Q0<HaPHLi`DU:@<DY@9240=Nm`=>L`9F]@INm`=BU0ENm`=:DPEF]@=:DP8@Q0<<H`<HaP<Q
209JeP=S60=F]@9JeP<e[@E:DPH8@P/<H`D8@P9oo`03001oogoo00Eoo`001Woo00<007ooDY@00U:D
0UJe1U:D0d8@0UJe0ekg0f<H0Ukg0cF]0a240QBU0bDY0dHa0ekg0V]J1QcW0Re[0fLi0e[F0UJe0e[F
1UJe0Sg_0bDY0`000TYB0dic0b481Ekg0f<H0ekg0V<H0ekg0f<H0VLi0f<H0Woo00<007ooOol027oo
00<007oo36<00PaS0Q240aS61QcW1BDY0aBU0T8@0ekg0dic0UJe1Ukg0e:D1Ekg0dYB1EJe0dYB0Q24
0`aS0aS60b480U[F0f<H0eJe0U[F0cF]1DYB1PQ22`aS1@Q20Woo00<007ooOol01Goo0006Ool00`00
OomBU002DY@2F]H3E[D3DY@3E[D2@Q03DY@3G_L2F]H3>Lh3=Jd2DY@3E[D3HaP3G_L2F]H37>L38@P2
F]H3HaP>DY@2CW<636<2>Lh3AS438@P;G_L5HaP3IcT5HaP2Ool00`00Oomoo`08Ool00`00OolDY@07
5:D67>L59BT37>L2CW<3F]H3CW<2E[D3G_L3CW<3:DX5G_L5E[D3AS457>L66<H3CW<5F]H3E[D2F]H3
=Jd5BU8A36<52482Ool00`00Oomoo`05Ool000Ioo`03001ooe:D009BU09JeP=F]@=BU0=F]@9240=B
U0=Nm`9JeP<icP<e[@9BU0=F]@=S60=Nm`9JeP<Li`<Q209JeP=S60iBU09>L`H<H`8icP=6<@<Q20]N
m`ES60=W>@ES609oo`03001oogoo00Qoo`03001ooaBU00LDY@HLi`DU:@<Li`9>L`=JeP=>L`9F]@=N
m`=>L`<YBPENm`EF]@=6<@DLi`HHaP=>L`EJeP=F]@9JeP<e[@E:DQ4<H`D8@P9oo`03001oogoo00Eo
o`001Woo00<007ooDY@00U:D0U[F0eJe0e:D0eJe0T8@0e:D0ekg0U[F0cW>0cF]0U:D0eJe0f<H0ekg
0U[F0acW0b480U[F0f<H3U:D0Tic1PaS0SW>0dHa0b482ekg1F<H0fLi1F<H0Woo00<007ooOol027oo
00<007oo5:D01aBU1QcW1BDY0acW0Tic0e[F0dic0UJe0ekg0dic0bU:1Ekg1EJe0dHa1AcW1QS60dic
1E[F0eJe0U[F0cF]1DYB4@aS1@Q20Woo00<007ooOol01Goo0006Ool00`00OomF]@02E[D2BU83DY@3
E[D5DY@3CW<3E[D2BU838@P348@25:D3BU83G_L3IcT2G_L37>L39BT2HaP6F]H2DY@3AS43DY@3BU82
5:D636<2@Q03BU838@P5F]H6G_L=HaP2Ool00`00Oomoo`08Ool00`00OolDY@025:D57>L86<H3>Lh3
DY@2F]H3G_L3DY@2F]H6HaP348@2F]H3DY@3E[D2DY@36<H35:D26<H3:DX3E[D5F]H3DY@3CW<2E[D3
?Nl5BU86248336<2248636<52482Ool00`00Oomoo`05Ool000Ioo`03001ooeJe009F]@9:DP=BU0=F
]@EBU0=>L`=F]@9:DP<Q20<@Q08DY@=:DP=Nm`=W>@9Nm`<Li`<U:@9S60IJeP9BU0=6<@=BU0=:DP8D
Y@H<H`9240=:DP<Q20EJePINm`eS609oo`03001oogoo00Qoo`03001ooaBU008DY@DLi`PHaP<icP=B
U09JeP=Nm`=BU09JePIS60<@Q09JeP=BU0=F]@9BU0<HaP<DY@8HaP<YBP=F]@EJeP=BU0=>L`9F]@<m
k`E:DPH8@P<<H`88@PH<H`D8@P9oo`03001oogoo00Eoo`001Woo00<007ooDY@015:D0d8@2e:D0be[
0QS60a240`aS0Q240aBU25[F0acW0b480V<H0ekg1EJe0dYB0cF]0`aS0PQ20`aS0acW0TYB0e:D0b48
0Ukg0e[F1Ukg0V<H0ekg26<H0Woo00<007ooOol027oo00<007oo48@00Q2421S60aBU0SF]1Tic0U:D
0dYB0aS60TYB0ekg0f<H0bU:0UJe0e:D1EJe0dYB0cW>1EJe1U[F0U:D0dYB1EJe0cg_1DYB0`aS0a24
0`aS3@Q20Woo00<007ooOol01Goo0006Ool00`00OomBU004DY@3@Q0;DY@3;F/26<H348@336<248@3
5:D8F]H37>L38@P2HaP3G_L5E[D3BU83=Jd336<2248336<37>L2BU83DY@38@P2G_L3F]H6G_L2HaP3
G_L8HaP2Ool00`00Oomoo`08Ool00`00Ool@Q00248@86<H35:D2=Jd6CW<2DY@3BU836<H2BU83G_L3
HaP3:DX2E[D3DY@5E[D3BU83>Lh5E[D6F]H2DY@3BU85E[D3?Nl5BU8336<348@336<=2482Ool00`00
Oomoo`05Ool000Ioo`03001ooe:D00ABU0=240]BU0<]J`8HaP<@Q0<<H`8@Q0<DY@QJeP<Li`<Q209S
60=Nm`EF]@=:DP<e[@<<H`88@P<<H`<Li`9:DP=BU0<Q209Nm`=JePINm`9S60=Nm`QS609oo`03001o
ogoo00Qoo`03001ooa24008@Q0PHaP<DY@8e[@I>L`9BU0=:DP<HaP9:DP=Nm`=S60<YBP9F]@=BU0EF
]@=:DP<icPEF]@IJeP9BU0=:DPEF]@<mk`E:DP<<H`<@Q0<<H`d8@P9oo`03001oogoo00Eoo`001Woo
00<007ooDY@015:D0dic0dYB0dHa0U:D0bU:1ABU21240aBU0d8@1E[F0b480acW0RU:0e:D0dHa0Re[
1Q240`Q21@aS0d8@1E:D0bDY0Ukg0eJe0e[F1F<H0ekg1F<H0fLi0Woo00<007ooOol027oo00<007oo
24800PQ221BU0acW25[F0Re[0a240`Q20PaS0e[F0eJe0bU:0TYB0dic0e:D0UJe1U[F0UJe0e[F0e:D
0cF]0PaS0e[F0eJe0THa0cg_1DYB0`aS0a241@aS2`Q20Woo00<007ooOol01Goo0006Ool00`00OomB
U004DY@3CW<3BU83AS42DY@3:DX55:D848@35:D3@Q05F]H38@P37>L2:DX3DY@3AS42;F/648@32485
36<3@Q05DY@39BT2G_L3E[D3F]H5HaP3G_L5HaP3IcT2Ool00`00Oomoo`08Ool00`00Ool8@P022488
5:D37>L8F]H2;F/348@3248236<3F]H3E[D3:DX2BU83CW<3DY@2E[D6F]H2E[D3F]H3DY@3=Jd236<3
F]H3E[D2AS43?Nl5BU8336<348@536<;2482Ool00`00Oomoo`05Ool000Ioo`03001ooe:D00ABU0=>
L`=:DP=6<@9BU0<YBPDDY@P@Q0<DY@=240EJeP<Q20<Li`8YBP=BU0=6<@8]J`H@Q0<8@PD<H`=240EB
U0<U:@9Nm`=F]@=JePES60=Nm`ES60=W>@9oo`03001oogoo00Qoo`03001oo`Q20088@PPDY@<Li`QJ
eP8]J`<@Q0<8@P8<H`=JeP=F]@<YBP9:DP=>L`=BU09F]@IJeP9F]@=JeP=BU0<e[@8<H`=JeP=F]@96
<@<mk`E:DP<<H`<@Q0D<H`/8@P9oo`03001oogoo00Eoo`001Woo00<007ooDY@015:D2Dic0Sg_1PQ2
0QBU2a240cW>0e[F0UJe21cW0aS60aBU1A241PaS0PQ20a2425:D0bDY1E[F1Ukg3F<H0Woo00<007oo
Ool027oo00<007oo36<010aS0a240aBU0be[1Ekg0be[0RDY22480d8@0eJe0bU:0TYB0dic0aBU0THa
0dYB0e:D0TYB0bU:1PaS0SW>0e[F0eJe0QBU0cF]1DHa0`aS0a241@aS2`Q20Woo00<007ooOol01Goo
0006Ool00`00OomBU004DY@9CW<2?Nl624825:D;48@3>Lh3F]H2E[D87>L36<H35:D548@636<22483
48@8DY@39BT5F]H6G_L=HaP2Ool00`00Oomoo`08Ool00`00Ool<H`0436<348@35:D3;F/5G_L3;F/2
9BT88@P3@Q03E[D3:DX2BU83CW<35:D2AS43BU83DY@2BU83:DX636<2>Lh3F]H3E[D25:D3=Jd5AS43
36<348@536<;2482Ool00`00Oomoo`05Ool000Ioo`03001ooeJe009F]@E>L`=F]@=BU08aS0<000<<
H`8DY@<U:@<YBP8@Q0<DY@=240EJeP<YBP<HaP8Li`<DY@<@Q0/<H`88@P<icP=2409BU0=>L`<YBPQJ
eP=Nm`eS609oo`03001oogoo00Qoo`03001oo`aS008<H`PDY@=BU09Nm`=6<@EJeP]BU0=JeP<YBP9:
DP=>L`<icP8<H`<@Q0<DY@8@Q0<<H`<8@P<HaPEJeP=BU08Q20<e[@E240h<H`P8@P9oo`03001oogoo
00Eoo`001Woo00<007ooE[D00UJe1Dic0eJe0e:D0S6<0`000`aS0QBU0bDY0bU:0Q240aBU0d8@1E[F
0bU:0aS60QcW0aBU0a242`aS0PQ20cW>0d8@0U:D0dic0bU:25[F0ekg3F<H0Woo00<007ooOol027oo
00<007oo36<00PaS21BU0e:D0Ukg0dHa1E[F2e:D0e[F0bU:0TYB0dic0cW>0PaS0a240aBU0Q240`aS
0`Q20aS61E[F0e:D0R480cF]1D8@3PaS20Q20Woo00<007ooOol01Goo0006Ool00`00OomF]@02E[D5
CW<3E[D3DY@2<H`3000336<25:D39BT3:DX248@35:D3@Q05F]H3:DX36<H27>L35:D348@;36<22483
>Lh3@Q02DY@3CW<3:DX8F]H3G_L=HaP2Ool00`00Oomoo`08Ool00`00Ool<H`0236<85:D3DY@2G_L3
AS45F]H;DY@3F]H3:DX2BU83CW<3>Lh236<348@35:D248@336<324836<H5F]H3DY@28@P3=Jd5@Q0>
36<82482Ool00`00Oomoo`05Ool000Ioo`03001ooeJe009F]@9BU0=6<@=>L`=BU08@Q0<48@<U:@9>
L`IBU08mk`<@Q0=BU0=F]@9BU0=:DP<HaP8Li`<DY@<@Q0D8@PH<H`8Li`=BU0<icP9240=:DP<]J`9J
eP=BU0=Nm`EJePINm`9S60=Nm`9oo`03001oogoo00Qoo`03001ooa24008@Q08DY@HLi`ENm`IW>@9J
eP=>L`QBU0=JeP<Q208mk`=>L`=BU0DLi`<DY@8@Q0<<H`<DY@=BU0EJeP=F]@9BU0<aS0Dmk`H<H`D@
Q0<<H`<48@D<H`9oo`03001oogoo00Eoo`001Woo00<007ooE[D00UJe0U:D0dHa0dic0e:D0Q240`@Q
0bDY0Tic1U:D0Sg_0a240e:D0eJe0U:D0dYB0aS60QcW0aBU0a241@Q21PaS0QcW0e:D0cW>0T8@0dYB
0be[0U[F0e:D0ekg1E[F1Ukg0V<H0ekg0Woo00<007ooOol027oo00<007oo48@00Q240QBU1QcW1Ekg
1VLi0U[F0dic25:D0e[F0b480Sg_0dic0e:D1AcW0aBU0Q240`aS0aBU0e:D1E[F0eJe0U:D0c6<1Cg_
1PaS1A240`aS0`@Q1@aS0Woo00<007ooOol01Goo0006Ool00`00OomF]@02E[D2DY@3AS43CW<3DY@2
48@312439BT2CW<6DY@2?Nl348@3DY@3E[D2DY@3BU836<H27>L35:D348@5248636<27>L3DY@3>Lh2
@Q03BU83;F/2F]H3DY@3G_L5F]H6G_L2HaP3G_L2Ool00`00Oomoo`08Ool00`00Ool@Q00248@25:D6
7>L5G_L6IcT2F]H3CW<8DY@3F]H38@P2?Nl3CW<3DY@57>L35:D248@336<35:D3DY@5F]H3E[D2DY@3
<H`5?Nl636<548@336<3124536<2Ool00`00Oomoo`05Ool000Ioo`03001ooe:D009BU09:DP=>L`<m
k`=>L`88@P<HaP=F]@9BU0=:DP=6<@8YBP<@Q0=240=JeP9>L`=JeP<]J`8HaP<DY@D8@P<<H`<@Q0<H
aP9>L`=6<@<<H`9BU0=240<e[@9F]@=JePIF]@9S60=Nm`ES60=Nm`9oo`03001oogoo00Qoo`03001o
oa24008@Q08DY@HHaP=F]@9JePIS608mk`=BU0=JePEF]@=Nm`<]J`8HaP=>L`=BU09F]@=6<@<DY@8@
Q0<icP=6<@=BU0QNm`9BU0<YBPDe[@/<H`<8@P<48@D8@P9oo`03001oogoo00Eoo`001Woo00<007oo
DY@00U:D0TYB0dic0cg_0dic0PQ20aS60eJe0U:D0dYB0dHa0RU:0a240d8@0e[F0Tic0e[F0be[0QS6
0aBU1@Q20`aS0a240aS60Tic0dHa0`aS0U:D0d8@0cF]0UJe0e[F1UJe0V<H0ekg1F<H0ekg0Woo00<0
07ooOol027oo00<007oo48@00Q240QBU1QS60eJe0U[F1V<H0Sg_0e:D0e[F1EJe0ekg0be[0QS60dic
0e:D0UJe0dHa0aBU0Q240cW>0dHa0e:D25kg0U:D0bU:1CF]2`aS0`Q20`@Q1@Q20Woo00<007ooOol0
1Goo0006Ool00`00OomF]@02E[D2DY@3CW<3BU83?Nl22483?Nl3DY@2CW<3<H`348@2248348@3=Jd3
G_L2E[D6F]H2@Q0648@2248348@3>Lh3@Q0248@3124348@2BU83?Nl3>Lh2E[D6F]H;G_L5HaP2Ool0
0`00Oomoo`08Ool00`00Ool@Q00448@66<H5E[D3HaP3E[D2F]H3E[D3CW<2BU83AS43G_L3=Jd25:D3
>Lh3DY@2E[D3HaP3F]H2BU83>Lh3AS48E[D3F]H2DY@38@P3:DX2;F/6248536<6248536<2Ool00`00
Oomoo`05Ool000Ioo`03001ooeJe009F]@9BU0=>L`=:DP<mk`88@P<mk`=BU09>L`<aS0<@Q088@P<@
Q0<e[@=Nm`9F]@IJeP9240H@Q088@P<@Q0<icP=2408@Q0<48@<@Q09:DP<mk`<icP9F]@IJeP]Nm`ES
609oo`03001oogoo00Qoo`03001ooa2400@@Q0HHaPEF]@=S60=F]@9JeP=F]@=>L`9:DP=6<@=Nm`<e
[@8DY@<icP=BU09F]@=S60=JeP9:DP<icP=6<@QF]@=JeP9BU0<Q20<YBP8]J`H8@PD<H`H8@PD<H`9o
o`03001oogoo00Eoo`001Woo00<007ooE[D00UJe0U:D0dic0dYB0cg_0PQ20cg_0e:D0Tic0c6<0a24
0PQ20a240cF]0ekg0UJe1U[F0T8@1Q240PQ20a240cW>0d8@0Q240`@Q0a240TYB0cg_0cW>0UJe1U[F
2ekg1F<H0Woo00<007ooOol027oo00<007oo48@011241QS61EJe0f<H0eJe0U[F0eJe0dic0TYB0dHa
0ekg0cF]0QBU0cW>0e:D0UJe0f<H0e[F0TYB0cW>0dHa25Je0e[F0U:D0b480bU:0Re[1PQ21@aS1PQ2
1@aS0Woo00<007ooOol01Goo0006Ool00`00OomBU002DY@;CW<212437>L548@;36<3<H`3DY@5E[D3
DY@2F]H3DY@3AS42<H`36<H336<324821243248336<2BU86?Nl5F]H8G_L3HaP3G_L5HaP2Ool00`00
Oomoo`08Ool00`00OolDY@025:D29BT36<H39BT3F]H2E[D3G_L3F]H2E[D3DY@3<H`236<3=Jd3G_L5
AS4348@38@P2E[D6F]H2CW<3?Nl8BU8348@3DY@2BU835:D39BT2:DXA248236<32482Ool00`00Oomo
o`05Ool000Ioo`03001ooe:D009BU0]>L`848@<Li`D@Q0/<H`<aS0=BU0EF]@=BU09JeP=BU0=6<@8a
S0<HaP<<H`<8@P848@<8@P<<H`9:DPHmk`EJePQNm`=S60=Nm`ES609oo`03001oogoo00Qoo`03001o
oaBU008DY@8U:@<HaP<U:@=JeP9F]@=Nm`=JeP9F]@=BU0<aS08<H`<e[@=Nm`E6<@<@Q0<Q209F]@IJ
eP9>L`<mk`Q:DP<@Q0=BU09:DP<DY@<U:@8YBQ48@P8<H`<8@P9oo`03001oogoo00Eoo`001Woo00<0
07ooDY@00U:D2dic0P@Q0acW1A242`aS0c6<0e:D1EJe0e:D0U[F0e:D0dHa0S6<0aS60`aS0`Q20P@Q
0`Q20`aS0TYB1Sg_1E[F25kg0f<H0ekg1F<H0Woo00<007ooOol027oo00<007oo5:D00QBU0RDY0aS6
0bDY0e[F0UJe0ekg0e[F0UJe0e:D0c6<0PaS0cF]0ekg1DHa0a240b480UJe1U[F0Tic0cg_24YB0a24
0e:D0TYB0aBU0bDY0RU:4@Q20PaS0`Q20Woo00<007ooOol01Goo0006Ool00`00OomJeP02F]H2BU83
?Nl3CW<3<H`5124336<248@636<2248348@3<H`39BT2E[D6DY@2@Q038@P348@22486124524831243
36<2@Q03>Lh3AS42E[D6F]H5G_L3F]H3G_L5HaP2Ool00`00Oomoo`08Ool00`00OolDY@025:D2?Nl6
E[D3F]H2E[D67>L536<324825:D3;F/3E[D5BU83CW<5F]H3G_L3F]H2CW<3=Jd36<H5248336<5DY@3
9BT3<H`29BT636<348@:36<32482Ool00`00Oomoo`05Ool000Ioo`03001ooe[F009JeP9:DP<mk`=>
L`<aS0D48@<<H`8@Q0H<H`88@P<@Q0<aS0<U:@9F]@IBU09240<Q20<@Q088@PH48@D8@P<48@<<H`92
40<icP=6<@9F]@IJePENm`=JeP=Nm`ES609oo`03001oogoo00Qoo`03001ooaBU008DY@8mk`IF]@=J
eP9F]@HLi`D<H`<8@P8DY@<]J`=F]@E:DP=>L`EJeP=Nm`=JeP9>L`<e[@<HaPD8@P<<H`EBU0<U:@<a
S08U:@H<H`<@Q0X<H`<8@P9oo`03001oogoo00Eoo`001Woo00<007ooDY@00U:D0Tic0bDY1PQ21@@Q
0`aS0Q241PQ20Q240aS60bU:1AcW0bDY0aS61A240`aS0PQ20`@Q0`aS2`Q20THa0c6<0dic1E[F0eJe
0e[F1F<H0ekg0V<H0ekg0Woo00<007ooOol027oo00<007oo5:D00QBU0T8@1UJe0e[F0SF]0`aS0a24
0QS60c6<0dHa1E:D0dYB25Je1E:D0cg_0acW0PaS2`Q20`aS0dic0TYB0cF]0cg_0QcW0`Q20`aS1A24
2`aS0Woo00<007ooOol01Goo0006Ool00`00OomBU002DY@2CW<39BT62485124336<248@6248248@3
6<H3:DX57>L39BT36<H548@336<22483124336<;2482AS43<H`3CW<5F]H3E[D3F]H5HaP3G_L2HaP3
G_L2Ool00`00Oomoo`08Ool00`00OolDY@025:D2@Q06E[D3F]H2=Jd336<348@26<H3<H`3AS45DY@3
BU88E[D5DY@3?Nl37>L236<;248336<3CW<2BU83=Jd3?Nl27>L3248336<548@;36<2Ool00`00Oomo
o`05Ool000Ioo`03001ooe:D009BU09>L`<U:@H8@PD48@<<H`8@Q0H8@P8@Q0<HaP<YBPDLi`<U:@<H
aPD@Q0<<H`88@P<48@<<H`/8@P96<@<aS0=>L`EJeP=F]@=JePES60=Nm`9S60=Nm`9oo`03001oogoo
00Qoo`03001ooaBU008DY@9240IF]@=JeP8e[@<<H`<@Q08HaP<aS0=6<@EBU0=:DPQF]@EBU0<mk`<L
i`8<H`/8@P<<H`=>L`9:DP<e[@<mk`8Li`<8@P<<H`D@Q0/<H`9oo`03001oogoo00Eoo`001Woo00<0
07ooDY@00U:D0Tic0b481PQ21@@Q0`aS0Q240acW0c6<0T8@0dic0bU:0aS60Q240aS60a2420aS40Q2
0`aS0THa0bDY0e:D2eJe0V<H0e[F0ekg0V<H0e[F0Woo00<007ooOol027oo00<007oo36<00PaS0SW>
0e[F0be[0`Q20PaS0be[0dic2U:D0dYB0d8@21cW0b480Q240`aS0a2420aS0aBU0RU:0d8@1DYB0dHa
0dYB0QBU0`Q20`aS1A242`aS0Woo00<007ooOol01Goo0006Ool00`00OomBU002DY@2CW<38@P62485
124336<248@37>L3<H`2@Q03CW<3:DX36<H248@36<H348@836<@248336<2AS439BT3DY@;E[D2HaP3
F]H3G_L2HaP3F]H2Ool00`00Oomoo`08Ool00`00Ool<H`0236<2>Lh3F]H3;F/3248236<3;F/3CW<:
DY@3BU83@Q087>L38@P248@336<348@836<35:D2:DX3@Q05BU83AS43BU825:D3248336<548@;36<2
Ool00`00Oomoo`05Ool000Ioo`03001ooe:D009BU09>L`<Q20H8@PD48@<<H`8@Q0<Li`<aS09240=>
L`<YBP<HaP8@Q0<HaP<@Q0P<Ha08@P<<H`96<@<U:@=BU0]F]@9S60=JeP=Nm`9S60=JeP9oo`03001o
ogoo00Qoo`03001oo`aS008<H`8icP=JeP<]J`<8@P8<H`<]J`=>L`YBU0=:DP=240PLi`<Q208@Q0<<
H`<@Q0P<H`<DY@8YBP=240E:DP=6<@=:DP8DY@<8@P<<H`D@Q0/<H`9oo`03001oogoo00Eoo`001Woo
00<007ooDY@00U:D0Tic0b480`000`@Q0PQ20`aS0bU:0THa0dic0dHa0SW>0aS60bDY0acW1ABU0a24
0PaS0a241@aS1P@Q0`Q20QBU0bU:0cg_0T8@0acW0eJe0U[F0eJe0e[F3Ekg0f<H0Woo00<007ooOol0
27oo00<007oo5:D00QBU0SW>0ekg0be[0c6<0THa0dYB4dic0acW1A240aBU1@Q20`aS0Q240`aS0`Q2
0cW>25Je0Tic0dYB0e:D1@aS21240`aS0`Q21@aS0Woo00<007ooOol01Goo0006Ool00`00OomBU002
DY@2CW<38@P300031242248336<3:DX2AS43CW<3AS42>Lh36<H39BT37>L55:D348@236<348@536<6
124324825:D3:DX3?Nl2@Q037>L3E[D2F]H3E[D3F]H=G_L3HaP2Ool00`00Oomoo`08Ool00`00OolD
Y@025:D2>Lh3G_L3;F/3<H`2AS43BU8CCW<37>L548@35:D5248336<248@336<32483>Lh8E[D2CW<3
BU83DY@536<848@336<3248536<2Ool00`00Oomoo`05Ool000Ioo`03001oodic009>L`9240<U:@<0
00<<H`8YBP<mk`E240<U:@P<H`<Q20<Li`8@Q0<DY@<<H`8@Q0<<H`<@Q0/8@P8e[@=BU0<mk`9:DP<H
aPEF]@=BU0=JeP=Nm`9JePINm`ES609oo`03001oogoo00Qoo`03001ooa24008@Q08e[@=Nm`<]J`<a
S096<@=:DP=6<@8aS0I>L`9:DP<e[@<Q20<HaPP<H`D8@P<<H`8@Q0<<H`<8@P<icP9F]@=:DP<aS08m
k`=:DP=BU0D<H`<@Q0/8@PD<H`9oo`03001oogoo00Eoo`001Woo00<007ooCW<00Tic0T8@0bDY0`00
0`aS0RU:0cg_1D8@0bDY20aS0b480acW0Q240aBU0`aS0Q240`aS0a242`Q20SF]0e:D0cg_0TYB0aS6
1EJe0e:D0e[F0ekg0U[F1Ukg1F<H0Woo00<007ooOol027oo00<007oo48@00Q240SF]0ekg0be[0c6<
0THa0dYB0dHa0S6<1Tic0TYB0cF]0b480aS620aS1@Q20`aS0Q240`aS0`Q20cW>0UJe0dYB0c6<0Sg_
0dYB0e:D1@aS0a242`Q21@aS0Woo00<007ooOol01Goo0006Ool00`00Oom>L`02CW<2@Q039BT30003
36<2:DX3?Nl5@Q039BT836<38@P37>L248@35:D336<248@336<348@;2482=Jd3DY@3?Nl2BU836<H5
E[D3DY@3F]H3G_L2F]H6G_L5HaP2Ool00`00Oomoo`08Ool00`00Ool@Q00248@2=Jd3G_L3;F/3<H`2
AS43BU83AS42<H`6CW<2BU83=Jd38@P36<H836<5248336<248@336<32483>Lh2E[D3BU83<H`2?Nl3
BU83DY@536<348@;248536<2Ool00`00Oomoo`05Ool000Ioo`03001oogoo06eoo`03001oogoo00Qo
o`03001oogoo06eoo`03001oogoo00Eoo`001Woo00<007ooOol0KGoo00<007ooOol027oo00<007oo
Ool0KGoo00<007ooOol01Goo0006Ooma000:Ooma0007Ool00?Uoo`00nGoo0000\
\>"],
  ImageRangeCache->{{{0, 248}, {117.5, 0}} -> {-0.0553287, -0.0238146, 
  0.00851072, 0.00851072}, {{6.5, 118.375}, {114.688, 
  2.75}} -> {-3.26921, -1.9066, 0.37268, 0.37268}, {{129.563, 241.5}, {
  114.688, 2.75}} -> {-49.105, -1.89434, 0.372471, 0.372471}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Morphological Thinning", "Subsection"],

Cell["UNDER CONSTRUCTION", "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["PROBLEM SOLUTIONS", "Subtitle"],

Cell[CellGroupData[{

Cell["Problem 1", "Exercise"],

Cell["Obtain the set description of the following binary image.", 
  "ExerciseText"],

Cell[CellGroupData[{

Cell[BoxData[
    \(x = {{0, 0, 0, 0, 0}, {0, 1, 1, 1, 0}, {0, 0, 1, 0, 0}, {0, 0, 1, 0, 0, 
          0}, {0, 0, 0, 0, 0}}\)], "Input"],

Cell[BoxData[
    \({{0, 0, 0, 0, 0}, {0, 1, 1, 1, 0}, {0, 0, 1, 0, 0}, {0, 0, 1, 0, 0, 
        0}, {0, 0, 0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Solution",
    FontWeight->"Bold"],
  ". Following the example in Section 2, the set description of x is"
}], "ExerciseText"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Position[x, 1]\)], "Input"],

Cell[BoxData[
    \({{2, 2}, {2, 3}, {2, 4}, {3, 3}, {4, 3}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problem 2", "Exercise"],

Cell["\<\
Use hand calculation to obtain the dilation of the image A by the structuring \
element B given below\
\>", "ExerciseText"],

Cell[BoxData[
    \(\(B = {{0, 0, 0}, {0, 1, 1}, {0, 1, 0}}; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problem 3", "Exercise"],

Cell[TextData[{
  "Change the structuring element so that erosion occurs at a smaller scale \
of structures in the example image.\n",
  StyleBox["Solution",
    FontWeight->"Bold"],
  ". Choose a structuring element with a small area of ones. The smallest is \
two neighboring elements, either in a row or column. Here we choose a small \
triangle."
}], "ExerciseText"],

Cell[CellGroupData[{

Cell[BoxData[
    \(S = {{0, 0, 0}, {0, 1, 1}, {0, 1, 0}}; \n
    Show[GraphicsArray[
        \((ListDensityPlot[#1, Mesh \[Rule] False, FrameTicks \[Rule] None, 
                DisplayFunction \[Rule] Identity]\ &)\)\ /@
          \ {B, Erode[B, S]}]]; \)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0240385 0.0192308 0.0240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
40 string
40 40 8 [40 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FF00FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFF00000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF00000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF0000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF0000000000
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF0000000000
00000000FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFF00FF0000FFFFFF
FFFF0000FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFF0000FFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFF0000FFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFF0000FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFF00FFFFFFFFFFFFFF
FF000000FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFFFF0000FFFFFFFFFFFF
00000000FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000000000FFFFFF0000FFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000000000FFFFFF0000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFF0000FFFFFFFF00000000000000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFF00FFFFFFFF00000000000000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFF00FFFFFFFFFF000000000000
00FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFF000000FFFFFFFFFFFF00000000FF
FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF0000
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000FFFFFFFFFFFF0000000000
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000000000000000FF0000FF00000000000000
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000000000FFFFFFFF00000000000000000000
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFF00FF00000000000000000000
0000FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFF0000000000000000000000000000
00FFFFFFFF00FFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0240385 0.0192308 0.0240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
40 string
40 40 8 [40 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFF00
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FF00FFFF0000FFFFFFFFFFFFFFFFFF00
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FF0000000000000000FFFFFF00
FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FF0000000000000000FFFFFF00
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
000000FFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00000000FFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00000000FFFFFFFF00FFFFFFFFFFFFFFFFFF000000
00000000FFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF00000000
000000FFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF0000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF000000000000
00000000FFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF000000000000
00000000FFFF00FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFF0000000000FFFFFFFF00000000000000
00000000FF0000FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFF0000000000FFFFFF0000000000FFFFFF
FF000000FF0000FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF00000000FFFFFF000000FFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFF
FFFF0000FFFF00FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFF
FF000000FF0000FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFF0000000000FFFF000000FFFFFFFFFFFF
00000000FF0000FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFF000000000000FFFF000000FFFFFFFF0000
00000000FF0000FFFFFFFFFFFFFFFF00
FFFFFFFFFFFF00000000000000FFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFF0000000000000000FFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFF00000000FF000000FFFFFF0000000000000000
0000FFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFF000000FFFFFFFF0000FFFFFF0000000000000000
0000FF00FFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFF000000FFFFFF000000FFFFFFFF00000000000000
00000000FFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFF000000000000000000FFFFFFFFFF000000000000
00000000FFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFF000000000000000000FFFFFFFFFFFF0000000000
00000000FFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00000000000000000000FF0000FF00000000000000
00000000FFFFFFFFFFFFFFFFFFFFFF00
FFFF00000000000000000000000000000000000000000000
00000000FFFFFFFFFFFFFFFFFFFFFF00
FFFF0000000000000000FFFF000000000000000000000000
00000000FF00FFFFFFFFFFFFFFFFFF00
FFFF0000000000FFFFFF0000000000000000000000000000
0000FFFF0000FFFFFFFFFFFFFFFFFF00
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{216, 102.813},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003H0000IQ000`40O003h00Of7oo003HOol000Eo
of8000Uoof8000Ioo`001Goo00<007ooOol0GWoo00<007ooOol01goo00<007ooOol0GWoo00<007oo
Ool017oo0005Ool00`00Oomoo`1NOol00`00Oomoo`07Ool00`00Oomoo`1NOol00`00Oomoo`04Ool0
00Eoo`03001oogoo049oo`<001Uoo`03001oogoo00Moo`03001oogoo041oo`D001Eoo`80009oo`03
001oogoo00Aoo`001Goo00<007ooOol0@Woo0`006Goo00<007ooOol01goo00<007ooOol0@7oo1@00
5Goo0P000Woo00<007ooOol017oo0005Ool00`00Oomoo`12Ool3000IOol00`00Oomoo`07Ool00`00
Oomoo`10Ool5000EOol20002Ool00`00Oomoo`04Ool000Eoo`03001oogoo049oo`<001Uoo`03001o
ogoo00Moo`03001oogoo041oo`D001Eoo`80009oo`03001oogoo00Aoo`001Goo00<007ooOol0@Woo
0`006Goo00<007ooOol01goo00<007ooOol0@7oo1@005Goo0P000Woo00<007ooOol017oo0005Ool0
0`00Oomoo`12Ool3000IOol00`00Oomoo`07Ool00`00Oomoo`10Ool5000EOol20002Ool00`00Oomo
o`04Ool000Eoo`03001oogoo049oo`<001Uoo`03001oogoo00Moo`03001oogoo041oo`D001Eoo`80
009oo`03001oogoo00Aoo`001Goo00<007ooOol0@Woo0`006Goo00<007ooOol01goo00<007ooOol0
@7oo1@005Goo0P000Woo00<007ooOol017oo0005Ool00`00Oomoo`12Ool3000IOol00`00Oomoo`07
Ool00`00Oomoo`10Ool5000EOol20002Ool00`00Oomoo`04Ool000Eoo`03001oogoo049oo`<001Uo
o`03001oogoo00Moo`03001oogoo00Qoo`<002Moo`8000Eoo`8000Eoo`D001Eoo`80009oo`03001o
ogoo00Aoo`001Goo00<007ooOol0@Woo0`006Goo00<007ooOol01goo00<007ooOol027oo0`009goo
0P001Goo0P001Goo1@005Goo0P000Woo00<007ooOol017oo0005Ool00`00Oomoo`12Ool3000IOol0
0`00Oomoo`07Ool00`00Oomoo`08Ool3000WOol20005Ool20005Ool5000EOol20002Ool00`00Oomo
o`04Ool000Eoo`03001oogoo00Qoo`<002Moo`8000Eoo`8000Moo`<001Uoo`03001oogoo00Moo`03
001oogoo00Ioo`D002Eoo`h0009ooa<000Moo`80009oo`03001oogoo00Aoo`001Goo00<007ooOol0
27oo0`009goo0P001Goo0P001goo0`006Goo00<007ooOol01goo00<007ooOol01Woo1@009Goo3P00
0Woo4`001goo0P000Woo00<007ooOol017oo0005Ool00`00Oomoo`06Ool5000WOol<0004OolA000;
Ool00`00Oomoo`07Ool00`00Oomoo`04Ool7000UOol>0002OolC0007Ool20002Ool00`00Oomoo`04
Ool000Eoo`03001oogoo00Ioo`D002Moo``000Aooa4000]oo`03001oogoo00Moo`03001oogoo00Ao
o`L002Eoo`h0009ooa<000Moo`80009oo`03001oogoo00Aoo`001Goo00<007ooOol0<7oo0P001goo
1@0087oo00<007ooOol01goo00<007ooOol027oo0`008Woo1`000goo1`0077oo0P000Woo00<007oo
Ool017oo0005Ool00`00Oomoo`0`Ool20007Ool5000POol00`00Oomoo`07Ool00`00Oomoo`08Ool3
000ROol70003Ool7000LOol20002Ool00`00Oomoo`04Ool000Eoo`03001oogoo031oo`8000Moo`D0
021oo`03001oogoo00Moo`03001oogoo00Qoo`<0029oo`L000=oo`L001aoo`80009oo`03001oogoo
00Aoo`001Goo00<007ooOol027oo0`009goo0P000goo1`0087oo00<007ooOol01goo00<007ooOol0
1Woo2@008Goo40006Woo0P000Woo00<007ooOol017oo0005Ool00`00Oomoo`08Ool3000WOol20003
Ool7000POol00`00Oomoo`07Ool00`00Oomoo`06Ool9000QOol@000JOol20002Ool00`00Oomoo`04
Ool000Eoo`03001oogoo00Qoo`L002=oo`h001ioo`03001oogoo00Moo`03001oogoo00Ioo`T000Yo
o`8001Eooa0001Yoo`80009oo`03001oogoo00Aoo`001Goo00<007ooOol027oo1`008goo3P007Woo
00<007ooOol01goo00<007ooOol01Woo2@002Woo0P005Goo40006Woo0P000Woo00<007ooOol017oo
0005Ool00`00Oomoo`0IOol2000LOol9000NOol00`00Oomoo`07Ool00`00Oomoo`0FOol5000IOol<
000JOol20002Ool00`00Oomoo`04Ool000Eoo`03001oogoo01Uoo`8001aoo`T001ioo`03001oogoo
00Moo`03001oogoo01Ioo`D001Uoo``001Yoo`80009oo`03001oogoo00Aoo`001Goo00<007ooOol0
6Goo0P0077oo2@007Woo00<007ooOol01goo00<007ooOol05Woo1@006Goo30006Woo0P000Woo00<0
07ooOol017oo0005Ool00`00Oomoo`0IOol2000LOol9000NOol00`00Oomoo`07Ool00`00Oomoo`0F
Ool5000IOol<000JOol20002Ool00`00Oomoo`04Ool000Eoo`03001oogoo01Uoo`8001aoo`T001io
o`03001oogoo00Moo`03001oogoo01Ioo`D001Uoo``001Yoo`80009oo`03001oogoo00Aoo`001Goo
00<007ooOol05Woo0`0087oo1`007Woo00<007ooOol01goo00<007ooOol057oo2@006Woo2@006Woo
0P000Woo00<007ooOol017oo0005Ool00`00Oomoo`0FOol3000POol7000NOol00`00Oomoo`07Ool0
0`00Oomoo`0DOol9000JOol9000JOol20002Ool00`00Oomoo`04Ool000Eoo`03001oogoo01Ioo`L0
01aoo`L001ioo`03001oogoo00Moo`03001oogoo01Aoo`T001Yoo`T001Yoo`80009oo`03001oogoo
00Aoo`001Goo00<007ooOol05Woo1`0077oo1`007Woo00<007ooOol01goo00<007ooOol057oo2@00
6Woo2@006Woo0P000Woo00<007ooOol017oo0005Ool00`00Oomoo`0FOol7000LOol7000NOol00`00
Oomoo`07Ool00`00Oomoo`0DOol9000JOol9000JOol20002Ool00`00Oomoo`04Ool000Eoo`03001o
ogoo01Ioo`D001ioo`L001ioo`03001oogoo00Moo`03001oogoo01Aoo`L001aoo`T001Yoo`80009o
o`03001oogoo00Aoo`001Goo00<007ooOol05Woo1@007Woo1`007Woo00<007ooOol01goo00<007oo
Ool057oo1`0077oo2@006Woo0P000Woo00<007ooOol017oo0005Ool00`00Oomoo`0DOol5000POol5
000POol00`00Oomoo`07Ool00`00Oomoo`0BOol9000IOol:000LOol20002Ool00`00Oomoo`04Ool0
00Eoo`03001oogoo01Aoo`D0021oo`D0021oo`03001oogoo00Moo`03001oogoo019oo`T001Uoo`X0
01aoo`80009oo`03001oogoo00Aoo`001Goo00<007ooOol057oo1`006Goo2P0087oo00<007ooOol0
1goo00<007ooOol04Woo2@005Goo3P0077oo0P000Woo00<007ooOol017oo0005Ool00`00Oomoo`0D
Ool7000IOol:000POol00`00Oomoo`07Ool00`00Oomoo`0BOol9000EOol>000LOol20002Ool00`00
Oomoo`04Ool000Eoo`03001oogoo01Aoo`L001Uoo`X0021oo`03001oogoo00Moo`03001oogoo019o
o`T001Eoo`h001aoo`80009oo`03001oogoo00Aoo`001Goo00<007ooOol057oo1`005Goo3P0087oo
00<007ooOol01goo00<007ooOol04Woo2@004Woo4@0077oo0P000Woo00<007ooOol017oo0005Ool0
0`00Oomoo`0DOol7000EOol>000POol00`00Oomoo`07Ool00`00Oomoo`0BOol9000BOolA000LOol2
0002Ool00`00Oomoo`04Ool000Eoo`03001oogoo01Aoo`L0019ooa40021oo`03001oogoo00Moo`03
001oogoo019oo`T0011ooa<001aoo`80009oo`03001oogoo00Aoo`001Goo00<007ooOol057oo1`00
4Woo4@0087oo00<007ooOol01goo00<007ooOol04Woo2@0047oo4`0077oo0P000Woo00<007ooOol0
17oo0005Ool00`00Oomoo`0DOol7000@OolC000POol00`00Oomoo`07Ool00`00Oomoo`0BOol9000>
OolG000JOol20002Ool00`00Oomoo`04Ool000Eoo`03001oogoo01Aoo`L0011ooa<0021oo`03001o
ogoo00Moo`03001oogoo019oo`T000iooaL001Yoo`80009oo`03001oogoo00Aoo`001Goo00<007oo
Ool057oo1`0047oo4`0087oo00<007ooOol01goo00<007ooOol04Woo2@003Woo5`006Woo0P000Woo
00<007ooOol017oo0005Ool00`00Oomoo`0DOol7000@OolE000NOol00`00Oomoo`07Ool00`00Oomo
o`0BOol9000>OolG0005Ool2000COol20002Ool00`00Oomoo`04Ool000Eoo`03001oogoo01Aoo`L0
011ooaD001ioo`03001oogoo00Moo`03001oogoo019oo`T000iooaL000Eoo`8001=oo`80009oo`03
001oogoo00Aoo`001Goo00<007ooOol057oo1`0047oo5@001Goo0P005goo00<007ooOol01goo00<0
07ooOol04Woo2`002Woo6@000Woo1@004goo0P000Woo00<007ooOol017oo0005Ool00`00Oomoo`0D
Ool7000@OolE0005Ool2000GOol00`00Oomoo`07Ool00`00Oomoo`0BOol;000:OolI0002Ool5000C
Ool20002Ool00`00Oomoo`04Ool000Eoo`03001oogoo01Aoo`T000Yoo`80009oo`D000]oo`D000Eo
o`8001Moo`03001oogoo00Moo`03001oogoo019oo`/000Moo``000Uoo`L0009oo`D001=oo`80009o
o`03001oogoo00Aoo`001Goo00<007ooOol057oo2@002Woo0P000Woo1@002goo1@001Goo0P005goo
00<007ooOol01goo00<007ooOol04Woo2`001goo30002Goo1`000Woo1@004goo0P000Woo00<007oo
Ool017oo0005Ool00`00Oomoo`0FOol7000:Ool4000COol2000NOol00`00Oomoo`07Ool00`00Oomo
o`0DOol90007Ool7000@Ool5000JOol20002Ool00`00Oomoo`04Ool000Eoo`03001oogoo01Ioo`L0
00Yoo`@001=oo`8001ioo`03001oogoo00Moo`03001oogoo01Aoo`T000Moo`L0011oo`D001Yoo`80
009oo`03001oogoo00Aoo`001Goo00<007ooOol05Woo1`002Woo10004goo0P007Woo00<007ooOol0
1goo00<007ooOol057oo2@001goo1`0047oo1@006Woo0P000Woo00<007ooOol017oo0005Ool00`00
Oomoo`0FOol50009Ool5000EOol2000NOol00`00Oomoo`07Ool00`00Oomoo`0DOol70007Ool7000B
Ool50005Ool2000COol20002Ool00`00Oomoo`04Ool000Eoo`03001oogoo01Ioo`D000Uoo`D001Eo
o`8001ioo`03001oogoo00Moo`03001oogoo01Aoo`L000Moo`L0019oo`D000Eoo`8001=oo`80009o
o`03001oogoo00Aoo`001Goo00<007ooOol097oo1@004Woo1@001Goo0P005goo00<007ooOol01goo
00<007ooOol057oo1`001goo1`0047oo1`000Woo1@004goo0P000Woo00<007ooOol017oo0005Ool0
0`00Oomoo`0TOol5000BOol50005Ool2000GOol00`00Oomoo`07Ool00`00Oomoo`0DOol70007Ool7
000@Ool70002Ool5000COol20002Ool00`00Oomoo`04Ool000Eoo`03001oogoo01Aoo`L000Uoo`<0
019oo`L000Eoo`8001Moo`03001oogoo00Moo`03001oogoo019oo`/000Eoo`L000ioo`T0009oo`D0
01=oo`80009oo`03001oogoo00Aoo`001Goo00<007ooOol057oo1`002Goo0`004Woo1`001Goo0P00
5goo00<007ooOol01goo00<007ooOol04Woo2`001Goo1`003Woo2@000Woo1@004goo0P000Woo00<0
07ooOol017oo0005Ool00`00Oomoo`0DOol70009Ool3000BOol70005Ool2000GOol00`00Oomoo`07
Ool00`00Oomoo`0BOol;0005Ool7000>Ool90002Ool5000COol20002Ool00`00Oomoo`04Ool000Eo
o`03001oogoo019oo`/000Moo`D000ioo`T000Eoo`8001Moo`03001oogoo00Moo`03001oogoo00mo
o`h000Eoo`L000Uoo`h0009oo`D001=oo`80009oo`03001oogoo00Aoo`001Goo00<007ooOol04Woo
2`001goo1@003Woo2@001Goo0P005goo00<007ooOol01goo00<007ooOol03goo3P001Goo1`002Goo
3P000Woo1@004goo0P000Woo00<007ooOol017oo0005Ool00`00Oomoo`0?Ool>0007Ool50009Ool<
000POol00`00Oomoo`07Ool00`00Oomoo`0=Ool@0005OolL000LOol20002Ool00`00Oomoo`04Ool0
00Eoo`03001oogoo00moo`h000Moo`D000Uoo``0021oo`03001oogoo00Moo`03001oogoo00eooa00
00Eooa`001aoo`80009oo`03001oogoo00Aoo`001Goo00<007ooOol03Goo40001goo6P0087oo00<0
07ooOol01goo00<007ooOol02goo4P001Goo700077oo0P000Woo00<007ooOol017oo0005Ool00`00
Oomoo`0=Ool@0007OolJ000POol00`00Oomoo`07Ool00`00Oomoo`0;OolB0005OolL000LOol20002
Ool00`00Oomoo`04Ool000Eoo`03001oogoo00eooa0000MooaX0021oo`03001oogoo00Moo`03001o
ogoo00]ooa8000Eooa`001aoo`80009oo`03001oogoo00Aoo`001Goo00<007ooOol03Goo1`001Goo
10002Woo50008goo00<007ooOol01goo00<007ooOol02goo2@000Woo1`001goo5`007goo0P000Woo
00<007ooOol017oo0005Ool00`00Oomoo`0=Ool70005Ool4000:OolD000SOol00`00Oomoo`07Ool0
0`00Oomoo`0;Ool90002Ool70007OolG000OOol20002Ool00`00Oomoo`04Ool000Eoo`03001oogoo
00]oo`@000aoo`8000Yooa@002=oo`03001oogoo00Moo`03001oogoo00Qoo`L000Yoo`@000MooaL0
00=oo`8001Yoo`80009oo`03001oogoo00Aoo`001Goo00<007ooOol02goo100037oo0P002Woo5000
8goo00<007ooOol01goo00<007ooOol027oo1`002Woo10001goo5`000goo0P006Woo0P000Woo00<0
07ooOol017oo0005Ool00`00Oomoo`0;Ool4000<Ool2000<Ool@0005Ool2000NOol00`00Oomoo`07
Ool00`00Oomoo`08Ool70007Ool7000:OolI000JOol20002Ool00`00Oomoo`04Ool000Eoo`03001o
ogoo00]oo`@000aoo`8000aooa0000Eoo`8001ioo`03001oogoo00Moo`03001oogoo00Qoo`L000Mo
o`L000YooaT001Yoo`80009oo`03001oogoo00Aoo`001Goo00<007ooOol02goo100037oo0P0037oo
40001Goo0P007Woo00<007ooOol01goo00<007ooOol027oo1`001goo1`002Woo6@006Woo0P000Woo
00<007ooOol017oo0005Ool00`00Oomoo`0;Ool20009Ool7000>Ool90005Ool7000NOol00`00Oomo
o`07Ool00`00Oomoo`08OolE000<OolG000JOol20002Ool00`00Oomoo`04Ool000Eoo`03001oogoo
00]oo`8000Uoo`L000ioo`T000Eoo`L001ioo`03001oogoo00Moo`03001oogoo00QooaD000aooaL0
01Yoo`80009oo`03001oogoo00Aoo`001Goo00<007ooOol02goo4P005Goo3P007Woo00<007ooOol0
1goo00<007ooOol027oo5@003Woo5@006Woo0P000Woo00<007ooOol017oo0005Ool00`00Oomoo`0;
OolB000EOol>000NOol00`00Oomoo`07Ool00`00Oomoo`08OolE000>OolE000JOol20002Ool00`00
Oomoo`04Ool000Eoo`03001oogoo00]ooa8000iooaD001ioo`03001oogoo00Moo`03001oogoo00Io
oaL000=oo`@000=ooaT001Yoo`80009oo`03001oogoo00Aoo`001Goo00<007ooOol02goo4P003Woo
5@007Woo00<007ooOol01goo00<007ooOol01Woo5`000goo10000goo6@006Woo0P000Woo00<007oo
Ool017oo0005Ool00`00Oomoo`0;OolB000>OolE000NOol00`00Oomoo`07Ool00`00Oomoo`06OolG
0003Ool40003OolI000JOol20002Ool00`00Oomoo`04Ool000Eoo`03001oogoo00IooaL000=oo`@0
00=ooaT001ioo`03001oogoo00Moo`03001oogoo00Aooc`001Yoo`80009oo`03001oogoo00Aoo`00
1Goo00<007ooOol01Woo5`000goo10000goo6@007Woo00<007ooOol01goo00<007ooOol017oo?000
6Woo0P000Woo00<007ooOol017oo0005Ool00`00Oomoo`06Ool@000:OolP000NOol00`00Oomoo`07
Ool00`00Oomoo`04OolB0005OolU0002Ool3000EOol20002Ool00`00Oomoo`04Ool000Eoo`03001o
ogoo00Iooa0000Yoob0001ioo`03001oogoo00Moo`03001oogoo00Aooa8000EoobD0009oo`<001Eo
o`80009oo`03001oogoo00Aoo`001Goo00<007ooOol01Woo2@0037oo0P000goo6`001goo0`006Goo
00<007ooOol01goo00<007ooOol017oo2`001goo9@001Goo1@005Goo0P000Woo00<007ooOol017oo
0005Ool00`00Oomoo`06Ool9000<Ool20003OolK0007Ool3000IOol00`00Oomoo`07Ool00`00Oomo
o`04Ool;0007OolU0005Ool5000EOol20002Ool00`00Oomoo`04Ool000Eoo`03001oogoo00Ioo`T0
00aoo`8000=ooa/000Moo`<001Uoo`03001oogoo00Moo`03001oogoo00Aoo`/000MoobD000Eoo`D0
01Eoo`80009oo`03001oogoo00Aoo`001Goo00<007ooOol01Woo1@002goo8`002Goo0`006Goo00<0
07ooOol01goo00<007oo0000G0000Woo00<007ooOol017oo0005Ool00`00Oomoo`06Ool5000;OolS
0009Ool3000IOol00`00Oomoo`07Ool00`00Ool0001L0002Ool00`00Oomoo`04Ool000Eoo`03001o
ogoo05ioo`03001oogoo00Moo`03001oogoo05ioo`03001oogoo00Aoo`001GooHP002GooHP001Woo
003HOol00=Qoo`00\
\>"],
  ImageRangeCache->{{{0, 215}, {101.813, 0}} -> {-0.055872, -0.0238146, 
  0.00982208, 0.00982208}, {{5.6875, 102.625}, {99.375, 
  2.375}} -> {-3.30107, -1.91618, 0.430256, 0.430256}, {{112.313, 209.313}, {
  99.375, 2.375}} -> {-49.1458, -1.90203, 0.429978, 0.429978}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["  Problem 4", "Exercise"],

Cell[TextData[{
  "Perform  open and close operations on the galaxy image using a 3x3 square \
structuring element.\n",
  StyleBox["Solution",
    FontWeight->"Bold"],
  ". A close operation is defined as a dilation followed by erosion, while an \
open operation is a erosion followed by dilation. The close operation tends \
to increase the spatial extent of an object, while the open operation \
decreases its spatial extent."
}], "ExerciseText"],

Cell[CellGroupData[{

Cell[BoxData[
    \(S = Table[1, {3}, {3}]; \n
    Show[GraphicsArray[
        \((ListDensityPlot[#1, Mesh \[Rule] False, FrameTicks \[Rule] None, 
                DisplayFunction \[Rule] Identity]\ &)\)\ /@
          \ {B, Dilate[Erode[B, S], S]}]]; \)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0240385 0.0192308 0.0240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
40 string
40 40 8 [40 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FF00FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFF00000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF00000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF0000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF0000000000
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF0000000000
00000000FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFF00FF0000FFFFFF
FFFF0000FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFF0000FFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFF0000FFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFF0000FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFF00FFFFFFFFFFFFFF
FF000000FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFFFF0000FFFFFFFFFFFF
00000000FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000000000FFFFFF0000FFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000000000FFFFFF0000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFF0000FFFFFFFF00000000000000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFF00FFFFFFFF00000000000000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFF00FFFFFFFFFF000000000000
00FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFF000000FFFFFFFFFFFF00000000FF
FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF0000
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000FFFFFFFFFFFF0000000000
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000000000000000FF0000FF00000000000000
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000000000FFFFFFFF00000000000000000000
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFF00FF00000000000000000000
0000FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFF0000000000000000000000000000
00FFFFFFFF00FFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0240385 0.0192308 0.0240385 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
40 string
40 40 8 [40 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
000000000000000000000000FFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF00000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF0000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF0000000000
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF0000000000
00000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFF00000000FFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFF0000FFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFF0000FFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFF0000FFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFF0000FFFFFFFFFFFF
FF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFFFF0000FFFFFFFFFFFF
00000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000000000FFFFFF0000FFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000000000FFFFFF0000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000000000FFFFFFFF00000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFF000000FFFFFFFF00000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFF000000FFFFFFFFFF000000000000
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFF000000FFFFFFFFFFFF0000000000
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000FFFFFFFFFFFF0000000000
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000FFFFFFFFFFFF0000000000
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000
00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{287.875, 137.063},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004O0000RA000`40O003h00Oogoo87oo003oOolP
Ool00?moob1oo`00ogoo87oo0007Oon2000=Oon20007Ool000Moo`03001oogoo07ioo`03001oogoo
00]oo`03001oogoo07ioo`03001oogoo00Eoo`001goo00<007ooOol0OWoo00<007ooOol02goo00<0
07ooOol0OWoo00<007ooOol01Goo0007Ool00`00Oomoo`1JOol3000QOol00`00Oomoo`0;Ool00`00
Oomoo`1IOol3000ROol00`00Oomoo`05Ool000Moo`03001oogoo05Yoo`<0025oo`03001oogoo00]o
o`03001oogoo05Uoo`<0029oo`03001oogoo00Eoo`001goo00<007ooOol0FWoo0`008Goo00<007oo
Ool02goo00<007ooOol0FGoo0`008Woo00<007ooOol01Goo0007Ool00`00Oomoo`1JOol3000QOol0
0`00Oomoo`0;Ool00`00Oomoo`1IOol3000ROol00`00Oomoo`05Ool000Moo`03001oogoo05Yoo`<0
025oo`03001oogoo00]oo`03001oogoo05Uoo`<0029oo`03001oogoo00Eoo`001goo00<007ooOol0
FWoo0`008Goo00<007ooOol02goo00<007ooOol0FGoo0`008Woo00<007ooOol01Goo0007Ool00`00
Oomoo`1JOol3000QOol00`00Oomoo`0;Ool00`00Oomoo`1IOol3000ROol00`00Oomoo`05Ool000Mo
o`03001oogoo05Yoo`<0025oo`03001oogoo00]oo`03001oogoo05Uoo`<0029oo`03001oogoo00Eo
o`001goo00<007ooOol0FWoo0`008Goo00<007ooOol02goo00<007ooOol0FGoo0`008Woo00<007oo
Ool01Goo0007Ool00`00Oomoo`1JOol3000QOol00`00Oomoo`0;Ool00`00Oomoo`1IOol3000ROol0
0`00Oomoo`05Ool000Moo`03001oogoo05Yoo`<0025oo`03001oogoo00]oo`03001oogoo05Uoo`<0
029oo`03001oogoo00Eoo`001goo00<007ooOol0FWoo0`008Goo00<007ooOol02goo00<007ooOol0
FGoo0`008Woo00<007ooOol01Goo0007Ool00`00Oomoo`1JOol3000QOol00`00Oomoo`0;Ool00`00
Oomoo`1IOol3000ROol00`00Oomoo`05Ool000Moo`03001oogoo05Yoo`<0025oo`03001oogoo00]o
o`03001oogoo05Uoo`<0029oo`03001oogoo00Eoo`001goo00<007ooOol0FWoo0`008Goo00<007oo
Ool02goo00<007ooOol0FGoo0`008Woo00<007ooOol01Goo0007Ool00`00Oomoo`1JOol3000QOol0
0`00Oomoo`0;Ool00`00Oomoo`1IOol3000ROol00`00Oomoo`05Ool000Moo`03001oogoo00]oo`@0
03Eoo`<000Ioo`<000Yoo`<0025oo`03001oogoo00]oo`03001oogoo00]oo`<003Eoo`d000Uoo`<0
029oo`03001oogoo00Eoo`001goo00<007ooOol02goo1000=Goo0`001Woo0`002Woo0`008Goo00<0
07ooOol02goo00<007ooOol02goo0`00=Goo3@002Goo0`008Woo00<007ooOol01Goo0007Ool00`00
Oomoo`0;Ool4000eOol30006Ool3000:Ool3000QOol00`00Oomoo`0;Ool00`00Oomoo`0;Ool3000e
Ool=0009Ool3000ROol00`00Oomoo`05Ool000Moo`03001oogoo00Qoo`L003Eoo`l000MooaD000mo
o`03001oogoo00]oo`03001oogoo00Qoo`H003Eoob`000moo`03001oogoo00Eoo`001goo00<007oo
Ool027oo1`00=Goo3`001goo5@003goo00<007ooOol02goo00<007ooOol027oo1P00=Goo;0003goo
00<007ooOol01Goo0007Ool00`00Oomoo`08Ool7000eOol?0007OolE000?Ool00`00Oomoo`0;Ool0
0`00Oomoo`08Ool6000eOol/000?Ool00`00Oomoo`05Ool000Moo`03001oogoo045oo`<000Uoo`H0
02]oo`03001oogoo00]oo`03001oogoo00]oo`<0039ooaH002Qoo`03001oogoo00Eoo`001goo00<0
07ooOol0@Goo0`002Goo1P00:goo00<007ooOol02goo00<007ooOol02goo0`00<Woo5P00:7oo00<0
07ooOol01Goo0007Ool00`00Oomoo`11Ool30009Ool6000[Ool00`00Oomoo`0;Ool00`00Oomoo`0;
Ool3000bOolF000XOol00`00Oomoo`05Ool000Moo`03001oogoo00]oo`@003Eoo`<000=oo`T002]o
o`03001oogoo00]oo`03001oogoo00]oo`<003Eooa<002Qoo`03001oogoo00Eoo`001goo00<007oo
Ool02goo1000=Goo0`000goo2@00:goo00<007ooOol02goo00<007ooOol02goo0`00=Goo4`00:7oo
00<007ooOol01Goo0007Ool00`00Oomoo`0;Ool4000eOol30003Ool9000[Ool00`00Oomoo`0;Ool0
0`00Oomoo`0;Ool3000eOolC000XOol00`00Oomoo`05Ool000Moo`03001oogoo00]oo`X002mooa80
02Qoo`03001oogoo00]oo`03001oogoo00]oo`X002iooa<002Qoo`03001oogoo00Eoo`001goo00<0
07ooOol02goo2P00;goo4P00:7oo00<007ooOol02goo00<007ooOol02goo2P00;Woo4`00:7oo00<0
07ooOol01Goo0007Ool00`00Oomoo`0;Ool:000_OolB000XOol00`00Oomoo`0;Ool00`00Oomoo`0;
Ool:000^OolC000XOol00`00Oomoo`05Ool000Moo`03001oogoo025oo`<002Ioo``002Qoo`03001o
ogoo00]oo`03001oogoo025oo`<002Eoo`d002Qoo`03001oogoo00Eoo`001goo00<007ooOol08Goo
0`009Woo3000:7oo00<007ooOol02goo00<007ooOol08Goo0`009Goo3@00:7oo00<007ooOol01Goo
0007Ool00`00Oomoo`0QOol3000VOol<000XOol00`00Oomoo`0;Ool00`00Oomoo`0QOol3000UOol=
000XOol00`00Oomoo`05Ool000Moo`03001oogoo025oo`<002Ioo``002Qoo`03001oogoo00]oo`03
001oogoo025oo`<002Eoo`d002Qoo`03001oogoo00Eoo`001goo00<007ooOol08Goo0`009Woo3000
:7oo00<007ooOol02goo00<007ooOol08Goo0`009Goo3@00:7oo00<007ooOol01Goo0007Ool00`00
Oomoo`0QOol3000VOol<000XOol00`00Oomoo`0;Ool00`00Oomoo`0QOol3000UOol=000XOol00`00
Oomoo`05Ool000Moo`03001oogoo025oo`<002Ioo``002Qoo`03001oogoo00]oo`03001oogoo025o
o`<002Eoo`d002Qoo`03001oogoo00Eoo`001goo00<007ooOol07Woo0`00;7oo2@00:7oo00<007oo
Ool02goo00<007ooOol07Woo1P00:7oo2P00:7oo00<007ooOol01Goo0007Ool00`00Oomoo`0NOol3
000/Ool9000XOol00`00Oomoo`0;Ool00`00Oomoo`0NOol6000XOol:000XOol00`00Oomoo`05Ool0
00Moo`03001oogoo01ioo`<002aoo`T002Qoo`03001oogoo00]oo`03001oogoo01ioo`H002Qoo`X0
02Qoo`03001oogoo00Eoo`001goo00<007ooOol07Woo2P009Goo2@00:7oo00<007ooOol02goo00<0
07ooOol07Woo2@009Goo2P00:7oo00<007ooOol01Goo0007Ool00`00Oomoo`0NOol:000UOol9000X
Ool00`00Oomoo`0;Ool00`00Oomoo`0NOol9000UOol:000XOol00`00Oomoo`05Ool000Moo`03001o
ogoo01ioo`X002Eoo`T002Qoo`03001oogoo00]oo`03001oogoo01ioo`T002Eoo`X002Qoo`03001o
ogoo00Eoo`001goo00<007ooOol07Woo1P00:Goo2@00:7oo00<007ooOol02goo00<007ooOol07Woo
1P00:7oo2P00:7oo00<007ooOol01Goo0007Ool00`00Oomoo`0NOol6000YOol9000XOol00`00Oomo
o`0;Ool00`00Oomoo`0NOol6000XOol:000XOol00`00Oomoo`05Ool000Moo`03001oogoo01ioo`H0
02Uoo`T002Qoo`03001oogoo00]oo`03001oogoo01ioo`H002Qoo`X002Qoo`03001oogoo00Eoo`00
1goo00<007ooOol06goo1P00;7oo1P00:goo00<007ooOol02goo00<007ooOol06goo2@00:7oo1`00
:goo00<007ooOol01Goo0007Ool00`00Oomoo`0KOol6000/Ool6000[Ool00`00Oomoo`0;Ool00`00
Oomoo`0KOol9000XOol7000[Ool00`00Oomoo`05Ool000Moo`03001oogoo01]oo`H002aoo`H002]o
o`03001oogoo00]oo`03001oogoo01]oo`T002Qoo`L002]oo`03001oogoo00Eoo`001goo00<007oo
Ool06goo2@008goo3000:goo00<007ooOol02goo00<007ooOol06goo2@008Woo3@00:goo00<007oo
Ool01Goo0007Ool00`00Oomoo`0KOol9000SOol<000[Ool00`00Oomoo`0;Ool00`00Oomoo`0KOol9
000ROol=000[Ool00`00Oomoo`05Ool000Moo`03001oogoo01]oo`T002=oo``002]oo`03001oogoo
00]oo`03001oogoo01]oo`T0029oo`d002]oo`03001oogoo00Eoo`001goo00<007ooOol06goo2@00
7Goo4P00:goo00<007ooOol02goo00<007ooOol06goo2@0077oo4`00:goo00<007ooOol01Goo0007
Ool00`00Oomoo`0KOol9000MOolB000[Ool00`00Oomoo`0;Ool00`00Oomoo`0KOol9000LOolC000[
Ool00`00Oomoo`05Ool000Moo`03001oogoo01]oo`T001eooa8002]oo`03001oogoo00]oo`03001o
ogoo01]oo`T001aooa<002]oo`03001oogoo00Eoo`001goo00<007ooOol06goo2@006Goo5P00:goo
00<007ooOol02goo00<007ooOol06goo2@006Goo5P00:goo00<007ooOol01Goo0007Ool00`00Oomo
o`0KOol9000IOolF000[Ool00`00Oomoo`0;Ool00`00Oomoo`0KOol9000IOolF000[Ool00`00Oomo
o`05Ool000Moo`03001oogoo01]oo`T001UooaH002]oo`03001oogoo00]oo`03001oogoo01]oo`T0
01UooaH002]oo`03001oogoo00Eoo`001goo00<007ooOol06goo2@005Woo6@00:goo00<007ooOol0
2goo00<007ooOol06goo2@005Woo6@00:goo00<007ooOol01Goo0007Ool00`00Oomoo`0KOol9000F
OolI000[Ool00`00Oomoo`0;Ool00`00Oomoo`0KOol9000FOolI000[Ool00`00Oomoo`05Ool000Mo
o`03001oogoo01]oo`T001IooaT002]oo`03001oogoo00]oo`03001oogoo01]oo`T001IooaT002]o
o`03001oogoo00Eoo`001goo00<007ooOol06goo2@005Woo6@00:goo00<007ooOol02goo00<007oo
Ool06goo2@005Woo6@00:goo00<007ooOol01Goo0007Ool00`00Oomoo`0KOol9000FOolL000XOol0
0`00Oomoo`0;Ool00`00Oomoo`0KOol9000FOolL000XOol00`00Oomoo`05Ool000Moo`03001oogoo
01]oo`T001Iooa`002Qoo`03001oogoo00]oo`03001oogoo01]oo`T001Iooa`002Qoo`03001oogoo
00Eoo`001goo00<007ooOol06goo2@005Woo7000:7oo00<007ooOol02goo00<007ooOol06goo2@00
5Woo7000:7oo00<007ooOol01Goo0007Ool00`00Oomoo`0KOol9000FOolL0007Ool3000NOol00`00
Oomoo`0;Ool00`00Oomoo`0KOol9000FOolU000OOol00`00Oomoo`05Ool000Moo`03001oogoo01]o
o`T001Iooa`000Moo`<001ioo`03001oogoo00]oo`03001oogoo01]oo`T001IoobD001moo`03001o
ogoo00Eoo`001goo00<007ooOol06goo2@005Woo70001goo0`007Woo00<007ooOol02goo00<007oo
Ool06goo2@005Woo9@007goo00<007ooOol01Goo0007Ool00`00Oomoo`0KOol=000<Ool30003Ool7
000?Ool60007Ool3000NOol00`00Oomoo`0;Ool00`00Oomoo`0KOol<000=Ool<000@Ool?000OOol0
0`00Oomoo`05Ool000Moo`03001oogoo01]oo`d000aoo`<000=oo`L000moo`H000Moo`<001ioo`03
001oogoo00]oo`03001oogoo01]oo``000eoo``0011oo`l001moo`03001oogoo00Eoo`001goo00<0
07ooOol06goo3@0037oo0`000goo1`003goo1P001goo0`007Woo00<007ooOol02goo00<007ooOol0
6goo30003Goo300047oo3`007goo00<007ooOol01Goo0007Ool00`00Oomoo`0NOol:000<Ool6000I
Ool3000XOol00`00Oomoo`0;Ool00`00Oomoo`0NOol9000=Ool6000FOol?000OOol00`00Oomoo`05
Ool000Moo`03001oogoo01ioo`X000aoo`H001Uoo`<002Qoo`03001oogoo00]oo`03001oogoo01io
o`T000eoo`H001Ioo`l001moo`03001oogoo00Eoo`001goo00<007ooOol07Woo2P0037oo1P006Goo
0`00:7oo00<007ooOol02goo00<007ooOol07Woo2@003Goo1P005Woo3`007goo00<007ooOol01Goo
0007Ool00`00Oomoo`0NOol6000=Ool6000LOol3000XOol00`00Oomoo`0;Ool00`00Oomoo`0NOol6
000=Ool6000IOol?000OOol00`00Oomoo`05Ool000Moo`03001oogoo01ioo`H000eoo`H001aoo`<0
02Qoo`03001oogoo00]oo`03001oogoo01ioo`H000eoo`H001Uoo`l001moo`03001oogoo00Eoo`00
1goo00<007ooOol07Woo1P003Goo1P0077oo0`00:7oo00<007ooOol02goo00<007ooOol07Woo1P00
3Goo1P006Goo3`007goo00<007ooOol01Goo0007Ool00`00Oomoo`0aOol6000IOol60007Ool3000N
Ool00`00Oomoo`0;Ool00`00Oomoo`0NOol6000=Ool6000IOol?000OOol00`00Oomoo`05Ool000Mo
o`03001oogoo035oo`H001Uoo`H000Moo`<001ioo`03001oogoo00]oo`03001oogoo01ioo`H000eo
o`H001Uoo`l001moo`03001oogoo00Eoo`001goo00<007ooOol0<Goo1P006Goo1P001goo0`007Woo
00<007ooOol02goo00<007ooOol07Woo1P003Goo1P006Goo3`007goo00<007ooOol01Goo0007Ool0
0`00Oomoo`0KOol9000=Ool3000IOol90007Ool3000NOol00`00Oomoo`0;Ool00`00Oomoo`0KOol9
000=Ool6000EOolC000OOol00`00Oomoo`05Ool000Moo`03001oogoo01]oo`T000eoo`<001Uoo`T0
00Moo`<001ioo`03001oogoo00]oo`03001oogoo01]oo`T000eoo`H001Eooa<001moo`03001oogoo
00Eoo`001goo00<007ooOol06goo2@003Goo0`006Goo2@001goo0`007Woo00<007ooOol02goo00<0
07ooOol06goo2@003Goo1P005Goo4`007goo00<007ooOol01Goo0007Ool00`00Oomoo`0HOol@0009
Ool6000COol<0007Ool3000NOol00`00Oomoo`0;Ool00`00Oomoo`0HOol?000:Ool6000BOolF000O
Ool00`00Oomoo`05Ool000Moo`03001oogoo01Qooa0000Uoo`H001=oo``000Moo`<001ioo`03001o
ogoo00]oo`03001oogoo01Qoo`l000Yoo`H0019ooaH001moo`03001oogoo00Eoo`001goo00<007oo
Ool067oo40002Goo1P004goo30001goo0`007Woo00<007ooOol02goo00<007ooOol067oo3`002Woo
1P004Woo5P007goo00<007ooOol01Goo0007Ool00`00Oomoo`0HOol@0009Ool6000COol<0007Ool3
000NOol00`00Oomoo`0;Ool00`00Oomoo`0HOol?000:Ool6000BOolF000OOol00`00Oomoo`05Ool0
00Moo`03001oogoo01Eooa<000Uoo`H000eoo`l002]oo`03001oogoo00]oo`03001oogoo01Eooa80
00Yoo`H000aooa0002]oo`03001oogoo00Eoo`001goo00<007ooOol05Goo4`002Goo1P003Goo3`00
:goo00<007ooOol02goo00<007ooOol05Goo4P002Woo1P0037oo4000:goo00<007ooOol01Goo0007
Ool00`00Oomoo`0EOolC0009Ool6000=Ool?000[Ool00`00Oomoo`0;Ool00`00Oomoo`0EOolB000:
Ool6000<Ool@000[Ool00`00Oomoo`05Ool000Moo`03001oogoo019ooaH000Uoob8002]oo`03001o
ogoo00]oo`03001oogoo019ooaD000Yoob8002]oo`03001oogoo00Eoo`001goo00<007ooOol04Woo
5P002Goo8P00:goo00<007ooOol02goo00<007ooOol04Woo5@002Woo8P00:goo00<007ooOol01Goo
0007Ool00`00Oomoo`0BOolF0009OolR000[Ool00`00Oomoo`0;Ool00`00Oomoo`0BOolE000:OolR
000[Ool00`00Oomoo`05Ool000Moo`03001oogoo019oo`T000Ioo`L000aooa`002ioo`03001oogoo
00]oo`03001oogoo019ooaD000eooal002]oo`03001oogoo00Eoo`001goo00<007ooOol04Woo2@00
1Woo1`0037oo7000;Woo00<007ooOol02goo00<007ooOol04Woo5@003Goo7`00:goo00<007ooOol0
1Goo0007Ool00`00Oomoo`0BOol90006Ool7000<OolL000^Ool00`00Oomoo`0;Ool00`00Oomoo`0B
OolE000=OolO000[Ool00`00Oomoo`05Ool000Moo`03001oogoo00moo`H000moo`@000aooa`002io
o`03001oogoo00]oo`03001oogoo00ioo`L000Uoo`T000eooal002]oo`03001oogoo00Eoo`001goo
00<007ooOol03goo1P003goo100037oo7000;Woo00<007ooOol02goo00<007ooOol03Woo1`002Goo
2@003Goo7`00:goo00<007ooOol01Goo0007Ool00`00Oomoo`0?Ool6000?Ool4000<OolL000^Ool0
0`00Oomoo`0;Ool00`00Oomoo`0>Ool70009Ool9000=OolO000[Ool00`00Oomoo`05Ool000Moo`03
001oogoo00moo`H000moo`@000mooaH000Ioo`<002Qoo`03001oogoo00]oo`03001oogoo00ioo`L0
00Uoo`T0011ooal002Qoo`03001oogoo00Eoo`001goo00<007ooOol03goo1P003goo10003goo5P00
1Woo0`00:7oo00<007ooOol02goo00<007ooOol03Woo1`002Goo2@0047oo7`00:7oo00<007ooOol0
1Goo0007Ool00`00Oomoo`0?Ool6000?Ool4000?OolF0006Ool3000XOol00`00Oomoo`0;Ool00`00
Oomoo`0>Ool70009Ool9000@OolO000XOol00`00Oomoo`05Ool000Moo`03001oogoo00moo`<000ao
o`X0019oo`d000Ioo`T002Qoo`03001oogoo00]oo`03001oogoo00ioo`L000Uoo`T001=ooa`002Qo
o`03001oogoo00Eoo`001goo00<007ooOol03goo0`0037oo2P004Woo3@001Woo2@00:7oo00<007oo
Ool02goo00<007ooOol03Woo1`002Goo2@004goo7000:7oo00<007ooOol01Goo0007Ool00`00Oomo
o`0?Ool3000<Ool:000BOol=0006Ool9000XOol00`00Oomoo`0;Ool00`00Oomoo`0>Ool70009Ool9
000COolL000XOol00`00Oomoo`05Ool000Moo`03001oogoo00mooaT001aooa8002Qoo`03001oogoo
00]oo`03001oogoo00iooaT001=ooa`002Qoo`03001oogoo00Eoo`001goo00<007ooOol03goo6@00
77oo4P00:7oo00<007ooOol02goo00<007ooOol03Woo6@004goo7000:7oo00<007ooOol01Goo0007
Ool00`00Oomoo`0?OolI000LOolB000XOol00`00Oomoo`0;Ool00`00Oomoo`0>OolI000COolL000X
Ool00`00Oomoo`05Ool000Moo`03001oogoo00mooaT0019ooa`002Qoo`03001oogoo00]oo`03001o
ogoo00iooaT001=ooa`002Qoo`03001oogoo00Eoo`001goo00<007ooOol03goo6@004Woo7000:7oo
00<007ooOol02goo00<007ooOol03Woo6@004goo7000:7oo00<007ooOol01Goo0007Ool00`00Oomo
o`0?OolI000BOolL000XOol00`00Oomoo`0;Ool00`00Oomoo`0>OolI000COolL000XOol00`00Oomo
o`05Ool000Moo`03001oogoo00mooaT0019ooa`002Qoo`03001oogoo00]oo`03001oogoo00iooaT0
01=ooa`002Qoo`03001oogoo00Eoo`001goo00<007ooOol027oo80000goo1P000goo8P00:7oo00<0
07ooOol02goo00<007ooOol027ooCP00:7oo00<007ooOol01Goo0007Ool00`00Oomoo`08OolP0003
Ool60003OolR000XOol00`00Oomoo`0;Ool00`00Oomoo`08Oom>000XOol00`00Oomoo`05Ool000Mo
o`03001oogoo00Qoob0000=oo`H000=oob8002Qoo`03001oogoo00]oo`03001oogoo00Qoodh002Qo
o`03001oogoo00Eoo`001goo00<007ooOol027oo5P003Goo:`00:7oo00<007ooOol02goo00<007oo
Ool027ooCP00:7oo00<007ooOol01Goo0007Ool00`00Oomoo`08OolF000=Ool[000XOol00`00Oomo
o`0;Ool00`00Oomoo`08Oom>000XOol00`00Oomoo`05Ool000Moo`03001oogoo00QooaH000eoob/0
02Qoo`03001oogoo00]oo`03001oogoo00Qoodh002Qoo`03001oogoo00Eoo`001goo00<007ooOol0
27oo3@003goo10000goo9@002Woo0`008Goo00<007ooOol02goo00<007ooOol027ooE0008Woo00<0
07ooOol01Goo0007Ool00`00Oomoo`08Ool=000?Ool40003OolU000:Ool3000QOol00`00Oomoo`0;
Ool00`00Oomoo`08OomD000ROol00`00Oomoo`05Ool000Moo`03001oogoo00Qoo`d000moo`@000=o
obD000Yoo`<0025oo`03001oogoo00]oo`03001oogoo00Qooe@0029oo`03001oogoo00Eoo`001goo
00<007ooOol027oo1`003goo;`003Goo0`008Goo00<007ooOol02goo00<007ooOol027ooE0008Woo
00<007ooOol01Goo0007Ool00`00Oomoo`08Ool7000?Ool_000=Ool3000QOol00`00Oomoo`0;Ool0
0`00Oomoo`08OomD000ROol00`00Oomoo`05Ool000Moo`03001oogoo00Qoo`L000moobl000eoo`<0
025oo`03001oogoo00]oo`03001oogoo00Qooe@0029oo`03001oogoo00Eoo`001goo00<007ooOol0
OWoo00<007ooOol02goo00<007ooOol0OWoo00<007ooOol01Goo0007Oon2000=Oon20007Ool00?mo
ob1oo`00ogoo87oo003oOolPOol00001\
\>"],
  ImageRangeCache->{{{0, 286.875}, {136.063, 0}} -> {-0.0542125, -0.0238146, 
  0.00734964, 0.00734964}, {{7.375, 136.938}, {132.813, 
  3.1875}} -> {-3.21299, -1.89601, 0.321704, 0.321704}, {{149.875, 279.5}, {
  132.813, 3.1875}} -> {-49.0325, -1.88543, 0.321549, 0.321549}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["HOMEWORK PROBLEMS", "Subtitle"],

Cell["UNDER CONSTRUCTION!", "Text"]
}, Closed]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{600, 556},
WindowMargins->{{Automatic, 128}, {Automatic, 25}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> "Classroom.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 34, 0, 55, "Title"],
Cell[1746, 51, 55, 0, 58, "Subsubtitle"],
Cell[1804, 53, 147, 5, 112, "Subsubtitle"],
Cell[1954, 60, 101, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[2080, 66, 31, 0, 56, "Section"],
Cell[2114, 68, 390, 6, 86, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2541, 79, 46, 0, 36, "Section"],
Cell[2590, 81, 172, 3, 48, "Text"],

Cell[CellGroupData[{
Cell[2787, 88, 55, 0, 46, "Subsection"],
Cell[2845, 90, 490, 8, 86, "Text"],

Cell[CellGroupData[{
Cell[3360, 102, 150, 2, 90, "Input"],
Cell[3513, 106, 308, 9, 108, "Output"]
}, Open  ]],
Cell[3836, 118, 63, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[3924, 122, 47, 1, 50, "Input"],
Cell[3974, 125, 90, 1, 49, "Output"]
}, Open  ]],
Cell[4079, 129, 219, 6, 48, "Text"],

Cell[CellGroupData[{
Cell[4323, 139, 47, 1, 50, "Input"],
Cell[4373, 142, 196, 3, 68, "Output"]
}, Open  ]],
Cell[4584, 148, 265, 9, 29, "Text"],

Cell[CellGroupData[{
Cell[4874, 161, 85, 1, 50, "Input"],
Cell[4962, 164, 255, 4, 87, "Output"]
}, Open  ]],
Cell[5232, 171, 42, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[5299, 175, 62, 1, 50, "Input"],
Cell[5364, 178, 196, 3, 68, "Output"]
}, Open  ]],
Cell[5575, 184, 50, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[5650, 188, 68, 1, 50, "Input"],
Cell[5721, 191, 308, 9, 108, "Output"]
}, Open  ]],
Cell[6044, 203, 173, 3, 48, "Text"],

Cell[CellGroupData[{
Cell[6242, 210, 118, 2, 50, "Input"],
Cell[6363, 214, 308, 9, 108, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6708, 228, 29, 0, 39, "Exercise"],
Cell[6740, 230, 84, 1, 29, "ExerciseText"],
Cell[6827, 233, 139, 2, 70, "Input"]
}, Open  ]],
Cell[6981, 238, 362, 6, 67, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7380, 249, 37, 0, 46, "Subsection"],
Cell[7420, 251, 242, 4, 48, "Text"],
Cell[7665, 257, 231, 3, 83, "Definition"],
Cell[7899, 262, 553, 8, 105, "Text"],
Cell[8455, 272, 232, 5, 28, "NumberedEquation"],

Cell[CellGroupData[{
Cell[8712, 281, 29, 0, 39, "Exercise"],
Cell[8744, 283, 134, 3, 29, "ExerciseText"],
Cell[8881, 288, 76, 1, 50, "Input"]
}, Open  ]],
Cell[8972, 292, 35, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[9032, 296, 61, 1, 50, "Input"],
Cell[9096, 299, 308, 9, 108, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9453, 314, 36, 0, 46, "Subsection"],
Cell[9492, 316, 215, 4, 48, "Text"],
Cell[9710, 322, 189, 3, 66, "Definition"],
Cell[9902, 327, 113, 3, 29, "Text"],
Cell[10018, 332, 255, 5, 28, "NumberedEquation"],
Cell[10276, 339, 239, 4, 48, "Text"],

Cell[CellGroupData[{
Cell[10540, 347, 60, 1, 50, "Input"],
Cell[10603, 350, 308, 9, 108, "Output"]
}, Open  ]],
Cell[10926, 362, 104, 3, 29, "Text"],
Cell[11033, 367, 147, 3, 51, "Definition"],
Cell[11183, 372, 289, 8, 48, "Text"],

Cell[CellGroupData[{
Cell[11497, 384, 93, 1, 50, "Input"],
Cell[11593, 387, 38, 1, 49, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[11680, 394, 41, 0, 46, "Subsection"],
Cell[11724, 396, 33, 0, 29, "Text"],
Cell[11760, 398, 156, 4, 70, "Input"],
Cell[11919, 404, 45, 0, 29, "Text"],
Cell[11967, 406, 59, 1, 50, "Input"],
Cell[12029, 409, 311, 5, 67, "Text"],
Cell[12343, 416, 76, 1, 50, "Input"],

Cell[CellGroupData[{
Cell[12444, 421, 247, 5, 90, "Input"],
Cell[12694, 428, 24972, 606, 92, 12663, 450, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37703, 1039, 29, 0, 39, "Exercise"],
Cell[37735, 1041, 142, 3, 48, "ExerciseText"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[37938, 1051, 49, 0, 36, "Section"],
Cell[37990, 1053, 777, 16, 191, "Text"],

Cell[CellGroupData[{
Cell[38792, 1073, 29, 0, 39, "Exercise"],
Cell[38824, 1075, 129, 3, 29, "ExerciseText"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[39002, 1084, 49, 0, 36, "Section"],
Cell[39054, 1086, 517, 8, 105, "Text"],
Cell[39574, 1096, 76, 1, 50, "Input"],

Cell[CellGroupData[{
Cell[39675, 1101, 270, 6, 90, "Input"],
Cell[39948, 1109, 43416, 834, 92, 12663, 450, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[83413, 1949, 52, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[83490, 1953, 41, 0, 46, "Subsection"],
Cell[83534, 1955, 306, 5, 67, "Text"],
Cell[83843, 1962, 135, 4, 25, "NumberedEquation"],
Cell[83981, 1968, 606, 11, 105, "Text"],
Cell[84590, 1981, 127, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[84742, 1987, 242, 5, 90, "Input"],
Cell[84987, 1994, 45776, 863, 120, 12663, 450, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[130812, 2863, 53, 0, 46, "Subsection"],
Cell[130868, 2865, 172, 5, 29, "Text"],
Cell[131043, 2872, 161, 3, 23, "NumberedEquation"],
Cell[131207, 2877, 104, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[131336, 2884, 271, 6, 90, "Input"],
Cell[131610, 2892, 42405, 733, 127, 8644, 312, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[174064, 3631, 44, 0, 46, "Subsection"],
Cell[174111, 3633, 34, 0, 29, "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[174194, 3639, 37, 0, 45, "Subtitle"],

Cell[CellGroupData[{
Cell[174256, 3643, 29, 0, 39, "Exercise"],
Cell[174288, 3645, 84, 1, 29, "ExerciseText"],

Cell[CellGroupData[{
Cell[174397, 3650, 136, 2, 70, "Input"],
Cell[174536, 3654, 131, 2, 68, "Output"]
}, Open  ]],
Cell[174682, 3659, 153, 4, 29, "ExerciseText"],

Cell[CellGroupData[{
Cell[174860, 3667, 47, 1, 50, "Input"],
Cell[174910, 3670, 74, 1, 49, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[175033, 3677, 29, 0, 39, "Exercise"],
Cell[175065, 3679, 133, 3, 29, "ExerciseText"],
Cell[175201, 3684, 76, 1, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[175314, 3690, 29, 0, 39, "Exercise"],
Cell[175346, 3692, 369, 8, 75, "ExerciseText"],

Cell[CellGroupData[{
Cell[175740, 3704, 268, 5, 110, "Input"],
Cell[176011, 3711, 20581, 464, 111, 8644, 312, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[196641, 4181, 31, 0, 39, "Exercise"],
Cell[196675, 4183, 448, 9, 94, "ExerciseText"],

Cell[CellGroupData[{
Cell[197148, 4196, 264, 5, 110, "Input"],
Cell[197415, 4203, 23036, 494, 146, 8644, 312, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[220512, 4704, 37, 0, 45, "Subtitle"],
Cell[220552, 4706, 35, 0, 29, "Text"]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

